/* ------------------------------------------------------------
name: "vintage_mics"
Code generated with Faust 2.22.5 (https://faust.grame.fr)
Compilation options: -lang cpp -scal -ftz 0
------------------------------------------------------------ */

#ifndef  __vintage_mics_H__
#define  __vintage_mics_H__

/************************************************************************
 ************************************************************************
    FAUST Architecture File
    Copyright (C) 2009-2016 Albert Graef <aggraef@gmail.com>
    ---------------------------------------------------------------------
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA.
 ************************************************************************
 ************************************************************************/

/* LV2 architecture for Faust synths. */

/* NOTE: This requires one of the Boost headers (boost/circular_buffer.hpp),
   so to compile Faust programs created with this architecture you need to
   have at least the Boost headers installed somewhere on your include path
   (the Boost libraries aren't needed). */

#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <list>
#include <map>
#include <set>

// generic Faust dsp and UI classes
/************************** BEGIN dsp.h **************************/
/************************************************************************
 FAUST Architecture File
 Copyright (C) 2003-2017 GRAME, Centre National de Creation Musicale
 ---------------------------------------------------------------------
 This Architecture section is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 EXCEPTION : As a special exception, you may create a larger work
 that contains this FAUST architecture section and distribute
 that work under terms of your choice, so long as this FAUST
 architecture section is not modified.
 ************************************************************************/

#ifndef __dsp__
#define __dsp__

#include <string>
#include <vector>

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

struct UI;
struct Meta;

/**
 * DSP memory manager.
 */

struct dsp_memory_manager {
    
    virtual ~dsp_memory_manager() {}
    
    virtual void* allocate(size_t size) = 0;
    virtual void destroy(void* ptr) = 0;
    
};

/**
* Signal processor definition.
*/

class dsp {

    public:

        dsp() {}
        virtual ~dsp() {}

        /* Return instance number of audio inputs */
        virtual int getNumInputs() = 0;
    
        /* Return instance number of audio outputs */
        virtual int getNumOutputs() = 0;
    
        /**
         * Trigger the ui_interface parameter with instance specific calls
         * to 'addBtton', 'addVerticalSlider'... in order to build the UI.
         *
         * @param ui_interface - the user interface builder
         */
        virtual void buildUserInterface(UI* ui_interface) = 0;
    
        /* Returns the sample rate currently used by the instance */
        virtual int getSampleRate() = 0;
    
        /**
         * Global init, calls the following methods:
         * - static class 'classInit': static tables initialization
         * - 'instanceInit': constants and instance state initialization
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void init(int sample_rate) = 0;

        /**
         * Init instance state
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void instanceInit(int sample_rate) = 0;

        /**
         * Init instance constant state
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void instanceConstants(int sample_rate) = 0;
    
        /* Init default control parameters values */
        virtual void instanceResetUserInterface() = 0;
    
        /* Init instance state (delay lines...) */
        virtual void instanceClear() = 0;
 
        /**
         * Return a clone of the instance.
         *
         * @return a copy of the instance on success, otherwise a null pointer.
         */
        virtual dsp* clone() = 0;
    
        /**
         * Trigger the Meta* parameter with instance specific calls to 'declare' (key, value) metadata.
         *
         * @param m - the Meta* meta user
         */
        virtual void metadata(Meta* m) = 0;
    
        /**
         * DSP instance computation, to be called with successive in/out audio buffers.
         *
         * @param count - the number of frames to compute
         * @param inputs - the input audio buffers as an array of non-interleaved FAUSTFLOAT samples (eiher float, double or quad)
         * @param outputs - the output audio buffers as an array of non-interleaved FAUSTFLOAT samples (eiher float, double or quad)
         *
         */
        virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) = 0;
    
        /**
         * DSP instance computation: alternative method to be used by subclasses.
         *
         * @param date_usec - the timestamp in microsec given by audio driver.
         * @param count - the number of frames to compute
         * @param inputs - the input audio buffers as an array of non-interleaved FAUSTFLOAT samples (either float, double or quad)
         * @param outputs - the output audio buffers as an array of non-interleaved FAUSTFLOAT samples (either float, double or quad)
         *
         */
        virtual void compute(double /*date_usec*/, int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { compute(count, inputs, outputs); }
       
};

/**
 * Generic DSP decorator.
 */

class decorator_dsp : public dsp {

    protected:

        dsp* fDSP;

    public:

        decorator_dsp(dsp* dsp = nullptr):fDSP(dsp) {}
        virtual ~decorator_dsp() { delete fDSP; }

        virtual int getNumInputs() { return fDSP->getNumInputs(); }
        virtual int getNumOutputs() { return fDSP->getNumOutputs(); }
        virtual void buildUserInterface(UI* ui_interface) { fDSP->buildUserInterface(ui_interface); }
        virtual int getSampleRate() { return fDSP->getSampleRate(); }
        virtual void init(int sample_rate) { fDSP->init(sample_rate); }
        virtual void instanceInit(int sample_rate) { fDSP->instanceInit(sample_rate); }
        virtual void instanceConstants(int sample_rate) { fDSP->instanceConstants(sample_rate); }
        virtual void instanceResetUserInterface() { fDSP->instanceResetUserInterface(); }
        virtual void instanceClear() { fDSP->instanceClear(); }
        virtual decorator_dsp* clone() { return new decorator_dsp(fDSP->clone()); }
        virtual void metadata(Meta* m) { fDSP->metadata(m); }
        // Beware: subclasses usually have to overload the two 'compute' methods
        virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { fDSP->compute(count, inputs, outputs); }
        virtual void compute(double date_usec, int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { fDSP->compute(date_usec, count, inputs, outputs); }
    
};

/**
 * DSP factory class.
 */

class dsp_factory {
    
    protected:
    
        // So that to force sub-classes to use deleteDSPFactory(dsp_factory* factory);
        virtual ~dsp_factory() {}
    
    public:
    
        virtual std::string getName() = 0;
        virtual std::string getSHAKey() = 0;
        virtual std::string getDSPCode() = 0;
        virtual std::string getCompileOptions() = 0;
        virtual std::vector<std::string> getLibraryList() = 0;
        virtual std::vector<std::string> getIncludePathnames() = 0;
    
        virtual dsp* createDSPInstance() = 0;
    
        virtual void setMemoryManager(dsp_memory_manager* manager) = 0;
        virtual dsp_memory_manager* getMemoryManager() = 0;
    
};

/**
 * On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
 * flags to avoid costly denormals.
 */

#ifdef __SSE__
    #include <xmmintrin.h>
    #ifdef __SSE2__
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
    #else
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
    #endif
#else
    #define AVOIDDENORMALS
#endif

#endif
/**************************  END  dsp.h **************************/
/************************** BEGIN UI.h **************************/
/************************************************************************
 FAUST Architecture File
 Copyright (C) 2003-2020 GRAME, Centre National de Creation Musicale
 ---------------------------------------------------------------------
 This Architecture section is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 EXCEPTION : As a special exception, you may create a larger work
 that contains this FAUST architecture section and distribute
 that work under terms of your choice, so long as this FAUST
 architecture section is not modified.
 ************************************************************************/

#ifndef __UI_H__
#define __UI_H__

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

/*******************************************************************************
 * UI : Faust DSP User Interface
 * User Interface as expected by the buildUserInterface() method of a DSP.
 * This abstract class contains only the method that the Faust compiler can
 * generate to describe a DSP user interface.
 ******************************************************************************/

struct Soundfile;

template <typename REAL>
struct UIReal
{
    UIReal() {}
    virtual ~UIReal() {}
    
    // -- widget's layouts
    
    virtual void openTabBox(const char* label) = 0;
    virtual void openHorizontalBox(const char* label) = 0;
    virtual void openVerticalBox(const char* label) = 0;
    virtual void closeBox() = 0;
    
    // -- active widgets
    
    virtual void addButton(const char* label, REAL* zone) = 0;
    virtual void addCheckButton(const char* label, REAL* zone) = 0;
    virtual void addVerticalSlider(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    virtual void addHorizontalSlider(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    virtual void addNumEntry(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    
    // -- passive widgets
    
    virtual void addHorizontalBargraph(const char* label, REAL* zone, REAL min, REAL max) = 0;
    virtual void addVerticalBargraph(const char* label, REAL* zone, REAL min, REAL max) = 0;
    
    // -- soundfiles
    
    virtual void addSoundfile(const char* label, const char* filename, Soundfile** sf_zone) = 0;
    
    // -- metadata declarations
    
    virtual void declare(REAL* zone, const char* key, const char* val) {}
};

struct UI : public UIReal<FAUSTFLOAT>
{
    UI() {}
    virtual ~UI() {}
};

#endif
/**************************  END  UI.h **************************/

using namespace std;

typedef pair<const char*,const char*> strpair;

struct Meta : std::map<const char*, const char*>
{
  void declare(const char *key, const char *value)
  {
    (*this)[key] = value;
  }
  const char* get(const char *key, const char *def)
  {
    if (this->find(key) != this->end())
      return (*this)[key];
    else
      return def;
  }
};

/******************************************************************************
*******************************************************************************

		       VECTOR INTRINSICS

*******************************************************************************
*******************************************************************************/


/***************************************************************************
   LV2 UI interface
 ***************************************************************************/

enum ui_elem_type_t {
  UI_BUTTON, UI_CHECK_BUTTON,
  UI_V_SLIDER, UI_H_SLIDER, UI_NUM_ENTRY,
  UI_V_BARGRAPH, UI_H_BARGRAPH,
  UI_END_GROUP, UI_V_GROUP, UI_H_GROUP, UI_T_GROUP
};

struct ui_elem_t {
  ui_elem_type_t type;
  const char *label;
  int port;
  float *zone;
  void *ref;
  float init, min, max, step;
};

class LV2UI : public UI
{
public:
  bool is_instr;
  int nelems, nports;
  ui_elem_t *elems;
  map< int, list<strpair> > metadata;

  LV2UI(int maxvoices = 0);
  virtual ~LV2UI();

protected:
  void add_elem(ui_elem_type_t type, const char *label = NULL);
  void add_elem(ui_elem_type_t type, const char *label, float *zone);
  void add_elem(ui_elem_type_t type, const char *label, float *zone,
		float init, float min, float max, float step);
  void add_elem(ui_elem_type_t type, const char *label, float *zone,
		float min, float max);

  bool have_freq, have_gain, have_gate;
  bool is_voice_ctrl(const char *label);

public:
  virtual void addButton(const char* label, float* zone);
  virtual void addCheckButton(const char* label, float* zone);
  virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step);
  virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step);
  virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step);

  virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max);
  virtual void addVerticalBargraph(const char* label, float* zone, float min, float max);
    
  virtual void addSoundfile(const char* label, const char* filename, Soundfile** sf_zone) {}

  virtual void openTabBox(const char* label);
  virtual void openHorizontalBox(const char* label);
  virtual void openVerticalBox(const char* label);
  virtual void closeBox();

  virtual void run();

  virtual void declare(float* zone, const char* key, const char* value);
};

LV2UI::LV2UI(int maxvoices)
{
  is_instr = maxvoices>0;
  have_freq = have_gain = have_gate = false;
  nelems = nports = 0;
  elems = NULL;
}

LV2UI::~LV2UI()
{
  if (elems) free(elems);
}

void LV2UI::declare(float* zone, const char* key, const char* value)
{
  map< int, list<strpair> >::iterator it = metadata.find(nelems);
  if (it != metadata.end())
    it->second.push_back(strpair(key, value));
  else
    metadata[nelems] = list<strpair>(1, strpair(key, value));
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = -1;
  elems[nelems].zone = NULL;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = 0.0;
  elems[nelems].max = 0.0;
  elems[nelems].step = 0.0;
  nelems++;
}

#define portno(label) (is_voice_ctrl(label)?-1:nports++)

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = 0.0;
  elems[nelems].max = 0.0;
  elems[nelems].step = 0.0;
  nelems++;
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone,
			     float init, float min, float max, float step)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = init;
  elems[nelems].min = min;
  elems[nelems].max = max;
  elems[nelems].step = step;
  nelems++;
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone,
			     float min, float max)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = min;
  elems[nelems].max = max;
  elems[nelems].step = 0.0;
  nelems++;
}

inline bool LV2UI::is_voice_ctrl(const char *label)
{
  if (!is_instr)
    return false;
  else if (!have_freq && !strcmp(label, "freq"))
    return (have_freq = true);
  else if (!have_gain && !strcmp(label, "gain"))
    return (have_gain = true);
  else if (!have_gate && !strcmp(label, "gate"))
    return (have_gate = true);
  else
    return false;
}

void LV2UI::addButton(const char* label, float* zone)
{ add_elem(UI_BUTTON, label, zone); }
void LV2UI::addCheckButton(const char* label, float* zone)
{ add_elem(UI_CHECK_BUTTON, label, zone); }
void LV2UI::addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_V_SLIDER, label, zone, init, min, max, step); }
void LV2UI::addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_H_SLIDER, label, zone, init, min, max, step); }
void LV2UI::addNumEntry(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_NUM_ENTRY, label, zone, init, min, max, step); }

void LV2UI::addHorizontalBargraph(const char* label, float* zone, float min, float max)
{ add_elem(UI_H_BARGRAPH, label, zone, min, max); }
void LV2UI::addVerticalBargraph(const char* label, float* zone, float min, float max)
{ add_elem(UI_V_BARGRAPH, label, zone, min, max); }

void LV2UI::openTabBox(const char* label)
{ add_elem(UI_T_GROUP, label); }
void LV2UI::openHorizontalBox(const char* label)
{ add_elem(UI_H_GROUP, label); }
void LV2UI::openVerticalBox(const char* label)
{ add_elem(UI_V_GROUP, label); }
void LV2UI::closeBox()
{ add_elem(UI_END_GROUP); }

void LV2UI::run() {}

//----------------------------------------------------------------------------
//  FAUST generated signal processor
//----------------------------------------------------------------------------

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif 

#include <algorithm>
#include <cmath>


#ifndef FAUSTCLASS 
#define FAUSTCLASS vintage_mics
#endif

#ifdef __APPLE__ 
#define exp10f __exp10f
#define exp10 __exp10
#endif

class vintage_mics : public dsp {
	
 private:
	
	FAUSTFLOAT fEntry0;
	int IOTA;
	float fVec0[512];
	float fVec1[512];
	float fVec2[512];
	float fVec3[512];
	float fVec4[512];
	float fVec5[512];
	float fVec6[512];
	float fVec7[512];
	float fVec8[512];
	float fVec9[512];
	float fVec10[512];
	float fVec11[512];
	float fVec12[512];
	float fVec13[512];
	float fVec14[512];
	float fVec15[512];
	float fVec16[512];
	float fVec17[512];
	float fVec18[512];
	float fVec19[512];
	float fVec20[512];
	float fVec21[512];
	float fVec22[512];
	float fVec23[512];
	float fVec24[512];
	float fVec25[512];
	float fVec26[512];
	float fVec27[512];
	float fVec28[512];
	float fVec29[512];
	float fVec30[512];
	float fVec31[512];
	float fVec32[512];
	float fVec33[512];
	float fVec34[512];
	float fVec35[512];
	float fVec36[512];
	float fVec37[512];
	float fVec38[512];
	float fVec39[512];
	float fVec40[512];
	float fVec41[512];
	float fVec42[512];
	float fVec43[512];
	float fVec44[512];
	float fVec45[512];
	float fVec46[512];
	float fVec47[512];
	float fVec48[512];
	float fVec49[512];
	float fVec50[512];
	float fVec51[512];
	float fVec52[512];
	float fVec53[512];
	float fVec54[512];
	float fVec55[512];
	float fVec56[512];
	float fVec57[512];
	float fVec58[512];
	float fVec59[512];
	float fVec60[512];
	float fVec61[512];
	float fVec62[512];
	float fVec63[512];
	float fVec64[512];
	int fSampleRate;
	
 public:
	
	void metadata(Meta* m) { 
		m->declare("basics.lib/name", "Faust Basic Element Library");
		m->declare("basics.lib/version", "0.1");
		m->declare("filename", "vintage_mics.dsp");
		m->declare("filters.lib/fir:author", "Julius O. Smith III");
		m->declare("filters.lib/fir:copyright", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m->declare("filters.lib/fir:license", "MIT-style STK-4.3 license");
		m->declare("filters.lib/lowpass0_highpass1", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m->declare("filters.lib/name", "Faust Filters Library");
		m->declare("name", "vintage_mics");
	}

	virtual int getNumInputs() {
		return 1;
	}
	virtual int getNumOutputs() {
		return 1;
	}
	virtual int getInputRate(int channel) {
		int rate;
		switch ((channel)) {
			case 0: {
				rate = 1;
				break;
			}
			default: {
				rate = -1;
				break;
			}
		}
		return rate;
	}
	virtual int getOutputRate(int channel) {
		int rate;
		switch ((channel)) {
			case 0: {
				rate = 1;
				break;
			}
			default: {
				rate = -1;
				break;
			}
		}
		return rate;
	}
	
	static void classInit(int sample_rate) {
	}
	
	virtual void instanceConstants(int sample_rate) {
		fSampleRate = sample_rate;
	}
	
	virtual void instanceResetUserInterface() {
		fEntry0 = FAUSTFLOAT(0.0f);
	}
	
	virtual void instanceClear() {
		IOTA = 0;
		for (int l0 = 0; (l0 < 512); l0 = (l0 + 1)) {
			fVec0[l0] = 0.0f;
		}
		for (int l1 = 0; (l1 < 512); l1 = (l1 + 1)) {
			fVec1[l1] = 0.0f;
		}
		for (int l2 = 0; (l2 < 512); l2 = (l2 + 1)) {
			fVec2[l2] = 0.0f;
		}
		for (int l3 = 0; (l3 < 512); l3 = (l3 + 1)) {
			fVec3[l3] = 0.0f;
		}
		for (int l4 = 0; (l4 < 512); l4 = (l4 + 1)) {
			fVec4[l4] = 0.0f;
		}
		for (int l5 = 0; (l5 < 512); l5 = (l5 + 1)) {
			fVec5[l5] = 0.0f;
		}
		for (int l6 = 0; (l6 < 512); l6 = (l6 + 1)) {
			fVec6[l6] = 0.0f;
		}
		for (int l7 = 0; (l7 < 512); l7 = (l7 + 1)) {
			fVec7[l7] = 0.0f;
		}
		for (int l8 = 0; (l8 < 512); l8 = (l8 + 1)) {
			fVec8[l8] = 0.0f;
		}
		for (int l9 = 0; (l9 < 512); l9 = (l9 + 1)) {
			fVec9[l9] = 0.0f;
		}
		for (int l10 = 0; (l10 < 512); l10 = (l10 + 1)) {
			fVec10[l10] = 0.0f;
		}
		for (int l11 = 0; (l11 < 512); l11 = (l11 + 1)) {
			fVec11[l11] = 0.0f;
		}
		for (int l12 = 0; (l12 < 512); l12 = (l12 + 1)) {
			fVec12[l12] = 0.0f;
		}
		for (int l13 = 0; (l13 < 512); l13 = (l13 + 1)) {
			fVec13[l13] = 0.0f;
		}
		for (int l14 = 0; (l14 < 512); l14 = (l14 + 1)) {
			fVec14[l14] = 0.0f;
		}
		for (int l15 = 0; (l15 < 512); l15 = (l15 + 1)) {
			fVec15[l15] = 0.0f;
		}
		for (int l16 = 0; (l16 < 512); l16 = (l16 + 1)) {
			fVec16[l16] = 0.0f;
		}
		for (int l17 = 0; (l17 < 512); l17 = (l17 + 1)) {
			fVec17[l17] = 0.0f;
		}
		for (int l18 = 0; (l18 < 512); l18 = (l18 + 1)) {
			fVec18[l18] = 0.0f;
		}
		for (int l19 = 0; (l19 < 512); l19 = (l19 + 1)) {
			fVec19[l19] = 0.0f;
		}
		for (int l20 = 0; (l20 < 512); l20 = (l20 + 1)) {
			fVec20[l20] = 0.0f;
		}
		for (int l21 = 0; (l21 < 512); l21 = (l21 + 1)) {
			fVec21[l21] = 0.0f;
		}
		for (int l22 = 0; (l22 < 512); l22 = (l22 + 1)) {
			fVec22[l22] = 0.0f;
		}
		for (int l23 = 0; (l23 < 512); l23 = (l23 + 1)) {
			fVec23[l23] = 0.0f;
		}
		for (int l24 = 0; (l24 < 512); l24 = (l24 + 1)) {
			fVec24[l24] = 0.0f;
		}
		for (int l25 = 0; (l25 < 512); l25 = (l25 + 1)) {
			fVec25[l25] = 0.0f;
		}
		for (int l26 = 0; (l26 < 512); l26 = (l26 + 1)) {
			fVec26[l26] = 0.0f;
		}
		for (int l27 = 0; (l27 < 512); l27 = (l27 + 1)) {
			fVec27[l27] = 0.0f;
		}
		for (int l28 = 0; (l28 < 512); l28 = (l28 + 1)) {
			fVec28[l28] = 0.0f;
		}
		for (int l29 = 0; (l29 < 512); l29 = (l29 + 1)) {
			fVec29[l29] = 0.0f;
		}
		for (int l30 = 0; (l30 < 512); l30 = (l30 + 1)) {
			fVec30[l30] = 0.0f;
		}
		for (int l31 = 0; (l31 < 512); l31 = (l31 + 1)) {
			fVec31[l31] = 0.0f;
		}
		for (int l32 = 0; (l32 < 512); l32 = (l32 + 1)) {
			fVec32[l32] = 0.0f;
		}
		for (int l33 = 0; (l33 < 512); l33 = (l33 + 1)) {
			fVec33[l33] = 0.0f;
		}
		for (int l34 = 0; (l34 < 512); l34 = (l34 + 1)) {
			fVec34[l34] = 0.0f;
		}
		for (int l35 = 0; (l35 < 512); l35 = (l35 + 1)) {
			fVec35[l35] = 0.0f;
		}
		for (int l36 = 0; (l36 < 512); l36 = (l36 + 1)) {
			fVec36[l36] = 0.0f;
		}
		for (int l37 = 0; (l37 < 512); l37 = (l37 + 1)) {
			fVec37[l37] = 0.0f;
		}
		for (int l38 = 0; (l38 < 512); l38 = (l38 + 1)) {
			fVec38[l38] = 0.0f;
		}
		for (int l39 = 0; (l39 < 512); l39 = (l39 + 1)) {
			fVec39[l39] = 0.0f;
		}
		for (int l40 = 0; (l40 < 512); l40 = (l40 + 1)) {
			fVec40[l40] = 0.0f;
		}
		for (int l41 = 0; (l41 < 512); l41 = (l41 + 1)) {
			fVec41[l41] = 0.0f;
		}
		for (int l42 = 0; (l42 < 512); l42 = (l42 + 1)) {
			fVec42[l42] = 0.0f;
		}
		for (int l43 = 0; (l43 < 512); l43 = (l43 + 1)) {
			fVec43[l43] = 0.0f;
		}
		for (int l44 = 0; (l44 < 512); l44 = (l44 + 1)) {
			fVec44[l44] = 0.0f;
		}
		for (int l45 = 0; (l45 < 512); l45 = (l45 + 1)) {
			fVec45[l45] = 0.0f;
		}
		for (int l46 = 0; (l46 < 512); l46 = (l46 + 1)) {
			fVec46[l46] = 0.0f;
		}
		for (int l47 = 0; (l47 < 512); l47 = (l47 + 1)) {
			fVec47[l47] = 0.0f;
		}
		for (int l48 = 0; (l48 < 512); l48 = (l48 + 1)) {
			fVec48[l48] = 0.0f;
		}
		for (int l49 = 0; (l49 < 512); l49 = (l49 + 1)) {
			fVec49[l49] = 0.0f;
		}
		for (int l50 = 0; (l50 < 512); l50 = (l50 + 1)) {
			fVec50[l50] = 0.0f;
		}
		for (int l51 = 0; (l51 < 512); l51 = (l51 + 1)) {
			fVec51[l51] = 0.0f;
		}
		for (int l52 = 0; (l52 < 512); l52 = (l52 + 1)) {
			fVec52[l52] = 0.0f;
		}
		for (int l53 = 0; (l53 < 512); l53 = (l53 + 1)) {
			fVec53[l53] = 0.0f;
		}
		for (int l54 = 0; (l54 < 512); l54 = (l54 + 1)) {
			fVec54[l54] = 0.0f;
		}
		for (int l55 = 0; (l55 < 512); l55 = (l55 + 1)) {
			fVec55[l55] = 0.0f;
		}
		for (int l56 = 0; (l56 < 512); l56 = (l56 + 1)) {
			fVec56[l56] = 0.0f;
		}
		for (int l57 = 0; (l57 < 512); l57 = (l57 + 1)) {
			fVec57[l57] = 0.0f;
		}
		for (int l58 = 0; (l58 < 512); l58 = (l58 + 1)) {
			fVec58[l58] = 0.0f;
		}
		for (int l59 = 0; (l59 < 512); l59 = (l59 + 1)) {
			fVec59[l59] = 0.0f;
		}
		for (int l60 = 0; (l60 < 512); l60 = (l60 + 1)) {
			fVec60[l60] = 0.0f;
		}
		for (int l61 = 0; (l61 < 512); l61 = (l61 + 1)) {
			fVec61[l61] = 0.0f;
		}
		for (int l62 = 0; (l62 < 512); l62 = (l62 + 1)) {
			fVec62[l62] = 0.0f;
		}
		for (int l63 = 0; (l63 < 512); l63 = (l63 + 1)) {
			fVec63[l63] = 0.0f;
		}
		for (int l64 = 0; (l64 < 512); l64 = (l64 + 1)) {
			fVec64[l64] = 0.0f;
		}
	}
	
	virtual void init(int sample_rate) {
		classInit(sample_rate);
		instanceInit(sample_rate);
	}
	virtual void instanceInit(int sample_rate) {
		instanceConstants(sample_rate);
		instanceResetUserInterface();
		instanceClear();
	}
	
	virtual vintage_mics* clone() {
		return new vintage_mics();
	}
	
	virtual int getSampleRate() {
		return fSampleRate;
	}
	
	virtual void buildUserInterface(UI* ui_interface) {
		ui_interface->openVerticalBox("vintage_mics");
		ui_interface->declare(&fEntry0, "name", "Impulse Response");
		ui_interface->declare(&fEntry0, "style", "menu{'None':0;'AKGD12':1;'AKG FaultyD12':2;'Altec 639':3;'Altec 670A':4;'Altec 670B':5;'American R331':6;'Amperite RA':7;'Astatic77':8;'BBCmarconi B':9;'BeO BM2':10;'BeO BM6':11;'Beomic 1000':12;'Beyer M260':13;'Beyer M360':14;'BeyerM500Stock':15;'Coles 4038':16;'Doremi 351':17;'EMI ribbon':18;'EV RE20 Flat':19;'EV RE20 HPF':20;'FilmIndustries M8':21;'FosterDynamicDF1':22;'Framez':23;'GaumontKalee':24;'GEC 2373 Ribbon':25;'GEC bigdynamic':26;'Grampian GR2':27;'Lomo52A5M':28;'Meazzi':29;'Melodium 42B 1':30;'Melodium Model12':31;'MelodiumRM6':32;'OktavaMK18 Overload':33;'OktavaMK18Silver':34;'OktavaML16':35;'Oktava ML19':36;'RCA 44BX 1':37;'RCA 44BX 2':38;'RCA 74B':39;'RCA 77DX 1':40;'RCA 77DX 2':41;'RCA KU3a 1':42;'RCAKU3a':43;'RCA PB90':44;'RCA varacoustic fig8':45;'ResloCR600':46;'ResloDynamic':47;'Reslo RB250':48;'Reslo RB RedLabel':49;'Reslo RV':50;'Reslo SR1':51;'ResloURA':52;'Reslo VMC2':53;'Shure315 flat':54;'Shure315 HPF':55;'Shure510C':56;'Sony C37Fet':57;'STC4033 Cardioid':58;'STC4033 Pressure':59;'STC4033 Ribbon':60;'Telefunken M201':61;'Toshiba TypeG':62;'Toshiba TypeH BK5':63;'Toshiba TypeK flat':64;'Toshiba TypeK HPF':65}");
		ui_interface->addNumEntry("ir", &fEntry0, 0.0f, 0.0f, 65.0f, 1.0f);
		ui_interface->closeBox();
	}
	
	virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) {
		FAUSTFLOAT* input0 = inputs[0];
		FAUSTFLOAT* output0 = outputs[0];
		float fSlow0 = float(fEntry0);
		int iSlow1 = (fSlow0 >= 33.0f);
		int iSlow2 = (fSlow0 >= 17.0f);
		int iSlow3 = (fSlow0 >= 9.0f);
		int iSlow4 = (fSlow0 >= 5.0f);
		int iSlow5 = (fSlow0 >= 3.0f);
		int iSlow6 = (fSlow0 >= 2.0f);
		int iSlow7 = (fSlow0 >= 1.0f);
		float fSlow8 = float((fSlow0 == 0.0f));
		float fSlow9 = float((fSlow0 == 1.0f));
		float fSlow10 = (0.0541398376f * fSlow9);
		float fSlow11 = float((fSlow0 == 2.0f));
		float fSlow12 = (0.0274666585f * fSlow11);
		int iSlow13 = (fSlow0 >= 4.0f);
		float fSlow14 = float((fSlow0 == 3.0f));
		float fSlow15 = float((fSlow0 == 4.0f));
		int iSlow16 = (fSlow0 >= 7.0f);
		int iSlow17 = (fSlow0 >= 6.0f);
		float fSlow18 = float((fSlow0 == 5.0f));
		float fSlow19 = float((fSlow0 == 6.0f));
		int iSlow20 = (fSlow0 >= 8.0f);
		float fSlow21 = float((fSlow0 == 7.0f));
		float fSlow22 = float((fSlow0 == 8.0f));
		float fSlow23 = (0.022705771f * fSlow22);
		int iSlow24 = (fSlow0 >= 13.0f);
		int iSlow25 = (fSlow0 >= 11.0f);
		int iSlow26 = (fSlow0 >= 10.0f);
		float fSlow27 = float((fSlow0 == 9.0f));
		float fSlow28 = float((fSlow0 == 10.0f));
		int iSlow29 = (fSlow0 >= 12.0f);
		float fSlow30 = float((fSlow0 == 11.0f));
		float fSlow31 = float((fSlow0 == 12.0f));
		int iSlow32 = (fSlow0 >= 15.0f);
		int iSlow33 = (fSlow0 >= 14.0f);
		float fSlow34 = float((fSlow0 == 13.0f));
		float fSlow35 = float((fSlow0 == 14.0f));
		int iSlow36 = (fSlow0 >= 16.0f);
		float fSlow37 = float((fSlow0 == 15.0f));
		float fSlow38 = (0.0216376241f * fSlow37);
		float fSlow39 = float((fSlow0 == 16.0f));
		int iSlow40 = (fSlow0 >= 25.0f);
		int iSlow41 = (fSlow0 >= 21.0f);
		int iSlow42 = (fSlow0 >= 19.0f);
		int iSlow43 = (fSlow0 >= 18.0f);
		float fSlow44 = float((fSlow0 == 17.0f));
		float fSlow45 = float((fSlow0 == 18.0f));
		int iSlow46 = (fSlow0 >= 20.0f);
		float fSlow47 = float((fSlow0 == 19.0f));
		float fSlow48 = float((fSlow0 == 20.0f));
		int iSlow49 = (fSlow0 >= 23.0f);
		int iSlow50 = (fSlow0 >= 22.0f);
		float fSlow51 = float((fSlow0 == 21.0f));
		float fSlow52 = float((fSlow0 == 22.0f));
		float fSlow53 = (0.0166631062f * fSlow52);
		int iSlow54 = (fSlow0 >= 24.0f);
		float fSlow55 = float((fSlow0 == 23.0f));
		float fSlow56 = (0.0389416181f * fSlow55);
		float fSlow57 = float((fSlow0 == 24.0f));
		float fSlow58 = (0.0495010242f * fSlow57);
		int iSlow59 = (fSlow0 >= 29.0f);
		int iSlow60 = (fSlow0 >= 27.0f);
		int iSlow61 = (fSlow0 >= 26.0f);
		float fSlow62 = float((fSlow0 == 25.0f));
		float fSlow63 = float((fSlow0 == 26.0f));
		int iSlow64 = (fSlow0 >= 28.0f);
		float fSlow65 = float((fSlow0 == 27.0f));
		float fSlow66 = float((fSlow0 == 28.0f));
		float fSlow67 = (0.0278939176f * fSlow66);
		int iSlow68 = (fSlow0 >= 31.0f);
		int iSlow69 = (fSlow0 >= 30.0f);
		float fSlow70 = float((fSlow0 == 29.0f));
		float fSlow71 = (0.022705771f * fSlow70);
		float fSlow72 = float((fSlow0 == 30.0f));
		int iSlow73 = (fSlow0 >= 32.0f);
		float fSlow74 = float((fSlow0 == 31.0f));
		float fSlow75 = float((fSlow0 == 32.0f));
		float fSlow76 = (0.0577715375f * fSlow75);
		int iSlow77 = (fSlow0 >= 50.0f);
		int iSlow78 = (fSlow0 >= 42.0f);
		int iSlow79 = (fSlow0 >= 38.0f);
		int iSlow80 = (fSlow0 >= 36.0f);
		int iSlow81 = (fSlow0 >= 35.0f);
		int iSlow82 = (fSlow0 >= 34.0f);
		float fSlow83 = float((fSlow0 == 33.0f));
		float fSlow84 = (0.0181890316f * fSlow83);
		float fSlow85 = float((fSlow0 == 34.0f));
		float fSlow86 = (0.0526749492f * fSlow85);
		float fSlow87 = float((fSlow0 == 35.0f));
		int iSlow88 = (fSlow0 >= 37.0f);
		float fSlow89 = float((fSlow0 == 36.0f));
		float fSlow90 = float((fSlow0 == 37.0f));
		int iSlow91 = (fSlow0 >= 40.0f);
		int iSlow92 = (fSlow0 >= 39.0f);
		float fSlow93 = float((fSlow0 == 38.0f));
		float fSlow94 = float((fSlow0 == 39.0f));
		int iSlow95 = (fSlow0 >= 41.0f);
		float fSlow96 = float((fSlow0 == 40.0f));
		float fSlow97 = float((fSlow0 == 41.0f));
		int iSlow98 = (fSlow0 >= 46.0f);
		int iSlow99 = (fSlow0 >= 44.0f);
		int iSlow100 = (fSlow0 >= 43.0f);
		float fSlow101 = float((fSlow0 == 42.0f));
		float fSlow102 = float((fSlow0 == 43.0f));
		int iSlow103 = (fSlow0 >= 45.0f);
		float fSlow104 = float((fSlow0 == 44.0f));
		float fSlow105 = float((fSlow0 == 45.0f));
		int iSlow106 = (fSlow0 >= 48.0f);
		int iSlow107 = (fSlow0 >= 47.0f);
		float fSlow108 = float((fSlow0 == 46.0f));
		float fSlow109 = (0.0194402914f * fSlow108);
		float fSlow110 = float((fSlow0 == 47.0f));
		float fSlow111 = (0.042542804f * fSlow110);
		int iSlow112 = (fSlow0 >= 49.0f);
		float fSlow113 = float((fSlow0 == 48.0f));
		float fSlow114 = float((fSlow0 == 49.0f));
		int iSlow115 = (fSlow0 >= 58.0f);
		int iSlow116 = (fSlow0 >= 54.0f);
		int iSlow117 = (fSlow0 >= 52.0f);
		int iSlow118 = (fSlow0 >= 51.0f);
		float fSlow119 = float((fSlow0 == 50.0f));
		float fSlow120 = float((fSlow0 == 51.0f));
		int iSlow121 = (fSlow0 >= 53.0f);
		float fSlow122 = float((fSlow0 == 52.0f));
		float fSlow123 = (0.0283822138f * fSlow122);
		float fSlow124 = float((fSlow0 == 53.0f));
		int iSlow125 = (fSlow0 >= 56.0f);
		int iSlow126 = (fSlow0 >= 55.0f);
		float fSlow127 = float((fSlow0 == 54.0f));
		float fSlow128 = float((fSlow0 == 55.0f));
		int iSlow129 = (fSlow0 >= 57.0f);
		float fSlow130 = float((fSlow0 == 56.0f));
		float fSlow131 = (0.0349436924f * fSlow130);
		float fSlow132 = float((fSlow0 == 57.0f));
		int iSlow133 = (fSlow0 >= 62.0f);
		int iSlow134 = (fSlow0 >= 60.0f);
		int iSlow135 = (fSlow0 >= 59.0f);
		float fSlow136 = float((fSlow0 == 58.0f));
		float fSlow137 = (0.0618915372f * fSlow136);
		float fSlow138 = float((fSlow0 == 59.0f));
		float fSlow139 = (0.0617999807f * fSlow138);
		int iSlow140 = (fSlow0 >= 61.0f);
		float fSlow141 = float((fSlow0 == 60.0f));
		float fSlow142 = (0.0223700684f * fSlow141);
		float fSlow143 = float((fSlow0 == 61.0f));
		float fSlow144 = (0.00350962859f * fSlow143);
		int iSlow145 = (fSlow0 >= 64.0f);
		int iSlow146 = (fSlow0 >= 63.0f);
		float fSlow147 = float((fSlow0 == 62.0f));
		float fSlow148 = float((fSlow0 == 63.0f));
		int iSlow149 = (fSlow0 >= 65.0f);
		float fSlow150 = float((fSlow0 == 64.0f));
		float fSlow151 = float((fSlow0 == 65.0f));
		for (int i = 0; (i < count); i = (i + 1)) {
			float fTemp0 = float(input0[i]);
			float fTemp1 = (fSlow9 * fTemp0);
			fVec0[(IOTA & 511)] = fTemp1;
			float fTemp2 = (fSlow11 * fTemp0);
			fVec1[(IOTA & 511)] = fTemp2;
			float fTemp3 = (fSlow14 * fTemp0);
			fVec2[(IOTA & 511)] = fTemp3;
			float fTemp4 = (fSlow15 * fTemp0);
			fVec3[(IOTA & 511)] = fTemp4;
			float fTemp5 = (fSlow18 * fTemp0);
			fVec4[(IOTA & 511)] = fTemp5;
			float fTemp6 = (fSlow19 * fTemp0);
			fVec5[(IOTA & 511)] = fTemp6;
			float fTemp7 = (fSlow21 * fTemp0);
			fVec6[(IOTA & 511)] = fTemp7;
			float fTemp8 = (fSlow22 * fTemp0);
			fVec7[(IOTA & 511)] = fTemp8;
			float fTemp9 = (fSlow27 * fTemp0);
			fVec8[(IOTA & 511)] = fTemp9;
			float fTemp10 = (fSlow28 * fTemp0);
			fVec9[(IOTA & 511)] = fTemp10;
			float fTemp11 = (fSlow30 * fTemp0);
			fVec10[(IOTA & 511)] = fTemp11;
			float fTemp12 = (fSlow31 * fTemp0);
			fVec11[(IOTA & 511)] = fTemp12;
			float fTemp13 = (fSlow34 * fTemp0);
			fVec12[(IOTA & 511)] = fTemp13;
			float fTemp14 = (fSlow35 * fTemp0);
			fVec13[(IOTA & 511)] = fTemp14;
			float fTemp15 = (fSlow37 * fTemp0);
			fVec14[(IOTA & 511)] = fTemp15;
			float fTemp16 = (fSlow39 * fTemp0);
			fVec15[(IOTA & 511)] = fTemp16;
			float fTemp17 = (fSlow44 * fTemp0);
			fVec16[(IOTA & 511)] = fTemp17;
			float fTemp18 = (fSlow45 * fTemp0);
			fVec17[(IOTA & 511)] = fTemp18;
			float fTemp19 = (fSlow47 * fTemp0);
			fVec18[(IOTA & 511)] = fTemp19;
			float fTemp20 = (fSlow48 * fTemp0);
			fVec19[(IOTA & 511)] = fTemp20;
			float fTemp21 = (fSlow51 * fTemp0);
			fVec20[(IOTA & 511)] = fTemp21;
			float fTemp22 = (fSlow52 * fTemp0);
			fVec21[(IOTA & 511)] = fTemp22;
			float fTemp23 = (fSlow55 * fTemp0);
			fVec22[(IOTA & 511)] = fTemp23;
			float fTemp24 = (fSlow57 * fTemp0);
			fVec23[(IOTA & 511)] = fTemp24;
			float fTemp25 = (fSlow62 * fTemp0);
			fVec24[(IOTA & 511)] = fTemp25;
			float fTemp26 = (fSlow63 * fTemp0);
			fVec25[(IOTA & 511)] = fTemp26;
			float fTemp27 = (fSlow65 * fTemp0);
			fVec26[(IOTA & 511)] = fTemp27;
			float fTemp28 = (fSlow66 * fTemp0);
			fVec27[(IOTA & 511)] = fTemp28;
			float fTemp29 = (fSlow70 * fTemp0);
			fVec28[(IOTA & 511)] = fTemp29;
			float fTemp30 = (fSlow72 * fTemp0);
			fVec29[(IOTA & 511)] = fTemp30;
			float fTemp31 = (fSlow74 * fTemp0);
			fVec30[(IOTA & 511)] = fTemp31;
			float fTemp32 = (fSlow75 * fTemp0);
			fVec31[(IOTA & 511)] = fTemp32;
			float fTemp33 = (fSlow83 * fTemp0);
			fVec32[(IOTA & 511)] = fTemp33;
			float fTemp34 = (fSlow85 * fTemp0);
			fVec33[(IOTA & 511)] = fTemp34;
			float fTemp35 = (fSlow87 * fTemp0);
			fVec34[(IOTA & 511)] = fTemp35;
			float fTemp36 = (fSlow89 * fTemp0);
			fVec35[(IOTA & 511)] = fTemp36;
			float fTemp37 = (fSlow90 * fTemp0);
			fVec36[(IOTA & 511)] = fTemp37;
			float fTemp38 = (fSlow93 * fTemp0);
			fVec37[(IOTA & 511)] = fTemp38;
			float fTemp39 = (fSlow94 * fTemp0);
			fVec38[(IOTA & 511)] = fTemp39;
			float fTemp40 = (fSlow96 * fTemp0);
			fVec39[(IOTA & 511)] = fTemp40;
			float fTemp41 = (fSlow97 * fTemp0);
			fVec40[(IOTA & 511)] = fTemp41;
			float fTemp42 = (fSlow101 * fTemp0);
			fVec41[(IOTA & 511)] = fTemp42;
			float fTemp43 = (fSlow102 * fTemp0);
			fVec42[(IOTA & 511)] = fTemp43;
			float fTemp44 = (fSlow104 * fTemp0);
			fVec43[(IOTA & 511)] = fTemp44;
			float fTemp45 = (fSlow105 * fTemp0);
			fVec44[(IOTA & 511)] = fTemp45;
			float fTemp46 = (fSlow108 * fTemp0);
			fVec45[(IOTA & 511)] = fTemp46;
			float fTemp47 = (fSlow110 * fTemp0);
			fVec46[(IOTA & 511)] = fTemp47;
			float fTemp48 = (fSlow113 * fTemp0);
			fVec47[(IOTA & 511)] = fTemp48;
			float fTemp49 = (fSlow114 * fTemp0);
			fVec48[(IOTA & 511)] = fTemp49;
			float fTemp50 = (fSlow119 * fTemp0);
			fVec49[(IOTA & 511)] = fTemp50;
			float fTemp51 = (fSlow120 * fTemp0);
			fVec50[(IOTA & 511)] = fTemp51;
			float fTemp52 = (fSlow122 * fTemp0);
			fVec51[(IOTA & 511)] = fTemp52;
			float fTemp53 = (fSlow124 * fTemp0);
			fVec52[(IOTA & 511)] = fTemp53;
			float fTemp54 = (fSlow127 * fTemp0);
			fVec53[(IOTA & 511)] = fTemp54;
			float fTemp55 = (fSlow128 * fTemp0);
			fVec54[(IOTA & 511)] = fTemp55;
			float fTemp56 = (fSlow130 * fTemp0);
			fVec55[(IOTA & 511)] = fTemp56;
			float fTemp57 = (fSlow132 * fTemp0);
			fVec56[(IOTA & 511)] = fTemp57;
			float fTemp58 = (fSlow136 * fTemp0);
			fVec57[(IOTA & 511)] = fTemp58;
			float fTemp59 = (fSlow138 * fTemp0);
			fVec58[(IOTA & 511)] = fTemp59;
			float fTemp60 = (fSlow141 * fTemp0);
			fVec59[(IOTA & 511)] = fTemp60;
			float fTemp61 = (fSlow143 * fTemp0);
			fVec60[(IOTA & 511)] = fTemp61;
			float fTemp62 = (fSlow147 * fTemp0);
			fVec61[(IOTA & 511)] = fTemp62;
			float fTemp63 = (fSlow148 * fTemp0);
			fVec62[(IOTA & 511)] = fTemp63;
			float fTemp64 = (fSlow150 * fTemp0);
			fVec63[(IOTA & 511)] = fTemp64;
			float fTemp65 = (fSlow151 * fTemp0);
			fVec64[(IOTA & 511)] = fTemp65;
			output0[i] = FAUSTFLOAT((iSlow1 ? (iSlow77 ? (iSlow115 ? (iSlow133 ? (iSlow145 ? (iSlow149 ? (((0.000213629566f * (((((fVec64[((IOTA - 397) & 511)] + fVec64[((IOTA - 398) & 511)]) - fVec64[((IOTA - 477) & 511)]) + fVec64[((IOTA - 497) & 511)]) + fVec64[((IOTA - 501) & 511)]) - fVec64[((IOTA - 509) & 511)])) + ((3.05185094e-05f * ((((fVec64[((IOTA - 196) & 511)] - fVec64[((IOTA - 330) & 511)]) - fVec64[((IOTA - 337) & 511)]) + fVec64[((IOTA - 462) & 511)]) + fVec64[((IOTA - 502) & 511)])) + ((0.000366222113f * (((((((fVec64[((IOTA - 42) & 511)] + fVec64[((IOTA - 50) & 511)]) + fVec64[((IOTA - 187) & 511)]) + fVec64[((IOTA - 317) & 511)]) - fVec64[((IOTA - 447) & 511)]) + fVec64[((IOTA - 461) & 511)]) - fVec64[((IOTA - 486) & 511)]) + fVec64[((IOTA - 500) & 511)])) + ((0.000427259132f * ((((((fVec64[((IOTA - 15) & 511)] - fVec64[((IOTA - 35) & 511)]) + fVec64[((IOTA - 37) & 511)]) + fVec64[((IOTA - 192) & 511)]) + fVec64[((IOTA - 315) & 511)]) + fVec64[((IOTA - 460) & 511)]) + fVec64[((IOTA - 499) & 511)])) + ((0.00054933317f * (((((fVec64[((IOTA - 28) & 511)] - fVec64[((IOTA - 171) & 511)]) + fVec64[((IOTA - 255) & 511)]) - fVec64[((IOTA - 285) & 511)]) + fVec64[((IOTA - 362) & 511)]) - fVec64[((IOTA - 494) & 511)])) + ((0.000793481246f * (((((((fVec64[((IOTA - 13) & 511)] + fVec64[((IOTA - 38) & 511)]) - fVec64[((IOTA - 253) & 511)]) - fVec64[((IOTA - 281) & 511)]) + fVec64[((IOTA - 313) & 511)]) - fVec64[((IOTA - 438) & 511)]) - fVec64[((IOTA - 440) & 511)]) - fVec64[((IOTA - 493) & 511)])) + ((0.00106814783f * ((fVec64[((IOTA - 410) & 511)] + fVec64[((IOTA - 414) & 511)]) - fVec64[((IOTA - 492) & 511)])) + ((0.0012817774f * (((((fVec64[((IOTA - 155) & 511)] - fVec64[((IOTA - 249) & 511)]) - fVec64[((IOTA - 350) & 511)]) - fVec64[((IOTA - 466) & 511)]) - fVec64[((IOTA - 490) & 511)]) - fVec64[((IOTA - 491) & 511)])) + ((0.00109866634f * (((((((fVec64[((IOTA - 197) & 511)] + fVec64[((IOTA - 225) & 511)]) + fVec64[((IOTA - 305) & 511)]) + fVec64[((IOTA - 311) & 511)]) + fVec64[((IOTA - 324) & 511)]) + fVec64[((IOTA - 325) & 511)]) - fVec64[((IOTA - 436) & 511)]) - fVec64[((IOTA - 489) & 511)])) + ((0.000610370189f * ((((((fVec64[((IOTA - 226) & 511)] + fVec64[((IOTA - 298) & 511)]) + fVec64[((IOTA - 333) & 511)]) - fVec64[((IOTA - 355) & 511)]) + fVec64[((IOTA - 408) & 511)]) - fVec64[((IOTA - 442) & 511)]) - fVec64[((IOTA - 487) & 511)])) + ((6.10370189e-05f * (((((((((((((fVec64[((IOTA - 16) & 511)] + fVec64[((IOTA - 56) & 511)]) - fVec64[((IOTA - 289) & 511)]) - fVec64[((IOTA - 331) & 511)]) + fVec64[((IOTA - 356) & 511)]) - fVec64[((IOTA - 384) & 511)]) - fVec64[((IOTA - 399) & 511)]) + fVec64[((IOTA - 416) & 511)]) - fVec64[((IOTA - 418) & 511)]) - fVec64[((IOTA - 419) & 511)]) - fVec64[((IOTA - 420) & 511)]) - fVec64[((IOTA - 478) & 511)]) + fVec64[((IOTA - 479) & 511)]) + fVec64[((IOTA - 484) & 511)])) + ((0.000122074038f * ((((fVec64[((IOTA - 262) & 511)] + fVec64[((IOTA - 341) & 511)]) + fVec64[((IOTA - 395) & 511)]) - fVec64[((IOTA - 417) & 511)]) + fVec64[((IOTA - 483) & 511)])) + ((0.000152592547f * (((((fVec64[((IOTA - 10) & 511)] - fVec64[((IOTA - 191) & 511)]) + fVec64[((IOTA - 227) & 511)]) - fVec64[((IOTA - 254) & 511)]) + fVec64[((IOTA - 396) & 511)]) + fVec64[((IOTA - 480) & 511)])) + ((0.000946073793f * ((((((((fVec64[((IOTA - 40) & 511)] - fVec64[((IOTA - 46) & 511)]) - fVec64[((IOTA - 60) & 511)]) - fVec64[((IOTA - 264) & 511)]) - fVec64[((IOTA - 274) & 511)]) + fVec64[((IOTA - 303) & 511)]) + fVec64[((IOTA - 312) & 511)]) + fVec64[((IOTA - 392) & 511)]) - fVec64[((IOTA - 469) & 511)])) + ((0.000488296151f * ((((((((fVec64[((IOTA - 11) & 511)] + fVec64[((IOTA - 55) & 511)]) - fVec64[((IOTA - 188) & 511)]) - fVec64[((IOTA - 263) & 511)]) - fVec64[((IOTA - 286) & 511)]) + fVec64[((IOTA - 297) & 511)]) + fVec64[((IOTA - 407) & 511)]) - fVec64[((IOTA - 431) & 511)]) - fVec64[((IOTA - 463) & 511)])) + ((0.00100711081f * ((((((fVec64[((IOTA - 53) & 511)] - fVec64[((IOTA - 271) & 511)]) - fVec64[((IOTA - 280) & 511)]) + fVec64[((IOTA - 304) & 511)]) + fVec64[((IOTA - 424) & 511)]) - fVec64[((IOTA - 437) & 511)]) - fVec64[((IOTA - 456) & 511)])) + ((0.00103762932f * ((((((fVec64[((IOTA - 256) & 511)] + fVec64[((IOTA - 319) & 511)]) - fVec64[((IOTA - 354) & 511)]) - fVec64[((IOTA - 383) & 511)]) - fVec64[((IOTA - 432) & 511)]) - fVec64[((IOTA - 454) & 511)]) - fVec64[((IOTA - 455) & 511)])) + ((0.00296029542f * (fVec64[((IOTA - 371) & 511)] - fVec64[((IOTA - 449) & 511)])) + ((0.00186162908f * (fVec64[((IOTA - 374) & 511)] - fVec64[((IOTA - 448) & 511)])) + ((0.000854518265f * ((((((fVec64[((IOTA - 26) & 511)] + fVec64[((IOTA - 54) & 511)]) - fVec64[((IOTA - 59) & 511)]) - fVec64[((IOTA - 189) & 511)]) + fVec64[((IOTA - 302) & 511)]) - fVec64[((IOTA - 402) & 511)]) + fVec64[((IOTA - 446) & 511)])) + ((0.000732444227f * ((((((fVec64[((IOTA - 12) & 511)] + fVec64[((IOTA - 25) & 511)]) + fVec64[((IOTA - 41) & 511)]) + fVec64[((IOTA - 51) & 511)]) - fVec64[((IOTA - 190) & 511)]) + fVec64[((IOTA - 301) & 511)]) - fVec64[((IOTA - 439) & 511)])) + ((0.00125125889f * (((fVec64[((IOTA - 310) & 511)] - fVec64[((IOTA - 346) & 511)]) + fVec64[((IOTA - 361) & 511)]) - fVec64[((IOTA - 433) & 511)])) + ((0.00112918485f * ((((fVec64[((IOTA - 159) & 511)] - fVec64[((IOTA - 230) & 511)]) + fVec64[((IOTA - 327) & 511)]) - fVec64[((IOTA - 345) & 511)]) + fVec64[((IOTA - 429) & 511)])) + ((0.00189214759f * fVec64[((IOTA - 426) & 511)]) + ((0.000457777642f * (((((((fVec64[((IOTA - 24) & 511)] - fVec64[((IOTA - 228) & 511)]) - fVec64[((IOTA - 293) & 511)]) + fVec64[((IOTA - 393) & 511)]) - fVec64[((IOTA - 400) & 511)]) - fVec64[((IOTA - 403) & 511)]) + fVec64[((IOTA - 406) & 511)]) + fVec64[((IOTA - 423) & 511)])) + ((0.00146488845f * ((fVec64[((IOTA - 223) & 511)] + fVec64[((IOTA - 259) & 511)]) + fVec64[((IOTA - 412) & 511)])) + ((0.00265511032f * fVec64[((IOTA - 389) & 511)]) + ((0.00314340647f * fVec64[((IOTA - 388) & 511)]) + ((0.00320444349f * fVec64[((IOTA - 387) & 511)]) + ((0.00253303628f * (fVec64[((IOTA - 148) & 511)] + fVec64[((IOTA - 386) & 511)])) + ((0.0019226661f * ((fVec64[((IOTA - 154) & 511)] - fVec64[((IOTA - 269) & 511)]) - fVec64[((IOTA - 377) & 511)])) + ((0.00305185094f * fVec64[((IOTA - 373) & 511)]) + ((0.00338755455f * fVec64[((IOTA - 372) & 511)]) + ((0.000671407208f * (((((fTemp65 - fVec64[((IOTA - 283) & 511)]) - fVec64[((IOTA - 284) & 511)]) + fVec64[((IOTA - 299) & 511)]) + fVec64[((IOTA - 300) & 511)]) - fVec64[((IOTA - 363) & 511)])) + ((0.001617481f * fVec64[((IOTA - 359) & 511)]) + ((0.00137333293f * (((((fVec64[((IOTA - 130) & 511)] - fVec64[((IOTA - 248) & 511)]) + fVec64[((IOTA - 308) & 511)]) + fVec64[((IOTA - 309) & 511)]) - fVec64[((IOTA - 347) & 511)]) + fVec64[((IOTA - 358) & 511)])) + ((0.00057985168f * ((((fVec64[((IOTA - 1) & 511)] - fVec64[((IOTA - 5) & 511)]) + fVec64[((IOTA - 314) & 511)]) + fVec64[((IOTA - 318) & 511)]) - fVec64[((IOTA - 343) & 511)])) + ((0.00167851802f * fVec64[((IOTA - 322) & 511)]) + ((0.00180059206f * (fVec64[((IOTA - 186) & 511)] - fVec64[((IOTA - 267) & 511)])) + ((0.00158696249f * ((fVec64[((IOTA - 69) & 511)] + fVec64[((IOTA - 258) & 511)]) + fVec64[((IOTA - 360) & 511)])) + ((0.00366222113f * fVec64[((IOTA - 221) & 511)]) + ((0.00476088747f * (fVec64[((IOTA - 210) & 511)] + fVec64[((IOTA - 220) & 511)])) + ((0.00521866512f * fVec64[((IOTA - 219) & 511)]) + ((0.00543229468f * (fVec64[((IOTA - 209) & 511)] + fVec64[((IOTA - 218) & 511)])) + ((0.00564592425f * (fVec64[((IOTA - 208) & 511)] + fVec64[((IOTA - 217) & 511)])) + ((0.00625629444f * (fVec64[((IOTA - 202) & 511)] + fVec64[((IOTA - 216) & 511)])) + ((0.00653096102f * fVec64[((IOTA - 215) & 511)]) + ((0.00466933195f * fVec64[((IOTA - 213) & 511)]) + ((0.00381481368f * fVec64[((IOTA - 211) & 511)]) + ((0.00573747978f * fVec64[((IOTA - 207) & 511)]) + ((0.00616473891f * fVec64[((IOTA - 206) & 511)]) + ((0.00689718314f * fVec64[((IOTA - 205) & 511)]) + ((0.00695822015f * (fVec64[((IOTA - 168) & 511)] + fVec64[((IOTA - 204) & 511)])) + ((0.00662251655f * fVec64[((IOTA - 203) & 511)]) + ((0.0057985168f * fVec64[((IOTA - 201) & 511)]) + ((0.00518814661f * fVec64[((IOTA - 200) & 511)]) + ((0.00402844325f * ((fVec64[((IOTA - 108) & 511)] - fVec64[((IOTA - 152) & 511)]) + fVec64[((IOTA - 199) & 511)])) + ((0.00286873989f * (fVec64[((IOTA - 169) & 511)] + fVec64[((IOTA - 198) & 511)])) + ((0.00302133244f * fVec64[((IOTA - 185) & 511)]) + ((0.00213629566f * fVec64[((IOTA - 184) & 511)]) + ((0.00967436749f * fVec64[((IOTA - 167) & 511)]) + ((0.00955229346f * fVec64[((IOTA - 166) & 511)]) + ((0.00943021942f * fVec64[((IOTA - 165) & 511)]) + ((0.0134586627f * fVec64[((IOTA - 163) & 511)]) + ((0.0156254768f * fVec64[((IOTA - 162) & 511)]) + ((0.0143436994f * fVec64[((IOTA - 161) & 511)]) + ((0.00753807183f * fVec64[((IOTA - 160) & 511)]) + ((0.00500503555f * (fVec64[((IOTA - 145) & 511)] - fVec64[((IOTA - 151) & 511)])) + ((0.00430310983f * fVec64[((IOTA - 147) & 511)]) + ((0.00442518387f * (fVec64[((IOTA - 116) & 511)] + fVec64[((IOTA - 146) & 511)])) + ((0.00650044251f * fVec64[((IOTA - 144) & 511)]) + ((0.0100100711f * fVec64[((IOTA - 143) & 511)]) + ((0.0133060701f * fVec64[((IOTA - 142) & 511)]) + ((0.0169377737f * fVec64[((IOTA - 141) & 511)]) + ((0.0180669576f * fVec64[((IOTA - 140) & 511)]) + ((0.0180059206f * fVec64[((IOTA - 139) & 511)]) + ((0.0151066622f * fVec64[((IOTA - 138) & 511)]) + ((0.008087405f * fVec64[((IOTA - 137) & 511)]) + ((0.0126956999f * fVec64[((IOTA - 129) & 511)]) + ((0.0197149571f * fVec64[((IOTA - 128) & 511)]) + ((0.0172429588f * fVec64[((IOTA - 127) & 511)]) + ((0.00527970213f * fVec64[((IOTA - 126) & 511)]) + ((0.0074159978f * fVec64[((IOTA - 115) & 511)]) + ((0.0159001444f * fVec64[((IOTA - 114) & 511)]) + ((0.0162663665f * fVec64[((IOTA - 113) & 511)]) + ((0.0208746605f * fVec64[((IOTA - 112) & 511)]) + ((0.0204168838f * fVec64[((IOTA - 111) & 511)]) + ((0.0260322895f * fVec64[((IOTA - 110) & 511)]) + ((0.01617481f * fVec64[((IOTA - 109) & 511)]) + ((0.00427259132f * fVec64[((IOTA - 101) & 511)]) + ((0.0253303628f * fVec64[((IOTA - 100) & 511)]) + ((0.018097477f * fVec64[((IOTA - 99) & 511)]) + ((0.00512710959f * fVec64[((IOTA - 98) & 511)]) + ((0.169713438f * fVec64[((IOTA - 75) & 511)]) + ((0.308816791f * fVec64[((IOTA - 74) & 511)]) + ((0.297128201f * fVec64[((IOTA - 73) & 511)]) + ((0.156651512f * fVec64[((IOTA - 72) & 511)]) + ((0.0466933213f * fVec64[((IOTA - 71) & 511)]) + ((0.000976592302f * (fVec64[((IOTA - 39) & 511)] + fVec64[((IOTA - 52) & 511)])) + (0.00897244178f * fVec64[((IOTA - 70) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000305185094f * ((((fVec64[((IOTA - 4) & 511)] + fVec64[((IOTA - 17) & 511)]) + fVec64[((IOTA - 22) & 511)]) + fVec64[((IOTA - 495) & 511)]) + fVec64[((IOTA - 510) & 511)])) + ((0.000183111057f * ((((((((((((fVec64[((IOTA - 9) & 511)] - fVec64[((IOTA - 29) & 511)]) + fVec64[((IOTA - 291) & 511)]) + fVec64[((IOTA - 338) & 511)]) - fVec64[((IOTA - 340) & 511)]) + fVec64[((IOTA - 342) & 511)]) - fVec64[((IOTA - 375) & 511)]) - fVec64[((IOTA - 394) & 511)]) - fVec64[((IOTA - 459) & 511)]) + fVec64[((IOTA - 475) & 511)]) + fVec64[((IOTA - 503) & 511)]) + fVec64[((IOTA - 507) & 511)]) + fVec64[((IOTA - 508) & 511)])) + ((0.000274666585f * (((((fVec64[((IOTA - 170) & 511)] + fVec64[((IOTA - 294) & 511)]) - fVec64[((IOTA - 329) & 511)]) - fVec64[((IOTA - 430) & 511)]) + fVec64[((IOTA - 458) & 511)]) + fVec64[((IOTA - 506) & 511)])) + ((0.000396740623f * ((((fVec64[((IOTA - 156) & 511)] + fVec64[((IOTA - 287) & 511)]) + fVec64[((IOTA - 292) & 511)]) - fVec64[((IOTA - 405) & 511)]) - fVec64[((IOTA - 498) & 511)])) + ((0.000885036774f * (((fVec64[((IOTA - 32) & 511)] + fVec64[((IOTA - 61) & 511)]) + fVec64[((IOTA - 441) & 511)]) + fVec64[((IOTA - 488) & 511)])) + ((9.15555283e-05f * ((((((((((fVec64[((IOTA - 49) & 511)] - (fVec64[((IOTA - 23) & 511)] - fVec64[((IOTA - 43) & 511)])) + fVec64[((IOTA - 194) & 511)]) - fVec64[((IOTA - 404) & 511)]) + fVec64[((IOTA - 421) & 511)]) - fVec64[((IOTA - 422) & 511)]) - fVec64[((IOTA - 443) & 511)]) + fVec64[((IOTA - 474) & 511)]) - fVec64[((IOTA - 481) & 511)]) - fVec64[((IOTA - 482) & 511)]) + fVec64[((IOTA - 485) & 511)])) + ((0.000244148076f * ((((((fVec64[((IOTA - 30) & 511)] - fVec64[((IOTA - 193) & 511)]) + fVec64[((IOTA - 288) & 511)]) - fVec64[((IOTA - 296) & 511)]) - fVec64[((IOTA - 332) & 511)]) + fVec64[((IOTA - 471) & 511)]) + fVec64[((IOTA - 476) & 511)])) + ((0.000640888698f * ((((((fVec64[((IOTA - 18) & 511)] + fVec64[((IOTA - 21) & 511)]) + fVec64[((IOTA - 31) & 511)]) + fVec64[((IOTA - 58) & 511)]) + fVec64[((IOTA - 272) & 511)]) + fVec64[((IOTA - 273) & 511)]) + fVec64[((IOTA - 470) & 511)])) + ((0.00119022187f * (fVec64[((IOTA - 353) & 511)] + fVec64[((IOTA - 468) & 511)])) + ((0.00131229591f * (((((((fVec64[((IOTA - 251) & 511)] - fVec64[((IOTA - 307) & 511)]) - fVec64[((IOTA - 323) & 511)]) + fVec64[((IOTA - 368) & 511)]) - fVec64[((IOTA - 385) & 511)]) - fVec64[((IOTA - 411) & 511)]) - fVec64[((IOTA - 445) & 511)]) + fVec64[((IOTA - 467) & 511)])) + ((0.00115970336f * (((((fVec64[((IOTA - 62) & 511)] + fVec64[((IOTA - 172) & 511)]) - fVec64[((IOTA - 260) & 511)]) + fVec64[((IOTA - 265) & 511)]) + fVec64[((IOTA - 435) & 511)]) + fVec64[((IOTA - 465) & 511)])) + ((0.000915555283f * ((((fVec64[((IOTA - 33) & 511)] + fVec64[((IOTA - 229) & 511)]) + fVec64[((IOTA - 344) & 511)]) - fVec64[((IOTA - 444) & 511)]) + fVec64[((IOTA - 464) & 511)])) + ((0.000762962736f * (((fVec64[((IOTA - 34) & 511)] + fVec64[((IOTA - 149) & 511)]) - fVec64[((IOTA - 328) & 511)]) + fVec64[((IOTA - 457) & 511)])) + ((0.00134281442f * ((fVec64[((IOTA - 275) & 511)] + fVec64[((IOTA - 279) & 511)]) + fVec64[((IOTA - 453) & 511)])) + ((0.00201422162f * ((fVec64[((IOTA - 235) & 511)] + fVec64[((IOTA - 242) & 511)]) + fVec64[((IOTA - 452) & 511)])) + ((0.00280770287f * ((fVec64[((IOTA - 63) & 511)] + fVec64[((IOTA - 175) & 511)]) + fVec64[((IOTA - 451) & 511)])) + ((0.00326548051f * fVec64[((IOTA - 450) & 511)]) + ((0.00122074038f * (((((((((((fVec64[((IOTA - 153) & 511)] - fVec64[((IOTA - 224) & 511)]) + fVec64[((IOTA - 231) & 511)]) + fVec64[((IOTA - 232) & 511)]) + fVec64[((IOTA - 250) & 511)]) + fVec64[((IOTA - 252) & 511)]) - fVec64[((IOTA - 306) & 511)]) - fVec64[((IOTA - 326) & 511)]) + fVec64[((IOTA - 351) & 511)]) + fVec64[((IOTA - 352) & 511)]) + fVec64[((IOTA - 376) & 511)]) + fVec64[((IOTA - 434) & 511)])) + ((0.00173955504f * (fVec64[((IOTA - 381) & 511)] - fVec64[((IOTA - 428) & 511)])) + ((0.00198370311f * (fVec64[((IOTA - 243) & 511)] - fVec64[((IOTA - 427) & 511)])) + ((0.00155644398f * (((fVec64[((IOTA - 173) & 511)] + fVec64[((IOTA - 247) & 511)]) - fVec64[((IOTA - 320) & 511)]) - fVec64[((IOTA - 425) & 511)])) + ((0.000518814661f * (((((fVec64[((IOTA - 8) & 511)] + fVec64[((IOTA - 44) & 511)]) + fVec64[((IOTA - 48) & 511)]) - fVec64[((IOTA - 183) & 511)]) - fVec64[((IOTA - 369) & 511)]) - fVec64[((IOTA - 415) & 511)])) + ((0.00140385143f * (((fVec64[((IOTA - 233) & 511)] - fVec64[((IOTA - 257) & 511)]) + fVec64[((IOTA - 349) & 511)]) - fVec64[((IOTA - 413) & 511)])) + ((0.000823999755f * ((((((((fVec64[((IOTA - 19) & 511)] + fVec64[((IOTA - 20) & 511)]) - fVec64[((IOTA - 27) & 511)]) + fVec64[((IOTA - 45) & 511)]) + fVec64[((IOTA - 47) & 511)]) - fVec64[((IOTA - 334) & 511)]) - fVec64[((IOTA - 357) & 511)]) + fVec64[((IOTA - 401) & 511)]) - fVec64[((IOTA - 409) & 511)])) + ((0.00149540696f * ((fVec64[((IOTA - 182) & 511)] + fVec64[((IOTA - 270) & 511)]) - fVec64[((IOTA - 391) & 511)])) + ((0.00204474013f * (((fVec64[((IOTA - 244) & 511)] + fVec64[((IOTA - 268) & 511)]) + fVec64[((IOTA - 378) & 511)]) - fVec64[((IOTA - 390) & 511)])) + ((0.00152592547f * fVec64[((IOTA - 382) & 511)]) + ((0.00183111057f * ((fVec64[((IOTA - 277) & 511)] - fVec64[((IOTA - 321) & 511)]) + fVec64[((IOTA - 380) & 511)])) + ((0.0019531846f * ((fVec64[((IOTA - 245) & 511)] - fVec64[((IOTA - 370) & 511)]) + fVec64[((IOTA - 379) & 511)])) + ((0.00308236945f * (fVec64[((IOTA - 157) & 511)] + fVec64[((IOTA - 367) & 511)])) + ((0.00408948027f * fVec64[((IOTA - 366) & 511)]) + ((0.00372325815f * fVec64[((IOTA - 365) & 511)]) + ((0.00228888821f * fVec64[((IOTA - 364) & 511)]) + ((0.00143436994f * (fVec64[((IOTA - 266) & 511)] + fVec64[((IOTA - 348) & 511)])) + ((0.000701925717f * (((((fVec64[((IOTA - 6) & 511)] + fVec64[((IOTA - 7) & 511)]) - fVec64[((IOTA - 14) & 511)]) - fVec64[((IOTA - 261) & 511)]) + fVec64[((IOTA - 282) & 511)]) - fVec64[((IOTA - 335) & 511)])) + ((0.00170903653f * (fVec64[((IOTA - 276) & 511)] + fVec64[((IOTA - 278) & 511)])) + ((0.00177007355f * fVec64[((IOTA - 246) & 511)]) + ((0.00207525864f * fVec64[((IOTA - 241) & 511)]) + ((0.00210577715f * (fVec64[((IOTA - 239) & 511)] + fVec64[((IOTA - 240) & 511)])) + ((0.00238044374f * ((fVec64[((IOTA - 136) & 511)] + fVec64[((IOTA - 180) & 511)]) + fVec64[((IOTA - 238) & 511)])) + ((0.00262459181f * fVec64[((IOTA - 237) & 511)]) + ((0.00250251777f * fVec64[((IOTA - 236) & 511)]) + ((0.00164799951f * fVec64[((IOTA - 234) & 511)]) + ((0.00219733268f * (fVec64[((IOTA - 181) & 511)] - fVec64[((IOTA - 222) & 511)])) + ((0.00610370189f * (fVec64[((IOTA - 178) & 511)] - fVec64[((IOTA - 214) & 511)])) + ((0.00375377666f * (fVec64[((IOTA - 179) & 511)] - fVec64[((IOTA - 212) & 511)])) + ((0.00732444227f * fVec64[((IOTA - 177) & 511)]) + ((0.00592059083f * fVec64[((IOTA - 176) & 511)]) + ((0.00216681417f * fVec64[((IOTA - 174) & 511)]) + ((0.0103762932f * (fVec64[((IOTA - 66) & 511)] - fVec64[((IOTA - 164) & 511)])) + ((0.00244148076f * fVec64[((IOTA - 158) & 511)]) + ((0.00363170262f * fVec64[((IOTA - 150) & 511)]) + ((0.0121768853f * fVec64[((IOTA - 135) & 511)]) + ((0.0176091809f * fVec64[((IOTA - 134) & 511)]) + ((0.021332439f * fVec64[((IOTA - 133) & 511)]) + ((0.0196234025f * fVec64[((IOTA - 132) & 511)]) + ((0.0118411817f * fVec64[((IOTA - 131) & 511)]) + ((0.0126346629f * fVec64[((IOTA - 125) & 511)]) + ((0.0274666585f * fVec64[((IOTA - 124) & 511)]) + ((0.0341196954f * fVec64[((IOTA - 123) & 511)]) + ((0.0351268053f * fVec64[((IOTA - 122) & 511)]) + ((0.0324716941f * fVec64[((IOTA - 121) & 511)]) + ((0.0302438438f * fVec64[((IOTA - 120) & 511)]) + ((0.0273751039f * fVec64[((IOTA - 119) & 511)]) + ((0.0187994018f * fVec64[((IOTA - 118) & 511)]) + ((0.00799584948f * fVec64[((IOTA - 117) & 511)]) + ((0.00976592302f * fVec64[((IOTA - 107) & 511)]) + ((0.0247199927f * fVec64[((IOTA - 106) & 511)]) + ((0.0274361409f * fVec64[((IOTA - 105) & 511)]) + ((0.0242316965f * fVec64[((IOTA - 104) & 511)]) + ((0.0201116987f * fVec64[((IOTA - 103) & 511)]) + ((0.0142521439f * fVec64[((IOTA - 102) & 511)]) + ((0.0234382153f * fVec64[((IOTA - 97) & 511)]) + ((0.0378734693f * fVec64[((IOTA - 96) & 511)]) + ((0.0516068004f * fVec64[((IOTA - 95) & 511)]) + ((0.0382702127f * fVec64[((IOTA - 94) & 511)]) + ((0.0241706595f * fVec64[((IOTA - 93) & 511)]) + ((0.0247810297f * fVec64[((IOTA - 92) & 511)]) + ((0.0353404358f * fVec64[((IOTA - 91) & 511)]) + ((0.0477614664f * fVec64[((IOTA - 90) & 511)]) + ((0.0470595434f * fVec64[((IOTA - 89) & 511)]) + ((0.0589922778f * fVec64[((IOTA - 88) & 511)]) + ((0.0414136164f * fVec64[((IOTA - 87) & 511)]) + ((0.0398876928f * fVec64[((IOTA - 86) & 511)]) + ((0.0105594043f * fVec64[((IOTA - 85) & 511)]) + ((0.0101626636f * fVec64[((IOTA - 84) & 511)]) + ((0.006469924f * fVec64[((IOTA - 83) & 511)]) + ((0.0267647337f * fVec64[((IOTA - 82) & 511)]) + ((0.0347911008f * fVec64[((IOTA - 81) & 511)]) + ((0.0657368675f * fVec64[((IOTA - 80) & 511)]) + ((0.118289746f * fVec64[((IOTA - 79) & 511)]) + ((0.137119666f * fVec64[((IOTA - 78) & 511)]) + ((0.12851344f * fVec64[((IOTA - 77) & 511)]) + ((0.00805688649f * fVec64[((IOTA - 76) & 511)]) + ((0.00405896176f * fVec64[((IOTA - 68) & 511)]) + ((0.00921658985f * fVec64[((IOTA - 67) & 511)]) + ((0.00601214636f * fVec64[((IOTA - 64) & 511)]) + (0.00909451582f * fVec64[((IOTA - 65) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000335703604f * ((fVec64[((IOTA - 505) & 511)] - (((((fVec64[((IOTA - 2) & 511)] - fVec64[((IOTA - 57) & 511)]) - fVec64[((IOTA - 195) & 511)]) + fVec64[((IOTA - 316) & 511)]) + fVec64[((IOTA - 336) & 511)]) - fVec64[((IOTA - 504) & 511)])) + fVec64[((IOTA - 511) & 511)])))) : (((0.000823999755f * ((((fVec63[((IOTA - 263) & 511)] + fVec63[((IOTA - 342) & 511)]) - fVec63[((IOTA - 381) & 511)]) - fVec63[((IOTA - 495) & 511)]) - fVec63[((IOTA - 510) & 511)])) + ((0.000854518265f * ((((((fVec63[((IOTA - 1) & 511)] - fVec63[((IOTA - 35) & 511)]) - fVec63[((IOTA - 58) & 511)]) + fVec63[((IOTA - 160) & 511)]) + fVec63[((IOTA - 330) & 511)]) - fVec63[((IOTA - 504) & 511)]) - fVec63[((IOTA - 506) & 511)])) + ((0.000915555283f * (((((((((((fTemp64 - fVec63[((IOTA - 6) & 511)]) + fVec63[((IOTA - 12) & 511)]) + fVec63[((IOTA - 25) & 511)]) + fVec63[((IOTA - 28) & 511)]) + fVec63[((IOTA - 51) & 511)]) + fVec63[((IOTA - 98) & 511)]) - fVec63[((IOTA - 130) & 511)]) + fVec63[((IOTA - 303) & 511)]) + fVec63[((IOTA - 314) & 511)]) - fVec63[((IOTA - 469) & 511)]) - fVec63[((IOTA - 505) & 511)])) + ((0.000122074038f * (((((fVec63[((IOTA - 233) & 511)] + fVec63[((IOTA - 253) & 511)]) + fVec63[((IOTA - 273) & 511)]) + fVec63[((IOTA - 433) & 511)]) + fVec63[((IOTA - 434) & 511)]) - fVec63[((IOTA - 500) & 511)])) + ((0.000366222113f * ((((((((fVec63[((IOTA - 37) & 511)] + fVec63[((IOTA - 169) & 511)]) - fVec63[((IOTA - 271) & 511)]) - fVec63[((IOTA - 293) & 511)]) - fVec63[((IOTA - 347) & 511)]) - fVec63[((IOTA - 349) & 511)]) + fVec63[((IOTA - 355) & 511)]) + fVec63[((IOTA - 442) & 511)]) - fVec63[((IOTA - 497) & 511)])) + ((0.00057985168f * (((((((((fVec63[((IOTA - 2) & 511)] - fVec63[((IOTA - 44) & 511)]) - fVec63[((IOTA - 240) & 511)]) - fVec63[((IOTA - 275) & 511)]) + fVec63[((IOTA - 298) & 511)]) + fVec63[((IOTA - 300) & 511)]) - fVec63[((IOTA - 382) & 511)]) + fVec63[((IOTA - 400) & 511)]) - fVec63[((IOTA - 486) & 511)]) - fVec63[((IOTA - 496) & 511)])) + ((0.00103762932f * (((((fVec63[((IOTA - 14) & 511)] - fVec63[((IOTA - 19) & 511)]) - fVec63[((IOTA - 236) & 511)]) + fVec63[((IOTA - 338) & 511)]) + fVec63[((IOTA - 404) & 511)]) - fVec63[((IOTA - 494) & 511)])) + ((0.00125125889f * (((((fVec63[((IOTA - 305) & 511)] - ((fVec63[((IOTA - 34) & 511)] + fVec63[((IOTA - 59) & 511)]) + fVec63[((IOTA - 237) & 511)])) + fVec63[((IOTA - 339) & 511)]) + fVec63[((IOTA - 398) & 511)]) + fVec63[((IOTA - 416) & 511)]) - fVec63[((IOTA - 493) & 511)])) + ((0.00149540696f * ((fVec63[((IOTA - 393) & 511)] - fVec63[((IOTA - 452) & 511)]) - fVec63[((IOTA - 492) & 511)])) + ((0.00164799951f * (((((fVec63[((IOTA - 200) & 511)] + fVec63[((IOTA - 308) & 511)]) + fVec63[((IOTA - 309) & 511)]) + fVec63[((IOTA - 407) & 511)]) + fVec63[((IOTA - 444) & 511)]) - fVec63[((IOTA - 491) & 511)])) + ((0.00158696249f * (((fVec63[((IOTA - 307) & 511)] + fVec63[((IOTA - 310) & 511)]) + fVec63[((IOTA - 369) & 511)]) - fVec63[((IOTA - 490) & 511)])) + ((0.00140385143f * ((fVec63[((IOTA - 40) & 511)] - fVec63[((IOTA - 46) & 511)]) - fVec63[((IOTA - 489) & 511)])) + ((0.000335703604f * ((((((((fVec63[((IOTA - 56) & 511)] + fVec63[((IOTA - 264) & 511)]) - fVec63[((IOTA - 281) & 511)]) - fVec63[((IOTA - 282) & 511)]) - fVec63[((IOTA - 287) & 511)]) - fVec63[((IOTA - 376) & 511)]) + fVec63[((IOTA - 437) & 511)]) - fVec63[((IOTA - 448) & 511)]) - fVec63[((IOTA - 485) & 511)])) + ((0.000183111057f * ((((((((((fVec63[((IOTA - 3) & 511)] + fVec63[((IOTA - 229) & 511)]) + fVec63[((IOTA - 232) & 511)]) - fVec63[((IOTA - 234) & 511)]) - fVec63[((IOTA - 266) & 511)]) - fVec63[((IOTA - 288) & 511)]) - fVec63[((IOTA - 351) & 511)]) + fVec63[((IOTA - 363) & 511)]) - fVec63[((IOTA - 368) & 511)]) - fVec63[((IOTA - 476) & 511)]) - fVec63[((IOTA - 483) & 511)])) + ((3.05185094e-05f * ((((((((fVec63[((IOTA - 10) & 511)] + fVec63[((IOTA - 265) & 511)]) - fVec63[((IOTA - 289) & 511)]) - fVec63[((IOTA - 295) & 511)]) - fVec63[((IOTA - 345) & 511)]) + fVec63[((IOTA - 463) & 511)]) + fVec63[((IOTA - 472) & 511)]) + fVec63[((IOTA - 479) & 511)]) - fVec63[((IOTA - 481) & 511)])) + ((6.10370189e-05f * ((((((fVec63[((IOTA - 43) & 511)] + fVec63[((IOTA - 290) & 511)]) - fVec63[((IOTA - 354) & 511)]) - fVec63[((IOTA - 383) & 511)]) + fVec63[((IOTA - 458) & 511)]) + fVec63[((IOTA - 474) & 511)]) + fVec63[((IOTA - 480) & 511)])) + ((0.000305185094f * ((((((fVec63[((IOTA - 16) & 511)] - fVec63[((IOTA - 57) & 511)]) - fVec63[((IOTA - 145) & 511)]) - fVec63[((IOTA - 251) & 511)]) - fVec63[((IOTA - 252) & 511)]) - fVec63[((IOTA - 457) & 511)]) - fVec63[((IOTA - 471) & 511)])) + ((0.000946073793f * (((fVec63[((IOTA - 38) & 511)] + fVec63[((IOTA - 55) & 511)]) + fVec63[((IOTA - 399) & 511)]) - fVec63[((IOTA - 466) & 511)])) + ((0.000457777642f * ((((fVec63[((IOTA - 24) & 511)] - fVec63[((IOTA - 286) & 511)]) + fVec63[((IOTA - 440) & 511)]) + fVec63[((IOTA - 459) & 511)]) - fVec63[((IOTA - 464) & 511)])) + ((0.000518814661f * ((((fVec63[((IOTA - 11) & 511)] - fVec63[((IOTA - 185) & 511)]) + fVec63[((IOTA - 199) & 511)]) - fVec63[((IOTA - 235) & 511)]) + fVec63[((IOTA - 462) & 511)])) + ((0.00228888821f * (fVec63[((IOTA - 260) & 511)] - fVec63[((IOTA - 450) & 511)])) + ((0.00112918485f * fVec63[((IOTA - 447) & 511)]) + ((0.00207525864f * fVec63[((IOTA - 446) & 511)]) + ((0.00222785119f * ((fVec63[((IOTA - 257) & 511)] + fVec63[((IOTA - 320) & 511)]) + fVec63[((IOTA - 445) & 511)])) + ((0.000274666585f * (fVec63[((IOTA - 441) & 511)] - (((((fVec63[((IOTA - 36) & 511)] - fVec63[((IOTA - 50) & 511)]) + fVec63[((IOTA - 69) & 511)]) + fVec63[((IOTA - 249) & 511)]) + fVec63[((IOTA - 292) & 511)]) - fVec63[((IOTA - 436) & 511)]))) + ((0.00177007355f * (fVec63[((IOTA - 408) & 511)] + fVec63[((IOTA - 430) & 511)])) + ((0.0025940733f * fVec63[((IOTA - 429) & 511)]) + ((0.00338755455f * fVec63[((IOTA - 427) & 511)]) + ((0.00329599902f * fVec63[((IOTA - 426) & 511)]) + ((0.00247199927f * ((fVec63[((IOTA - 201) & 511)] + fVec63[((IOTA - 259) & 511)]) + fVec63[((IOTA - 424) & 511)])) + ((0.0019226661f * ((fVec63[((IOTA - 224) & 511)] + fVec63[((IOTA - 323) & 511)]) + fVec63[((IOTA - 423) & 511)])) + ((0.00119022187f * (((fVec63[((IOTA - 26) & 511)] + fVec63[((IOTA - 41) & 511)]) - fVec63[((IOTA - 186) & 511)]) + fVec63[((IOTA - 421) & 511)])) + ((0.00109866634f * (((((fVec63[((IOTA - 13) & 511)] - fVec63[((IOTA - 45) & 511)]) - fVec63[((IOTA - 269) & 511)]) - fVec63[((IOTA - 278) & 511)]) + fVec63[((IOTA - 313) & 511)]) + fVec63[((IOTA - 418) & 511)])) + ((0.00173955504f * (fVec63[((IOTA - 335) & 511)] + fVec63[((IOTA - 415) & 511)])) + ((0.00231940672f * (fVec63[((IOTA - 358) & 511)] + fVec63[((IOTA - 414) & 511)])) + ((0.00271614734f * fVec63[((IOTA - 413) & 511)]) + ((0.00277718436f * fVec63[((IOTA - 412) & 511)]) + ((0.00262459181f * (((fVec63[((IOTA - 211) & 511)] + fVec63[((IOTA - 212) & 511)]) + fVec63[((IOTA - 374) & 511)]) + fVec63[((IOTA - 411) & 511)])) + ((0.00234992523f * (fVec63[((IOTA - 391) & 511)] + fVec63[((IOTA - 410) & 511)])) + ((0.00204474013f * ((fVec63[((IOTA - 225) & 511)] - fVec63[((IOTA - 367) & 511)]) + fVec63[((IOTA - 409) & 511)])) + ((0.00146488845f * ((fVec63[((IOTA - 262) & 511)] + fVec63[((IOTA - 405) & 511)]) + fVec63[((IOTA - 422) & 511)])) + ((0.001617481f * ((fVec63[((IOTA - 319) & 511)] + fVec63[((IOTA - 333) & 511)]) + fVec63[((IOTA - 406) & 511)])) + ((0.00131229591f * (((fVec63[((IOTA - 39) & 511)] - fVec63[((IOTA - 61) & 511)]) + fVec63[((IOTA - 227) & 511)]) + fVec63[((IOTA - 397) & 511)])) + ((0.00396740623f * fVec63[((IOTA - 388) & 511)]) + ((0.00408948027f * (fVec63[((IOTA - 372) & 511)] + fVec63[((IOTA - 387) & 511)])) + ((0.0035401471f * fVec63[((IOTA - 386) & 511)]) + ((0.00122074038f * ((((fVec63[((IOTA - 27) & 511)] - fVec63[((IOTA - 277) & 511)]) + fVec63[((IOTA - 332) & 511)]) + fVec63[((IOTA - 341) & 511)]) - fVec63[((IOTA - 378) & 511)])) + ((0.00106814783f * ((((fVec63[((IOTA - 304) & 511)] + fVec63[((IOTA - 329) & 511)]) + fVec63[((IOTA - 337) & 511)]) + fVec63[((IOTA - 356) & 511)]) - fVec63[((IOTA - 377) & 511)])) + ((0.00372325815f * fVec63[((IOTA - 371) & 511)]) + ((0.00283822138f * fVec63[((IOTA - 370) & 511)]) + ((0.0022583697f * (fVec63[((IOTA - 322) & 511)] + fVec63[((IOTA - 361) & 511)])) + ((0.00256355479f * (fVec63[((IOTA - 359) & 511)] + fVec63[((IOTA - 360) & 511)])) + ((0.00180059206f * fVec63[((IOTA - 357) & 511)]) + ((0.00286873989f * fVec63[((IOTA - 390) & 511)]) + ((0.00137333293f * (((fVec63[((IOTA - 52) & 511)] + fVec63[((IOTA - 54) & 511)]) + fVec63[((IOTA - 84) & 511)]) + fVec63[((IOTA - 336) & 511)])) + ((0.00183111057f * (fVec63[((IOTA - 256) & 511)] + fVec63[((IOTA - 334) & 511)])) + ((0.00152592547f * ((fVec63[((IOTA - 53) & 511)] + fVec63[((IOTA - 144) & 511)]) + fVec63[((IOTA - 328) & 511)])) + ((0.0019531846f * fVec63[((IOTA - 327) & 511)]) + ((0.00216681417f * (fVec63[((IOTA - 223) & 511)] + fVec63[((IOTA - 326) & 511)])) + ((0.00198370311f * (fVec63[((IOTA - 261) & 511)] + fVec63[((IOTA - 325) & 511)])) + ((0.00244148076f * (fVec63[((IOTA - 258) & 511)] + fVec63[((IOTA - 321) & 511)])) + ((0.000762962736f * (((fVec63[((IOTA - 15) & 511)] - fVec63[((IOTA - 243) & 511)]) + fVec63[((IOTA - 254) & 511)]) + fVec63[((IOTA - 315) & 511)])) + ((0.00347911008f * fVec63[((IOTA - 389) & 511)]) + ((0.00170903653f * fVec63[((IOTA - 226) & 511)]) + ((0.00436414685f * ((fVec63[((IOTA - 85) & 511)] - fVec63[((IOTA - 195) & 511)]) + fVec63[((IOTA - 221) & 511)])) + ((0.00552385021f * fVec63[((IOTA - 219) & 511)]) + ((0.00537125766f * fVec63[((IOTA - 218) & 511)]) + ((0.00546281319f * fVec63[((IOTA - 217) & 511)]) + ((0.00589007232f * (fVec63[((IOTA - 216) & 511)] - (fVec63[((IOTA - 175) & 511)] - fVec63[((IOTA - 215) & 511)]))) + ((0.00494399853f * fVec63[((IOTA - 214) & 511)]) + ((0.00344859157f * (fVec63[((IOTA - 83) & 511)] + fVec63[((IOTA - 213) & 511)])) + ((0.00326548051f * fVec63[((IOTA - 210) & 511)]) + ((0.00369273964f * fVec63[((IOTA - 209) & 511)]) + ((0.00384533219f * fVec63[((IOTA - 208) & 511)]) + ((0.00393688772f * (fVec63[((IOTA - 203) & 511)] + fVec63[((IOTA - 207) & 511)])) + ((0.00482192449f * (fVec63[((IOTA - 143) & 511)] + fVec63[((IOTA - 205) & 511)])) + ((0.00442518387f * fVec63[((IOTA - 204) & 511)]) + ((0.00314340647f * fVec63[((IOTA - 202) & 511)]) + ((0.00381481368f * fVec63[((IOTA - 168) & 511)]) + ((0.0057985168f * fVec63[((IOTA - 167) & 511)]) + ((0.00592059083f * fVec63[((IOTA - 166) & 511)]) + ((0.00601214636f * fVec63[((IOTA - 165) & 511)]) + ((0.00686666463f * fVec63[((IOTA - 164) & 511)]) + ((0.00900296029f * fVec63[((IOTA - 163) & 511)]) + ((0.0101321451f * fVec63[((IOTA - 162) & 511)]) + ((0.00756859034f * fVec63[((IOTA - 161) & 511)]) + ((0.00769066438f * fVec63[((IOTA - 142) & 511)]) + ((0.0106814783f * fVec63[((IOTA - 141) & 511)]) + ((0.0109256264f * fVec63[((IOTA - 140) & 511)]) + ((0.0102847377f * fVec63[((IOTA - 139) & 511)]) + ((0.00595110934f * fVec63[((IOTA - 138) & 511)]) + ((0.00921658985f * fVec63[((IOTA - 129) & 511)]) + ((0.0139774773f * fVec63[((IOTA - 128) & 511)]) + ((0.00881984923f * fVec63[((IOTA - 127) & 511)]) + ((0.00497451704f * (fVec63[((IOTA - 70) & 511)] + fVec63[((IOTA - 116) & 511)])) + ((0.0158085879f * fVec63[((IOTA - 114) & 511)]) + ((0.0157475509f * fVec63[((IOTA - 113) & 511)]) + ((0.0198065136f * fVec63[((IOTA - 112) & 511)]) + ((0.019348735f * fVec63[((IOTA - 111) & 511)]) + ((0.0239875484f * fVec63[((IOTA - 110) & 511)]) + ((0.0104068117f * fVec63[((IOTA - 109) & 511)]) + ((0.0106509598f * fVec63[((IOTA - 101) & 511)]) + ((0.0268257707f * fVec63[((IOTA - 100) & 511)]) + ((0.0152592547f * fVec63[((IOTA - 99) & 511)]) + ((0.051759392f * fVec63[((IOTA - 76) & 511)]) + ((0.226142153f * fVec63[((IOTA - 75) & 511)]) + ((0.334818572f * fVec63[((IOTA - 74) & 511)]) + ((0.277077556f * fVec63[((IOTA - 73) & 511)]) + ((0.0322580636f * fVec63[((IOTA - 71) & 511)]) + (0.127018034f * fVec63[((IOTA - 72) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000701925717f * ((((fVec63[((IOTA - 18) & 511)] - fVec63[((IOTA - 42) & 511)]) - fVec63[((IOTA - 302) & 511)]) - fVec63[((IOTA - 317) & 511)]) + fVec63[((IOTA - 509) & 511)])) + ((0.000732444227f * (((fVec63[((IOTA - 31) & 511)] + fVec63[((IOTA - 198) & 511)]) + fVec63[((IOTA - 241) & 511)]) + fVec63[((IOTA - 507) & 511)])) + ((0.000640888698f * (((fVec63[((IOTA - 239) & 511)] + fVec63[((IOTA - 267) & 511)]) - fVec63[((IOTA - 299) & 511)]) + fVec63[((IOTA - 503) & 511)])) + ((0.000427259132f * (((((((fVec63[((IOTA - 9) & 511)] - fVec63[((IOTA - 29) & 511)]) - fVec63[((IOTA - 297) & 511)]) - fVec63[((IOTA - 343) & 511)]) + fVec63[((IOTA - 348) & 511)]) + fVec63[((IOTA - 454) & 511)]) + fVec63[((IOTA - 456) & 511)]) + fVec63[((IOTA - 502) & 511)])) + ((0.000244148076f * ((((fVec63[((IOTA - 4) & 511)] + fVec63[((IOTA - 294) & 511)]) + fVec63[((IOTA - 350) & 511)]) + fVec63[((IOTA - 477) & 511)]) + fVec63[((IOTA - 501) & 511)])) + ((9.15555283e-05f * ((((((fVec63[((IOTA - 23) & 511)] - fVec63[((IOTA - 108) & 511)]) + fVec63[((IOTA - 274) & 511)]) + fVec63[((IOTA - 291) & 511)]) - fVec63[((IOTA - 473) & 511)]) + fVec63[((IOTA - 475) & 511)]) + fVec63[((IOTA - 499) & 511)])) + ((0.000213629566f * (((((((((fVec63[((IOTA - 17) & 511)] + fVec63[((IOTA - 250) & 511)]) - fVec63[((IOTA - 296) & 511)]) + fVec63[((IOTA - 346) & 511)]) + fVec63[((IOTA - 352) & 511)]) + fVec63[((IOTA - 353) & 511)]) - fVec63[((IOTA - 401) & 511)]) - fVec63[((IOTA - 435) & 511)]) + fVec63[((IOTA - 484) & 511)]) + fVec63[((IOTA - 498) & 511)])) + ((0.00115970336f * (((((fVec63[((IOTA - 20) & 511)] + fVec63[((IOTA - 32) & 511)]) + fVec63[((IOTA - 379) & 511)]) - fVec63[((IOTA - 419) & 511)]) - fVec63[((IOTA - 420) & 511)]) + fVec63[((IOTA - 488) & 511)])) + ((0.000152592547f * ((((fVec63[((IOTA - 30) & 511)] - fVec63[((IOTA - 344) & 511)]) - fVec63[((IOTA - 402) & 511)]) + fVec63[((IOTA - 478) & 511)]) + fVec63[((IOTA - 482) & 511)])) + ((0.00100711081f * (((((((((fVec63[((IOTA - 21) & 511)] + fVec63[((IOTA - 238) & 511)]) + fVec63[((IOTA - 268) & 511)]) + fVec63[((IOTA - 276) & 511)]) - fVec63[((IOTA - 318) & 511)]) - fVec63[((IOTA - 375) & 511)]) - fVec63[((IOTA - 384) & 511)]) - fVec63[((IOTA - 417) & 511)]) + fVec63[((IOTA - 467) & 511)]) + fVec63[((IOTA - 468) & 511)])) + ((0.000793481246f * (((((((((fVec63[((IOTA - 8) & 511)] - fVec63[((IOTA - 228) & 511)]) + fVec63[((IOTA - 242) & 511)]) + fVec63[((IOTA - 246) & 511)]) + fVec63[((IOTA - 270) & 511)]) + fVec63[((IOTA - 279) & 511)]) + fVec63[((IOTA - 453) & 511)]) - fVec63[((IOTA - 460) & 511)]) - fVec63[((IOTA - 461) & 511)]) + fVec63[((IOTA - 465) & 511)])) + ((0.000671407208f * ((((fVec63[((IOTA - 5) & 511)] + fVec63[((IOTA - 147) & 511)]) - fVec63[((IOTA - 316) & 511)]) + fVec63[((IOTA - 470) & 511)]) + fVec63[((IOTA - 508) & 511)])) + ((0.000396740623f * ((((fVec63[((IOTA - 49) & 511)] + fVec63[((IOTA - 248) & 511)]) + fVec63[((IOTA - 283) & 511)]) - fVec63[((IOTA - 432) & 511)]) + fVec63[((IOTA - 455) & 511)])) + ((0.00213629566f * fVec63[((IOTA - 451) & 511)]) + ((0.00167851802f * (fVec63[((IOTA - 137) & 511)] + fVec63[((IOTA - 449) & 511)])) + ((0.00054933317f * (fVec63[((IOTA - 247) & 511)] - fVec63[((IOTA - 439) & 511)])) + ((0.000488296151f * ((((fVec63[((IOTA - 280) & 511)] + fVec63[((IOTA - 284) & 511)]) + fVec63[((IOTA - 285) & 511)]) - fVec63[((IOTA - 403) & 511)]) - fVec63[((IOTA - 438) & 511)])) + ((0.000976592302f * (((fVec63[((IOTA - 7) & 511)] + fVec63[((IOTA - 48) & 511)]) + fVec63[((IOTA - 380) & 511)]) - fVec63[((IOTA - 431) & 511)])) + ((0.00317392498f * ((fVec63[((IOTA - 192) & 511)] + fVec63[((IOTA - 366) & 511)]) - fVec63[((IOTA - 428) & 511)])) + ((0.00299081393f * (fVec63[((IOTA - 365) & 511)] - fVec63[((IOTA - 425) & 511)])) + ((0.0012817774f * ((((fVec63[((IOTA - 62) & 511)] - fVec63[((IOTA - 312) & 511)]) - fVec63[((IOTA - 394) & 511)]) - fVec63[((IOTA - 395) & 511)]) - fVec63[((IOTA - 396) & 511)])) + ((0.00186162908f * ((fVec63[((IOTA - 184) & 511)] - fVec63[((IOTA - 324) & 511)]) - fVec63[((IOTA - 392) & 511)])) + ((0.00238044374f * (fVec63[((IOTA - 63) & 511)] - fVec63[((IOTA - 385) & 511)])) + ((0.00375377666f * (fVec63[((IOTA - 196) & 511)] - fVec63[((IOTA - 373) & 511)])) + ((0.00155644398f * ((fVec63[((IOTA - 148) & 511)] - fVec63[((IOTA - 362) & 511)]) + fVec63[((IOTA - 364) & 511)])) + ((0.00134281442f * (((fVec63[((IOTA - 33) & 511)] + fVec63[((IOTA - 47) & 511)]) - fVec63[((IOTA - 255) & 511)]) - fVec63[((IOTA - 340) & 511)])) + ((0.00143436994f * ((fVec63[((IOTA - 60) & 511)] - fVec63[((IOTA - 306) & 511)]) - fVec63[((IOTA - 311) & 511)])) + ((0.000610370189f * (fVec63[((IOTA - 22) & 511)] - fVec63[((IOTA - 301) & 511)])) + ((0.0028992584f * (fVec63[((IOTA - 197) & 511)] - fVec63[((IOTA - 222) & 511)])) + ((0.00518814661f * (fVec63[((IOTA - 64) & 511)] - fVec63[((IOTA - 220) & 511)])) + ((0.00427259132f * (fVec63[((IOTA - 172) & 511)] - fVec63[((IOTA - 206) & 511)])) + ((0.00402844325f * fVec63[((IOTA - 194) & 511)]) + ((0.00357066561f * (fVec63[((IOTA - 170) & 511)] + fVec63[((IOTA - 193) & 511)])) + ((0.00378429517f * fVec63[((IOTA - 191) & 511)]) + ((0.00418103579f * fVec63[((IOTA - 190) & 511)]) + ((0.00430310983f * fVec63[((IOTA - 189) & 511)]) + ((0.00411999878f * ((fVec63[((IOTA - 171) & 511)] + fVec63[((IOTA - 173) & 511)]) + fVec63[((IOTA - 188) & 511)])) + ((0.003234962f * fVec63[((IOTA - 187) & 511)]) + ((0.00439466536f * fVec63[((IOTA - 183) & 511)]) + ((0.0061342204f * fVec63[((IOTA - 182) & 511)]) + ((0.00665303506f * fVec63[((IOTA - 181) & 511)]) + ((0.00643940549f * fVec63[((IOTA - 180) & 511)]) + ((0.00778221991f * fVec63[((IOTA - 179) & 511)]) + ((0.00958281197f * fVec63[((IOTA - 178) & 511)]) + ((0.0105899228f * fVec63[((IOTA - 177) & 511)]) + ((0.00830103457f * fVec63[((IOTA - 176) & 511)]) + ((0.00500503555f * fVec63[((IOTA - 174) & 511)]) + ((0.00527970213f * fVec63[((IOTA - 159) & 511)]) + ((0.0101626636f * fVec63[((IOTA - 158) & 511)]) + ((0.00985747855f * fVec63[((IOTA - 157) & 511)]) + ((0.00668355357f * fVec63[((IOTA - 156) & 511)]) + ((0.00350962859f * fVec63[((IOTA - 155) & 511)]) + ((0.0042115543f * fVec63[((IOTA - 154) & 511)]) + ((0.00833155308f * fVec63[((IOTA - 153) & 511)]) + ((0.0111392559f * fVec63[((IOTA - 152) & 511)]) + ((0.0116885891f * fVec63[((IOTA - 151) & 511)]) + ((0.0125736259f * fVec63[((IOTA - 136) & 511)]) + ((0.0207831059f * fVec63[((IOTA - 135) & 511)]) + ((0.0252693258f * fVec63[((IOTA - 134) & 511)]) + ((0.0271614734f * fVec63[((IOTA - 133) & 511)]) + ((0.0237434004f * fVec63[((IOTA - 132) & 511)]) + ((0.0140995514f * fVec63[((IOTA - 131) & 511)]) + ((0.004852443f * (fVec63[((IOTA - 117) & 511)] + fVec63[((IOTA - 126) & 511)])) + ((0.02252266f * (fVec63[((IOTA - 104) & 511)] + fVec63[((IOTA - 125) & 511)])) + ((0.0350657664f * fVec63[((IOTA - 124) & 511)]) + ((0.0389111005f * fVec63[((IOTA - 123) & 511)]) + ((0.0379039906f * fVec63[((IOTA - 122) & 511)]) + ((0.0335703604f * fVec63[((IOTA - 121) & 511)]) + ((0.0315561406f * fVec63[((IOTA - 120) & 511)]) + ((0.0266121402f * fVec63[((IOTA - 119) & 511)]) + ((0.0174565874f * fVec63[((IOTA - 118) & 511)]) + ((0.00845362712f * (fVec63[((IOTA - 65) & 511)] - fVec63[((IOTA - 115) & 511)])) + ((0.00869777519f * fVec63[((IOTA - 150) & 511)]) + ((0.00506607257f * fVec63[((IOTA - 149) & 511)]) + ((0.0156865139f * fVec63[((IOTA - 107) & 511)]) + ((0.0270088818f * fVec63[((IOTA - 106) & 511)]) + ((0.0274361409f * fVec63[((IOTA - 105) & 511)]) + ((0.0185247362f * fVec63[((IOTA - 103) & 511)]) + ((0.0106204413f * fVec63[((IOTA - 102) & 511)]) + ((0.0280770287f * fVec63[((IOTA - 97) & 511)]) + ((0.0382091738f * fVec63[((IOTA - 96) & 511)]) + ((0.0494094677f * fVec63[((IOTA - 95) & 511)]) + ((0.0270699188f * fVec63[((IOTA - 94) & 511)]) + ((0.0196539201f * fVec63[((IOTA - 93) & 511)]) + ((0.0187994018f * fVec63[((IOTA - 92) & 511)]) + ((0.034272287f * fVec63[((IOTA - 91) & 511)]) + ((0.0390942097f * fVec63[((IOTA - 90) & 511)]) + ((0.0444654673f * fVec63[((IOTA - 89) & 511)]) + ((0.047212135f * fVec63[((IOTA - 88) & 511)]) + ((0.030854214f * fVec63[((IOTA - 87) & 511)]) + ((0.0231330302f * fVec63[((IOTA - 86) & 511)]) + ((0.0201116987f * fVec63[((IOTA - 82) & 511)]) + ((0.0250556972f * fVec63[((IOTA - 81) & 511)]) + ((0.0667745024f * fVec63[((IOTA - 80) & 511)]) + ((0.106570639f * fVec63[((IOTA - 79) & 511)]) + ((0.120151371f * fVec63[((IOTA - 78) & 511)]) + ((0.0897549391f * fVec63[((IOTA - 77) & 511)]) + ((0.00610370189f * fVec63[((IOTA - 68) & 511)]) + ((0.0103152562f * fVec63[((IOTA - 66) & 511)]) + (0.0100405896f * fVec63[((IOTA - 67) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000885036774f * ((((((fVec63[((IOTA - 146) & 511)] + fVec63[((IOTA - 244) & 511)]) + fVec63[((IOTA - 245) & 511)]) - fVec63[((IOTA - 331) & 511)]) - fVec63[((IOTA - 443) & 511)]) + fVec63[((IOTA - 487) & 511)]) + fVec63[((IOTA - 511) & 511)]))))) : (iSlow146 ? (((0.000488296151f * (((((fVec62[((IOTA - 418) & 511)] - fVec62[((IOTA - 422) & 511)]) - fVec62[((IOTA - 438) & 511)]) + fVec62[((IOTA - 449) & 511)]) + fVec62[((IOTA - 475) & 511)]) - fVec62[((IOTA - 506) & 511)])) + ((0.000335703604f * ((((((((((((((((fVec62[((IOTA - 157) & 511)] - fVec62[((IOTA - 201) & 511)]) - fVec62[((IOTA - 255) & 511)]) - fVec62[((IOTA - 265) & 511)]) + fVec62[((IOTA - 302) & 511)]) + fVec62[((IOTA - 305) & 511)]) - fVec62[((IOTA - 360) & 511)]) + fVec62[((IOTA - 382) & 511)]) + fVec62[((IOTA - 394) & 511)]) + fVec62[((IOTA - 419) & 511)]) - fVec62[((IOTA - 430) & 511)]) - fVec62[((IOTA - 434) & 511)]) - fVec62[((IOTA - 442) & 511)]) + fVec62[((IOTA - 481) & 511)]) + fVec62[((IOTA - 488) & 511)]) - fVec62[((IOTA - 502) & 511)]) - fVec62[((IOTA - 504) & 511)])) + ((0.000305185094f * ((fVec62[((IOTA - 483) & 511)] - (((((((fVec62[((IOTA - 174) & 511)] + fVec62[((IOTA - 235) & 511)]) - fVec62[((IOTA - 357) & 511)]) - fVec62[((IOTA - 365) & 511)]) + fVec62[((IOTA - 391) & 511)]) + fVec62[((IOTA - 424) & 511)]) + fVec62[((IOTA - 426) & 511)]) - fVec62[((IOTA - 480) & 511)])) - fVec62[((IOTA - 503) & 511)])) + ((0.000457777642f * ((((((((((((fVec62[((IOTA - 8) & 511)] + fVec62[((IOTA - 27) & 511)]) + fVec62[((IOTA - 232) & 511)]) - fVec62[((IOTA - 236) & 511)]) - fVec62[((IOTA - 239) & 511)]) - fVec62[((IOTA - 390) & 511)]) + fVec62[((IOTA - 403) & 511)]) - fVec62[((IOTA - 407) & 511)]) - fVec62[((IOTA - 431) & 511)]) - fVec62[((IOTA - 445) & 511)]) - fVec62[((IOTA - 447) & 511)]) - fVec62[((IOTA - 499) & 511)]) - fVec62[((IOTA - 500) & 511)])) + ((0.000366222113f * (((((((((fVec62[((IOTA - 154) & 511)] + fVec62[((IOTA - 185) & 511)]) + fVec62[((IOTA - 196) & 511)]) + fVec62[((IOTA - 280) & 511)]) + fVec62[((IOTA - 395) & 511)]) - fVec62[((IOTA - 429) & 511)]) + fVec62[((IOTA - 464) & 511)]) + fVec62[((IOTA - 482) & 511)]) + fVec62[((IOTA - 489) & 511)]) - fVec62[((IOTA - 497) & 511)])) + ((0.000244148076f * (((((((((((fVec62[((IOTA - 202) & 511)] - fVec62[((IOTA - 250) & 511)]) - fVec62[((IOTA - 263) & 511)]) + fVec62[((IOTA - 328) & 511)]) + fVec62[((IOTA - 330) & 511)]) + fVec62[((IOTA - 331) & 511)]) - fVec62[((IOTA - 369) & 511)]) + fVec62[((IOTA - 387) & 511)]) + fVec62[((IOTA - 393) & 511)]) - fVec62[((IOTA - 425) & 511)]) - fVec62[((IOTA - 465) & 511)]) - fVec62[((IOTA - 496) & 511)])) + ((0.000152592547f * ((((((((((fVec62[((IOTA - 173) & 511)] - fVec62[((IOTA - 254) & 511)]) - fVec62[((IOTA - 343) & 511)]) + fVec62[((IOTA - 345) & 511)]) - fVec62[((IOTA - 368) & 511)]) - fVec62[((IOTA - 379) & 511)]) - fVec62[((IOTA - 415) & 511)]) - fVec62[((IOTA - 453) & 511)]) - fVec62[((IOTA - 492) & 511)]) - fVec62[((IOTA - 493) & 511)]) - fVec62[((IOTA - 495) & 511)])) + ((0.000122074038f * ((((((((((((((fVec62[((IOTA - 152) & 511)] - fVec62[((IOTA - 234) & 511)]) + fVec62[((IOTA - 261) & 511)]) + fVec62[((IOTA - 266) & 511)]) + fVec62[((IOTA - 332) & 511)]) + fVec62[((IOTA - 335) & 511)]) - fVec62[((IOTA - 344) & 511)]) - fVec62[((IOTA - 358) & 511)]) - fVec62[((IOTA - 362) & 511)]) - fVec62[((IOTA - 373) & 511)]) - fVec62[((IOTA - 388) & 511)]) + fVec62[((IOTA - 402) & 511)]) - fVec62[((IOTA - 414) & 511)]) - fVec62[((IOTA - 437) & 511)]) - fVec62[((IOTA - 494) & 511)])) + ((0.000213629566f * ((((((((((fVec62[((IOTA - 170) & 511)] + fVec62[((IOTA - 233) & 511)]) + fVec62[((IOTA - 253) & 511)]) - fVec62[((IOTA - 339) & 511)]) - fVec62[((IOTA - 361) & 511)]) - fVec62[((IOTA - 370) & 511)]) + fVec62[((IOTA - 381) & 511)]) + fVec62[((IOTA - 413) & 511)]) - fVec62[((IOTA - 443) & 511)]) + fVec62[((IOTA - 487) & 511)]) + fVec62[((IOTA - 490) & 511)])) + ((0.000823999755f * (fVec62[((IOTA - 282) & 511)] + fVec62[((IOTA - 478) & 511)])) + ((0.000854518265f * ((fVec62[((IOTA - 207) & 511)] + fVec62[((IOTA - 259) & 511)]) + fVec62[((IOTA - 476) & 511)])) + ((0.000610370189f * (((((((fVec62[((IOTA - 276) & 511)] + fVec62[((IOTA - 281) & 511)]) + fVec62[((IOTA - 306) & 511)]) + fVec62[((IOTA - 386) & 511)]) + fVec62[((IOTA - 398) & 511)]) + fVec62[((IOTA - 412) & 511)]) - fVec62[((IOTA - 432) & 511)]) - fVec62[((IOTA - 473) & 511)])) + ((0.000946073793f * (((((fVec62[((IOTA - 283) & 511)] + fVec62[((IOTA - 292) & 511)]) + fVec62[((IOTA - 296) & 511)]) + fVec62[((IOTA - 299) & 511)]) - fVec62[((IOTA - 375) & 511)]) - fVec62[((IOTA - 471) & 511)])) + ((0.000671407208f * (((((fVec62[((IOTA - 230) & 511)] - fVec62[((IOTA - 247) & 511)]) + fVec62[((IOTA - 267) & 511)]) + fVec62[((IOTA - 346) & 511)]) + fVec62[((IOTA - 463) & 511)]) - fVec62[((IOTA - 469) & 511)])) + ((0.000885036774f * ((fVec62[((IOTA - 326) & 511)] - fVec62[((IOTA - 377) & 511)]) - fVec62[((IOTA - 467) & 511)])) + ((0.000640888698f * (((fVec62[((IOTA - 48) & 511)] + fVec62[((IOTA - 192) & 511)]) + fVec62[((IOTA - 397) & 511)]) + fVec62[((IOTA - 462) & 511)])) + ((0.000396740623f * (fVec62[((IOTA - 461) & 511)] - (((fVec62[((IOTA - 96) & 511)] + fVec62[((IOTA - 359) & 511)]) + fVec62[((IOTA - 389) & 511)]) + fVec62[((IOTA - 427) & 511)]))) + ((0.00164799951f * ((fVec62[((IOTA - 311) & 511)] + fVec62[((IOTA - 323) & 511)]) - fVec62[((IOTA - 455) & 511)])) + ((0.00103762932f * (fVec62[((IOTA - 300) & 511)] + fVec62[((IOTA - 450) & 511)])) + ((0.000274666585f * ((((((fVec62[((IOTA - 39) & 511)] + fVec62[((IOTA - 210) & 511)]) + fVec62[((IOTA - 251) & 511)]) + fVec62[((IOTA - 257) & 511)]) + fVec62[((IOTA - 366) & 511)]) - fVec62[((IOTA - 421) & 511)]) - fVec62[((IOTA - 444) & 511)])) + ((0.000732444227f * (((fVec62[((IOTA - 200) & 511)] + fVec62[((IOTA - 384) & 511)]) + fVec62[((IOTA - 404) & 511)]) - fVec62[((IOTA - 439) & 511)])) + ((0.0012817774f * (fVec62[((IOTA - 354) & 511)] - ((((fVec62[((IOTA - 38) & 511)] - fVec62[((IOTA - 40) & 511)]) + fVec62[((IOTA - 213) & 511)]) - fVec62[((IOTA - 228) & 511)]) - fVec62[((IOTA - 350) & 511)]))) + ((0.00112918485f * ((((((fVec62[((IOTA - 3) & 511)] - fVec62[((IOTA - 9) & 511)]) + fVec62[((IOTA - 80) & 511)]) + fVec62[((IOTA - 227) & 511)]) + fVec62[((IOTA - 268) & 511)]) + fVec62[((IOTA - 275) & 511)]) + fVec62[((IOTA - 351) & 511)])) + ((0.00149540696f * ((((fVec62[((IOTA - 285) & 511)] + fVec62[((IOTA - 294) & 511)]) + fVec62[((IOTA - 320) & 511)]) + fVec62[((IOTA - 321) & 511)]) + fVec62[((IOTA - 349) & 511)])) + ((0.00119022187f * ((fVec62[((IOTA - 288) & 511)] + fVec62[((IOTA - 309) & 511)]) + fVec62[((IOTA - 347) & 511)])) + ((0.00131229591f * (fVec62[((IOTA - 295) & 511)] + fVec62[((IOTA - 325) & 511)])) + ((0.00155644398f * (fVec62[((IOTA - 319) & 511)] + fVec62[((IOTA - 322) & 511)])) + ((0.00180059206f * fVec62[((IOTA - 317) & 511)]) + ((0.00167851802f * (fVec62[((IOTA - 312) & 511)] + fVec62[((IOTA - 316) & 511)])) + ((0.00134281442f * fVec62[((IOTA - 314) & 511)]) + ((0.00143436994f * (((fVec62[((IOTA - 133) & 511)] + fVec62[((IOTA - 164) & 511)]) - fVec62[((IOTA - 244) & 511)]) + fVec62[((IOTA - 310) & 511)])) + ((0.00152592547f * ((fVec62[((IOTA - 32) & 511)] + fVec62[((IOTA - 273) & 511)]) + fVec62[((IOTA - 287) & 511)])) + ((0.00125125889f * (fVec62[((IOTA - 21) & 511)] + fVec62[((IOTA - 284) & 511)])) + ((0.00140385143f * (fVec62[((IOTA - 110) & 511)] - fVec62[((IOTA - 242) & 511)])) + ((0.00100711081f * (fVec62[((IOTA - 226) & 511)] + fVec62[((IOTA - 229) & 511)])) + ((0.00183111057f * ((fVec62[((IOTA - 149) & 511)] + fVec62[((IOTA - 194) & 511)]) + fVec62[((IOTA - 224) & 511)])) + ((0.00299081393f * fVec62[((IOTA - 222) & 511)]) + ((0.00277718436f * fVec62[((IOTA - 221) & 511)]) + ((0.0025940733f * (((fVec62[((IOTA - 199) & 511)] + fVec62[((IOTA - 206) & 511)]) + fVec62[((IOTA - 219) & 511)]) + fVec62[((IOTA - 220) & 511)])) + ((0.00262459181f * (fVec62[((IOTA - 193) & 511)] + fVec62[((IOTA - 218) & 511)])) + ((0.0022583697f * fVec62[((IOTA - 217) & 511)]) + ((0.00402844325f * (fVec62[((IOTA - 45) & 511)] + fVec62[((IOTA - 205) & 511)])) + ((0.00375377666f * fVec62[((IOTA - 204) & 511)]) + ((0.00189214759f * fVec62[((IOTA - 203) & 511)]) + ((0.00265511032f * fVec62[((IOTA - 197) & 511)]) + ((0.00253303628f * (fVec62[((IOTA - 150) & 511)] - fVec62[((IOTA - 191) & 511)])) + ((0.00238044374f * fVec62[((IOTA - 187) & 511)]) + ((0.00241096225f * (fVec62[((IOTA - 43) & 511)] - fVec62[((IOTA - 181) & 511)])) + ((0.00234992523f * fVec62[((IOTA - 169) & 511)]) + ((0.00531022064f * fVec62[((IOTA - 168) & 511)]) + ((0.00708029419f * (fVec62[((IOTA - 71) & 511)] + fVec62[((IOTA - 167) & 511)])) + ((0.00643940549f * fVec62[((IOTA - 166) & 511)]) + ((0.00363170262f * fVec62[((IOTA - 165) & 511)]) + ((0.00329599902f * ((fVec62[((IOTA - 140) & 511)] - fVec62[((IOTA - 160) & 511)]) - fVec62[((IOTA - 161) & 511)])) + ((0.00177007355f * (fVec62[((IOTA - 41) & 511)] + fVec62[((IOTA - 148) & 511)])) + ((0.00274666585f * fVec62[((IOTA - 147) & 511)]) + ((0.00589007232f * fVec62[((IOTA - 146) & 511)]) + ((0.0077517014f * fVec62[((IOTA - 145) & 511)]) + ((0.0101626636f * fVec62[((IOTA - 144) & 511)]) + ((0.011200293f * fVec62[((IOTA - 143) & 511)]) + ((0.0109866634f * fVec62[((IOTA - 142) & 511)]) + ((0.0074159978f * fVec62[((IOTA - 141) & 511)]) + ((0.0144657735f * fVec62[((IOTA - 131) & 511)]) + ((0.00482192449f * fVec62[((IOTA - 130) & 511)]) + ((0.00964384899f * (fVec62[((IOTA - 29) & 511)] - fVec62[((IOTA - 128) & 511)])) + ((0.00207525864f * fVec62[((IOTA - 119) & 511)]) + ((0.00805688649f * fVec62[((IOTA - 118) & 511)]) + ((0.0108035523f * fVec62[((IOTA - 117) & 511)]) + ((0.0150761437f * fVec62[((IOTA - 116) & 511)]) + ((0.0245979186f * fVec62[((IOTA - 115) & 511)]) + ((0.0250556972f * fVec62[((IOTA - 114) & 511)]) + ((0.0185552537f * fVec62[((IOTA - 113) & 511)]) + ((0.0119022187f * fVec62[((IOTA - 112) & 511)]) + ((0.0148014771f * fVec62[((IOTA - 132) & 511)]) + ((0.00692770164f * fVec62[((IOTA - 105) & 511)]) + ((0.0233161412f * fVec62[((IOTA - 104) & 511)]) + ((0.0252693258f * fVec62[((IOTA - 103) & 511)]) + ((0.00930814538f * fVec62[((IOTA - 102) & 511)]) + ((0.00280770287f * (fVec62[((IOTA - 6) & 511)] + fVec62[((IOTA - 98) & 511)])) + ((0.0116275521f * fVec62[((IOTA - 97) & 511)]) + ((0.0237128828f * fVec62[((IOTA - 87) & 511)]) + ((0.0511490218f * fVec62[((IOTA - 86) & 511)]) + ((0.0541703552f * fVec62[((IOTA - 85) & 511)]) + ((0.225592822f * fVec62[((IOTA - 79) & 511)]) + ((0.28720969f * fVec62[((IOTA - 78) & 511)]) + ((0.172521129f * fVec62[((IOTA - 77) & 511)]) + ((0.0494399853f * fVec62[((IOTA - 76) & 511)]) + ((0.012817774f * fVec62[((IOTA - 75) & 511)]) + ((0.0230719931f * fVec62[((IOTA - 74) & 511)]) + ((0.0274361409f * fVec62[((IOTA - 73) & 511)]) + ((0.0195623655f * fVec62[((IOTA - 72) & 511)]) + ((0.00231940672f * fVec62[((IOTA - 64) & 511)]) + ((0.00201422162f * (fVec62[((IOTA - 42) & 511)] + fVec62[((IOTA - 63) & 511)])) + ((0.00314340647f * fVec62[((IOTA - 58) & 511)]) + ((0.0102237007f * fVec62[((IOTA - 57) & 511)]) + ((0.0134891812f * fVec62[((IOTA - 56) & 511)]) + ((0.0110782189f * fVec62[((IOTA - 55) & 511)]) + ((0.00408948027f * fVec62[((IOTA - 54) & 511)]) + ((0.0035401471f * fVec62[((IOTA - 47) & 511)]) + ((0.00445570238f * fVec62[((IOTA - 46) & 511)]) + ((0.00311288796f * fVec62[((IOTA - 44) & 511)]) + ((0.006469924f * fVec62[((IOTA - 31) & 511)]) + ((0.009704886f * fVec62[((IOTA - 30) & 511)]) + (((0.00286873989f * fVec62[((IOTA - 5) & 511)]) + ((0.00222785119f * fVec62[((IOTA - 4) & 511)]) + (((0.0042115543f * fVec62[((IOTA - 17) & 511)]) + ((((0.0019226661f * (fVec62[((IOTA - 7) & 511)] - fVec62[((IOTA - 14) & 511)])) + (0.00210577715f * fVec62[((IOTA - 16) & 511)])) + (0.00555436872f * fVec62[((IOTA - 18) & 511)])) + (0.00564592425f * fVec62[((IOTA - 19) & 511)]))) + (0.00418103579f * fVec62[((IOTA - 20) & 511)])))) + (0.0061342204f * fVec62[((IOTA - 28) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000701925717f * (((fVec62[((IOTA - 249) & 511)] - fVec62[((IOTA - 411) & 511)]) + fVec62[((IOTA - 508) & 511)]) + fVec62[((IOTA - 510) & 511)])) + ((0.000762962736f * ((((((((((fVec62[((IOTA - 153) & 511)] + fVec62[((IOTA - 246) & 511)]) - fVec62[((IOTA - 289) & 511)]) - fVec62[((IOTA - 297) & 511)]) - fVec62[((IOTA - 301) & 511)]) - fVec62[((IOTA - 385) & 511)]) - fVec62[((IOTA - 452) & 511)]) + fVec62[((IOTA - 466) & 511)]) + fVec62[((IOTA - 468) & 511)]) + fVec62[((IOTA - 470) & 511)]) + fVec62[((IOTA - 509) & 511)])) + ((0.00057985168f * (((fVec62[((IOTA - 212) & 511)] + fVec62[((IOTA - 433) & 511)]) + fVec62[((IOTA - 441) & 511)]) + fVec62[((IOTA - 507) & 511)])) + ((0.000427259132f * ((((((((fVec62[((IOTA - 264) & 511)] - fVec62[((IOTA - 399) & 511)]) - fVec62[((IOTA - 410) & 511)]) - fVec62[((IOTA - 417) & 511)]) + fVec62[((IOTA - 423) & 511)]) + fVec62[((IOTA - 428) & 511)]) + fVec62[((IOTA - 498) & 511)]) + fVec62[((IOTA - 501) & 511)]) + fVec62[((IOTA - 505) & 511)])) + ((3.05185094e-05f * ((((((((((fVec62[((IOTA - 2) & 511)] - fVec62[((IOTA - 195) & 511)]) + fVec62[((IOTA - 208) & 511)]) + fVec62[((IOTA - 209) & 511)]) + fVec62[((IOTA - 211) & 511)]) - fVec62[((IOTA - 333) & 511)]) + fVec62[((IOTA - 392) & 511)]) - fVec62[((IOTA - 406) & 511)]) - fVec62[((IOTA - 420) & 511)]) - fVec62[((IOTA - 486) & 511)]) - fVec62[((IOTA - 491) & 511)])) + ((9.15555283e-05f * ((((((((((((fVec62[((IOTA - 15) & 511)] - fVec62[((IOTA - 279) & 511)]) - fVec62[((IOTA - 303) & 511)]) - fVec62[((IOTA - 304) & 511)]) - fVec62[((IOTA - 334) & 511)]) + fVec62[((IOTA - 342) & 511)]) + fVec62[((IOTA - 363) & 511)]) - fVec62[((IOTA - 364) & 511)]) - fVec62[((IOTA - 380) & 511)]) + fVec62[((IOTA - 409) & 511)]) - fVec62[((IOTA - 416) & 511)]) + fVec62[((IOTA - 448) & 511)]) - fVec62[((IOTA - 484) & 511)])) + ((0.000518814661f * (((((((((fVec62[((IOTA - 237) & 511)] - fVec62[((IOTA - 252) & 511)]) - fVec62[((IOTA - 260) & 511)]) - fVec62[((IOTA - 290) & 511)]) - fVec62[((IOTA - 327) & 511)]) + fVec62[((IOTA - 374) & 511)]) - fVec62[((IOTA - 396) & 511)]) + fVec62[((IOTA - 408) & 511)]) + fVec62[((IOTA - 458) & 511)]) - fVec62[((IOTA - 479) & 511)])) + ((0.000976592302f * ((fVec62[((IOTA - 241) & 511)] - fVec62[((IOTA - 308) & 511)]) - fVec62[((IOTA - 477) & 511)])) + ((6.10370189e-05f * (((((fVec62[((IOTA - 401) & 511)] - ((((((((fVec62[((IOTA - 215) & 511)] - fVec62[((IOTA - 262) & 511)]) + fVec62[((IOTA - 336) & 511)]) - fVec62[((IOTA - 337) & 511)]) - fVec62[((IOTA - 341) & 511)]) + fVec62[((IOTA - 367) & 511)]) - fVec62[((IOTA - 371) & 511)]) + fVec62[((IOTA - 372) & 511)]) + fVec62[((IOTA - 400) & 511)])) + fVec62[((IOTA - 435) & 511)]) - fVec62[((IOTA - 436) & 511)]) + fVec62[((IOTA - 459) & 511)]) + fVec62[((IOTA - 474) & 511)])) + ((0.000915555283f * (fVec62[((IOTA - 188) & 511)] + fVec62[((IOTA - 472) & 511)])) + ((0.00115970336f * ((((fVec62[((IOTA - 1) & 511)] - fVec62[((IOTA - 225) & 511)]) - fVec62[((IOTA - 355) & 511)]) - fVec62[((IOTA - 451) & 511)]) + fVec62[((IOTA - 457) & 511)])) + ((0.001617481f * (fVec62[((IOTA - 243) & 511)] + fVec62[((IOTA - 456) & 511)])) + ((0.00106814783f * ((fVec62[((IOTA - 245) & 511)] + fVec62[((IOTA - 376) & 511)]) + fVec62[((IOTA - 454) & 511)])) + ((0.000793481246f * (((((fVec62[((IOTA - 248) & 511)] - fVec62[((IOTA - 258) & 511)]) - fVec62[((IOTA - 298) & 511)]) - fVec62[((IOTA - 307) & 511)]) - fVec62[((IOTA - 356) & 511)]) + fVec62[((IOTA - 440) & 511)])) + ((0.000183111057f * (((((fVec62[((IOTA - 256) & 511)] - fVec62[((IOTA - 277) & 511)]) - fVec62[((IOTA - 329) & 511)]) + fVec62[((IOTA - 338) & 511)]) + fVec62[((IOTA - 340) & 511)]) - fVec62[((IOTA - 460) & 511)])) + ((0.00122074038f * ((fVec62[((IOTA - 65) & 511)] - fVec62[((IOTA - 151) & 511)]) - fVec62[((IOTA - 353) & 511)])) + ((0.00109866634f * (fVec62[((IOTA - 214) & 511)] - fVec62[((IOTA - 352) & 511)])) + ((0.00146488845f * (((((fVec62[((IOTA - 171) & 511)] - fVec62[((IOTA - 269) & 511)]) - fVec62[((IOTA - 274) & 511)]) - fVec62[((IOTA - 313) & 511)]) - fVec62[((IOTA - 315) & 511)]) - fVec62[((IOTA - 348) & 511)])) + ((0.00158696249f * (((fVec62[((IOTA - 180) & 511)] - fVec62[((IOTA - 272) & 511)]) - fVec62[((IOTA - 286) & 511)]) - fVec62[((IOTA - 324) & 511)])) + ((0.00170903653f * (((fVec62[((IOTA - 62) & 511)] - fVec62[((IOTA - 270) & 511)]) - fVec62[((IOTA - 271) & 511)]) - fVec62[((IOTA - 318) & 511)])) + ((0.00137333293f * ((fVec62[((IOTA - 172) & 511)] - fVec62[((IOTA - 216) & 511)]) - fVec62[((IOTA - 293) & 511)])) + ((0.00268562883f * (fVec62[((IOTA - 22) & 511)] - fVec62[((IOTA - 223) & 511)])) + ((0.00384533219f * (fVec62[((IOTA - 179) & 511)] - fVec62[((IOTA - 198) & 511)])) + ((0.00436414685f * fVec62[((IOTA - 190) & 511)]) + ((0.00411999878f * (fVec62[((IOTA - 53) & 511)] + fVec62[((IOTA - 189) & 511)])) + ((0.003234962f * (fVec62[((IOTA - 37) & 511)] - fVec62[((IOTA - 186) & 511)])) + ((0.00347911008f * ((fVec62[((IOTA - 12) & 511)] + fVec62[((IOTA - 88) & 511)]) + fVec62[((IOTA - 184) & 511)])) + ((0.00527970213f * fVec62[((IOTA - 183) & 511)]) + ((0.00424207281f * fVec62[((IOTA - 182) & 511)]) + ((0.0090334788f * fVec62[((IOTA - 178) & 511)]) + ((0.0129093295f * fVec62[((IOTA - 177) & 511)]) + ((0.0113528855f * fVec62[((IOTA - 176) & 511)]) + ((0.00524918362f * fVec62[((IOTA - 175) & 511)]) + ((0.00332651753f * fVec62[((IOTA - 159) & 511)]) + ((0.0019531846f * (fTemp63 + fVec62[((IOTA - 158) & 511)])) + ((0.00247199927f * (fVec62[((IOTA - 10) & 511)] - fVec62[((IOTA - 156) & 511)])) + ((0.0102542192f * fVec62[((IOTA - 138) & 511)]) + ((0.0191351064f * fVec62[((IOTA - 137) & 511)]) + ((0.0057985168f * (fVec62[((IOTA - 34) & 511)] + fVec62[((IOTA - 129) & 511)])) + ((0.0246894751f * fVec62[((IOTA - 136) & 511)]) + ((0.0247199927f * fVec62[((IOTA - 135) & 511)]) + ((0.0149235511f * fVec62[((IOTA - 134) & 511)]) + ((0.00875881221f * fVec62[((IOTA - 127) & 511)]) + ((0.00698873866f * fVec62[((IOTA - 126) & 511)]) + ((0.0126346629f * fVec62[((IOTA - 125) & 511)]) + ((0.021271402f * fVec62[((IOTA - 124) & 511)]) + ((0.0250251777f * fVec62[((IOTA - 123) & 511)]) + ((0.0213934761f * fVec62[((IOTA - 122) & 511)]) + ((0.0147709586f * fVec62[((IOTA - 121) & 511)]) + ((0.00723288674f * fVec62[((IOTA - 120) & 511)]) + ((0.00427259132f * (fVec62[((IOTA - 89) & 511)] - fVec62[((IOTA - 111) & 511)])) + ((0.0045167394f * fVec62[((IOTA - 109) & 511)]) + ((0.0169072542f * fVec62[((IOTA - 108) & 511)]) + ((0.0301217698f * fVec62[((IOTA - 107) & 511)]) + ((0.0200201422f * fVec62[((IOTA - 106) & 511)]) + ((0.019287698f * fVec62[((IOTA - 101) & 511)]) + ((0.0358592495f * fVec62[((IOTA - 100) & 511)]) + ((0.0268562883f * fVec62[((IOTA - 99) & 511)]) + ((0.00216681417f * ((fVec62[((IOTA - 139) & 511)] - fVec62[((IOTA - 155) & 511)]) + fVec62[((IOTA - 162) & 511)])) + ((0.0398876928f * fVec62[((IOTA - 95) & 511)]) + ((0.0617389455f * fVec62[((IOTA - 94) & 511)]) + ((0.0697042793f * fVec62[((IOTA - 93) & 511)]) + ((0.0415356904f * fVec62[((IOTA - 92) & 511)]) + ((0.021210365f * fVec62[((IOTA - 91) & 511)]) + ((0.0235908087f * fVec62[((IOTA - 84) & 511)]) + ((0.145451218f * fVec62[((IOTA - 83) & 511)]) + ((0.252784818f * fVec62[((IOTA - 82) & 511)]) + ((0.210333571f * fVec62[((IOTA - 81) & 511)]) + ((0.00296029542f * fVec62[((IOTA - 90) & 511)]) + ((0.00479140598f * fVec62[((IOTA - 70) & 511)]) + ((0.0120548112f * fVec62[((IOTA - 69) & 511)]) + ((0.0138859218f * fVec62[((IOTA - 68) & 511)]) + ((0.0114139225f * fVec62[((IOTA - 67) & 511)]) + ((0.00662251655f * fVec62[((IOTA - 66) & 511)]) + ((0.00592059083f * fVec62[((IOTA - 61) & 511)]) + ((0.00726340525f * fVec62[((IOTA - 60) & 511)]) + ((0.00381481368f * fVec62[((IOTA - 59) & 511)]) + ((0.00991851557f * fVec62[((IOTA - 52) & 511)]) + ((0.011322367f * fVec62[((IOTA - 51) & 511)]) + ((0.00869777519f * fVec62[((IOTA - 50) & 511)]) + ((0.00393688772f * fVec62[((IOTA - 49) & 511)]) + ((0.00518814661f * fVec62[((IOTA - 36) & 511)]) + ((0.00631733146f * fVec62[((IOTA - 35) & 511)]) + ((0.00305185094f * (fVec62[((IOTA - 13) & 511)] + fVec62[((IOTA - 33) & 511)])) + ((0.00512710959f * fVec62[((IOTA - 26) & 511)]) + ((0.00857570115f * fVec62[((IOTA - 25) & 511)]) + ((0.00891140476f * fVec62[((IOTA - 24) & 511)]) + ((0.00326548051f * fVec62[((IOTA - 11) & 511)]) + (0.00653096102f * fVec62[((IOTA - 23) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00054933317f * (((((((((fVec62[((IOTA - 163) & 511)] - fVec62[((IOTA - 231) & 511)]) + fVec62[((IOTA - 238) & 511)]) + fVec62[((IOTA - 240) & 511)]) - fVec62[((IOTA - 291) & 511)]) + fVec62[((IOTA - 378) & 511)]) - fVec62[((IOTA - 383) & 511)]) - fVec62[((IOTA - 405) & 511)]) + fVec62[((IOTA - 446) & 511)]) + fVec62[((IOTA - 511) & 511)])))) : (((0.000457777642f * ((((((((((fVec61[((IOTA - 147) & 511)] - fVec61[((IOTA - 268) & 511)]) + fVec61[((IOTA - 284) & 511)]) + fVec61[((IOTA - 302) & 511)]) + fVec61[((IOTA - 355) & 511)]) - fVec61[((IOTA - 442) & 511)]) + fVec61[((IOTA - 464) & 511)]) - fVec61[((IOTA - 482) & 511)]) - fVec61[((IOTA - 497) & 511)]) - fVec61[((IOTA - 498) & 511)]) - fVec61[((IOTA - 511) & 511)])) + ((3.05185094e-05f * ((((((((((((fVec61[((IOTA - 196) & 511)] + fVec61[((IOTA - 270) & 511)]) - fVec61[((IOTA - 283) & 511)]) - fVec61[((IOTA - 290) & 511)]) + fVec61[((IOTA - 291) & 511)]) + fVec61[((IOTA - 357) & 511)]) + fVec61[((IOTA - 376) & 511)]) - fVec61[((IOTA - 386) & 511)]) - fVec61[((IOTA - 393) & 511)]) + fVec61[((IOTA - 408) & 511)]) - fVec61[((IOTA - 440) & 511)]) - fVec61[((IOTA - 473) & 511)]) + fVec61[((IOTA - 505) & 511)])) + ((0.000427259132f * (((((((fVec61[((IOTA - 31) & 511)] - fVec61[((IOTA - 280) & 511)]) - fVec61[((IOTA - 372) & 511)]) + fVec61[((IOTA - 432) & 511)]) + fVec61[((IOTA - 436) & 511)]) - fVec61[((IOTA - 467) & 511)]) - fVec61[((IOTA - 472) & 511)]) + fVec61[((IOTA - 502) & 511)])) + ((0.000213629566f * (((((((((((fVec61[((IOTA - 297) & 511)] - fVec61[((IOTA - 305) & 511)]) - fVec61[((IOTA - 306) & 511)]) - fVec61[((IOTA - 307) & 511)]) + fVec61[((IOTA - 348) & 511)]) + fVec61[((IOTA - 368) & 511)]) - fVec61[((IOTA - 392) & 511)]) + fVec61[((IOTA - 405) & 511)]) + fVec61[((IOTA - 406) & 511)]) + fVec61[((IOTA - 492) & 511)]) - fVec61[((IOTA - 494) & 511)]) + fVec61[((IOTA - 501) & 511)])) + ((0.000396740623f * (((((fVec61[((IOTA - 341) & 511)] + fVec61[((IOTA - 379) & 511)]) + fVec61[((IOTA - 419) & 511)]) + fVec61[((IOTA - 477) & 511)]) + fVec61[((IOTA - 484) & 511)]) - fVec61[((IOTA - 496) & 511)])) + ((0.00100711081f * (((fVec61[((IOTA - 322) & 511)] + fVec61[((IOTA - 334) & 511)]) + fVec61[((IOTA - 384) & 511)]) + fVec61[((IOTA - 486) & 511)])) + ((0.000183111057f * ((((((((((fVec61[((IOTA - 226) & 511)] + fVec61[((IOTA - 243) & 511)]) + fVec61[((IOTA - 274) & 511)]) + fVec61[((IOTA - 349) & 511)]) - fVec61[((IOTA - 375) & 511)]) + fVec61[((IOTA - 378) & 511)]) + fVec61[((IOTA - 402) & 511)]) - fVec61[((IOTA - 413) & 511)]) + fVec61[((IOTA - 427) & 511)]) - fVec61[((IOTA - 446) & 511)]) - fVec61[((IOTA - 479) & 511)])) + ((0.000305185094f * (((((((fVec61[((IOTA - 5) & 511)] + fVec61[((IOTA - 20) & 511)]) - fVec61[((IOTA - 242) & 511)]) + fVec61[((IOTA - 265) & 511)]) + fVec61[((IOTA - 369) & 511)]) + fVec61[((IOTA - 438) & 511)]) + fVec61[((IOTA - 465) & 511)]) + fVec61[((IOTA - 474) & 511)])) + ((0.000854518265f * ((((((((((fVec61[((IOTA - 15) & 511)] - fVec61[((IOTA - 197) & 511)]) - fVec61[((IOTA - 240) & 511)]) - fVec61[((IOTA - 252) & 511)]) + fVec61[((IOTA - 300) & 511)]) + fVec61[((IOTA - 321) & 511)]) + fVec61[((IOTA - 397) & 511)]) + fVec61[((IOTA - 423) & 511)]) - fVec61[((IOTA - 452) & 511)]) + fVec61[((IOTA - 459) & 511)]) - fVec61[((IOTA - 471) & 511)])) + ((0.00103762932f * ((((((fTemp62 + fVec61[((IOTA - 119) & 511)]) - fVec61[((IOTA - 235) & 511)]) + fVec61[((IOTA - 315) & 511)]) + fVec61[((IOTA - 366) & 511)]) + fVec61[((IOTA - 461) & 511)]) + fVec61[((IOTA - 488) & 511)])) + ((0.000793481246f * (((((((fVec61[((IOTA - 210) & 511)] - fVec61[((IOTA - 239) & 511)]) + fVec61[((IOTA - 301) & 511)]) + fVec61[((IOTA - 364) & 511)]) + fVec61[((IOTA - 396) & 511)]) + fVec61[((IOTA - 398) & 511)]) + fVec61[((IOTA - 421) & 511)]) + fVec61[((IOTA - 462) & 511)])) + ((0.000244148076f * ((((((fVec61[((IOTA - 287) & 511)] + fVec61[((IOTA - 346) & 511)]) + fVec61[((IOTA - 350) & 511)]) + fVec61[((IOTA - 356) & 511)]) + fVec61[((IOTA - 418) & 511)]) + fVec61[((IOTA - 451) & 511)]) + fVec61[((IOTA - 458) & 511)])) + ((0.0019531846f * ((fVec61[((IOTA - 217) & 511)] - fVec61[((IOTA - 204) & 511)]) - fVec61[((IOTA - 455) & 511)])) + ((0.00122074038f * (((fVec61[((IOTA - 4) & 511)] - fVec61[((IOTA - 227) & 511)]) + fVec61[((IOTA - 365) & 511)]) + fVec61[((IOTA - 450) & 511)])) + ((0.000274666585f * ((((fVec61[((IOTA - 347) & 511)] - fVec61[((IOTA - 391) & 511)]) + fVec61[((IOTA - 394) & 511)]) + fVec61[((IOTA - 431) & 511)]) - fVec61[((IOTA - 441) & 511)])) + ((0.000152592547f * ((((((((((fVec61[((IOTA - 257) & 511)] - fVec61[((IOTA - 266) & 511)]) - fVec61[((IOTA - 269) & 511)]) - fVec61[((IOTA - 304) & 511)]) + fVec61[((IOTA - 342) & 511)]) + fVec61[((IOTA - 345) & 511)]) - fVec61[((IOTA - 358) & 511)]) + fVec61[((IOTA - 404) & 511)]) + fVec61[((IOTA - 410) & 511)]) - fVec61[((IOTA - 416) & 511)]) + fVec61[((IOTA - 439) & 511)])) + ((0.000366222113f * (((((((fVec61[((IOTA - 250) & 511)] - fVec61[((IOTA - 251) & 511)]) + fVec61[((IOTA - 298) & 511)]) + fVec61[((IOTA - 351) & 511)]) - fVec61[((IOTA - 359) & 511)]) - fVec61[((IOTA - 390) & 511)]) + fVec61[((IOTA - 401) & 511)]) + fVec61[((IOTA - 437) & 511)])) + ((0.00054933317f * (((fVec61[((IOTA - 385) & 511)] + fVec61[((IOTA - 400) & 511)]) + fVec61[((IOTA - 425) & 511)]) + fVec61[((IOTA - 434) & 511)])) + ((0.000518814661f * (((fVec61[((IOTA - 367) & 511)] - ((fVec61[((IOTA - 14) & 511)] + fVec61[((IOTA - 63) & 511)]) - fVec61[((IOTA - 352) & 511)])) - fVec61[((IOTA - 374) & 511)]) + fVec61[((IOTA - 433) & 511)])) + (((0.000915555283f * (fVec61[((IOTA - 325) & 511)] + fVec61[((IOTA - 338) & 511)])) + ((0.000976592302f * ((((fVec61[((IOTA - 26) & 511)] + fVec61[((IOTA - 133) & 511)]) + fVec61[((IOTA - 209) & 511)]) + fVec61[((IOTA - 312) & 511)]) + fVec61[((IOTA - 313) & 511)])) + ((0.00198370311f * fVec61[((IOTA - 261) & 511)]) + ((0.00204474013f * (fVec61[((IOTA - 57) & 511)] + fVec61[((IOTA - 260) & 511)])) + ((0.001617481f * fVec61[((IOTA - 259) & 511)]) + ((0.00131229591f * (((fVec61[((IOTA - 207) & 511)] - fVec61[((IOTA - 231) & 511)]) + fVec61[((IOTA - 247) & 511)]) + fVec61[((IOTA - 248) & 511)])) + ((0.00231940672f * (fVec61[((IOTA - 46) & 511)] - fVec61[((IOTA - 229) & 511)])) + ((0.00222785119f * (fVec61[((IOTA - 30) & 511)] - fVec61[((IOTA - 228) & 511)])) + ((0.00244148076f * fVec61[((IOTA - 224) & 511)]) + ((0.00277718436f * (fVec61[((IOTA - 53) & 511)] + fVec61[((IOTA - 223) & 511)])) + ((0.00280770287f * fVec61[((IOTA - 222) & 511)]) + ((0.00268562883f * fVec61[((IOTA - 221) & 511)]) + ((0.00265511032f * ((fVec61[((IOTA - 218) & 511)] + fVec61[((IOTA - 219) & 511)]) + fVec61[((IOTA - 220) & 511)])) + ((0.0022583697f * fVec61[((IOTA - 212) & 511)]) + ((0.00167851802f * fVec61[((IOTA - 211) & 511)]) + ((0.00302133244f * (fVec61[((IOTA - 27) & 511)] - fVec61[((IOTA - 188) & 511)])) + ((0.00241096225f * (((fVec61[((IOTA - 16) & 511)] - fVec61[((IOTA - 66) & 511)]) - fVec61[((IOTA - 179) & 511)]) - fVec61[((IOTA - 185) & 511)])) + ((0.00814844202f * (fVec61[((IOTA - 73) & 511)] - fVec61[((IOTA - 176) & 511)])) + ((0.00207525864f * (fVec61[((IOTA - 3) & 511)] - fVec61[((IOTA - 173) & 511)])) + ((0.00405896176f * fVec61[((IOTA - 172) & 511)]) + ((0.00927762687f * fVec61[((IOTA - 171) & 511)]) + ((0.0114139225f * fVec61[((IOTA - 170) & 511)]) + ((0.009704886f * fVec61[((IOTA - 169) & 511)]) + ((0.00650044251f * fVec61[((IOTA - 168) & 511)]) + ((0.00381481368f * fVec61[((IOTA - 166) & 511)]) + ((0.0054933317f * fVec61[((IOTA - 158) & 511)]) + ((0.00512710959f * (fVec61[((IOTA - 72) & 511)] + fVec61[((IOTA - 157) & 511)])) + ((0.00408948027f * fVec61[((IOTA - 156) & 511)]) + ((0.00286873989f * fVec61[((IOTA - 155) & 511)]) + ((0.00341807306f * ((fVec61[((IOTA - 17) & 511)] - fVec61[((IOTA - 129) & 511)]) - fVec61[((IOTA - 149) & 511)])) + ((0.00518814661f * fVec61[((IOTA - 146) & 511)]) + ((0.0110782189f * fVec61[((IOTA - 145) & 511)]) + ((0.0152592547f * fVec61[((IOTA - 144) & 511)]) + ((0.0163884405f * fVec61[((IOTA - 143) & 511)]) + ((0.0133365886f * fVec61[((IOTA - 142) & 511)]) + ((0.00918607134f * fVec61[((IOTA - 141) & 511)]) + ((0.0124820704f * fVec61[((IOTA - 132) & 511)]) + ((0.0165105145f * fVec61[((IOTA - 131) & 511)]) + ((0.00979644153f * fVec61[((IOTA - 130) & 511)]) + ((0.00836207159f * fVec61[((IOTA - 118) & 511)]) + ((0.00952177495f * fVec61[((IOTA - 117) & 511)]) + ((0.0118106632f * fVec61[((IOTA - 116) & 511)]) + ((0.0282906592f * fVec61[((IOTA - 114) & 511)]) + ((0.0314951017f * fVec61[((IOTA - 113) & 511)]) + ((0.0186468102f * fVec61[((IOTA - 112) & 511)]) + ((0.00665303506f * fVec61[((IOTA - 111) & 511)]) + ((0.0367137678f * fVec61[((IOTA - 104) & 511)]) + ((0.0451368764f * fVec61[((IOTA - 103) & 511)]) + ((0.0299386587f * fVec61[((IOTA - 102) & 511)]) + ((0.00769066438f * fVec61[((IOTA - 88) & 511)]) + ((0.0301522873f * fVec61[((IOTA - 87) & 511)]) + ((0.0513626523f * fVec61[((IOTA - 86) & 511)]) + ((0.0394604318f * fVec61[((IOTA - 85) & 511)]) + ((0.0156254768f * fVec61[((IOTA - 84) & 511)]) + ((0.0415051728f * fVec61[((IOTA - 79) & 511)]) + ((0.232337415f * fVec61[((IOTA - 78) & 511)]) + ((0.29990539f * fVec61[((IOTA - 77) & 511)]) + ((0.203985721f * fVec61[((IOTA - 76) & 511)]) + ((0.0745872408f * fVec61[((IOTA - 75) & 511)]) + ((0.0161442924f * fVec61[((IOTA - 74) & 511)]) + ((0.00457777642f * fVec61[((IOTA - 56) & 511)]) + ((0.00576799829f * fVec61[((IOTA - 55) & 511)]) + ((0.0051576281f * fVec61[((IOTA - 54) & 511)]) + ((0.00439466536f * fVec61[((IOTA - 44) & 511)]) + ((0.00335703604f * fVec61[((IOTA - 43) & 511)]) + ((0.00360118411f * fVec61[((IOTA - 29) & 511)]) + ((0.00393688772f * fVec61[((IOTA - 28) & 511)]) + ((0.00238044374f * fVec61[((IOTA - 19) & 511)]) + ((0.00347911008f * fVec61[((IOTA - 18) & 511)]) + ((0.00210577715f * fVec61[((IOTA - 1) & 511)]) + (0.00247199927f * fVec61[((IOTA - 2) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000610370189f * ((((((fVec61[((IOTA - 327) & 511)] + fVec61[((IOTA - 353) & 511)]) - fVec61[((IOTA - 388) & 511)]) + fVec61[((IOTA - 420) & 511)]) - fVec61[((IOTA - 445) & 511)]) + fVec61[((IOTA - 447) & 511)]) + fVec61[((IOTA - 463) & 511)])))))))))))))))))))))) - ((((0.000335703604f * ((((((((fVec61[((IOTA - 6) & 511)] - fVec61[((IOTA - 370) & 511)]) + fVec61[((IOTA - 414) & 511)]) + fVec61[((IOTA - 415) & 511)]) - fVec61[((IOTA - 426) & 511)]) + fVec61[((IOTA - 495) & 511)]) + fVec61[((IOTA - 499) & 511)]) - fVec61[((IOTA - 504) & 511)]) + fVec61[((IOTA - 506) & 511)])) + ((0.000488296151f * (((((((((((fVec61[((IOTA - 64) & 511)] - fVec61[((IOTA - 154) & 511)]) + fVec61[((IOTA - 267) & 511)]) - fVec61[((IOTA - 278) & 511)]) + fVec61[((IOTA - 282) & 511)]) - fVec61[((IOTA - 310) & 511)]) + fVec61[((IOTA - 387) & 511)]) + fVec61[((IOTA - 389) & 511)]) - fVec61[((IOTA - 435) & 511)]) + fVec61[((IOTA - 480) & 511)]) - fVec61[((IOTA - 491) & 511)]) - fVec61[((IOTA - 503) & 511)])) + ((6.10370189e-05f * ((((((((fVec61[((IOTA - 206) & 511)] - fVec61[((IOTA - 271) & 511)]) + fVec61[((IOTA - 289) & 511)]) - fVec61[((IOTA - 371) & 511)]) - fVec61[((IOTA - 417) & 511)]) - fVec61[((IOTA - 429) & 511)]) + fVec61[((IOTA - 483) & 511)]) + fVec61[((IOTA - 493) & 511)]) + fVec61[((IOTA - 500) & 511)])) + ((0.000762962736f * (((fVec61[((IOTA - 9) & 511)] + fVec61[((IOTA - 37) & 511)]) - fVec61[((IOTA - 485) & 511)]) - fVec61[((IOTA - 490) & 511)])) + ((0.000946073793f * ((((((((((fVec61[((IOTA - 10) & 511)] - fVec61[((IOTA - 249) & 511)]) + fVec61[((IOTA - 255) & 511)]) - fVec61[((IOTA - 258) & 511)]) - fVec61[((IOTA - 276) & 511)]) - fVec61[((IOTA - 314) & 511)]) - fVec61[((IOTA - 319) & 511)]) - fVec61[((IOTA - 330) & 511)]) - fVec61[((IOTA - 331) & 511)]) - fVec61[((IOTA - 381) & 511)]) - fVec61[((IOTA - 489) & 511)])) + ((0.00106814783f * (((((fVec61[((IOTA - 65) & 511)] - fVec61[((IOTA - 245) & 511)]) + fVec61[((IOTA - 253) & 511)]) - fVec61[((IOTA - 324) & 511)]) - fVec61[((IOTA - 337) & 511)]) - fVec61[((IOTA - 487) & 511)])) + ((9.15555283e-05f * ((((((((((fVec61[((IOTA - 272) & 511)] + fVec61[((IOTA - 273) & 511)]) - fVec61[((IOTA - 292) & 511)]) - fVec61[((IOTA - 293) & 511)]) - fVec61[((IOTA - 294) & 511)]) - fVec61[((IOTA - 295) & 511)]) - fVec61[((IOTA - 303) & 511)]) - fVec61[((IOTA - 407) & 511)]) - fVec61[((IOTA - 409) & 511)]) - fVec61[((IOTA - 428) & 511)]) - fVec61[((IOTA - 478) & 511)])) + ((0.00112918485f * (((((((fVec61[((IOTA - 35) & 511)] - fVec61[((IOTA - 165) & 511)]) + fVec61[((IOTA - 193) & 511)]) + fVec61[((IOTA - 234) & 511)]) - fVec61[((IOTA - 323) & 511)]) - fVec61[((IOTA - 382) & 511)]) - fVec61[((IOTA - 460) & 511)]) + fVec61[((IOTA - 470) & 511)])) + ((0.00115970336f * ((((((fVec61[((IOTA - 32) & 511)] - fVec61[((IOTA - 214) & 511)]) + fVec61[((IOTA - 232) & 511)]) - fVec61[((IOTA - 318) & 511)]) - fVec61[((IOTA - 335) & 511)]) - fVec61[((IOTA - 383) & 511)]) + fVec61[((IOTA - 469) & 511)])) + ((0.000885036774f * (((((fVec61[((IOTA - 236) & 511)] - fVec61[((IOTA - 277) & 511)]) - fVec61[((IOTA - 332) & 511)]) - fVec61[((IOTA - 333) & 511)]) - fVec61[((IOTA - 422) & 511)]) + fVec61[((IOTA - 468) & 511)])) + ((0.00137333293f * ((fVec61[((IOTA - 13) & 511)] - fVec61[((IOTA - 448) & 511)]) + fVec61[((IOTA - 456) & 511)])) + ((0.00213629566f * fVec61[((IOTA - 454) & 511)]) + ((0.00177007355f * (fVec61[((IOTA - 34) & 511)] + fVec61[((IOTA - 453) & 511)])) + ((0.00164799951f * (((fVec61[((IOTA - 25) & 511)] - fVec61[((IOTA - 42) & 511)]) - fVec61[((IOTA - 225) & 511)]) - fVec61[((IOTA - 449) & 511)])) + ((0.000122074038f * (((((((fVec61[((IOTA - 195) & 511)] - fVec61[((IOTA - 296) & 511)]) + fVec61[((IOTA - 308) & 511)]) - fVec61[((IOTA - 309) & 511)]) - fVec61[((IOTA - 377) & 511)]) - fVec61[((IOTA - 403) & 511)]) - fVec61[((IOTA - 411) & 511)]) - fVec61[((IOTA - 430) & 511)])) + ((0.000732444227f * (((fVec61[((IOTA - 238) & 511)] - fVec61[((IOTA - 264) & 511)]) - fVec61[((IOTA - 339) & 511)]) - fVec61[((IOTA - 424) & 511)])) + ((0.000640888698f * ((((((fVec61[((IOTA - 7) & 511)] + fVec61[((IOTA - 241) & 511)]) + fVec61[((IOTA - 281) & 511)]) - fVec61[((IOTA - 299) & 511)]) - fVec61[((IOTA - 328) & 511)]) + fVec61[((IOTA - 362) & 511)]) + fVec61[((IOTA - 373) & 511)])) + ((0.000823999755f * (((((fVec61[((IOTA - 58) & 511)] + fVec61[((IOTA - 237) & 511)]) - fVec61[((IOTA - 311) & 511)]) - fVec61[((IOTA - 320) & 511)]) - fVec61[((IOTA - 329) & 511)]) + fVec61[((IOTA - 361) & 511)])) + ((0.00119022187f * ((fVec61[((IOTA - 38) & 511)] - fVec61[((IOTA - 316) & 511)]) - fVec61[((IOTA - 336) & 511)])) + ((0.000701925717f * (((fVec61[((IOTA - 8) & 511)] + fVec61[((IOTA - 36) & 511)]) - fVec61[((IOTA - 285) & 511)]) - fVec61[((IOTA - 326) & 511)])) + ((0.00125125889f * (((fVec61[((IOTA - 184) & 511)] + fVec61[((IOTA - 233) & 511)]) - fVec61[((IOTA - 246) & 511)]) - fVec61[((IOTA - 317) & 511)])) + ((0.00109866634f * (((fVec61[((IOTA - 40) & 511)] - fVec61[((IOTA - 216) & 511)]) + fVec61[((IOTA - 254) & 511)]) - fVec61[((IOTA - 263) & 511)])) + ((0.00158696249f * (fVec61[((IOTA - 191) & 511)] - fVec61[((IOTA - 262) & 511)])) + ((0.00186162908f * fVec61[((IOTA - 230) & 511)]) + ((0.0019226661f * ((fVec61[((IOTA - 33) & 511)] + fVec61[((IOTA - 189) & 511)]) - fVec61[((IOTA - 213) & 511)])) + ((0.00149540696f * (fVec61[((IOTA - 71) & 511)] - fVec61[((IOTA - 208) & 511)])) + ((0.00146488845f * fVec61[((IOTA - 205) & 511)]) + ((0.00180059206f * (fVec61[((IOTA - 202) & 511)] + fVec61[((IOTA - 203) & 511)])) + ((0.00296029542f * fVec61[((IOTA - 201) & 511)]) + ((0.00378429517f * fVec61[((IOTA - 200) & 511)]) + ((0.00369273964f * fVec61[((IOTA - 199) & 511)]) + ((0.00234992523f * fVec61[((IOTA - 198) & 511)]) + ((0.0012817774f * (fVec61[((IOTA - 11) & 511)] + fVec61[((IOTA - 192) & 511)])) + ((0.00170903653f * fVec61[((IOTA - 190) & 511)]) + ((0.00427259132f * ((fVec61[((IOTA - 150) & 511)] + fVec61[((IOTA - 160) & 511)]) + fVec61[((IOTA - 187) & 511)])) + ((0.00411999878f * fVec61[((IOTA - 186) & 511)]) + ((0.00152592547f * fVec61[((IOTA - 183) & 511)]) + ((0.003234962f * fVec61[((IOTA - 182) & 511)]) + ((0.00448622089f * fVec61[((IOTA - 181) & 511)]) + ((0.0038758507f * ((fVec61[((IOTA - 24) & 511)] + fVec61[((IOTA - 51) & 511)]) + fVec61[((IOTA - 180) & 511)])) + ((0.00256355479f * fVec61[((IOTA - 178) & 511)]) + ((0.00491348002f * (fVec61[((IOTA - 67) & 511)] + fVec61[((IOTA - 177) & 511)])) + ((0.0093691824f * fVec61[((IOTA - 175) & 511)]) + ((0.00726340525f * fVec61[((IOTA - 174) & 511)]) + ((0.00476088747f * (fVec61[((IOTA - 152) & 511)] - fVec61[((IOTA - 167) & 511)])) + ((0.00643940549f * (fVec61[((IOTA - 70) & 511)] + fVec61[((IOTA - 164) & 511)])) + ((0.0142521439f * fVec61[((IOTA - 163) & 511)]) + ((0.0171819218f * fVec61[((IOTA - 162) & 511)]) + ((0.0126346629f * fVec61[((IOTA - 161) & 511)]) + ((0.0025940733f * (fVec61[((IOTA - 153) & 511)] - fVec61[((IOTA - 159) & 511)])) + ((0.0045167394f * fVec61[((IOTA - 151) & 511)]) + ((0.00250251777f * fVec61[((IOTA - 148) & 511)]) + ((0.00866725668f * fVec61[((IOTA - 139) & 511)]) + ((0.0173955504f * fVec61[((IOTA - 138) & 511)]) + ((0.0233466607f * fVec61[((IOTA - 137) & 511)]) + ((0.0249031037f * fVec61[((IOTA - 136) & 511)]) + ((0.0208746605f * fVec61[((IOTA - 135) & 511)]) + ((0.0107730338f * fVec61[((IOTA - 134) & 511)]) + ((0.0159306619f * fVec61[((IOTA - 128) & 511)]) + ((0.0198980682f * fVec61[((IOTA - 127) & 511)]) + ((0.0219122898f * fVec61[((IOTA - 126) & 511)]) + ((0.0215765871f * fVec61[((IOTA - 125) & 511)]) + ((0.0252388082f * fVec61[((IOTA - 124) & 511)]) + ((0.0285958443f * fVec61[((IOTA - 123) & 511)]) + ((0.0257271044f * fVec61[((IOTA - 122) & 511)]) + ((0.0177617725f * (fVec61[((IOTA - 121) & 511)] - fVec61[((IOTA - 115) & 511)])) + ((0.0133976256f * fVec61[((IOTA - 110) & 511)]) + ((0.02600177f * fVec61[((IOTA - 109) & 511)]) + ((0.0326242857f * fVec61[((IOTA - 108) & 511)]) + ((0.0318308063f * fVec61[((IOTA - 107) & 511)]) + ((0.021271402f * fVec61[((IOTA - 106) & 511)]) + ((0.00143436994f * (fVec61[((IOTA - 39) & 511)] + fVec61[((IOTA - 105) & 511)])) + ((0.00534073915f * fVec61[((IOTA - 120) & 511)]) + ((0.00140385143f * fVec61[((IOTA - 101) & 511)]) + ((0.0327463597f * fVec61[((IOTA - 100) & 511)]) + ((0.0461134687f * fVec61[((IOTA - 99) & 511)]) + ((0.0372936204f * fVec61[((IOTA - 98) & 511)]) + ((0.00219733268f * fVec61[((IOTA - 97) & 511)]) + ((0.00424207281f * fVec61[((IOTA - 96) & 511)]) + ((0.00759910885f * fVec61[((IOTA - 95) & 511)]) + ((0.0330210291f * fVec61[((IOTA - 94) & 511)]) + ((0.0285653248f * fVec61[((IOTA - 93) & 511)]) + ((0.0437330231f * fVec61[((IOTA - 92) & 511)]) + ((0.029175695f * fVec61[((IOTA - 91) & 511)]) + ((0.0312509537f * fVec61[((IOTA - 90) & 511)]) + ((0.0175786614f * fVec61[((IOTA - 89) & 511)]) + ((0.07849361f * fVec61[((IOTA - 83) & 511)]) + ((0.16660054f * fVec61[((IOTA - 82) & 511)]) + ((0.218482003f * fVec61[((IOTA - 81) & 511)]) + ((0.151066616f * fVec61[((IOTA - 80) & 511)]) + ((0.00842310861f * fVec61[((IOTA - 69) & 511)]) + ((0.00747703481f * fVec61[((IOTA - 68) & 511)]) + ((0.00134281442f * fVec61[((IOTA - 62) & 511)]) + ((0.00262459181f * fVec61[((IOTA - 61) & 511)]) + ((0.00344859157f * fVec61[((IOTA - 60) & 511)]) + ((0.0028992584f * fVec61[((IOTA - 59) & 511)]) + ((0.00592059083f * fVec61[((IOTA - 50) & 511)]) + ((0.00589007232f * fVec61[((IOTA - 49) & 511)]) + ((0.00384533219f * fVec61[((IOTA - 48) & 511)]) + ((0.00415051728f * (fVec61[((IOTA - 22) & 511)] - fVec61[((IOTA - 45) & 511)])) + ((0.004852443f * fVec61[((IOTA - 23) & 511)]) + ((0.00155644398f * fVec61[((IOTA - 12) & 511)]) + (0.00216681417f * fVec61[((IOTA - 21) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000671407208f * ((((((((fVec61[((IOTA - 47) & 511)] - fVec61[((IOTA - 244) & 511)]) - fVec61[((IOTA - 275) & 511)]) + fVec61[((IOTA - 360) & 511)]) - fVec61[((IOTA - 380) & 511)]) - fVec61[((IOTA - 399) & 511)]) + fVec61[((IOTA - 444) & 511)]) + fVec61[((IOTA - 508) & 511)]) + fVec61[((IOTA - 509) & 511)]))) + (0.00057985168f * (((((((((((((((fVec61[((IOTA - 52) & 511)] - fVec61[((IOTA - 140) & 511)]) + fVec61[((IOTA - 194) & 511)]) - fVec61[((IOTA - 215) & 511)]) + fVec61[((IOTA - 256) & 511)]) - fVec61[((IOTA - 286) & 511)]) - fVec61[((IOTA - 340) & 511)]) - fVec61[((IOTA - 354) & 511)]) - fVec61[((IOTA - 395) & 511)]) + fVec61[((IOTA - 443) & 511)]) + fVec61[((IOTA - 457) & 511)]) - fVec61[((IOTA - 475) & 511)]) - fVec61[((IOTA - 476) & 511)]) + fVec61[((IOTA - 481) & 511)]) + fVec61[((IOTA - 507) & 511)]) + fVec61[((IOTA - 510) & 511)])))))) : (iSlow134 ? (iSlow140 ? (((0.000671407208f * (((((fVec60[((IOTA - 54) & 511)] - fVec60[((IOTA - 217) & 511)]) - fVec60[((IOTA - 218) & 511)]) + fVec60[((IOTA - 359) & 511)]) + fVec60[((IOTA - 368) & 511)]) + fVec60[((IOTA - 511) & 511)])) + ((0.000701925717f * (((fVec60[((IOTA - 408) & 511)] + fVec60[((IOTA - 472) & 511)]) + fVec60[((IOTA - 495) & 511)]) + fVec60[((IOTA - 508) & 511)])) + ((0.00057985168f * (((((((((fVec60[((IOTA - 213) & 511)] - fVec60[((IOTA - 231) & 511)]) + fVec60[((IOTA - 252) & 511)]) - fVec60[((IOTA - 262) & 511)]) - fVec60[((IOTA - 290) & 511)]) + fVec60[((IOTA - 376) & 511)]) + fVec60[((IOTA - 471) & 511)]) + fVec60[((IOTA - 501) & 511)]) + fVec60[((IOTA - 502) & 511)]) + fVec60[((IOTA - 507) & 511)])) + ((0.000488296151f * ((((((((fVec60[((IOTA - 188) & 511)] - fVec60[((IOTA - 230) & 511)]) + fVec60[((IOTA - 245) & 511)]) - fVec60[((IOTA - 281) & 511)]) - fVec60[((IOTA - 283) & 511)]) + fVec60[((IOTA - 317) & 511)]) + fVec60[((IOTA - 412) & 511)]) + fVec60[((IOTA - 504) & 511)]) + fVec60[((IOTA - 506) & 511)])) + ((0.000610370189f * (((((fVec60[((IOTA - 216) & 511)] - fVec60[((IOTA - 295) & 511)]) + fVec60[((IOTA - 318) & 511)]) + fVec60[((IOTA - 330) & 511)]) + fVec60[((IOTA - 348) & 511)]) + fVec60[((IOTA - 496) & 511)])) + ((0.000823999755f * (((fVec60[((IOTA - 407) & 511)] - ((fVec60[((IOTA - 280) & 511)] + fVec60[((IOTA - 284) & 511)]) - fVec60[((IOTA - 360) & 511)])) + fVec60[((IOTA - 422) & 511)]) + fVec60[((IOTA - 494) & 511)])) + ((0.000885036774f * (fVec60[((IOTA - 488) & 511)] - (((((fVec60[((IOTA - 145) & 511)] + fVec60[((IOTA - 155) & 511)]) + fVec60[((IOTA - 277) & 511)]) - fVec60[((IOTA - 405) & 511)]) - fVec60[((IOTA - 406) & 511)]) - fVec60[((IOTA - 487) & 511)]))) + ((0.0012817774f * ((((fVec60[((IOTA - 39) & 511)] - fVec60[((IOTA - 372) & 511)]) + fVec60[((IOTA - 420) & 511)]) + fVec60[((IOTA - 478) & 511)]) + fVec60[((IOTA - 485) & 511)])) + ((0.00146488845f * ((((((fVec60[((IOTA - 44) & 511)] + fVec60[((IOTA - 397) & 511)]) + fVec60[((IOTA - 427) & 511)]) + fVec60[((IOTA - 437) & 511)]) + fVec60[((IOTA - 447) & 511)]) + fVec60[((IOTA - 482) & 511)]) + fVec60[((IOTA - 484) & 511)])) + ((0.00140385143f * (fVec60[((IOTA - 443) & 511)] + fVec60[((IOTA - 481) & 511)])) + ((0.00119022187f * (((((fVec60[((IOTA - 379) & 511)] - fVec60[((IOTA - 385) & 511)]) - fVec60[((IOTA - 388) & 511)]) + fVec60[((IOTA - 415) & 511)]) + fVec60[((IOTA - 460) & 511)]) + fVec60[((IOTA - 477) & 511)])) + ((0.000732444227f * ((((fVec60[((IOTA - 333) & 511)] + fVec60[((IOTA - 347) & 511)]) + fVec60[((IOTA - 423) & 511)]) + fVec60[((IOTA - 469) & 511)]) + fVec60[((IOTA - 474) & 511)])) + ((0.00170903653f * (((((fVec60[((IOTA - 165) & 511)] - fVec60[((IOTA - 195) & 511)]) - fVec60[((IOTA - 235) & 511)]) - fVec60[((IOTA - 286) & 511)]) + fVec60[((IOTA - 428) & 511)]) + fVec60[((IOTA - 466) & 511)])) + ((0.00131229591f * (((fVec60[((IOTA - 444) & 511)] - (((fVec60[((IOTA - 228) & 511)] - fVec60[((IOTA - 345) & 511)]) - fVec60[((IOTA - 381) & 511)]) - fVec60[((IOTA - 438) & 511)])) + fVec60[((IOTA - 463) & 511)]) + fVec60[((IOTA - 464) & 511)])) + ((0.00100711081f * (fVec60[((IOTA - 414) & 511)] + fVec60[((IOTA - 459) & 511)])) + ((6.10370189e-05f * (((((fVec60[((IOTA - 309) & 511)] - fVec60[((IOTA - 335) & 511)]) - fVec60[((IOTA - 336) & 511)]) - fVec60[((IOTA - 354) & 511)]) - fVec60[((IOTA - 375) & 511)]) - fVec60[((IOTA - 455) & 511)])) + ((0.00222785119f * (fVec60[((IOTA - 395) & 511)] + fVec60[((IOTA - 449) & 511)])) + ((0.00186162908f * ((fVec60[((IOTA - 215) & 511)] + fVec60[((IOTA - 431) & 511)]) + fVec60[((IOTA - 448) & 511)])) + ((0.00177007355f * ((fVec60[((IOTA - 392) & 511)] + fVec60[((IOTA - 429) & 511)]) + fVec60[((IOTA - 435) & 511)])) + ((0.00198370311f * fVec60[((IOTA - 433) & 511)]) + ((0.0019531846f * ((fVec60[((IOTA - 11) & 511)] + fVec60[((IOTA - 251) & 511)]) + fVec60[((IOTA - 432) & 511)])) + ((0.00183111057f * ((fVec60[((IOTA - 135) & 511)] - fVec60[((IOTA - 260) & 511)]) + fVec60[((IOTA - 430) & 511)])) + ((0.00155644398f * (fVec60[((IOTA - 8) & 511)] + fVec60[((IOTA - 418) & 511)])) + ((0.00158696249f * (((fVec60[((IOTA - 45) & 511)] - fVec60[((IOTA - 288) & 511)]) - fVec60[((IOTA - 297) & 511)]) - fVec60[((IOTA - 387) & 511)])) + ((3.05185094e-05f * ((((((((fVec60[((IOTA - 43) & 511)] - fVec60[((IOTA - 256) & 511)]) + fVec60[((IOTA - 266) & 511)]) - fVec60[((IOTA - 292) & 511)]) + fVec60[((IOTA - 307) & 511)]) - fVec60[((IOTA - 322) & 511)]) + fVec60[((IOTA - 325) & 511)]) + fVec60[((IOTA - 337) & 511)]) + fVec60[((IOTA - 339) & 511)])) + ((0.000244148076f * (fVec60[((IOTA - 68) & 511)] - fVec60[((IOTA - 303) & 511)])) + ((0.000152592547f * (((((fVec60[((IOTA - 3) & 511)] + fVec60[((IOTA - 46) & 511)]) + fVec60[((IOTA - 50) & 511)]) - fVec60[((IOTA - 108) & 511)]) - fVec60[((IOTA - 189) & 511)]) + fVec60[((IOTA - 293) & 511)])) + ((0.00216681417f * (((fVec60[((IOTA - 26) & 511)] - fVec60[((IOTA - 222) & 511)]) + fVec60[((IOTA - 250) & 511)]) - fVec60[((IOTA - 274) & 511)])) + ((0.000854518265f * fVec60[((IOTA - 267) & 511)]) + ((0.0022583697f * (fVec60[((IOTA - 244) & 511)] - fVec60[((IOTA - 248) & 511)])) + ((0.00369273964f * (((fVec60[((IOTA - 10) & 511)] - fVec60[((IOTA - 13) & 511)]) + fVec60[((IOTA - 107) & 511)]) - fVec60[((IOTA - 225) & 511)])) + ((0.00378429517f * (fVec60[((IOTA - 161) & 511)] - fVec60[((IOTA - 224) & 511)])) + ((0.00201422162f * fVec60[((IOTA - 214) & 511)]) + ((0.003234962f * (fVec60[((IOTA - 17) & 511)] - fVec60[((IOTA - 211) & 511)])) + ((0.00494399853f * (fVec60[((IOTA - 137) & 511)] - fVec60[((IOTA - 192) & 511)])) + ((0.0035401471f * (fVec60[((IOTA - 151) & 511)] + fVec60[((IOTA - 176) & 511)])) + ((0.0273751039f * fVec60[((IOTA - 163) & 511)]) + ((0.022583697f * fVec60[((IOTA - 162) & 511)]) + ((0.00180059206f * (fVec60[((IOTA - 30) & 511)] - fVec60[((IOTA - 157) & 511)])) + ((0.00347911008f * (fVec60[((IOTA - 9) & 511)] - fVec60[((IOTA - 147) & 511)])) + ((0.00344859157f * fVec60[((IOTA - 144) & 511)]) + ((0.00823999755f * fVec60[((IOTA - 143) & 511)]) + ((0.0107730338f * fVec60[((IOTA - 142) & 511)]) + ((0.0111087374f * fVec60[((IOTA - 141) & 511)]) + ((0.00967436749f * fVec60[((IOTA - 140) & 511)]) + ((0.0106204413f * fVec60[((IOTA - 127) & 511)]) + ((0.0174260698f * fVec60[((IOTA - 126) & 511)]) + ((0.0117801446f * fVec60[((IOTA - 125) & 511)]) + ((0.00305185094f * (fVec60[((IOTA - 36) & 511)] + fVec60[((IOTA - 115) & 511)])) + ((0.00601214636f * fVec60[((IOTA - 138) & 511)]) + ((0.00701925717f * fVec60[((IOTA - 139) & 511)]) + ((0.0127872555f * fVec60[((IOTA - 114) & 511)]) + ((0.00787377544f * fVec60[((IOTA - 113) & 511)]) + ((0.00857570115f * fVec60[((IOTA - 102) & 511)]) + ((0.00625629444f * (fVec60[((IOTA - 27) & 511)] + fVec60[((IOTA - 94) & 511)])) + ((0.0261543635f * fVec60[((IOTA - 101) & 511)]) + ((0.0312204361f * fVec60[((IOTA - 93) & 511)]) + ((0.0219733268f * fVec60[((IOTA - 100) & 511)]) + ((0.00939970091f * fVec60[((IOTA - 85) & 511)]) + ((0.058107242f * fVec60[((IOTA - 84) & 511)]) + ((0.0833765715f * fVec60[((IOTA - 83) & 511)]) + ((0.0680867955f * fVec60[((IOTA - 82) & 511)]) + ((0.161931217f * fVec60[((IOTA - 76) & 511)]) + ((0.293923765f * fVec60[((IOTA - 75) & 511)]) + ((0.256355494f * fVec60[((IOTA - 74) & 511)]) + ((0.122257151f * fVec60[((IOTA - 73) & 511)]) + ((0.035645619f * fVec60[((IOTA - 72) & 511)]) + ((0.021149328f * fVec60[((IOTA - 71) & 511)]) + ((0.0235297717f * fVec60[((IOTA - 70) & 511)]) + ((0.0147709586f * fVec60[((IOTA - 69) & 511)]) + ((0.00598162785f * fVec60[((IOTA - 62) & 511)]) + ((0.0107425153f * fVec60[((IOTA - 61) & 511)]) + ((0.00976592302f * fVec60[((IOTA - 60) & 511)]) + ((0.00436414685f * fVec60[((IOTA - 59) & 511)]) + ((0.00433362834f * fVec60[((IOTA - 53) & 511)]) + ((0.00524918362f * fVec60[((IOTA - 52) & 511)]) + ((0.00338755455f * fVec60[((IOTA - 51) & 511)]) + ((0.00360118411f * fVec60[((IOTA - 38) & 511)]) + ((0.00445570238f * fVec60[((IOTA - 37) & 511)]) + ((0.00781273842f * fVec60[((IOTA - 28) & 511)]) + ((0.00357066561f * fVec60[((IOTA - 20) & 511)]) + ((0.0061342204f * fVec60[((IOTA - 19) & 511)]) + ((((fSlow144 * fTemp0) + (0.00396740623f * fVec60[((IOTA - 1) & 511)])) + (0.00262459181f * fVec60[((IOTA - 2) & 511)])) + (0.00589007232f * fVec60[((IOTA - 18) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000457777642f * ((((((((fVec60[((IOTA - 220) & 511)] + fVec60[((IOTA - 258) & 511)]) - fVec60[((IOTA - 320) & 511)]) - fVec60[((IOTA - 350) & 511)]) - fVec60[((IOTA - 357) & 511)]) + fVec60[((IOTA - 389) & 511)]) - fVec60[((IOTA - 470) & 511)]) - fVec60[((IOTA - 498) & 511)]) - fVec60[((IOTA - 505) & 511)])) + ((0.000518814661f * ((((((fVec60[((IOTA - 112) & 511)] + fVec60[((IOTA - 312) & 511)]) - fVec60[((IOTA - 358) & 511)]) - fVec60[((IOTA - 383) & 511)]) - fVec60[((IOTA - 399) & 511)]) - fVec60[((IOTA - 500) & 511)]) - fVec60[((IOTA - 503) & 511)])) + ((0.000427259132f * ((((fVec60[((IOTA - 207) & 511)] - fVec60[((IOTA - 249) & 511)]) + fVec60[((IOTA - 255) & 511)]) - fVec60[((IOTA - 410) & 511)]) - fVec60[((IOTA - 499) & 511)])) + ((0.00054933317f * ((((((((fVec60[((IOTA - 16) & 511)] + fVec60[((IOTA - 152) & 511)]) + fVec60[((IOTA - 219) & 511)]) + fVec60[((IOTA - 265) & 511)]) + fVec60[((IOTA - 313) & 511)]) - fVec60[((IOTA - 349) & 511)]) - fVec60[((IOTA - 403) & 511)]) - fVec60[((IOTA - 409) & 511)]) - fVec60[((IOTA - 497) & 511)])) + ((0.000976592302f * (((((((fVec60[((IOTA - 12) & 511)] + fVec60[((IOTA - 208) & 511)]) + fVec60[((IOTA - 289) & 511)]) - fVec60[((IOTA - 361) & 511)]) - fVec60[((IOTA - 377) & 511)]) - fVec60[((IOTA - 398) & 511)]) - fVec60[((IOTA - 476) & 511)]) - fVec60[((IOTA - 493) & 511)])) + ((0.00106814783f * (((((fVec60[((IOTA - 221) & 511)] + fVec60[((IOTA - 259) & 511)]) - fVec60[((IOTA - 331) & 511)]) - fVec60[((IOTA - 362) & 511)]) - fVec60[((IOTA - 486) & 511)]) - fVec60[((IOTA - 492) & 511)])) + ((0.00109866634f * ((((((((fVec60[((IOTA - 7) & 511)] + fVec60[((IOTA - 40) & 511)]) - fVec60[((IOTA - 243) & 511)]) + fVec60[((IOTA - 254) & 511)]) + fVec60[((IOTA - 276) & 511)]) - fVec60[((IOTA - 332) & 511)]) - fVec60[((IOTA - 343) & 511)]) - fVec60[((IOTA - 365) & 511)]) - fVec60[((IOTA - 491) & 511)])) + ((0.00103762932f * (((((fVec60[((IOTA - 201) & 511)] + fVec60[((IOTA - 279) & 511)]) - fVec60[((IOTA - 346) & 511)]) - fVec60[((IOTA - 366) & 511)]) - fVec60[((IOTA - 421) & 511)]) - fVec60[((IOTA - 490) & 511)])) + ((0.000946073793f * (((fVec60[((IOTA - 237) & 511)] - fVec60[((IOTA - 425) & 511)]) - fVec60[((IOTA - 458) & 511)]) - fVec60[((IOTA - 489) & 511)])) + ((0.00152592547f * (((((fVec60[((IOTA - 206) & 511)] + fVec60[((IOTA - 234) & 511)]) + fVec60[((IOTA - 236) & 511)]) + fVec60[((IOTA - 298) & 511)]) - fVec60[((IOTA - 465) & 511)]) - fVec60[((IOTA - 483) & 511)])) + ((0.00137333293f * (((((fVec60[((IOTA - 109) & 511)] - fVec60[((IOTA - 149) & 511)]) + fVec60[((IOTA - 242) & 511)]) - fVec60[((IOTA - 442) & 511)]) - fVec60[((IOTA - 462) & 511)]) - fVec60[((IOTA - 480) & 511)])) + ((0.00134281442f * ((((fVec60[((IOTA - 285) & 511)] - fVec60[((IOTA - 344) & 511)]) - fVec60[((IOTA - 416) & 511)]) - fVec60[((IOTA - 461) & 511)]) - fVec60[((IOTA - 479) & 511)])) + ((0.000762962736f * ((((((fVec60[((IOTA - 229) & 511)] - fVec60[((IOTA - 269) & 511)]) + fVec60[((IOTA - 300) & 511)]) - fVec60[((IOTA - 404) & 511)]) - fVec60[((IOTA - 413) & 511)]) - fVec60[((IOTA - 457) & 511)]) - fVec60[((IOTA - 473) & 511)])) + ((0.00122074038f * ((((fVec60[((IOTA - 111) & 511)] - fVec60[((IOTA - 426) & 511)]) - fVec60[((IOTA - 439) & 511)]) - fVec60[((IOTA - 445) & 511)]) - fVec60[((IOTA - 468) & 511)])) + ((0.001617481f * ((((fVec60[((IOTA - 42) & 511)] + fVec60[((IOTA - 275) & 511)]) + fVec60[((IOTA - 386) & 511)]) - fVec60[((IOTA - 436) & 511)]) - fVec60[((IOTA - 467) & 511)])) + ((0.000366222113f * ((((fVec60[((IOTA - 311) & 511)] + fVec60[((IOTA - 384) & 511)]) - fVec60[((IOTA - 390) & 511)]) - fVec60[((IOTA - 411) & 511)]) - fVec60[((IOTA - 456) & 511)])) + ((0.000122074038f * (((((fVec60[((IOTA - 177) & 511)] + fVec60[((IOTA - 310) & 511)]) + fVec60[((IOTA - 323) & 511)]) - fVec60[((IOTA - 338) & 511)]) + fVec60[((IOTA - 353) & 511)]) + fVec60[((IOTA - 454) & 511)])) + ((0.000335703604f * (((((fVec60[((IOTA - 301) & 511)] + fVec60[((IOTA - 327) & 511)]) + fVec60[((IOTA - 328) & 511)]) + fVec60[((IOTA - 370) & 511)]) - fVec60[((IOTA - 402) & 511)]) - fVec60[((IOTA - 453) & 511)])) + ((0.00115970336f * (((fVec60[((IOTA - 296) & 511)] - fVec60[((IOTA - 391) & 511)]) - fVec60[((IOTA - 440) & 511)]) - fVec60[((IOTA - 452) & 511)])) + ((0.0019226661f * (((((fVec60[((IOTA - 47) & 511)] - fVec60[((IOTA - 99) & 511)]) + fVec60[((IOTA - 287) & 511)]) - fVec60[((IOTA - 396) & 511)]) - fVec60[((IOTA - 434) & 511)]) - fVec60[((IOTA - 451) & 511)])) + ((0.00231940672f * (fVec60[((IOTA - 4) & 511)] - fVec60[((IOTA - 450) & 511)])) + ((0.00125125889f * (((((((fVec60[((IOTA - 202) & 511)] + fVec60[((IOTA - 239) & 511)]) - fVec60[((IOTA - 268) & 511)]) + fVec60[((IOTA - 299) & 511)]) + fVec60[((IOTA - 373) & 511)]) - fVec60[((IOTA - 380) & 511)]) - fVec60[((IOTA - 441) & 511)]) - fVec60[((IOTA - 446) & 511)])) + ((0.00149540696f * ((fVec60[((IOTA - 212) & 511)] - fVec60[((IOTA - 417) & 511)]) - fVec60[((IOTA - 419) & 511)])) + ((0.000183111057f * ((((fVec60[((IOTA - 294) & 511)] + fVec60[((IOTA - 302) & 511)]) + fVec60[((IOTA - 306) & 511)]) - fVec60[((IOTA - 321) & 511)]) - fVec60[((IOTA - 401) & 511)])) + ((0.000213629566f * ((((((fVec60[((IOTA - 35) & 511)] + fVec60[((IOTA - 305) & 511)]) - fVec60[((IOTA - 334) & 511)]) - fVec60[((IOTA - 341) & 511)]) - fVec60[((IOTA - 351) & 511)]) - fVec60[((IOTA - 369) & 511)]) - fVec60[((IOTA - 400) & 511)])) + ((0.00228888821f * ((fVec60[((IOTA - 58) & 511)] + fVec60[((IOTA - 106) & 511)]) - fVec60[((IOTA - 394) & 511)])) + ((0.00213629566f * (fVec60[((IOTA - 209) & 511)] - fVec60[((IOTA - 393) & 511)])) + ((0.00112918485f * (((((fVec60[((IOTA - 200) & 511)] + fVec60[((IOTA - 233) & 511)]) - fVec60[((IOTA - 363) & 511)]) - fVec60[((IOTA - 364) & 511)]) - fVec60[((IOTA - 378) & 511)]) - fVec60[((IOTA - 382) & 511)])) + ((0.000305185094f * (fVec60[((IOTA - 264) & 511)] - fVec60[((IOTA - 356) & 511)])) + ((9.15555283e-05f * ((((fVec60[((IOTA - 263) & 511)] - fVec60[((IOTA - 308) & 511)]) + fVec60[((IOTA - 315) & 511)]) + fVec60[((IOTA - 326) & 511)]) - fVec60[((IOTA - 355) & 511)])) + ((0.000640888698f * ((fVec60[((IOTA - 238) & 511)] - fVec60[((IOTA - 319) & 511)]) - fVec60[((IOTA - 342) & 511)])) + ((0.000274666585f * ((((fVec60[((IOTA - 270) & 511)] + fVec60[((IOTA - 282) & 511)]) + fVec60[((IOTA - 291) & 511)]) + fVec60[((IOTA - 304) & 511)]) - fVec60[((IOTA - 316) & 511)])) + ((0.000396740623f * fVec60[((IOTA - 314) & 511)]) + ((0.00268562883f * (fVec60[((IOTA - 187) & 511)] + fVec60[((IOTA - 273) & 511)])) + ((0.000915555283f * ((fVec60[((IOTA - 278) & 511)] - fVec60[((IOTA - 367) & 511)]) + fVec60[((IOTA - 371) & 511)])) + ((0.00143436994f * (fVec60[((IOTA - 148) & 511)] + fVec60[((IOTA - 261) & 511)])) + ((0.00375377666f * (fVec60[((IOTA - 210) & 511)] + fVec60[((IOTA - 247) & 511)])) + ((0.00247199927f * ((fVec60[((IOTA - 49) & 511)] + fVec60[((IOTA - 196) & 511)]) + fVec60[((IOTA - 246) & 511)])) + ((0.0028992584f * (fVec60[((IOTA - 31) & 511)] + fVec60[((IOTA - 241) & 511)])) + ((0.00241096225f * fVec60[((IOTA - 240) & 511)]) + ((0.00210577715f * (fVec60[((IOTA - 190) & 511)] + fVec60[((IOTA - 227) & 511)])) + ((0.00292977691f * ((fVec60[((IOTA - 25) & 511)] + fVec60[((IOTA - 203) & 511)]) + fVec60[((IOTA - 226) & 511)])) + ((0.00332651753f * fVec60[((IOTA - 223) & 511)]) + ((0.00253303628f * fVec60[((IOTA - 272) & 511)]) + ((0.00341807306f * fVec60[((IOTA - 205) & 511)]) + ((0.00399792474f * ((fVec60[((IOTA - 34) & 511)] - fVec60[((IOTA - 136) & 511)]) + fVec60[((IOTA - 204) & 511)])) + ((0.00167851802f * fVec60[((IOTA - 271) & 511)]) + ((0.00277718436f * ((fVec60[((IOTA - 134) & 511)] - fVec60[((IOTA - 175) & 511)]) + fVec60[((IOTA - 194) & 511)])) + ((0.00411999878f * fVec60[((IOTA - 193) & 511)]) + ((0.00405896176f * fVec60[((IOTA - 191) & 511)]) + ((0.00274666585f * fVec60[((IOTA - 199) & 511)]) + ((0.00717184972f * fVec60[((IOTA - 186) & 511)]) + ((0.0116885891f * fVec60[((IOTA - 185) & 511)]) + ((0.0127262184f * fVec60[((IOTA - 184) & 511)]) + ((0.0120242927f * fVec60[((IOTA - 183) & 511)]) + ((0.00866725668f * fVec60[((IOTA - 182) & 511)]) + ((0.0045167394f * fVec60[((IOTA - 181) & 511)]) + ((0.00460829493f * fVec60[((IOTA - 180) & 511)]) + ((0.00448622089f * fVec60[((IOTA - 179) & 511)]) + ((0.00527970213f * fVec60[((IOTA - 178) & 511)]) + ((0.00308236945f * (fVec60[((IOTA - 63) & 511)] + fVec60[((IOTA - 174) & 511)])) + ((0.00280770287f * fVec60[((IOTA - 197) & 511)]) + ((0.00329599902f * fVec60[((IOTA - 198) & 511)]) + ((0.00885036774f * fVec60[((IOTA - 173) & 511)]) + ((0.00982696004f * fVec60[((IOTA - 172) & 511)]) + ((0.0111392559f * fVec60[((IOTA - 171) & 511)]) + ((0.0157475509f * (fVec60[((IOTA - 91) & 511)] - fVec60[((IOTA - 164) & 511)])) + ((0.00680562761f * fVec60[((IOTA - 170) & 511)]) + ((0.0201116987f * fVec60[((IOTA - 160) & 511)]) + ((0.0292062145f * fVec60[((IOTA - 159) & 511)]) + ((0.0179448836f * fVec60[((IOTA - 158) & 511)]) + ((0.00390636921f * ((fVec60[((IOTA - 110) & 511)] - fVec60[((IOTA - 150) & 511)]) - fVec60[((IOTA - 156) & 511)])) + ((0.00802636798f * fVec60[((IOTA - 166) & 511)]) + ((0.00576799829f * fVec60[((IOTA - 154) & 511)]) + ((0.0051576281f * fVec60[((IOTA - 153) & 511)]) + ((0.0110171819f * fVec60[((IOTA - 167) & 511)]) + ((0.00659199804f * fVec60[((IOTA - 169) & 511)]) + ((0.00769066438f * fVec60[((IOTA - 168) & 511)]) + ((0.00320444349f * fVec60[((IOTA - 146) & 511)]) + ((0.0116275521f * fVec60[((IOTA - 133) & 511)]) + ((0.0218512528f * fVec60[((IOTA - 132) & 511)]) + ((0.0295419171f * fVec60[((IOTA - 131) & 511)]) + ((0.0307016205f * fVec60[((IOTA - 130) & 511)]) + ((0.0223700684f * fVec60[((IOTA - 129) & 511)]) + ((0.00616473891f * fVec60[((IOTA - 128) & 511)]) + ((0.00204474013f * fVec60[((IOTA - 124) & 511)]) + ((0.0158085879f * fVec60[((IOTA - 123) & 511)]) + ((0.0232551042f * fVec60[((IOTA - 122) & 511)]) + ((0.022461623f * fVec60[((IOTA - 121) & 511)]) + ((0.0191045869f * fVec60[((IOTA - 120) & 511)]) + ((0.0193182174f * fVec60[((IOTA - 119) & 511)]) + ((0.0188604388f * fVec60[((IOTA - 118) & 511)]) + ((0.0156865139f * fVec60[((IOTA - 117) & 511)]) + ((0.00668355357f * fVec60[((IOTA - 116) & 511)]) + ((0.00759910885f * fVec60[((IOTA - 105) & 511)]) + ((0.0156254768f * fVec60[((IOTA - 104) & 511)]) + ((0.0115970336f * fVec60[((IOTA - 103) & 511)]) + ((0.0240485854f * fVec60[((IOTA - 98) & 511)]) + ((0.0422070995f * fVec60[((IOTA - 97) & 511)]) + ((0.0464186519f * fVec60[((IOTA - 96) & 511)]) + ((0.0184026621f * fVec60[((IOTA - 95) & 511)]) + ((0.0138554033f * (fVec60[((IOTA - 67) & 511)] - fVec60[((IOTA - 92) & 511)])) + ((0.0440687276f * fVec60[((IOTA - 90) & 511)]) + ((0.0608844273f * fVec60[((IOTA - 89) & 511)]) + ((0.0474562831f * fVec60[((IOTA - 88) & 511)]) + ((0.0473342091f * fVec60[((IOTA - 87) & 511)]) + ((0.0143742179f * fVec60[((IOTA - 86) & 511)]) + ((0.00595110934f * fVec60[((IOTA - 81) & 511)]) + ((0.108157597f * fVec60[((IOTA - 80) & 511)]) + ((0.194799647f * fVec60[((IOTA - 79) & 511)]) + ((0.196874902f * fVec60[((IOTA - 78) & 511)]) + ((0.0450453199f * fVec60[((IOTA - 77) & 511)]) + ((0.0217902157f * fVec60[((IOTA - 66) & 511)]) + ((0.021332439f * fVec60[((IOTA - 65) & 511)]) + ((0.0136417737f * fVec60[((IOTA - 64) & 511)]) + ((0.0067751091f * fVec60[((IOTA - 57) & 511)]) + ((0.00723288674f * fVec60[((IOTA - 56) & 511)]) + ((0.00402844325f * fVec60[((IOTA - 55) & 511)]) + ((0.00317392498f * fVec60[((IOTA - 48) & 511)]) + ((0.00219733268f * fVec60[((IOTA - 41) & 511)]) + ((0.00665303506f * fVec60[((IOTA - 24) & 511)]) + ((0.00744651631f * fVec60[((IOTA - 23) & 511)]) + ((0.00509659108f * fVec60[((IOTA - 22) & 511)]) + ((0.00366222113f * fVec60[((IOTA - 15) & 511)]) + ((0.00482192449f * fVec60[((IOTA - 14) & 511)]) + ((0.00314340647f * fVec60[((IOTA - 6) & 511)]) + ((0.00363170262f * fVec60[((IOTA - 5) & 511)]) + ((0.00604266487f * (fVec60[((IOTA - 32) & 511)] - fVec60[((IOTA - 29) & 511)])) + (0.00634784997f * fVec60[((IOTA - 33) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000793481246f * (((((((fVec60[((IOTA - 21) & 511)] + fVec60[((IOTA - 232) & 511)]) + fVec60[((IOTA - 253) & 511)]) + fVec60[((IOTA - 374) & 511)]) - fVec60[((IOTA - 424) & 511)]) - fVec60[((IOTA - 475) & 511)]) - fVec60[((IOTA - 509) & 511)]) - fVec60[((IOTA - 510) & 511)])))) : ((((0.00204474013f * (((fVec59[((IOTA - 356) & 511)] + fVec59[((IOTA - 358) & 511)]) + fVec59[((IOTA - 362) & 511)]) + fVec59[((IOTA - 508) & 511)])) + ((0.00210577715f * (fVec59[((IOTA - 357) & 511)] + fVec59[((IOTA - 507) & 511)])) + ((0.00219733268f * fVec59[((IOTA - 506) & 511)]) + ((0.00228888821f * (fVec59[((IOTA - 363) & 511)] + fVec59[((IOTA - 505) & 511)])) + ((0.00253303628f * (((((fVec59[((IOTA - 364) & 511)] + fVec59[((IOTA - 366) & 511)]) + fVec59[((IOTA - 472) & 511)]) + fVec59[((IOTA - 478) & 511)]) + fVec59[((IOTA - 481) & 511)]) + fVec59[((IOTA - 503) & 511)])) + ((0.00271614734f * (fVec59[((IOTA - 425) & 511)] + fVec59[((IOTA - 502) & 511)])) + ((0.00286873989f * ((fVec59[((IOTA - 426) & 511)] + fVec59[((IOTA - 485) & 511)]) + fVec59[((IOTA - 501) & 511)])) + ((0.00302133244f * ((fVec59[((IOTA - 460) & 511)] + fVec59[((IOTA - 461) & 511)]) + fVec59[((IOTA - 500) & 511)])) + ((0.00311288796f * ((fVec59[((IOTA - 408) & 511)] + fVec59[((IOTA - 435) & 511)]) + fVec59[((IOTA - 499) & 511)])) + ((0.00329599902f * (((fVec59[((IOTA - 447) & 511)] - ((((fVec59[((IOTA - 89) & 511)] + fVec59[((IOTA - 235) & 511)]) - fVec59[((IOTA - 399) & 511)]) - fVec59[((IOTA - 429) & 511)]) - fVec59[((IOTA - 442) & 511)])) + fVec59[((IOTA - 490) & 511)]) + fVec59[((IOTA - 496) & 511)])) + ((0.00338755455f * ((((((fVec59[((IOTA - 323) & 511)] + fVec59[((IOTA - 371) & 511)]) + fVec59[((IOTA - 418) & 511)]) + fVec59[((IOTA - 443) & 511)]) + fVec59[((IOTA - 446) & 511)]) + fVec59[((IOTA - 491) & 511)]) + fVec59[((IOTA - 495) & 511)])) + ((0.00305185094f * ((((((((fVec59[((IOTA - 19) & 511)] - fVec59[((IOTA - 250) & 511)]) + fVec59[((IOTA - 405) & 511)]) + fVec59[((IOTA - 427) & 511)]) + fVec59[((IOTA - 433) & 511)]) + fVec59[((IOTA - 450) & 511)]) + fVec59[((IOTA - 451) & 511)]) + fVec59[((IOTA - 452) & 511)]) + fVec59[((IOTA - 488) & 511)])) + ((0.00268562883f * ((fVec59[((IOTA - 422) & 511)] + fVec59[((IOTA - 471) & 511)]) + fVec59[((IOTA - 483) & 511)])) + ((0.00256355479f * fVec59[((IOTA - 482) & 511)]) + ((0.00250251777f * (((fVec59[((IOTA - 476) & 511)] + fVec59[((IOTA - 477) & 511)]) + fVec59[((IOTA - 479) & 511)]) + fVec59[((IOTA - 480) & 511)])) + ((0.00283822138f * (((fVec59[((IOTA - 421) & 511)] + fVec59[((IOTA - 464) & 511)]) + fVec59[((IOTA - 468) & 511)]) + fVec59[((IOTA - 469) & 511)])) + ((0.00274666585f * fVec59[((IOTA - 466) & 511)]) + ((0.00341807306f * (fVec59[((IOTA - 444) & 511)] + fVec59[((IOTA - 445) & 511)])) + ((0.0035401471f * (fVec59[((IOTA - 403) & 511)] + fVec59[((IOTA - 417) & 511)])) + ((0.00399792474f * fVec59[((IOTA - 414) & 511)]) + ((0.00381481368f * ((fVec59[((IOTA - 342) & 511)] - (fVec59[((IOTA - 158) & 511)] + fVec59[((IOTA - 208) & 511)])) + fVec59[((IOTA - 402) & 511)])) + ((0.00378429517f * (fVec59[((IOTA - 341) & 511)] + fVec59[((IOTA - 400) & 511)])) + ((0.0019531846f * (fVec59[((IOTA - 360) & 511)] + fVec59[((IOTA - 397) & 511)])) + ((0.00146488845f * ((((((fVec59[((IOTA - 69) & 511)] - fVec59[((IOTA - 261) & 511)]) - fVec59[((IOTA - 262) & 511)]) - fVec59[((IOTA - 303) & 511)]) - fVec59[((IOTA - 307) & 511)]) + fVec59[((IOTA - 379) & 511)]) + fVec59[((IOTA - 396) & 511)])) + ((0.0012817774f * ((((fVec59[((IOTA - 34) & 511)] - fVec59[((IOTA - 264) & 511)]) - fVec59[((IOTA - 269) & 511)]) - fVec59[((IOTA - 298) & 511)]) + fVec59[((IOTA - 395) & 511)])) + ((0.00143436994f * fVec59[((IOTA - 394) & 511)]) + ((0.00411999878f * ((fVec59[((IOTA - 86) & 511)] - fVec59[((IOTA - 191) & 511)]) + fVec59[((IOTA - 387) & 511)])) + ((0.00363170262f * ((fVec59[((IOTA - 87) & 511)] - fVec59[((IOTA - 244) & 511)]) + fVec59[((IOTA - 384) & 511)])) + ((0.00375377666f * fVec59[((IOTA - 383) & 511)]) + ((0.00231940672f * (fVec59[((IOTA - 380) & 511)] - (fVec59[((IOTA - 256) & 511)] - fVec59[((IOTA - 369) & 511)]))) + ((0.0051576281f * fVec59[((IOTA - 374) & 511)]) + ((0.00430310983f * fVec59[((IOTA - 372) & 511)]) + ((0.00265511032f * fVec59[((IOTA - 370) & 511)]) + ((0.00262459181f * fVec59[((IOTA - 365) & 511)]) + ((0.00189214759f * fVec59[((IOTA - 361) & 511)]) + ((0.00201422162f * fVec59[((IOTA - 359) & 511)]) + ((0.00186162908f * ((((fVec59[((IOTA - 57) & 511)] + fVec59[((IOTA - 345) & 511)]) + fVec59[((IOTA - 352) & 511)]) + fVec59[((IOTA - 353) & 511)]) + fVec59[((IOTA - 354) & 511)])) + ((0.00183111057f * fVec59[((IOTA - 351) & 511)]) + ((0.00152592547f * fVec59[((IOTA - 349) & 511)]) + ((0.00131229591f * fVec59[((IOTA - 346) & 511)]) + ((0.00222785119f * (fVec59[((IOTA - 327) & 511)] + fVec59[((IOTA - 339) & 511)])) + ((0.000976592302f * (((fVec59[((IOTA - 88) & 511)] - fVec59[((IOTA - 295) & 511)]) - fVec59[((IOTA - 308) & 511)]) + fVec59[((IOTA - 338) & 511)])) + ((0.000823999755f * fVec59[((IOTA - 329) & 511)]) + ((0.00149540696f * fVec59[((IOTA - 313) & 511)]) + ((0.00134281442f * fVec59[((IOTA - 312) & 511)]) + ((0.000946073793f * fVec59[((IOTA - 311) & 511)]) + ((0.000366222113f * fVec59[((IOTA - 310) & 511)]) + ((0.00332651753f * (((fVec59[((IOTA - 74) & 511)] - fVec59[((IOTA - 114) & 511)]) - fVec59[((IOTA - 237) & 511)]) - fVec59[((IOTA - 242) & 511)])) + ((0.0071108127f * (fVec59[((IOTA - 39) & 511)] - fVec59[((IOTA - 93) & 511)])) + ((0.00100711081f * fVec59[((IOTA - 85) & 511)]) + ((0.00891140476f * (fVec59[((IOTA - 61) & 511)] - fVec59[((IOTA - 83) & 511)])) + ((0.0158085879f * (fVec59[((IOTA - 58) & 511)] - fVec59[((IOTA - 78) & 511)])) + ((0.00985747855f * fVec59[((IOTA - 73) & 511)]) + ((0.0136722922f * fVec59[((IOTA - 72) & 511)]) + ((0.0134281442f * fVec59[((IOTA - 71) & 511)]) + ((0.0102847377f * fVec59[((IOTA - 70) & 511)]) + ((0.019226661f * fVec59[((IOTA - 60) & 511)]) + ((0.0229804385f * fVec59[((IOTA - 59) & 511)]) + ((0.0057985168f * fVec59[((IOTA - 47) & 511)]) + ((0.0165105145f * fVec59[((IOTA - 46) & 511)]) + ((0.0219122898f * fVec59[((IOTA - 45) & 511)]) + ((0.0239570308f * fVec59[((IOTA - 44) & 511)]) + ((0.0265816227f * fVec59[((IOTA - 43) & 511)]) + ((0.0236518458f * fVec59[((IOTA - 42) & 511)]) + ((0.0219428092f * fVec59[((IOTA - 41) & 511)]) + ((0.0145268105f * fVec59[((IOTA - 40) & 511)]) + ((0.0141605884f * fVec59[((IOTA - 33) & 511)]) + ((0.0281991027f * fVec59[((IOTA - 32) & 511)]) + ((0.0341807306f * fVec59[((IOTA - 31) & 511)]) + ((0.0303659178f * fVec59[((IOTA - 30) & 511)]) + (((((((((((((fSlow142 * fTemp0) + (0.0921353772f * fVec59[((IOTA - 1) & 511)])) + (0.222876668f * fVec59[((IOTA - 2) & 511)])) + (0.325998724f * fVec59[((IOTA - 3) & 511)])) + (0.323770881f * fVec59[((IOTA - 4) & 511)])) + (0.21512498f * fVec59[((IOTA - 5) & 511)])) + (0.0466322824f * fVec59[((IOTA - 6) & 511)])) + (0.0238654744f * fVec59[((IOTA - 14) & 511)])) + (0.0278328806f * fVec59[((IOTA - 15) & 511)])) + (0.0414136164f * fVec59[((IOTA - 16) & 511)])) + (0.0357676931f * fVec59[((IOTA - 17) & 511)])) + (0.0250862148f * fVec59[((IOTA - 18) & 511)])) + (0.0115054781f * fVec59[((IOTA - 29) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0019226661f * (((fVec59[((IOTA - 355) & 511)] + fVec59[((IOTA - 377) & 511)]) + fVec59[((IOTA - 510) & 511)]) + fVec59[((IOTA - 511) & 511)]))) - (((0.00241096225f * (((fVec59[((IOTA - 255) & 511)] + fVec59[((IOTA - 320) & 511)]) - fVec59[((IOTA - 367) & 511)]) - fVec59[((IOTA - 504) & 511)])) + ((0.00317392498f * ((((fVec59[((IOTA - 241) & 511)] - fVec59[((IOTA - 376) & 511)]) - fVec59[((IOTA - 439) & 511)]) - fVec59[((IOTA - 440) & 511)]) - fVec59[((IOTA - 498) & 511)])) + ((0.003234962f * (((((((fVec59[((IOTA - 319) & 511)] - fVec59[((IOTA - 326) & 511)]) - fVec59[((IOTA - 340) & 511)]) - fVec59[((IOTA - 381) & 511)]) - fVec59[((IOTA - 409) & 511)]) - fVec59[((IOTA - 448) & 511)]) - fVec59[((IOTA - 455) & 511)]) - fVec59[((IOTA - 497) & 511)])) + ((0.00347911008f * ((fVec59[((IOTA - 157) & 511)] - fVec59[((IOTA - 493) & 511)]) - fVec59[((IOTA - 494) & 511)])) + ((0.00344859157f * ((fVec59[((IOTA - 203) & 511)] - fVec59[((IOTA - 410) & 511)]) - fVec59[((IOTA - 492) & 511)])) + ((0.00314340647f * (((((fVec59[((IOTA - 205) & 511)] - fVec59[((IOTA - 436) & 511)]) - fVec59[((IOTA - 449) & 511)]) - fVec59[((IOTA - 453) & 511)]) - fVec59[((IOTA - 458) & 511)]) - fVec59[((IOTA - 489) & 511)])) + ((0.00299081393f * ((fVec59[((IOTA - 239) & 511)] - fVec59[((IOTA - 420) & 511)]) - fVec59[((IOTA - 487) & 511)])) + ((0.00292977691f * (((fVec59[((IOTA - 318) & 511)] - fVec59[((IOTA - 406) & 511)]) - fVec59[((IOTA - 463) & 511)]) - fVec59[((IOTA - 486) & 511)])) + ((0.00277718436f * ((((fVec59[((IOTA - 96) & 511)] - fVec59[((IOTA - 465) & 511)]) - fVec59[((IOTA - 467) & 511)]) - fVec59[((IOTA - 470) & 511)]) - fVec59[((IOTA - 484) & 511)])) + ((0.00247199927f * ((((fVec59[((IOTA - 254) & 511)] - fVec59[((IOTA - 391) & 511)]) - fVec59[((IOTA - 473) & 511)]) - fVec59[((IOTA - 474) & 511)]) - fVec59[((IOTA - 475) & 511)])) + ((0.00296029542f * ((fVec59[((IOTA - 251) & 511)] - fVec59[((IOTA - 407) & 511)]) - fVec59[((IOTA - 462) & 511)])) + ((0.00308236945f * (((((fVec59[((IOTA - 238) & 511)] + fVec59[((IOTA - 240) & 511)]) - fVec59[((IOTA - 390) & 511)]) - fVec59[((IOTA - 432) & 511)]) - fVec59[((IOTA - 434) & 511)]) - fVec59[((IOTA - 459) & 511)])) + ((0.00320444349f * (((((((((fVec59[((IOTA - 249) & 511)] - fVec59[((IOTA - 419) & 511)]) - fVec59[((IOTA - 428) & 511)]) - fVec59[((IOTA - 431) & 511)]) - fVec59[((IOTA - 437) & 511)]) - fVec59[((IOTA - 438) & 511)]) - fVec59[((IOTA - 441) & 511)]) - fVec59[((IOTA - 454) & 511)]) - fVec59[((IOTA - 456) & 511)]) - fVec59[((IOTA - 457) & 511)])) + ((0.00326548051f * (((fVec59[((IOTA - 204) & 511)] + fVec59[((IOTA - 206) & 511)]) - fVec59[((IOTA - 404) & 511)]) - fVec59[((IOTA - 430) & 511)])) + ((0.0025940733f * ((((fVec59[((IOTA - 253) & 511)] - fVec59[((IOTA - 344) & 511)]) - fVec59[((IOTA - 398) & 511)]) - fVec59[((IOTA - 423) & 511)]) - fVec59[((IOTA - 424) & 511)])) + ((0.00369273964f * ((fVec59[((IOTA - 232) & 511)] - fVec59[((IOTA - 385) & 511)]) - fVec59[((IOTA - 416) & 511)])) + ((0.00384533219f * (fVec59[((IOTA - 196) & 511)] - fVec59[((IOTA - 415) & 511)])) + ((0.00402844325f * (((fVec59[((IOTA - 113) & 511)] + fVec59[((IOTA - 154) & 511)]) + fVec59[((IOTA - 201) & 511)]) - fVec59[((IOTA - 413) & 511)])) + ((0.00393688772f * ((fVec59[((IOTA - 209) & 511)] - fVec59[((IOTA - 401) & 511)]) - fVec59[((IOTA - 412) & 511)])) + ((0.00372325815f * ((((fVec59[((IOTA - 193) & 511)] + fVec59[((IOTA - 202) & 511)]) - fVec59[((IOTA - 382) & 511)]) - fVec59[((IOTA - 389) & 511)]) - fVec59[((IOTA - 411) & 511)])) + ((0.00167851802f * (fVec59[((IOTA - 306) & 511)] - fVec59[((IOTA - 393) & 511)])) + ((0.00408948027f * (((fVec59[((IOTA - 115) & 511)] + fVec59[((IOTA - 199) & 511)]) - fVec59[((IOTA - 325) & 511)]) - fVec59[((IOTA - 388) & 511)])) + ((0.00390636921f * (((fVec59[((IOTA - 192) & 511)] + fVec59[((IOTA - 198) & 511)]) + fVec59[((IOTA - 231) & 511)]) - fVec59[((IOTA - 386) & 511)])) + ((0.00125125889f * ((((fVec59[((IOTA - 265) & 511)] + fVec59[((IOTA - 270) & 511)]) + fVec59[((IOTA - 296) & 511)]) - fVec59[((IOTA - 348) & 511)]) - fVec59[((IOTA - 378) & 511)])) + ((0.00445570238f * (fVec59[((IOTA - 229) & 511)] - fVec59[((IOTA - 375) & 511)])) + ((0.00503555406f * ((fVec59[((IOTA - 140) & 511)] + fVec59[((IOTA - 213) & 511)]) - fVec59[((IOTA - 373) & 511)])) + ((0.0022583697f * (fVec59[((IOTA - 23) & 511)] - fVec59[((IOTA - 368) & 511)])) + ((0.00173955504f * (fVec59[((IOTA - 259) & 511)] - fVec59[((IOTA - 350) & 511)])) + ((0.00112918485f * ((fVec59[((IOTA - 283) & 511)] + fVec59[((IOTA - 300) & 511)]) - fVec59[((IOTA - 347) & 511)])) + ((0.00335703604f * (((fVec59[((IOTA - 234) & 511)] + fVec59[((IOTA - 236) & 511)]) + fVec59[((IOTA - 248) & 511)]) - fVec59[((IOTA - 343) & 511)])) + ((0.000274666585f * ((fVec59[((IOTA - 279) & 511)] + fVec59[((IOTA - 316) & 511)]) + fVec59[((IOTA - 337) & 511)])) + ((0.00122074038f * (((fVec59[((IOTA - 266) & 511)] + fVec59[((IOTA - 301) & 511)]) + fVec59[((IOTA - 333) & 511)]) + fVec59[((IOTA - 336) & 511)])) + ((0.00164799951f * fVec59[((IOTA - 335) & 511)]) + ((0.001617481f * fVec59[((IOTA - 334) & 511)]) + ((0.000671407208f * ((fVec59[((IOTA - 289) & 511)] + fVec59[((IOTA - 294) & 511)]) + fVec59[((IOTA - 332) & 511)])) + ((6.10370189e-05f * (fVec59[((IOTA - 287) & 511)] + fVec59[((IOTA - 331) & 511)])) + ((0.000427259132f * (fVec59[((IOTA - 280) & 511)] - fVec59[((IOTA - 330) & 511)])) + ((0.00140385143f * ((fVec59[((IOTA - 97) & 511)] - fVec59[((IOTA - 314) & 511)]) - fVec59[((IOTA - 328) & 511)])) + ((0.00424207281f * (fVec59[((IOTA - 152) & 511)] - fVec59[((IOTA - 324) & 511)])) + ((0.00155644398f * (fVec59[((IOTA - 260) & 511)] - fVec59[((IOTA - 322) & 511)])) + ((0.000610370189f * ((fVec59[((IOTA - 273) & 511)] + fVec59[((IOTA - 292) & 511)]) + fVec59[((IOTA - 321) & 511)])) + ((0.00170903653f * ((fVec59[((IOTA - 100) & 511)] + fVec59[((IOTA - 305) & 511)]) + fVec59[((IOTA - 317) & 511)])) + ((0.000854518265f * (fVec59[((IOTA - 290) & 511)] - fVec59[((IOTA - 315) & 511)])) + ((0.000305185094f * (fVec59[((IOTA - 278) & 511)] + fVec59[((IOTA - 309) & 511)])) + ((0.00158696249f * fVec59[((IOTA - 304) & 511)]) + ((0.00137333293f * ((fVec59[((IOTA - 263) & 511)] + fVec59[((IOTA - 297) & 511)]) + fVec59[((IOTA - 302) & 511)])) + ((0.00115970336f * (fVec59[((IOTA - 267) & 511)] + fVec59[((IOTA - 299) & 511)])) + ((0.000518814661f * (fVec59[((IOTA - 276) & 511)] + fVec59[((IOTA - 293) & 511)])) + ((0.000793481246f * (fVec59[((IOTA - 272) & 511)] + fVec59[((IOTA - 291) & 511)])) + ((0.000335703604f * fVec59[((IOTA - 288) & 511)]) + ((0.000122074038f * fVec59[((IOTA - 286) & 511)]) + ((0.000488296151f * (((fVec59[((IOTA - 274) & 511)] + fVec59[((IOTA - 275) & 511)]) + fVec59[((IOTA - 277) & 511)]) + fVec59[((IOTA - 285) & 511)])) + ((0.000885036774f * fVec59[((IOTA - 284) & 511)]) + ((0.00103762932f * (fVec59[((IOTA - 271) & 511)] + fVec59[((IOTA - 282) & 511)])) + ((0.000762962736f * fVec59[((IOTA - 281) & 511)]) + ((0.00119022187f * fVec59[((IOTA - 268) & 511)]) + ((0.00216681417f * fVec59[((IOTA - 257) & 511)]) + ((0.00280770287f * fVec59[((IOTA - 252) & 511)]) + ((0.00350962859f * (((fVec59[((IOTA - 233) & 511)] + fVec59[((IOTA - 243) & 511)]) + fVec59[((IOTA - 246) & 511)]) + fVec59[((IOTA - 247) & 511)])) + ((0.00357066561f * ((fVec59[((IOTA - 156) & 511)] + fVec59[((IOTA - 194) & 511)]) + fVec59[((IOTA - 245) & 511)])) + ((0.0042115543f * (fVec59[((IOTA - 200) & 511)] + fVec59[((IOTA - 230) & 511)])) + ((0.00457777642f * (fVec59[((IOTA - 143) & 511)] + fVec59[((IOTA - 228) & 511)])) + ((0.0045167394f * (((fVec59[((IOTA - 144) & 511)] + fVec59[((IOTA - 145) & 511)]) + fVec59[((IOTA - 190) & 511)]) + fVec59[((IOTA - 227) & 511)])) + ((0.00442518387f * (fVec59[((IOTA - 150) & 511)] + fVec59[((IOTA - 226) & 511)])) + ((0.00436414685f * (fVec59[((IOTA - 151) & 511)] + fVec59[((IOTA - 225) & 511)])) + ((0.00433362834f * fVec59[((IOTA - 224) & 511)]) + ((0.00454725791f * fVec59[((IOTA - 223) & 511)]) + ((0.00479140598f * fVec59[((IOTA - 222) & 511)]) + ((0.00494399853f * (fVec59[((IOTA - 147) & 511)] + fVec59[((IOTA - 221) & 511)])) + ((0.00482192449f * fVec59[((IOTA - 220) & 511)]) + ((0.00469985045f * (fVec59[((IOTA - 22) & 511)] + fVec59[((IOTA - 219) & 511)])) + ((0.00460829493f * fVec59[((IOTA - 218) & 511)]) + ((0.00466933195f * fVec59[((IOTA - 217) & 511)]) + ((0.00488296151f * ((fVec59[((IOTA - 38) & 511)] + fVec59[((IOTA - 212) & 511)]) + fVec59[((IOTA - 216) & 511)])) + ((0.00512710959f * fVec59[((IOTA - 215) & 511)]) + ((0.00518814661f * ((fVec59[((IOTA - 139) & 511)] + fVec59[((IOTA - 189) & 511)]) + fVec59[((IOTA - 214) & 511)])) + ((0.00463881344f * (fVec59[((IOTA - 146) & 511)] + fVec59[((IOTA - 211) & 511)])) + ((0.00427259132f * fVec59[((IOTA - 210) & 511)]) + ((0.00360118411f * fVec59[((IOTA - 207) & 511)]) + ((0.0038758507f * (fVec59[((IOTA - 155) & 511)] + fVec59[((IOTA - 197) & 511)])) + ((0.00366222113f * fVec59[((IOTA - 195) & 511)]) + ((0.00592059083f * fVec59[((IOTA - 188) & 511)]) + ((0.00650044251f * fVec59[((IOTA - 187) & 511)]) + ((0.00698873866f * fVec59[((IOTA - 186) & 511)]) + ((0.00726340525f * fVec59[((IOTA - 185) & 511)]) + ((0.00729392376f * fVec59[((IOTA - 184) & 511)]) + ((0.00717184972f * (fVec59[((IOTA - 182) & 511)] + fVec59[((IOTA - 183) & 511)])) + ((0.00720236823f * fVec59[((IOTA - 181) & 511)]) + ((0.00708029419f * (fVec59[((IOTA - 172) & 511)] + fVec59[((IOTA - 180) & 511)])) + ((0.00692770164f * (fVec59[((IOTA - 48) & 511)] + fVec59[((IOTA - 179) & 511)])) + ((0.00668355357f * fVec59[((IOTA - 178) & 511)]) + ((0.00637836847f * fVec59[((IOTA - 177) & 511)]) + ((0.00622577593f * fVec59[((IOTA - 176) & 511)]) + ((0.00643940549f * (fVec59[((IOTA - 163) & 511)] + fVec59[((IOTA - 175) & 511)])) + ((0.00680562761f * ((fVec59[((IOTA - 164) & 511)] + fVec59[((IOTA - 165) & 511)]) + fVec59[((IOTA - 174) & 511)])) + ((0.00704977568f * fVec59[((IOTA - 173) & 511)]) + ((0.00689718314f * fVec59[((IOTA - 171) & 511)]) + ((0.00640888698f * fVec59[((IOTA - 170) & 511)]) + ((0.00589007232f * fVec59[((IOTA - 169) & 511)]) + ((0.0058290353f * (fVec59[((IOTA - 162) & 511)] + fVec59[((IOTA - 168) & 511)])) + ((0.00616473891f * fVec59[((IOTA - 167) & 511)]) + ((0.00653096102f * fVec59[((IOTA - 166) & 511)]) + ((0.00521866512f * (fVec59[((IOTA - 75) & 511)] + fVec59[((IOTA - 161) & 511)])) + ((0.004852443f * fVec59[((IOTA - 160) & 511)]) + ((0.00439466536f * fVec59[((IOTA - 159) & 511)]) + ((0.00415051728f * (fVec59[((IOTA - 101) & 511)] + fVec59[((IOTA - 153) & 511)])) + ((0.00476088747f * (fVec59[((IOTA - 141) & 511)] + fVec59[((IOTA - 149) & 511)])) + ((0.00473036896f * fVec59[((IOTA - 142) & 511)]) + ((0.00555436872f * fVec59[((IOTA - 138) & 511)]) + ((0.00564592425f * fVec59[((IOTA - 137) & 511)]) + ((0.00543229468f * (fVec59[((IOTA - 135) & 511)] + fVec59[((IOTA - 136) & 511)])) + ((0.00610370189f * fVec59[((IOTA - 134) & 511)]) + ((0.00723288674f * fVec59[((IOTA - 133) & 511)]) + ((0.00823999755f * fVec59[((IOTA - 132) & 511)]) + ((0.00854518265f * fVec59[((IOTA - 131) & 511)]) + ((0.00833155308f * fVec59[((IOTA - 130) & 511)]) + ((0.00790429395f * fVec59[((IOTA - 129) & 511)]) + ((0.00762962736f * fVec59[((IOTA - 128) & 511)]) + ((0.00799584948f * fVec59[((IOTA - 127) & 511)]) + ((0.00881984923f * fVec59[((IOTA - 126) & 511)]) + ((0.00918607134f * fVec59[((IOTA - 125) & 511)]) + ((0.00924710836f * fVec59[((IOTA - 124) & 511)]) + ((0.00949125644f * fVec59[((IOTA - 123) & 511)]) + ((0.00930814538f * fVec59[((IOTA - 122) & 511)]) + ((0.00900296029f * fVec59[((IOTA - 121) & 511)]) + ((0.00863673817f * fVec59[((IOTA - 120) & 511)]) + ((0.00842310861f * fVec59[((IOTA - 119) & 511)]) + ((0.00781273842f * fVec59[((IOTA - 118) & 511)]) + ((0.00671407208f * fVec59[((IOTA - 117) & 511)]) + ((0.00527970213f * fVec59[((IOTA - 116) & 511)]) + ((0.00506607257f * fVec59[((IOTA - 148) & 511)]) + ((0.00601214636f * fVec59[((IOTA - 112) & 511)]) + ((0.0083925901f * fVec59[((IOTA - 111) & 511)]) + ((0.0105899228f * fVec59[((IOTA - 110) & 511)]) + ((0.0118411817f * fVec59[((IOTA - 109) & 511)]) + ((0.0125125889f * fVec59[((IOTA - 108) & 511)]) + ((0.0125431074f * fVec59[((IOTA - 107) & 511)]) + ((0.0122684408f * fVec59[((IOTA - 106) & 511)]) + ((0.0117801446f * fVec59[((IOTA - 105) & 511)]) + ((0.0114139225f * fVec59[((IOTA - 104) & 511)]) + ((0.0100711081f * fVec59[((IOTA - 103) & 511)]) + ((0.00714133121f * fVec59[((IOTA - 102) & 511)]) + ((0.000183111057f * fVec59[((IOTA - 99) & 511)]) + ((0.00793481246f * fVec59[((IOTA - 92) & 511)]) + ((0.00802636798f * fVec59[((IOTA - 91) & 511)]) + ((0.00659199804f * fVec59[((IOTA - 90) & 511)]) + ((0.00396740623f * (fVec59[((IOTA - 13) & 511)] + fVec59[((IOTA - 84) & 511)])) + ((0.0117191076f * (fVec59[((IOTA - 20) & 511)] + fVec59[((IOTA - 82) & 511)])) + ((0.00546281319f * fVec59[((IOTA - 94) & 511)]) + ((0.00405896176f * fVec59[((IOTA - 95) & 511)]) + ((0.0122074038f * fVec59[((IOTA - 81) & 511)]) + ((0.0123294778f * fVec59[((IOTA - 80) & 511)]) + ((0.0133976256f * fVec59[((IOTA - 79) & 511)]) + ((0.000244148076f * fVec59[((IOTA - 98) & 511)]) + ((0.0159001444f * fVec59[((IOTA - 77) & 511)]) + ((0.0124820704f * fVec59[((IOTA - 76) & 511)]) + ((0.0110782189f * fVec59[((IOTA - 68) & 511)]) + ((0.0254524369f * fVec59[((IOTA - 67) & 511)]) + ((0.035523545f * fVec59[((IOTA - 66) & 511)]) + ((0.0383617654f * fVec59[((IOTA - 65) & 511)]) + ((0.033600878f * fVec59[((IOTA - 64) & 511)]) + ((0.0215765871f * fVec59[((IOTA - 63) & 511)]) + ((0.00662251655f * fVec59[((IOTA - 62) & 511)]) + ((0.0130314035f * fVec59[((IOTA - 56) & 511)]) + ((0.0247810297f * fVec59[((IOTA - 55) & 511)]) + ((0.03234962f * fVec59[((IOTA - 54) & 511)]) + ((0.037324138f * fVec59[((IOTA - 53) & 511)]) + ((0.0390331745f * fVec59[((IOTA - 52) & 511)]) + ((0.0366527289f * fVec59[((IOTA - 51) & 511)]) + ((0.0287179183f * fVec59[((IOTA - 50) & 511)]) + ((0.0197759941f * fVec59[((IOTA - 49) & 511)]) + ((0.01126133f * fVec59[((IOTA - 35) & 511)]) + ((0.0206610318f * fVec59[((IOTA - 28) & 511)]) + ((0.0396740623f * fVec59[((IOTA - 27) & 511)]) + ((0.0460524298f * fVec59[((IOTA - 26) & 511)]) + ((0.0286263619f * fVec59[((IOTA - 25) & 511)]) + ((0.0176702179f * fVec59[((IOTA - 24) & 511)]) + ((0.00820947904f * fVec59[((IOTA - 21) & 511)]) + ((0.0290231034f * fVec59[((IOTA - 12) & 511)]) + ((0.0686056092f * fVec59[((IOTA - 11) & 511)]) + ((0.111514635f * fVec59[((IOTA - 10) & 511)]) + ((0.159428701f * fVec59[((IOTA - 9) & 511)]) + ((0.168340102f * fVec59[((IOTA - 8) & 511)]) + ((0.0917386413f * fVec59[((IOTA - 7) & 511)]) + ((0.0135196997f * fVec59[((IOTA - 36) & 511)]) + (0.0120242927f * fVec59[((IOTA - 37) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00198370311f * ((fVec59[((IOTA - 258) & 511)] - fVec59[((IOTA - 392) & 511)]) - fVec59[((IOTA - 509) & 511)]))))) : (iSlow135 ? (((9.15555283e-05f * (((((((((((fVec58[((IOTA - 159) & 511)] - fVec58[((IOTA - 220) & 511)]) - fVec58[((IOTA - 284) & 511)]) - fVec58[((IOTA - 352) & 511)]) - fVec58[((IOTA - 353) & 511)]) + fVec58[((IOTA - 411) & 511)]) - fVec58[((IOTA - 414) & 511)]) + fVec58[((IOTA - 447) & 511)]) + fVec58[((IOTA - 449) & 511)]) + fVec58[((IOTA - 480) & 511)]) + fVec58[((IOTA - 501) & 511)]) - fVec58[((IOTA - 511) & 511)])) + ((0.000122074038f * (((((((((((((fVec58[((IOTA - 61) & 511)] - fVec58[((IOTA - 161) & 511)]) - fVec58[((IOTA - 163) & 511)]) + fVec58[((IOTA - 223) & 511)]) - fVec58[((IOTA - 290) & 511)]) + fVec58[((IOTA - 370) & 511)]) - fVec58[((IOTA - 406) & 511)]) - fVec58[((IOTA - 477) & 511)]) + fVec58[((IOTA - 481) & 511)]) + fVec58[((IOTA - 482) & 511)]) + fVec58[((IOTA - 485) & 511)]) - fVec58[((IOTA - 504) & 511)]) - fVec58[((IOTA - 509) & 511)]) - fVec58[((IOTA - 510) & 511)])) + ((0.000152592547f * (((((((((((((fVec58[((IOTA - 179) & 511)] - fVec58[((IOTA - 222) & 511)]) - fVec58[((IOTA - 285) & 511)]) - fVec58[((IOTA - 312) & 511)]) - fVec58[((IOTA - 407) & 511)]) + fVec58[((IOTA - 412) & 511)]) + fVec58[((IOTA - 483) & 511)]) + fVec58[((IOTA - 484) & 511)]) + fVec58[((IOTA - 486) & 511)]) + fVec58[((IOTA - 487) & 511)]) - fVec58[((IOTA - 505) & 511)]) - fVec58[((IOTA - 506) & 511)]) - fVec58[((IOTA - 507) & 511)]) - fVec58[((IOTA - 508) & 511)])) + ((6.10370189e-05f * (((((((((fVec58[((IOTA - 131) & 511)] + fVec58[((IOTA - 278) & 511)]) - fVec58[((IOTA - 283) & 511)]) + fVec58[((IOTA - 388) & 511)]) - fVec58[((IOTA - 397) & 511)]) - fVec58[((IOTA - 410) & 511)]) + fVec58[((IOTA - 413) & 511)]) + fVec58[((IOTA - 448) & 511)]) - fVec58[((IOTA - 478) & 511)]) - fVec58[((IOTA - 503) & 511)])) + ((0.000274666585f * ((((fVec58[((IOTA - 178) & 511)] + fVec58[((IOTA - 228) & 511)]) + fVec58[((IOTA - 445) & 511)]) - fVec58[((IOTA - 471) & 511)]) + fVec58[((IOTA - 499) & 511)])) + ((0.000305185094f * ((((((((((((fVec58[((IOTA - 89) & 511)] - fVec58[((IOTA - 121) & 511)]) + fVec58[((IOTA - 206) & 511)]) + fVec58[((IOTA - 311) & 511)]) - fVec58[((IOTA - 330) & 511)]) - fVec58[((IOTA - 369) & 511)]) - fVec58[((IOTA - 438) & 511)]) + fVec58[((IOTA - 457) & 511)]) + fVec58[((IOTA - 494) & 511)]) + fVec58[((IOTA - 495) & 511)]) + fVec58[((IOTA - 496) & 511)]) + fVec58[((IOTA - 497) & 511)]) + fVec58[((IOTA - 498) & 511)])) + ((0.000396740623f * ((((((((((((((fVec58[((IOTA - 185) & 511)] + fVec58[((IOTA - 205) & 511)]) + fVec58[((IOTA - 224) & 511)]) + fVec58[((IOTA - 227) & 511)]) + fVec58[((IOTA - 230) & 511)]) + fVec58[((IOTA - 269) & 511)]) + fVec58[((IOTA - 270) & 511)]) + fVec58[((IOTA - 276) & 511)]) + fVec58[((IOTA - 294) & 511)]) - fVec58[((IOTA - 343) & 511)]) + fVec58[((IOTA - 382) & 511)]) + fVec58[((IOTA - 387) & 511)]) + fVec58[((IOTA - 442) & 511)]) - fVec58[((IOTA - 469) & 511)]) + fVec58[((IOTA - 492) & 511)])) + ((0.000335703604f * ((((((((((((fVec58[((IOTA - 158) & 511)] - fVec58[((IOTA - 166) & 511)]) + fVec58[((IOTA - 175) & 511)]) - fVec58[((IOTA - 183) & 511)]) + fVec58[((IOTA - 219) & 511)]) + fVec58[((IOTA - 293) & 511)]) - fVec58[((IOTA - 367) & 511)]) + fVec58[((IOTA - 386) & 511)]) - fVec58[((IOTA - 429) & 511)]) + fVec58[((IOTA - 451) & 511)]) - fVec58[((IOTA - 459) & 511)]) - fVec58[((IOTA - 470) & 511)]) + fVec58[((IOTA - 490) & 511)])) + ((0.000244148076f * ((((((((fVec58[((IOTA - 132) & 511)] + fVec58[((IOTA - 148) & 511)]) - fVec58[((IOTA - 174) & 511)]) - fVec58[((IOTA - 221) & 511)]) + fVec58[((IOTA - 229) & 511)]) + fVec58[((IOTA - 331) & 511)]) + fVec58[((IOTA - 385) & 511)]) - fVec58[((IOTA - 415) & 511)]) + fVec58[((IOTA - 489) & 511)])) + ((0.000488296151f * (((((fVec58[((IOTA - 177) & 511)] + fVec58[((IOTA - 342) & 511)]) - fVec58[((IOTA - 368) & 511)]) - fVec58[((IOTA - 430) & 511)]) + fVec58[((IOTA - 452) & 511)]) - fVec58[((IOTA - 467) & 511)])) + ((0.00054933317f * (((((((((((fVec58[((IOTA - 123) & 511)] + fVec58[((IOTA - 149) & 511)]) + fVec58[((IOTA - 157) & 511)]) - fVec58[((IOTA - 171) & 511)]) + fVec58[((IOTA - 207) & 511)]) + fVec58[((IOTA - 226) & 511)]) + fVec58[((IOTA - 231) & 511)]) + fVec58[((IOTA - 297) & 511)]) - fVec58[((IOTA - 437) & 511)]) - fVec58[((IOTA - 460) & 511)]) - fVec58[((IOTA - 465) & 511)]) - fVec58[((IOTA - 466) & 511)])) + ((0.000610370189f * ((((((fVec58[((IOTA - 124) & 511)] + fVec58[((IOTA - 133) & 511)]) + fVec58[((IOTA - 272) & 511)]) - fVec58[((IOTA - 313) & 511)]) + fVec58[((IOTA - 364) & 511)]) - fVec58[((IOTA - 424) & 511)]) - fVec58[((IOTA - 463) & 511)])) + ((0.000671407208f * ((((((fVec58[((IOTA - 300) & 511)] - ((((((fVec58[((IOTA - 120) & 511)] - fVec58[((IOTA - 232) & 511)]) - fVec58[((IOTA - 236) & 511)]) - fVec58[((IOTA - 238) & 511)]) - fVec58[((IOTA - 243) & 511)]) - fVec58[((IOTA - 244) & 511)]) - fVec58[((IOTA - 299) & 511)])) + fVec58[((IOTA - 310) & 511)]) + fVec58[((IOTA - 371) & 511)]) + fVec58[((IOTA - 375) & 511)]) - fVec58[((IOTA - 461) & 511)]) - fVec58[((IOTA - 462) & 511)])) + (((0.000701925717f * (((((((fVec58[((IOTA - 67) & 511)] - fVec58[((IOTA - 167) & 511)]) - fVec58[((IOTA - 169) & 511)]) + fVec58[((IOTA - 233) & 511)]) + fVec58[((IOTA - 234) & 511)]) + fVec58[((IOTA - 235) & 511)]) - fVec58[((IOTA - 349) & 511)]) + fVec58[((IOTA - 455) & 511)])) + ((0.000640888698f * ((((((fVec58[((IOTA - 154) & 511)] + fVec58[((IOTA - 237) & 511)]) + fVec58[((IOTA - 267) & 511)]) + fVec58[((IOTA - 275) & 511)]) + fVec58[((IOTA - 298) & 511)]) - fVec58[((IOTA - 431) & 511)]) + fVec58[((IOTA - 453) & 511)])) + ((0.000427259132f * ((fVec58[((IOTA - 295) & 511)] + fVec58[((IOTA - 404) & 511)]) + fVec58[((IOTA - 443) & 511)])) + ((0.000823999755f * ((((((((fVec58[((IOTA - 241) & 511)] - ((fVec58[((IOTA - 80) & 511)] - fVec58[((IOTA - 115) & 511)]) - fVec58[((IOTA - 240) & 511)])) + fVec58[((IOTA - 246) & 511)]) + fVec58[((IOTA - 253) & 511)]) - fVec58[((IOTA - 329) & 511)]) + fVec58[((IOTA - 357) & 511)]) + fVec58[((IOTA - 363) & 511)]) - fVec58[((IOTA - 389) & 511)]) - fVec58[((IOTA - 433) & 511)])) + ((0.000762962736f * ((((((fVec58[((IOTA - 142) & 511)] - fVec58[((IOTA - 172) & 511)]) + fVec58[((IOTA - 239) & 511)]) + fVec58[((IOTA - 254) & 511)]) + fVec58[((IOTA - 274) & 511)]) + fVec58[((IOTA - 324) & 511)]) - fVec58[((IOTA - 432) & 511)])) + ((0.000885036774f * (((fVec58[((IOTA - 194) & 511)] + fVec58[((IOTA - 218) & 511)]) + fVec58[((IOTA - 262) & 511)]) - fVec58[((IOTA - 423) & 511)])) + ((0.00112918485f * ((((((fVec58[((IOTA - 134) & 511)] + fVec58[((IOTA - 248) & 511)]) + fVec58[((IOTA - 250) & 511)]) - fVec58[((IOTA - 315) & 511)]) - fVec58[((IOTA - 347) & 511)]) + fVec58[((IOTA - 361) & 511)]) - fVec58[((IOTA - 422) & 511)])) + ((0.00131229591f * ((fVec58[((IOTA - 192) & 511)] - fVec58[((IOTA - 326) & 511)]) - fVec58[((IOTA - 420) & 511)])) + ((0.00122074038f * ((((fVec58[((IOTA - 137) & 511)] + fVec58[((IOTA - 203) & 511)]) + fVec58[((IOTA - 216) & 511)]) + fVec58[((IOTA - 319) & 511)]) - fVec58[((IOTA - 419) & 511)])) + ((0.00115970336f * (((fVec58[((IOTA - 153) & 511)] + fVec58[((IOTA - 249) & 511)]) + fVec58[((IOTA - 360) & 511)]) + fVec58[((IOTA - 403) & 511)])) + ((0.00238044374f * fVec58[((IOTA - 401) & 511)]) + ((0.00231940672f * fVec58[((IOTA - 400) & 511)]) + ((0.00173955504f * (fVec58[((IOTA - 152) & 511)] + fVec58[((IOTA - 399) & 511)])) + ((0.00167851802f * (fVec58[((IOTA - 146) & 511)] - fVec58[((IOTA - 380) & 511)])) + ((0.00177007355f * (((fVec58[((IOTA - 13) & 511)] + fVec58[((IOTA - 337) & 511)]) + fVec58[((IOTA - 340) & 511)]) - fVec58[((IOTA - 377) & 511)])) + ((0.00106814783f * (((fVec58[((IOTA - 195) & 511)] + fVec58[((IOTA - 304) & 511)]) + fVec58[((IOTA - 333) & 511)]) + fVec58[((IOTA - 372) & 511)])) + ((0.00103762932f * ((fVec58[((IOTA - 251) & 511)] - fVec58[((IOTA - 316) & 511)]) + fVec58[((IOTA - 362) & 511)])) + ((0.000518814661f * (((((fVec58[((IOTA - 113) & 511)] + fVec58[((IOTA - 155) & 511)]) + fVec58[((IOTA - 225) & 511)]) + fVec58[((IOTA - 268) & 511)]) - fVec58[((IOTA - 325) & 511)]) + fVec58[((IOTA - 356) & 511)])) + ((0.0019531846f * fVec58[((IOTA - 339) & 511)]) + ((0.00155644398f * ((fVec58[((IOTA - 114) & 511)] + fVec58[((IOTA - 210) & 511)]) + fVec58[((IOTA - 336) & 511)])) + ((0.00137333293f * (((fVec58[((IOTA - 135) & 511)] + fVec58[((IOTA - 150) & 511)]) + fVec58[((IOTA - 305) & 511)]) + fVec58[((IOTA - 335) & 511)])) + ((0.00125125889f * ((fVec58[((IOTA - 136) & 511)] - fVec58[((IOTA - 328) & 511)]) + fVec58[((IOTA - 334) & 511)])) + ((0.00149540696f * (((fVec58[((IOTA - 141) & 511)] + fVec58[((IOTA - 197) & 511)]) + fVec58[((IOTA - 306) & 511)]) - fVec58[((IOTA - 327) & 511)])) + ((0.00204474013f * ((fVec58[((IOTA - 81) & 511)] + fVec58[((IOTA - 188) & 511)]) + fVec58[((IOTA - 323) & 511)])) + ((0.00283822138f * fVec58[((IOTA - 322) & 511)]) + ((0.00286873989f * fVec58[((IOTA - 321) & 511)]) + ((0.00222785119f * (fVec58[((IOTA - 190) & 511)] + fVec58[((IOTA - 320) & 511)])) + ((0.000976592302f * (((fVec58[((IOTA - 208) & 511)] + fVec58[((IOTA - 260) & 511)]) + fVec58[((IOTA - 261) & 511)]) - fVec58[((IOTA - 314) & 511)])) + ((0.000946073793f * (((fVec58[((IOTA - 143) & 511)] + fVec58[((IOTA - 186) & 511)]) + fVec58[((IOTA - 193) & 511)]) + fVec58[((IOTA - 309) & 511)])) + ((0.00119022187f * ((fVec58[((IOTA - 212) & 511)] + fVec58[((IOTA - 217) & 511)]) + fVec58[((IOTA - 308) & 511)])) + ((0.00146488845f * fVec58[((IOTA - 211) & 511)]) + ((0.00180059206f * ((fVec58[((IOTA - 138) & 511)] + fVec58[((IOTA - 198) & 511)]) + fVec58[((IOTA - 202) & 511)])) + ((0.00228888821f * (fVec58[((IOTA - 189) & 511)] + fVec58[((IOTA - 200) & 511)])) + ((0.00207525864f * (fVec58[((IOTA - 145) & 511)] + fVec58[((IOTA - 199) & 511)])) + ((0.00183111057f * fVec58[((IOTA - 191) & 511)]) + ((0.00189214759f * (fVec58[((IOTA - 56) & 511)] + fVec58[((IOTA - 151) & 511)])) + ((0.00241096225f * fVec58[((IOTA - 140) & 511)]) + ((0.00250251777f * fVec58[((IOTA - 139) & 511)]) + ((0.00552385021f * (fVec58[((IOTA - 88) & 511)] - fVec58[((IOTA - 108) & 511)])) + ((0.0074159978f * (fVec58[((IOTA - 98) & 511)] - fVec58[((IOTA - 104) & 511)])) + ((0.00164799951f * (fVec58[((IOTA - 101) & 511)] - fVec58[((IOTA - 102) & 511)])) + ((0.00466933195f * (fVec58[((IOTA - 82) & 511)] + fVec58[((IOTA - 100) & 511)])) + ((0.00671407208f * fVec58[((IOTA - 99) & 511)]) + ((0.00772118289f * fVec58[((IOTA - 97) & 511)]) + ((0.00848414563f * fVec58[((IOTA - 96) & 511)]) + ((0.0067751091f * fVec58[((IOTA - 94) & 511)]) + ((0.00253303628f * fVec58[((IOTA - 93) & 511)]) + ((0.00802636798f * fVec58[((IOTA - 87) & 511)]) + ((0.00717184972f * fVec58[((IOTA - 86) & 511)]) + ((0.00650044251f * fVec58[((IOTA - 85) & 511)]) + ((0.00643940549f * fVec58[((IOTA - 84) & 511)]) + ((0.00631733146f * fVec58[((IOTA - 83) & 511)]) + ((0.0111697745f * (fVec58[((IOTA - 40) & 511)] - fVec58[((IOTA - 77) & 511)])) + ((0.00607318338f * fVec58[((IOTA - 72) & 511)]) + ((0.0154118473f * fVec58[((IOTA - 71) & 511)]) + ((0.024506364f * fVec58[((IOTA - 70) & 511)]) + ((0.0271004364f * fVec58[((IOTA - 69) & 511)]) + ((0.0191351064f * fVec58[((IOTA - 68) & 511)]) + ((0.0136722922f * fVec58[((IOTA - 60) & 511)]) + ((0.0209662169f * fVec58[((IOTA - 59) & 511)]) + ((0.0210272539f * fVec58[((IOTA - 58) & 511)]) + ((0.0136112552f * fVec58[((IOTA - 57) & 511)]) + ((0.0191961434f * (fVec58[((IOTA - 11) & 511)] - fVec58[((IOTA - 47) & 511)])) + ((0.0131534776f * fVec58[((IOTA - 45) & 511)]) + ((0.0241096225f * fVec58[((IOTA - 44) & 511)]) + ((0.03234962f * fVec58[((IOTA - 43) & 511)]) + ((0.0339365825f * fVec58[((IOTA - 42) & 511)]) + ((0.0262764376f * fVec58[((IOTA - 41) & 511)]) + ((0.0249946602f * fVec58[((IOTA - 31) & 511)]) + ((0.0473342091f * fVec58[((IOTA - 30) & 511)]) + ((0.0469374694f * fVec58[((IOTA - 29) & 511)]) + ((0.0162053294f * fVec58[((IOTA - 28) & 511)]) + ((0.0120548112f * fVec58[((IOTA - 23) & 511)]) + ((0.0143742179f * fVec58[((IOTA - 22) & 511)]) + ((0.00738547929f * fVec58[((IOTA - 5) & 511)]) + ((0.215430155f * fVec58[((IOTA - 4) & 511)]) + ((0.313913375f * fVec58[((IOTA - 3) & 511)]) + ((0.265572071f * fVec58[((IOTA - 2) & 511)]) + ((0.149479657f * fVec58[((IOTA - 1) & 511)]) + ((fSlow139 * fTemp0) + ((0.00546281319f * fVec58[((IOTA - 16) & 511)]) + ((0.00967436749f * fVec58[((IOTA - 12) & 511)]) + ((0.00213629566f * fVec58[((IOTA - 14) & 511)]) + (0.00759910885f * fVec58[((IOTA - 15) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * (fVec58[((IOTA - 493) & 511)] - ((((((fVec58[((IOTA - 182) & 511)] - fVec58[((IOTA - 365) & 511)]) - fVec58[((IOTA - 384) & 511)]) + fVec58[((IOTA - 425) & 511)]) - fVec58[((IOTA - 441) & 511)]) - fVec58[((IOTA - 444) & 511)]) - fVec58[((IOTA - 491) & 511)]))))))))))))))))) - (((0.000183111057f * ((((((((((fVec58[((IOTA - 125) & 511)] + fVec58[((IOTA - 181) & 511)]) - fVec58[((IOTA - 277) & 511)]) + fVec58[((IOTA - 286) & 511)]) - fVec58[((IOTA - 355) & 511)]) + fVec58[((IOTA - 409) & 511)]) + fVec58[((IOTA - 427) & 511)]) - fVec58[((IOTA - 446) & 511)]) - fVec58[((IOTA - 450) & 511)]) + fVec58[((IOTA - 476) & 511)]) - fVec58[((IOTA - 488) & 511)])) + ((0.000457777642f * (((((((fVec58[((IOTA - 170) & 511)] - fVec58[((IOTA - 271) & 511)]) - fVec58[((IOTA - 296) & 511)]) + fVec58[((IOTA - 350) & 511)]) + fVec58[((IOTA - 376) & 511)]) + fVec58[((IOTA - 381) & 511)]) + fVec58[((IOTA - 416) & 511)]) + fVec58[((IOTA - 468) & 511)])) + ((0.00057985168f * ((((fVec58[((IOTA - 317) & 511)] - (((fVec58[((IOTA - 156) & 511)] + fVec58[((IOTA - 176) & 511)]) + fVec58[((IOTA - 301) & 511)]) + fVec58[((IOTA - 302) & 511)])) - fVec58[((IOTA - 383) & 511)]) - fVec58[((IOTA - 456) & 511)]) + fVec58[((IOTA - 464) & 511)])) + ((0.000732444227f * (((((((((((((((fVec58[((IOTA - 173) & 511)] - fVec58[((IOTA - 204) & 511)]) - fVec58[((IOTA - 242) & 511)]) - fVec58[((IOTA - 245) & 511)]) - fVec58[((IOTA - 255) & 511)]) - fVec58[((IOTA - 256) & 511)]) - fVec58[((IOTA - 257) & 511)]) - fVec58[((IOTA - 264) & 511)]) - fVec58[((IOTA - 265) & 511)]) - fVec58[((IOTA - 266) & 511)]) - fVec58[((IOTA - 273) & 511)]) - fVec58[((IOTA - 303) & 511)]) - fVec58[((IOTA - 332) & 511)]) + fVec58[((IOTA - 417) & 511)]) + fVec58[((IOTA - 436) & 511)]) - fVec58[((IOTA - 454) & 511)])) + ((0.0012817774f * ((((fVec58[((IOTA - 73) & 511)] - fVec58[((IOTA - 196) & 511)]) - fVec58[((IOTA - 341) & 511)]) - fVec58[((IOTA - 374) & 511)]) + fVec58[((IOTA - 421) & 511)])) + ((0.000854518265f * (((fVec58[((IOTA - 168) & 511)] - fVec58[((IOTA - 214) & 511)]) + fVec58[((IOTA - 434) & 511)]) + fVec58[((IOTA - 435) & 511)])) + ((3.05185094e-05f * (((((((fVec58[((IOTA - 160) & 511)] + fVec58[((IOTA - 165) & 511)]) - fVec58[((IOTA - 180) & 511)]) + fVec58[((IOTA - 184) & 511)]) - fVec58[((IOTA - 291) & 511)]) + fVec58[((IOTA - 354) & 511)]) - fVec58[((IOTA - 366) & 511)]) - fVec58[((IOTA - 405) & 511)])) + ((0.0019226661f * (((fVec58[((IOTA - 127) & 511)] - fVec58[((IOTA - 338) & 511)]) + fVec58[((IOTA - 390) & 511)]) - fVec58[((IOTA - 402) & 511)])) + ((0.000915555283f * ((fVec58[((IOTA - 396) & 511)] - ((((fVec58[((IOTA - 32) & 511)] + fVec58[((IOTA - 213) & 511)]) + fVec58[((IOTA - 252) & 511)]) + fVec58[((IOTA - 259) & 511)]) - fVec58[((IOTA - 348) & 511)])) - fVec58[((IOTA - 398) & 511)])) + ((0.00100711081f * (fVec58[((IOTA - 418) & 511)] - ((fVec58[((IOTA - 215) & 511)] + fVec58[((IOTA - 247) & 511)]) + fVec58[((IOTA - 358) & 511)]))) + ((0.001617481f * fVec58[((IOTA - 395) & 511)]) + ((0.00216681417f * fVec58[((IOTA - 394) & 511)]) + ((0.00262459181f * (fVec58[((IOTA - 378) & 511)] + fVec58[((IOTA - 393) & 511)])) + ((0.00292977691f * fVec58[((IOTA - 392) & 511)]) + ((0.00271614734f * fVec58[((IOTA - 391) & 511)]) + ((0.00256355479f * fVec58[((IOTA - 379) & 511)]) + ((0.00134281442f * ((fVec58[((IOTA - 126) & 511)] + fVec58[((IOTA - 346) & 511)]) - fVec58[((IOTA - 373) & 511)])) + ((0.00109866634f * (fVec58[((IOTA - 344) & 511)] - fVec58[((IOTA - 359) & 511)])) + ((0.00140385143f * (((fVec58[((IOTA - 116) & 511)] - fVec58[((IOTA - 209) & 511)]) - fVec58[((IOTA - 307) & 511)]) + fVec58[((IOTA - 345) & 511)])) + ((0.000793481246f * ((((fVec58[((IOTA - 112) & 511)] + fVec58[((IOTA - 129) & 511)]) - fVec58[((IOTA - 147) & 511)]) - fVec58[((IOTA - 258) & 511)]) - fVec58[((IOTA - 263) & 511)])) + ((0.00219733268f * (fVec58[((IOTA - 92) & 511)] - fVec58[((IOTA - 201) & 511)])) + ((0.00152592547f * (fVec58[((IOTA - 111) & 511)] - fVec58[((IOTA - 187) & 511)])) + ((0.00170903653f * (fVec58[((IOTA - 119) & 511)] - fVec58[((IOTA - 144) & 511)])) + ((0.00158696249f * (fVec58[((IOTA - 46) & 511)] + fVec58[((IOTA - 128) & 511)])) + ((0.00305185094f * fVec58[((IOTA - 118) & 511)]) + ((0.00317392498f * fVec58[((IOTA - 117) & 511)]) + ((0.00210577715f * fVec58[((IOTA - 110) & 511)]) + ((0.00350962859f * fVec58[((IOTA - 109) & 511)]) + ((0.00747703481f * (fVec58[((IOTA - 78) & 511)] + fVec58[((IOTA - 107) & 511)])) + ((0.00878933072f * fVec58[((IOTA - 106) & 511)]) + ((0.00881984923f * fVec58[((IOTA - 105) & 511)]) + ((0.00469985045f * fVec58[((IOTA - 103) & 511)]) + ((0.0087282937f * (fVec58[((IOTA - 10) & 511)] - fVec58[((IOTA - 95) & 511)])) + ((0.00506607257f * fVec58[((IOTA - 91) & 511)]) + ((0.00442518387f * fVec58[((IOTA - 90) & 511)]) + ((0.00405896176f * fVec58[((IOTA - 79) & 511)]) + ((0.0126041444f * fVec58[((IOTA - 76) & 511)]) + ((0.0110782189f * fVec58[((IOTA - 75) & 511)]) + ((0.00656147953f * fVec58[((IOTA - 74) & 511)]) + ((0.0190740693f * fVec58[((IOTA - 66) & 511)]) + ((0.0313119926f * fVec58[((IOTA - 65) & 511)]) + ((0.032227546f * fVec58[((IOTA - 64) & 511)]) + ((0.025818659f * fVec58[((IOTA - 63) & 511)]) + ((0.0139164403f * fVec58[((IOTA - 62) & 511)]) + ((0.0116885891f * fVec58[((IOTA - 55) & 511)]) + ((0.0229499191f * fVec58[((IOTA - 54) & 511)]) + ((0.0300912503f * fVec58[((IOTA - 53) & 511)]) + ((0.0333567299f * fVec58[((IOTA - 52) & 511)]) + ((0.0356151015f * fVec58[((IOTA - 51) & 511)]) + ((0.0394299142f * fVec58[((IOTA - 50) & 511)]) + ((0.0412915424f * fVec58[((IOTA - 49) & 511)]) + ((0.0348216183f * fVec58[((IOTA - 48) & 511)]) + ((0.00518814661f * fVec58[((IOTA - 39) & 511)]) + ((0.0173039958f * (fVec58[((IOTA - 24) & 511)] + fVec58[((IOTA - 38) & 511)])) + ((0.0214545131f * fVec58[((IOTA - 37) & 511)]) + ((0.0186162908f * fVec58[((IOTA - 36) & 511)]) + ((0.0141300699f * fVec58[((IOTA - 35) & 511)]) + ((0.0124515519f * fVec58[((IOTA - 34) & 511)]) + ((0.00994903408f * fVec58[((IOTA - 33) & 511)]) + ((0.025879696f * fVec58[((IOTA - 27) & 511)]) + ((0.0531022064f * fVec58[((IOTA - 26) & 511)]) + ((0.0493484288f * fVec58[((IOTA - 25) & 511)]) + ((0.0158391073f * fVec58[((IOTA - 21) & 511)]) + ((0.0479750969f * fVec58[((IOTA - 20) & 511)]) + ((0.0619220547f * fVec58[((IOTA - 19) & 511)]) + ((0.095858641f * fVec58[((IOTA - 9) & 511)]) + ((0.210333571f * fVec58[((IOTA - 8) & 511)]) + ((0.259590447f * fVec58[((IOTA - 7) & 511)]) + ((0.183111057f * fVec58[((IOTA - 6) & 511)]) + ((0.0171514023f * fVec58[((IOTA - 17) & 511)]) + (0.0458082817f * fVec58[((IOTA - 18) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000213629566f * ((((((((((((((((fVec58[((IOTA - 130) & 511)] + fVec58[((IOTA - 162) & 511)]) + fVec58[((IOTA - 287) & 511)]) + fVec58[((IOTA - 288) & 511)]) + fVec58[((IOTA - 289) & 511)]) - fVec58[((IOTA - 292) & 511)]) - fVec58[((IOTA - 318) & 511)]) + fVec58[((IOTA - 351) & 511)]) + fVec58[((IOTA - 408) & 511)]) + fVec58[((IOTA - 426) & 511)]) + fVec58[((IOTA - 428) & 511)]) - fVec58[((IOTA - 440) & 511)]) + fVec58[((IOTA - 472) & 511)]) + fVec58[((IOTA - 473) & 511)]) + fVec58[((IOTA - 474) & 511)]) + fVec58[((IOTA - 475) & 511)]) - fVec58[((IOTA - 500) & 511)])))) : (((0.00155644398f * (((fVec57[((IOTA - 363) & 511)] + fVec57[((IOTA - 411) & 511)]) + fVec57[((IOTA - 447) & 511)]) + fVec57[((IOTA - 501) & 511)])) + ((0.00180059206f * (((((fVec57[((IOTA - 83) & 511)] - fVec57[((IOTA - 225) & 511)]) + fVec57[((IOTA - 339) & 511)]) + fVec57[((IOTA - 386) & 511)]) + fVec57[((IOTA - 444) & 511)]) + fVec57[((IOTA - 491) & 511)])) + ((0.001617481f * ((((fVec57[((IOTA - 358) & 511)] + fVec57[((IOTA - 413) & 511)]) + fVec57[((IOTA - 446) & 511)]) + fVec57[((IOTA - 450) & 511)]) + fVec57[((IOTA - 489) & 511)])) + ((0.0019226661f * fVec57[((IOTA - 456) & 511)]) + ((0.00173955504f * (((fVec57[((IOTA - 360) & 511)] + fVec57[((IOTA - 361) & 511)]) + fVec57[((IOTA - 404) & 511)]) + fVec57[((IOTA - 451) & 511)])) + ((0.00164799951f * (((fVec57[((IOTA - 16) & 511)] - fVec57[((IOTA - 231) & 511)]) + fVec57[((IOTA - 412) & 511)]) + fVec57[((IOTA - 440) & 511)])) + ((0.000732444227f * fVec57[((IOTA - 436) & 511)]) + ((0.00238044374f * fVec57[((IOTA - 403) & 511)]) + ((0.00109866634f * (fVec57[((IOTA - 459) & 511)] - ((((fVec57[((IOTA - 243) & 511)] + fVec57[((IOTA - 245) & 511)]) + fVec57[((IOTA - 378) & 511)]) + fVec57[((IOTA - 391) & 511)]) - fVec57[((IOTA - 426) & 511)]))) + ((0.00332651753f * fVec57[((IOTA - 401) & 511)]) + ((9.15555283e-05f * ((((fVec57[((IOTA - 274) & 511)] - fVec57[((IOTA - 298) & 511)]) - fVec57[((IOTA - 299) & 511)]) - fVec57[((IOTA - 303) & 511)]) + fVec57[((IOTA - 396) & 511)])) + ((0.00216681417f * fVec57[((IOTA - 375) & 511)]) + ((0.00271614734f * fVec57[((IOTA - 374) & 511)]) + ((6.10370189e-05f * (((((fVec57[((IOTA - 82) & 511)] + fVec57[((IOTA - 93) & 511)]) - fVec57[((IOTA - 199) & 511)]) + fVec57[((IOTA - 201) & 511)]) - fVec57[((IOTA - 311) & 511)]) - fVec57[((IOTA - 348) & 511)])) + ((0.000244148076f * ((fVec57[((IOTA - 309) & 511)] - (((fVec57[((IOTA - 101) & 511)] + fVec57[((IOTA - 263) & 511)]) + fVec57[((IOTA - 264) & 511)]) + fVec57[((IOTA - 302) & 511)])) - fVec57[((IOTA - 347) & 511)])) + ((0.00213629566f * fVec57[((IOTA - 321) & 511)]) + ((0.000122074038f * ((fVec57[((IOTA - 200) & 511)] - fVec57[((IOTA - 300) & 511)]) + fVec57[((IOTA - 310) & 511)])) + (((0.00558488723f * (fVec57[((IOTA - 98) & 511)] - fVec57[((IOTA - 127) & 511)])) + ((0.00384533219f * (fVec57[((IOTA - 32) & 511)] - fVec57[((IOTA - 125) & 511)])) + ((0.00314340647f * (fVec57[((IOTA - 85) & 511)] - fVec57[((IOTA - 123) & 511)])) + ((0.00561540574f * (fVec57[((IOTA - 87) & 511)] - fVec57[((IOTA - 111) & 511)])) + ((0.00283822138f * fVec57[((IOTA - 100) & 511)]) + ((0.00491348002f * fVec57[((IOTA - 99) & 511)]) + ((0.00576799829f * fVec57[((IOTA - 97) & 511)]) + ((0.00415051728f * fVec57[((IOTA - 94) & 511)]) + ((0.00430310983f * (fVec57[((IOTA - 72) & 511)] - fVec57[((IOTA - 92) & 511)])) + ((0.00366222113f * fVec57[((IOTA - 88) & 511)]) + ((0.00424207281f * fVec57[((IOTA - 86) & 511)]) + ((0.00241096225f * fVec57[((IOTA - 84) & 511)]) + ((0.0130924406f * (fVec57[((IOTA - 40) & 511)] - fVec57[((IOTA - 76) & 511)])) + ((0.0121463668f * fVec57[((IOTA - 71) & 511)]) + ((0.0197454765f * fVec57[((IOTA - 70) & 511)]) + ((0.0210577715f * fVec57[((IOTA - 69) & 511)]) + ((0.0120242927f * fVec57[((IOTA - 68) & 511)]) + ((0.0119632557f * fVec57[((IOTA - 60) & 511)]) + ((0.0175481439f * fVec57[((IOTA - 59) & 511)]) + ((0.0155949583f * fVec57[((IOTA - 58) & 511)]) + ((0.00601214636f * fVec57[((IOTA - 57) & 511)]) + ((0.00604266487f * fVec57[((IOTA - 46) & 511)]) + ((0.0200506616f * fVec57[((IOTA - 45) & 511)]) + ((0.0295724366f * fVec57[((IOTA - 44) & 511)]) + ((0.0359202847f * fVec57[((IOTA - 43) & 511)]) + ((0.0361949541f * fVec57[((IOTA - 42) & 511)]) + ((0.027802363f * fVec57[((IOTA - 41) & 511)]) + ((0.0248420667f * fVec57[((IOTA - 31) & 511)]) + ((0.0426648781f * fVec57[((IOTA - 30) & 511)]) + ((0.0388805829f * fVec57[((IOTA - 29) & 511)]) + ((0.00781273842f * fVec57[((IOTA - 28) & 511)]) + ((0.0105899228f * fVec57[((IOTA - 23) & 511)]) + ((((((((fSlow137 * fTemp0) + (0.157444984f * fVec57[((IOTA - 1) & 511)])) + (0.283639014f * fVec57[((IOTA - 2) & 511)])) + (0.346385092f * fVec57[((IOTA - 3) & 511)])) + (0.266548663f * fVec57[((IOTA - 4) & 511)])) + (0.0731223524f * fVec57[((IOTA - 5) & 511)])) + (0.0111087374f * fVec57[((IOTA - 11) & 511)])) + (0.0135196997f * fVec57[((IOTA - 22) & 511)])))))))))))))))))))))))))))))))))) + (3.05185094e-05f * fVec57[((IOTA - 275) & 511)]))))))))))))))))))) - (((0.000976592302f * ((((fVec57[((IOTA - 246) & 511)] - fVec57[((IOTA - 333) & 511)]) - fVec57[((IOTA - 425) & 511)]) - fVec57[((IOTA - 470) & 511)]) - fVec57[((IOTA - 509) & 511)])) + ((0.00100711081f * (((((fVec57[((IOTA - 153) & 511)] + fVec57[((IOTA - 239) & 511)]) + fVec57[((IOTA - 242) & 511)]) - fVec57[((IOTA - 471) & 511)]) - fVec57[((IOTA - 475) & 511)]) - fVec57[((IOTA - 508) & 511)])) + ((0.00103762932f * (((((((((fVec57[((IOTA - 212) & 511)] + fVec57[((IOTA - 315) & 511)]) - fVec57[((IOTA - 336) & 511)]) - fVec57[((IOTA - 342) & 511)]) - fVec57[((IOTA - 429) & 511)]) - fVec57[((IOTA - 472) & 511)]) - fVec57[((IOTA - 473) & 511)]) - fVec57[((IOTA - 474) & 511)]) - fVec57[((IOTA - 476) & 511)]) - fVec57[((IOTA - 507) & 511)])) + ((0.00106814783f * ((((fVec57[((IOTA - 89) & 511)] + fVec57[((IOTA - 316) & 511)]) - fVec57[((IOTA - 376) & 511)]) - fVec57[((IOTA - 477) & 511)]) - fVec57[((IOTA - 506) & 511)])) + ((0.00112918485f * (((((((fVec57[((IOTA - 238) & 511)] + fVec57[((IOTA - 244) & 511)]) - fVec57[((IOTA - 370) & 511)]) + fVec57[((IOTA - 379) & 511)]) - fVec57[((IOTA - 427) & 511)]) - fVec57[((IOTA - 428) & 511)]) - fVec57[((IOTA - 478) & 511)]) - fVec57[((IOTA - 505) & 511)])) + ((0.00119022187f * ((((fVec57[((IOTA - 141) & 511)] + fVec57[((IOTA - 204) & 511)]) + fVec57[((IOTA - 237) & 511)]) - fVec57[((IOTA - 479) & 511)]) - fVec57[((IOTA - 504) & 511)])) + ((0.00131229591f * ((((fVec57[((IOTA - 207) & 511)] - fVec57[((IOTA - 337) & 511)]) - fVec57[((IOTA - 481) & 511)]) - fVec57[((IOTA - 482) & 511)]) - fVec57[((IOTA - 503) & 511)])) + ((0.00143436994f * ((((((fVec57[((IOTA - 154) & 511)] + fVec57[((IOTA - 157) & 511)]) - fVec57[((IOTA - 320) & 511)]) - fVec57[((IOTA - 364) & 511)]) - fVec57[((IOTA - 439) & 511)]) - fVec57[((IOTA - 487) & 511)]) - fVec57[((IOTA - 502) & 511)])) + ((0.00167851802f * (((fVec57[((IOTA - 158) & 511)] - fVec57[((IOTA - 362) & 511)]) - fVec57[((IOTA - 385) & 511)]) - fVec57[((IOTA - 500) & 511)])) + ((0.00177007355f * (((((((fVec57[((IOTA - 73) & 511)] + fVec57[((IOTA - 137) & 511)]) + fVec57[((IOTA - 142) & 511)]) + fVec57[((IOTA - 226) & 511)]) - fVec57[((IOTA - 371) & 511)]) - fVec57[((IOTA - 398) & 511)]) - fVec57[((IOTA - 441) & 511)]) - fVec57[((IOTA - 499) & 511)])) + ((0.00183111057f * ((((((((((((fVec57[((IOTA - 136) & 511)] + fVec57[((IOTA - 187) & 511)]) - fVec57[((IOTA - 323) & 511)]) - fVec57[((IOTA - 340) & 511)]) - fVec57[((IOTA - 383) & 511)]) - fVec57[((IOTA - 442) & 511)]) - fVec57[((IOTA - 443) & 511)]) - fVec57[((IOTA - 492) & 511)]) - fVec57[((IOTA - 494) & 511)]) - fVec57[((IOTA - 495) & 511)]) - fVec57[((IOTA - 496) & 511)]) - fVec57[((IOTA - 497) & 511)]) - fVec57[((IOTA - 498) & 511)])) + ((0.00186162908f * ((fVec57[((IOTA - 135) & 511)] + fVec57[((IOTA - 230) & 511)]) - fVec57[((IOTA - 493) & 511)])) + ((0.00170903653f * (((((fVec57[((IOTA - 149) & 511)] - fVec57[((IOTA - 359) & 511)]) - fVec57[((IOTA - 384) & 511)]) - fVec57[((IOTA - 445) & 511)]) - fVec57[((IOTA - 457) & 511)]) - fVec57[((IOTA - 490) & 511)])) + ((0.00149540696f * ((fVec57[((IOTA - 143) & 511)] - fVec57[((IOTA - 414) & 511)]) - fVec57[((IOTA - 488) & 511)])) + ((0.00140385143f * ((((fVec57[((IOTA - 156) & 511)] + fVec57[((IOTA - 194) & 511)]) - fVec57[((IOTA - 405) & 511)]) - fVec57[((IOTA - 458) & 511)]) - fVec57[((IOTA - 486) & 511)])) + ((0.00137333293f * (((fVec57[((IOTA - 215) & 511)] - fVec57[((IOTA - 410) & 511)]) - fVec57[((IOTA - 484) & 511)]) - fVec57[((IOTA - 485) & 511)])) + ((0.00134281442f * ((((fVec57[((IOTA - 213) & 511)] + fVec57[((IOTA - 233) & 511)]) + fVec57[((IOTA - 392) & 511)]) - fVec57[((IOTA - 415) & 511)]) - fVec57[((IOTA - 483) & 511)])) + ((0.00125125889f * ((((((fVec57[((IOTA - 138) & 511)] + fVec57[((IOTA - 188) & 511)]) + fVec57[((IOTA - 235) & 511)]) + fVec57[((IOTA - 236) & 511)]) - fVec57[((IOTA - 365) & 511)]) - fVec57[((IOTA - 407) & 511)]) - fVec57[((IOTA - 480) & 511)])) + ((0.000915555283f * (((((((((((fVec57[((IOTA - 208) & 511)] + fVec57[((IOTA - 240) & 511)]) + fVec57[((IOTA - 241) & 511)]) - fVec57[((IOTA - 324) & 511)]) - fVec57[((IOTA - 335) & 511)]) - fVec57[((IOTA - 366) & 511)]) + fVec57[((IOTA - 394) & 511)]) - fVec57[((IOTA - 430) & 511)]) - fVec57[((IOTA - 437) & 511)]) - fVec57[((IOTA - 460) & 511)]) - fVec57[((IOTA - 467) & 511)]) - fVec57[((IOTA - 468) & 511)])) + ((0.000885036774f * ((fVec57[((IOTA - 196) & 511)] - fVec57[((IOTA - 465) & 511)]) - fVec57[((IOTA - 466) & 511)])) + ((0.000854518265f * ((((fVec57[((IOTA - 314) & 511)] + fVec57[((IOTA - 317) & 511)]) - fVec57[((IOTA - 355) & 511)]) - fVec57[((IOTA - 397) & 511)]) - fVec57[((IOTA - 464) & 511)])) + ((0.000823999755f * ((((((fVec57[((IOTA - 189) & 511)] + fVec57[((IOTA - 247) & 511)]) + fVec57[((IOTA - 253) & 511)]) + fVec57[((IOTA - 254) & 511)]) + fVec57[((IOTA - 255) & 511)]) - fVec57[((IOTA - 332) & 511)]) - fVec57[((IOTA - 463) & 511)])) + ((0.000793481246f * ((((fVec57[((IOTA - 252) & 511)] - fVec57[((IOTA - 381) & 511)]) - fVec57[((IOTA - 424) & 511)]) - fVec57[((IOTA - 461) & 511)]) - fVec57[((IOTA - 462) & 511)])) + ((0.00207525864f * ((fVec57[((IOTA - 160) & 511)] + fVec57[((IOTA - 219) & 511)]) - fVec57[((IOTA - 455) & 511)])) + ((0.00210577715f * (fVec57[((IOTA - 114) & 511)] - fVec57[((IOTA - 454) & 511)])) + ((0.00201422162f * ((fVec57[((IOTA - 228) & 511)] + fVec57[((IOTA - 229) & 511)]) - fVec57[((IOTA - 453) & 511)])) + ((0.00189214759f * (((fVec57[((IOTA - 159) & 511)] + fVec57[((IOTA - 227) & 511)]) - fVec57[((IOTA - 387) & 511)]) - fVec57[((IOTA - 452) & 511)])) + ((0.00152592547f * ((((fVec57[((IOTA - 147) & 511)] + fVec57[((IOTA - 155) & 511)]) + fVec57[((IOTA - 206) & 511)]) - fVec57[((IOTA - 448) & 511)]) - fVec57[((IOTA - 449) & 511)])) + ((0.00115970336f * ((((fVec57[((IOTA - 195) & 511)] - fVec57[((IOTA - 356) & 511)]) - fVec57[((IOTA - 408) & 511)]) - fVec57[((IOTA - 416) & 511)]) - fVec57[((IOTA - 438) & 511)])) + ((0.000610370189f * (((((fVec57[((IOTA - 209) & 511)] + fVec57[((IOTA - 284) & 511)]) + fVec57[((IOTA - 285) & 511)]) + fVec57[((IOTA - 288) & 511)]) - fVec57[((IOTA - 353) & 511)]) - fVec57[((IOTA - 435) & 511)])) + ((0.00057985168f * ((((((((((fVec57[((IOTA - 139) & 511)] + fVec57[((IOTA - 258) & 511)]) + fVec57[((IOTA - 283) & 511)]) + fVec57[((IOTA - 286) & 511)]) + fVec57[((IOTA - 287) & 511)]) + fVec57[((IOTA - 290) & 511)]) + fVec57[((IOTA - 313) & 511)]) - fVec57[((IOTA - 367) & 511)]) - fVec57[((IOTA - 423) & 511)]) - fVec57[((IOTA - 433) & 511)]) - fVec57[((IOTA - 434) & 511)])) + ((0.000640888698f * (((((fVec57[((IOTA - 197) & 511)] + fVec57[((IOTA - 289) & 511)]) + fVec57[((IOTA - 327) & 511)]) - fVec57[((IOTA - 352) & 511)]) - fVec57[((IOTA - 369) & 511)]) - fVec57[((IOTA - 432) & 511)])) + ((0.000762962736f * ((((((fVec57[((IOTA - 144) & 511)] + fVec57[((IOTA - 190) & 511)]) + fVec57[((IOTA - 203) & 511)]) + fVec57[((IOTA - 251) & 511)]) + fVec57[((IOTA - 256) & 511)]) - fVec57[((IOTA - 389) & 511)]) - fVec57[((IOTA - 431) & 511)])) + ((0.000427259132f * (((((((fVec57[((IOTA - 259) & 511)] + fVec57[((IOTA - 279) & 511)]) + fVec57[((IOTA - 291) & 511)]) - fVec57[((IOTA - 307) & 511)]) + fVec57[((IOTA - 328) & 511)]) + fVec57[((IOTA - 346) & 511)]) - fVec57[((IOTA - 368) & 511)]) - fVec57[((IOTA - 422) & 511)])) + ((0.000305185094f * (((((((fVec57[((IOTA - 260) & 511)] + fVec57[((IOTA - 271) & 511)]) + fVec57[((IOTA - 277) & 511)]) - fVec57[((IOTA - 308) & 511)]) + fVec57[((IOTA - 312) & 511)]) + fVec57[((IOTA - 318) & 511)]) + fVec57[((IOTA - 390) & 511)]) - fVec57[((IOTA - 421) & 511)])) + ((0.000335703604f * ((((fVec57[((IOTA - 198) & 511)] + fVec57[((IOTA - 268) & 511)]) - fVec57[((IOTA - 350) & 511)]) + fVec57[((IOTA - 380) & 511)]) - fVec57[((IOTA - 420) & 511)])) + ((0.000457777642f * ((((fVec57[((IOTA - 61) & 511)] + fVec57[((IOTA - 280) & 511)]) - fVec57[((IOTA - 306) & 511)]) + fVec57[((IOTA - 345) & 511)]) - fVec57[((IOTA - 419) & 511)])) + ((0.000701925717f * (((((fVec57[((IOTA - 146) & 511)] + fVec57[((IOTA - 211) & 511)]) + fVec57[((IOTA - 248) & 511)]) + fVec57[((IOTA - 250) & 511)]) + fVec57[((IOTA - 257) & 511)]) - fVec57[((IOTA - 418) & 511)])) + ((0.00122074038f * ((fVec57[((IOTA - 216) & 511)] + fVec57[((IOTA - 393) & 511)]) - fVec57[((IOTA - 409) & 511)])) + ((0.0012817774f * (((fVec57[((IOTA - 192) & 511)] + fVec57[((IOTA - 217) & 511)]) + fVec57[((IOTA - 234) & 511)]) - fVec57[((IOTA - 406) & 511)])) + ((0.00299081393f * (fVec57[((IOTA - 185) & 511)] - fVec57[((IOTA - 402) & 511)])) + ((0.00317392498f * (fVec57[((IOTA - 180) & 511)] - fVec57[((IOTA - 400) & 511)])) + ((0.0025940733f * (fVec57[((IOTA - 176) & 511)] - fVec57[((IOTA - 399) & 511)])) + ((0.000488296151f * (fVec57[((IOTA - 281) & 511)] + fVec57[((IOTA - 395) & 511)])) + ((0.00158696249f * ((((fVec57[((IOTA - 218) & 511)] - fVec57[((IOTA - 338) & 511)]) - fVec57[((IOTA - 341) & 511)]) - fVec57[((IOTA - 382) & 511)]) - fVec57[((IOTA - 388) & 511)])) + ((0.000213629566f * ((((((fVec57[((IOTA - 261) & 511)] + fVec57[((IOTA - 262) & 511)]) + fVec57[((IOTA - 265) & 511)]) + fVec57[((IOTA - 267) & 511)]) + fVec57[((IOTA - 301) & 511)]) + fVec57[((IOTA - 344) & 511)]) + fVec57[((IOTA - 377) & 511)])) + ((0.00268562883f * (fVec57[((IOTA - 177) & 511)] - fVec57[((IOTA - 373) & 511)])) + ((0.00231940672f * ((fVec57[((IOTA - 134) & 511)] - fVec57[((IOTA - 322) & 511)]) - fVec57[((IOTA - 372) & 511)])) + ((0.00146488845f * ((((fVec57[((IOTA - 193) & 511)] + fVec57[((IOTA - 205) & 511)]) + fVec57[((IOTA - 214) & 511)]) + fVec57[((IOTA - 232) & 511)]) - fVec57[((IOTA - 357) & 511)])) + ((0.000671407208f * (fVec57[((IOTA - 249) & 511)] - fVec57[((IOTA - 354) & 511)])) + ((0.00054933317f * ((((fVec57[((IOTA - 12) & 511)] - fVec57[((IOTA - 15) & 511)]) + fVec57[((IOTA - 326) & 511)]) - fVec57[((IOTA - 331) & 511)]) - fVec57[((IOTA - 351) & 511)])) + ((0.000152592547f * ((((((fVec57[((IOTA - 272) & 511)] + fVec57[((IOTA - 276) & 511)]) + fVec57[((IOTA - 294) & 511)]) + fVec57[((IOTA - 297) & 511)]) - fVec57[((IOTA - 304) & 511)]) + fVec57[((IOTA - 329) & 511)]) - fVec57[((IOTA - 349) & 511)])) + ((0.000366222113f * (fVec57[((IOTA - 145) & 511)] - fVec57[((IOTA - 343) & 511)])) + ((0.000183111057f * ((((fVec57[((IOTA - 266) & 511)] + fVec57[((IOTA - 293) & 511)]) + fVec57[((IOTA - 295) & 511)]) + fVec57[((IOTA - 296) & 511)]) - fVec57[((IOTA - 330) & 511)])) + ((0.000518814661f * ((((fVec57[((IOTA - 140) & 511)] + fVec57[((IOTA - 152) & 511)]) + fVec57[((IOTA - 210) & 511)]) + fVec57[((IOTA - 282) & 511)]) - fVec57[((IOTA - 319) & 511)])) + ((0.000396740623f * ((((fVec57[((IOTA - 151) & 511)] + fVec57[((IOTA - 269) & 511)]) + fVec57[((IOTA - 270) & 511)]) + fVec57[((IOTA - 278) & 511)]) - fVec57[((IOTA - 305) & 511)])) + ((0.000274666585f * (fVec57[((IOTA - 202) & 511)] + fVec57[((IOTA - 292) & 511)])) + ((0.0019531846f * fVec57[((IOTA - 224) & 511)]) + ((0.00222785119f * fVec57[((IOTA - 223) & 511)]) + ((0.00247199927f * (((fVec57[((IOTA - 115) & 511)] + fVec57[((IOTA - 186) & 511)]) + fVec57[((IOTA - 220) & 511)]) + fVec57[((IOTA - 222) & 511)])) + ((0.00262459181f * (fVec57[((IOTA - 163) & 511)] + fVec57[((IOTA - 221) & 511)])) + ((0.00341807306f * (fVec57[((IOTA - 170) & 511)] + fVec57[((IOTA - 184) & 511)])) + ((0.00363170262f * ((fVec57[((IOTA - 132) & 511)] + fVec57[((IOTA - 168) & 511)]) + fVec57[((IOTA - 183) & 511)])) + ((0.00360118411f * fVec57[((IOTA - 182) & 511)]) + ((0.00338755455f * fVec57[((IOTA - 181) & 511)]) + ((0.00302133244f * fVec57[((IOTA - 179) & 511)]) + ((0.0028992584f * fVec57[((IOTA - 178) & 511)]) + ((0.00280770287f * fVec57[((IOTA - 175) & 511)]) + ((0.00335703604f * fVec57[((IOTA - 174) & 511)]) + ((0.00381481368f * (fVec57[((IOTA - 172) & 511)] + fVec57[((IOTA - 173) & 511)])) + ((0.0035401471f * ((fVec57[((IOTA - 122) & 511)] + fVec57[((IOTA - 169) & 511)]) + fVec57[((IOTA - 171) & 511)])) + ((0.00344859157f * fVec57[((IOTA - 167) & 511)]) + ((0.00311288796f * (fVec57[((IOTA - 124) & 511)] + fVec57[((IOTA - 166) & 511)])) + ((0.00277718436f * (fVec57[((IOTA - 39) & 511)] + fVec57[((IOTA - 165) & 511)])) + ((0.00265511032f * fVec57[((IOTA - 164) & 511)]) + ((0.00250251777f * fVec57[((IOTA - 162) & 511)]) + ((0.0022583697f * fVec57[((IOTA - 161) & 511)]) + ((0.00198370311f * fVec57[((IOTA - 148) & 511)]) + ((0.00308236945f * fVec57[((IOTA - 133) & 511)]) + ((0.00393688772f * (fVec57[((IOTA - 120) & 511)] + fVec57[((IOTA - 131) & 511)])) + ((0.0042115543f * fVec57[((IOTA - 130) & 511)]) + ((0.00476088747f * fVec57[((IOTA - 129) & 511)]) + ((0.00537125766f * fVec57[((IOTA - 128) & 511)]) + ((0.00494399853f * fVec57[((IOTA - 126) & 511)]) + ((0.00369273964f * fVec57[((IOTA - 121) & 511)]) + ((0.00482192449f * fVec57[((IOTA - 119) & 511)]) + ((0.00598162785f * fVec57[((IOTA - 118) & 511)]) + ((0.00595110934f * fVec57[((IOTA - 117) & 511)]) + ((0.00433362834f * fVec57[((IOTA - 116) & 511)]) + ((0.00329599902f * fVec57[((IOTA - 113) & 511)]) + ((0.00473036896f * fVec57[((IOTA - 112) & 511)]) + ((0.00643940549f * fVec57[((IOTA - 110) & 511)]) + ((0.00793481246f * fVec57[((IOTA - 109) & 511)]) + ((0.00976592302f * fVec57[((IOTA - 104) & 511)]) + ((0.00686666463f * fVec57[((IOTA - 103) & 511)]) + ((0.00372325815f * fVec57[((IOTA - 102) & 511)]) + ((0.00625629444f * ((fVec57[((IOTA - 33) & 511)] - fVec57[((IOTA - 95) & 511)]) - fVec57[((IOTA - 96) & 511)])) + ((0.0113528855f * fVec57[((IOTA - 107) & 511)]) + ((0.0115970336f * fVec57[((IOTA - 105) & 511)]) + ((0.00671407208f * fVec57[((IOTA - 91) & 511)]) + ((0.00570696127f * fVec57[((IOTA - 90) & 511)]) + ((0.00204474013f * fVec57[((IOTA - 81) & 511)]) + ((0.00405896176f * fVec57[((IOTA - 80) & 511)]) + ((0.006469924f * fVec57[((IOTA - 79) & 511)]) + ((0.00930814538f * fVec57[((IOTA - 78) & 511)]) + ((0.0124210333f * fVec57[((IOTA - 77) & 511)]) + ((0.0121158483f * fVec57[((IOTA - 106) & 511)]) + ((0.00979644153f * fVec57[((IOTA - 108) & 511)]) + ((0.0109256264f * fVec57[((IOTA - 75) & 511)]) + ((0.00640888698f * fVec57[((IOTA - 74) & 511)]) + ((0.00668355357f * fVec57[((IOTA - 67) & 511)]) + ((0.0258491784f * fVec57[((IOTA - 66) & 511)]) + ((0.0364391021f * (fVec57[((IOTA - 53) & 511)] + fVec57[((IOTA - 65) & 511)])) + ((0.0353404358f * fVec57[((IOTA - 64) & 511)]) + ((0.0271004364f * fVec57[((IOTA - 63) & 511)]) + ((0.0142521439f * fVec57[((IOTA - 62) & 511)]) + ((0.00717184972f * fVec57[((IOTA - 56) & 511)]) + ((0.0209356975f * fVec57[((IOTA - 55) & 511)]) + ((0.0312204361f * fVec57[((IOTA - 54) & 511)]) + ((0.0374156944f * fVec57[((IOTA - 52) & 511)]) + ((0.0370799899f * fVec57[((IOTA - 51) & 511)]) + ((0.0379955433f * fVec57[((IOTA - 50) & 511)]) + ((0.036774803f * fVec57[((IOTA - 49) & 511)]) + ((0.0281991027f * fVec57[((IOTA - 48) & 511)]) + ((0.0115359966f * fVec57[((IOTA - 47) & 511)]) + ((0.0143742179f * (fVec57[((IOTA - 21) & 511)] + fVec57[((IOTA - 38) & 511)])) + ((0.0188299213f * fVec57[((IOTA - 37) & 511)]) + ((0.016235847f * fVec57[((IOTA - 36) & 511)]) + ((0.0116275521f * fVec57[((IOTA - 35) & 511)]) + ((0.00946073793f * fVec57[((IOTA - 34) & 511)]) + ((0.0323191024f * fVec57[((IOTA - 27) & 511)]) + ((0.0557878353f * fVec57[((IOTA - 26) & 511)]) + ((0.0497451723f * fVec57[((IOTA - 25) & 511)]) + ((0.0174260698f * fVec57[((IOTA - 24) & 511)]) + ((0.0438245796f * fVec57[((IOTA - 20) & 511)]) + ((0.0567949452f * fVec57[((IOTA - 19) & 511)]) + ((0.0419019125f * fVec57[((IOTA - 18) & 511)]) + (((0.00762962736f * fVec57[((IOTA - 14) & 511)]) + ((((((0.114444412f * fVec57[((IOTA - 6) & 511)]) + (0.202703938f * fVec57[((IOTA - 7) & 511)])) + (0.17371136f * fVec57[((IOTA - 8) & 511)])) + (0.0810876787f * fVec57[((IOTA - 9) & 511)])) + (0.00967436749f * fVec57[((IOTA - 10) & 511)])) + (0.00830103457f * fVec57[((IOTA - 13) & 511)]))) + (0.016296884f * fVec57[((IOTA - 17) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000946073793f * ((((((fVec57[((IOTA - 150) & 511)] + fVec57[((IOTA - 191) & 511)]) - fVec57[((IOTA - 334) & 511)]) - fVec57[((IOTA - 417) & 511)]) - fVec57[((IOTA - 469) & 511)]) - fVec57[((IOTA - 510) & 511)]) - fVec57[((IOTA - 511) & 511)]))))))) : (iSlow116 ? (iSlow125 ? (iSlow129 ? (((9.15555283e-05f * (((((((((fVec56[((IOTA - 57) & 511)] + fVec56[((IOTA - 61) & 511)]) - fVec56[((IOTA - 62) & 511)]) - fVec56[((IOTA - 220) & 511)]) - fVec56[((IOTA - 260) & 511)]) + fVec56[((IOTA - 265) & 511)]) + fVec56[((IOTA - 288) & 511)]) + fVec56[((IOTA - 478) & 511)]) - fVec56[((IOTA - 491) & 511)]) + fVec56[((IOTA - 511) & 511)])) + ((3.05185094e-05f * ((((((((((((((((((((((((((((((((((((((((((((((((fVec56[((IOTA - 1) & 511)] + fVec56[((IOTA - 3) & 511)]) + fVec56[((IOTA - 4) & 511)]) + fVec56[((IOTA - 5) & 511)]) + fVec56[((IOTA - 6) & 511)]) + fVec56[((IOTA - 7) & 511)]) + fVec56[((IOTA - 9) & 511)]) + fVec56[((IOTA - 10) & 511)]) + fVec56[((IOTA - 11) & 511)]) + fVec56[((IOTA - 12) & 511)]) + fVec56[((IOTA - 13) & 511)]) + fVec56[((IOTA - 14) & 511)]) + fVec56[((IOTA - 15) & 511)]) + fVec56[((IOTA - 16) & 511)]) + fVec56[((IOTA - 17) & 511)]) + fVec56[((IOTA - 18) & 511)]) + fVec56[((IOTA - 19) & 511)]) + fVec56[((IOTA - 20) & 511)]) + fVec56[((IOTA - 22) & 511)]) + fVec56[((IOTA - 24) & 511)]) + fVec56[((IOTA - 26) & 511)]) + fVec56[((IOTA - 27) & 511)]) + fVec56[((IOTA - 28) & 511)]) + fVec56[((IOTA - 29) & 511)]) + fVec56[((IOTA - 30) & 511)]) + fVec56[((IOTA - 31) & 511)]) + fVec56[((IOTA - 32) & 511)]) + fVec56[((IOTA - 33) & 511)]) + fVec56[((IOTA - 35) & 511)]) + fVec56[((IOTA - 36) & 511)]) + fVec56[((IOTA - 37) & 511)]) + fVec56[((IOTA - 39) & 511)]) + fVec56[((IOTA - 41) & 511)]) + fVec56[((IOTA - 42) & 511)]) + fVec56[((IOTA - 43) & 511)]) + fVec56[((IOTA - 44) & 511)]) + fVec56[((IOTA - 45) & 511)]) + fVec56[((IOTA - 46) & 511)]) + fVec56[((IOTA - 53) & 511)]) + fVec56[((IOTA - 54) & 511)]) + fVec56[((IOTA - 55) & 511)]) - fVec56[((IOTA - 190) & 511)]) - fVec56[((IOTA - 263) & 511)]) - fVec56[((IOTA - 273) & 511)]) + fVec56[((IOTA - 372) & 511)]) + fVec56[((IOTA - 391) & 511)]) + fVec56[((IOTA - 479) & 511)]) - fVec56[((IOTA - 482) & 511)]) - fVec56[((IOTA - 510) & 511)])) + ((0.000152592547f * (((((fVec56[((IOTA - 58) & 511)] - fVec56[((IOTA - 146) & 511)]) - fVec56[((IOTA - 443) & 511)]) + fVec56[((IOTA - 484) & 511)]) + fVec56[((IOTA - 490) & 511)]) - fVec56[((IOTA - 509) & 511)])) + ((0.000244148076f * (((((((((((fVec56[((IOTA - 59) & 511)] + fVec56[((IOTA - 135) & 511)]) - fVec56[((IOTA - 198) & 511)]) + fVec56[((IOTA - 272) & 511)]) + fVec56[((IOTA - 286) & 511)]) + fVec56[((IOTA - 296) & 511)]) + fVec56[((IOTA - 336) & 511)]) - fVec56[((IOTA - 469) & 511)]) + fVec56[((IOTA - 472) & 511)]) + fVec56[((IOTA - 477) & 511)]) + fVec56[((IOTA - 504) & 511)]) - fVec56[((IOTA - 508) & 511)])) + ((0.000274666585f * (fVec56[((IOTA - 335) & 511)] - fVec56[((IOTA - 507) & 511)])) + ((0.000366222113f * (((((fVec56[((IOTA - 300) & 511)] + fVec56[((IOTA - 388) & 511)]) + fVec56[((IOTA - 474) & 511)]) + fVec56[((IOTA - 489) & 511)]) - fVec56[((IOTA - 497) & 511)]) + fVec56[((IOTA - 503) & 511)])) + ((0.000427259132f * ((((((((fVec56[((IOTA - 298) & 511)] + fVec56[((IOTA - 322) & 511)]) + fVec56[((IOTA - 326) & 511)]) + fVec56[((IOTA - 441) & 511)]) + fVec56[((IOTA - 467) & 511)]) + fVec56[((IOTA - 475) & 511)]) - fVec56[((IOTA - 493) & 511)]) - fVec56[((IOTA - 496) & 511)]) + fVec56[((IOTA - 502) & 511)])) + ((0.000122074038f * (((((fVec56[((IOTA - 199) & 511)] - fVec56[((IOTA - 207) & 511)]) + fVec56[((IOTA - 390) & 511)]) + fVec56[((IOTA - 442) & 511)]) - fVec56[((IOTA - 458) & 511)]) + fVec56[((IOTA - 500) & 511)])) + ((0.000213629566f * (((fVec56[((IOTA - 60) & 511)] + fVec56[((IOTA - 392) & 511)]) - fVec56[((IOTA - 470) & 511)]) - fVec56[((IOTA - 499) & 511)])) + ((0.000335703604f * ((((((fVec56[((IOTA - 249) & 511)] + fVec56[((IOTA - 289) & 511)]) + fVec56[((IOTA - 297) & 511)]) + fVec56[((IOTA - 324) & 511)]) - fVec56[((IOTA - 444) & 511)]) - fVec56[((IOTA - 445) & 511)]) - fVec56[((IOTA - 498) & 511)])) + ((0.000457777642f * ((((fVec56[((IOTA - 239) & 511)] + fVec56[((IOTA - 334) & 511)]) + fVec56[((IOTA - 476) & 511)]) - fVec56[((IOTA - 494) & 511)]) - fVec56[((IOTA - 495) & 511)])) + ((0.000305185094f * (((((fVec56[((IOTA - 323) & 511)] + fVec56[((IOTA - 337) & 511)]) + fVec56[((IOTA - 389) & 511)]) + fVec56[((IOTA - 473) & 511)]) + fVec56[((IOTA - 485) & 511)]) - fVec56[((IOTA - 492) & 511)])) + ((0.000518814661f * ((((fVec56[((IOTA - 275) & 511)] + fVec56[((IOTA - 295) & 511)]) + fVec56[((IOTA - 338) & 511)]) + fVec56[((IOTA - 459) & 511)]) + fVec56[((IOTA - 488) & 511)])) + ((0.000488296151f * (((((fVec56[((IOTA - 246) & 511)] - fVec56[((IOTA - 262) & 511)]) + fVec56[((IOTA - 285) & 511)]) + fVec56[((IOTA - 327) & 511)]) + fVec56[((IOTA - 387) & 511)]) + fVec56[((IOTA - 487) & 511)])) + ((0.000946073793f * (((((((fVec56[((IOTA - 200) & 511)] + fVec56[((IOTA - 259) & 511)]) + fVec56[((IOTA - 283) & 511)]) + fVec56[((IOTA - 436) & 511)]) + fVec56[((IOTA - 437) & 511)]) + fVec56[((IOTA - 451) & 511)]) + fVec56[((IOTA - 460) & 511)]) + fVec56[((IOTA - 465) & 511)])) + ((0.000885036774f * ((((((((fVec56[((IOTA - 240) & 511)] + fVec56[((IOTA - 331) & 511)]) + fVec56[((IOTA - 354) & 511)]) + fVec56[((IOTA - 365) & 511)]) + fVec56[((IOTA - 383) & 511)]) + fVec56[((IOTA - 404) & 511)]) + fVec56[((IOTA - 428) & 511)]) + fVec56[((IOTA - 463) & 511)]) + fVec56[((IOTA - 464) & 511)])) + ((0.00112918485f * ((fVec56[((IOTA - 363) & 511)] - fVec56[((IOTA - 456) & 511)]) + fVec56[((IOTA - 461) & 511)])) + ((6.10370189e-05f * ((((((((((((((fVec56[((IOTA - 21) & 511)] + fVec56[((IOTA - 23) & 511)]) + fVec56[((IOTA - 47) & 511)]) + fVec56[((IOTA - 48) & 511)]) + fVec56[((IOTA - 49) & 511)]) + fVec56[((IOTA - 50) & 511)]) + fVec56[((IOTA - 51) & 511)]) + fVec56[((IOTA - 52) & 511)]) + fVec56[((IOTA - 56) & 511)]) + fVec56[((IOTA - 287) & 511)]) + fVec56[((IOTA - 446) & 511)]) - fVec56[((IOTA - 452) & 511)]) + fVec56[((IOTA - 471) & 511)]) + fVec56[((IOTA - 480) & 511)]) + fVec56[((IOTA - 505) & 511)])) + ((0.00134281442f * ((fVec56[((IOTA - 398) & 511)] + fVec56[((IOTA - 432) & 511)]) - fVec56[((IOTA - 455) & 511)])) + ((0.0012817774f * (fVec56[((IOTA - 346) & 511)] - fVec56[((IOTA - 454) & 511)])) + ((0.0022583697f * fVec56[((IOTA - 449) & 511)]) + ((0.00180059206f * fVec56[((IOTA - 448) & 511)]) + ((0.000671407208f * ((((((fVec56[((IOTA - 284) & 511)] + fVec56[((IOTA - 321) & 511)]) + fVec56[((IOTA - 328) & 511)]) + fVec56[((IOTA - 339) & 511)]) + fVec56[((IOTA - 350) & 511)]) + fVec56[((IOTA - 405) & 511)]) + fVec56[((IOTA - 440) & 511)])) + ((0.000701925717f * (((fVec56[((IOTA - 212) & 511)] + fVec56[((IOTA - 349) & 511)]) + fVec56[((IOTA - 407) & 511)]) - fVec56[((IOTA - 457) & 511)])) + ((0.000915555283f * ((((((fVec56[((IOTA - 145) & 511)] + fVec56[((IOTA - 311) & 511)]) + fVec56[((IOTA - 315) & 511)]) + fVec56[((IOTA - 329) & 511)]) + fVec56[((IOTA - 415) & 511)]) + fVec56[((IOTA - 422) & 511)]) + fVec56[((IOTA - 438) & 511)])) + ((0.00122074038f * (((((fVec56[((IOTA - 267) & 511)] + fVec56[((IOTA - 270) & 511)]) + fVec56[((IOTA - 292) & 511)]) + fVec56[((IOTA - 293) & 511)]) + fVec56[((IOTA - 377) & 511)]) + fVec56[((IOTA - 434) & 511)])) + ((0.00137333293f * (((fVec56[((IOTA - 318) & 511)] + fVec56[((IOTA - 343) & 511)]) + fVec56[((IOTA - 402) & 511)]) + fVec56[((IOTA - 433) & 511)])) + ((0.00115970336f * (((((((fVec56[((IOTA - 310) & 511)] + fVec56[((IOTA - 342) & 511)]) + fVec56[((IOTA - 357) & 511)]) + fVec56[((IOTA - 360) & 511)]) + fVec56[((IOTA - 361) & 511)]) + fVec56[((IOTA - 382) & 511)]) + fVec56[((IOTA - 403) & 511)]) + fVec56[((IOTA - 430) & 511)])) + ((0.00103762932f * (((fVec56[((IOTA - 341) & 511)] + fVec56[((IOTA - 347) & 511)]) + fVec56[((IOTA - 375) & 511)]) + fVec56[((IOTA - 429) & 511)])) + ((0.000762962736f * ((((fVec56[((IOTA - 179) & 511)] + fVec56[((IOTA - 393) & 511)]) + fVec56[((IOTA - 408) & 511)]) + fVec56[((IOTA - 417) & 511)]) + fVec56[((IOTA - 420) & 511)])) + ((0.00143436994f * ((((fVec56[((IOTA - 148) & 511)] + fVec56[((IOTA - 178) & 511)]) + fVec56[((IOTA - 206) & 511)]) + fVec56[((IOTA - 345) & 511)]) + fVec56[((IOTA - 401) & 511)])) + ((0.00131229591f * (((((fVec56[((IOTA - 305) & 511)] + fVec56[((IOTA - 319) & 511)]) + fVec56[((IOTA - 367) & 511)]) + fVec56[((IOTA - 370) & 511)]) + fVec56[((IOTA - 394) & 511)]) + fVec56[((IOTA - 400) & 511)])) + ((0.00152592547f * (fVec56[((IOTA - 257) & 511)] + fVec56[((IOTA - 397) & 511)])) + ((0.00164799951f * ((fVec56[((IOTA - 250) & 511)] + fVec56[((IOTA - 308) & 511)]) + fVec56[((IOTA - 396) & 511)])) + ((0.001617481f * ((fVec56[((IOTA - 368) & 511)] + fVec56[((IOTA - 380) & 511)]) + fVec56[((IOTA - 395) & 511)])) + ((0.00167851802f * (fVec56[((IOTA - 219) & 511)] + fVec56[((IOTA - 379) & 511)])) + ((0.00109866634f * ((fVec56[((IOTA - 242) & 511)] + fVec56[((IOTA - 282) & 511)]) + fVec56[((IOTA - 376) & 511)])) + ((0.00054933317f * ((((fVec56[((IOTA - 266) & 511)] + fVec56[((IOTA - 278) & 511)]) + fVec56[((IOTA - 279) & 511)]) + fVec56[((IOTA - 302) & 511)]) + fVec56[((IOTA - 371) & 511)])) + ((0.00173955504f * (fVec56[((IOTA - 307) & 511)] + fVec56[((IOTA - 369) & 511)])) + ((0.000976592302f * (((fVec56[((IOTA - 294) & 511)] + fVec56[((IOTA - 330) & 511)]) + fVec56[((IOTA - 355) & 511)]) + fVec56[((IOTA - 364) & 511)])) + ((0.00119022187f * fVec56[((IOTA - 362) & 511)]) + ((0.00106814783f * (((fVec56[((IOTA - 147) & 511)] + fVec56[((IOTA - 291) & 511)]) + fVec56[((IOTA - 304) & 511)]) + fVec56[((IOTA - 356) & 511)])) + ((0.00155644398f * (((fVec56[((IOTA - 149) & 511)] + fVec56[((IOTA - 243) & 511)]) + fVec56[((IOTA - 245) & 511)]) + fVec56[((IOTA - 306) & 511)])) + ((0.00210577715f * fVec56[((IOTA - 254) & 511)]) + ((0.00256355479f * (fVec56[((IOTA - 150) & 511)] + fVec56[((IOTA - 253) & 511)])) + ((0.00286873989f * ((fVec56[((IOTA - 125) & 511)] - fVec56[((IOTA - 210) & 511)]) + fVec56[((IOTA - 252) & 511)])) + ((0.00262459181f * fVec56[((IOTA - 251) & 511)]) + ((0.00189214759f * fVec56[((IOTA - 244) & 511)]) + ((0.00216681417f * (fVec56[((IOTA - 98) & 511)] - fVec56[((IOTA - 228) & 511)])) + ((0.00314340647f * (fVec56[((IOTA - 144) & 511)] - fVec56[((IOTA - 224) & 511)])) + ((0.00296029542f * (fVec56[((IOTA - 154) & 511)] - fVec56[((IOTA - 222) & 511)])) + ((0.00375377666f * fVec56[((IOTA - 217) & 511)]) + ((0.00454725791f * (fVec56[((IOTA - 81) & 511)] + fVec56[((IOTA - 216) & 511)])) + ((0.00497451704f * fVec56[((IOTA - 215) & 511)]) + ((0.00292977691f * (fVec56[((IOTA - 140) & 511)] + fVec56[((IOTA - 205) & 511)])) + ((0.00253303628f * (fVec56[((IOTA - 201) & 511)] + fVec56[((IOTA - 204) & 511)])) + ((0.00280770287f * fVec56[((IOTA - 203) & 511)]) + ((0.00317392498f * fVec56[((IOTA - 202) & 511)]) + ((0.00396740623f * (fVec56[((IOTA - 70) & 511)] - fVec56[((IOTA - 193) & 511)])) + ((0.00366222113f * (fVec56[((IOTA - 167) & 511)] - fVec56[((IOTA - 188) & 511)])) + ((0.00744651631f * fVec56[((IOTA - 166) & 511)]) + ((0.00772118289f * fVec56[((IOTA - 165) & 511)]) + ((0.00491348002f * fVec56[((IOTA - 164) & 511)]) + ((0.0054933317f * ((fVec56[((IOTA - 142) & 511)] + fVec56[((IOTA - 151) & 511)]) + fVec56[((IOTA - 163) & 511)])) + ((0.00439466536f * (fVec56[((IOTA - 214) & 511)] - fVec56[((IOTA - 168) & 511)])) + ((0.00717184972f * fVec56[((IOTA - 162) & 511)]) + ((0.00967436749f * fVec56[((IOTA - 161) & 511)]) + ((0.011383404f * fVec56[((IOTA - 160) & 511)]) + ((0.00384533219f * fVec56[((IOTA - 159) & 511)]) + ((0.00881984923f * fVec56[((IOTA - 153) & 511)]) + ((0.0087282937f * fVec56[((IOTA - 152) & 511)]) + ((0.00473036896f * fVec56[((IOTA - 143) & 511)]) + ((0.00701925717f * fVec56[((IOTA - 141) & 511)]) + ((0.00338755455f * fVec56[((IOTA - 139) & 511)]) + ((0.0144657735f * (fVec56[((IOTA - 126) & 511)] - fVec56[((IOTA - 129) & 511)])) + ((0.00622577593f * fVec56[((IOTA - 138) & 511)]) + ((0.00735496078f * fVec56[((IOTA - 137) & 511)]) + ((0.00463881344f * fVec56[((IOTA - 136) & 511)]) + ((0.00720236823f * fVec56[((IOTA - 128) & 511)]) + ((0.019470809f * fVec56[((IOTA - 127) & 511)]) + ((0.00482192449f * fVec56[((IOTA - 115) & 511)]) + ((0.0123905148f * fVec56[((IOTA - 114) & 511)]) + ((0.00671407208f * fVec56[((IOTA - 113) & 511)]) + ((0.0119632557f * fVec56[((IOTA - 112) & 511)]) + ((0.0171819218f * fVec56[((IOTA - 111) & 511)]) + ((0.0231025126f * fVec56[((IOTA - 110) & 511)]) + ((0.0233466607f * fVec56[((IOTA - 109) & 511)]) + ((0.0154423658f * fVec56[((IOTA - 108) & 511)]) + ((0.00576799829f * fVec56[((IOTA - 107) & 511)]) + ((0.0274971779f * fVec56[((IOTA - 101) & 511)]) + ((0.0351573229f * fVec56[((IOTA - 100) & 511)]) + ((0.0202032533f * fVec56[((IOTA - 99) & 511)]) + ((0.0164494775f * fVec56[((IOTA - 84) & 511)]) + ((0.048585467f * fVec56[((IOTA - 83) & 511)]) + ((0.0666524246f * fVec56[((IOTA - 82) & 511)]) + ((0.132084116f * fVec56[((IOTA - 76) & 511)]) + ((0.312753677f * fVec56[((IOTA - 75) & 511)]) + ((0.294412047f * fVec56[((IOTA - 74) & 511)]) + ((0.143986329f * fVec56[((IOTA - 73) & 511)]) + ((0.00762962736f * fVec56[((IOTA - 71) & 511)]) + (0.0348521397f * fVec56[((IOTA - 72) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000396740623f * ((((((fVec56[((IOTA - 247) & 511)] + fVec56[((IOTA - 248) & 511)]) - fVec56[((IOTA - 299) & 511)]) - fVec56[((IOTA - 301) & 511)]) - fVec56[((IOTA - 325) & 511)]) - fVec56[((IOTA - 486) & 511)]) - fVec56[((IOTA - 501) & 511)])) + ((0.000823999755f * (((((((fVec56[((IOTA - 192) & 511)] - fVec56[((IOTA - 271) & 511)]) - fVec56[((IOTA - 312) & 511)]) - fVec56[((IOTA - 348) & 511)]) - fVec56[((IOTA - 384) & 511)]) - fVec56[((IOTA - 409) & 511)]) - fVec56[((IOTA - 427) & 511)]) - fVec56[((IOTA - 466) & 511)])) + ((0.00100711081f * ((((((((fVec56[((IOTA - 236) & 511)] - fVec56[((IOTA - 241) & 511)]) - fVec56[((IOTA - 316) & 511)]) - fVec56[((IOTA - 320) & 511)]) - fVec56[((IOTA - 366) & 511)]) - fVec56[((IOTA - 413) & 511)]) - fVec56[((IOTA - 414) & 511)]) - fVec56[((IOTA - 435) & 511)]) - fVec56[((IOTA - 462) & 511)])) + ((0.000854518265f * ((((((((((((fVec56[((IOTA - 189) & 511)] - fVec56[((IOTA - 281) & 511)]) - fVec56[((IOTA - 303) & 511)]) - fVec56[((IOTA - 314) & 511)]) - fVec56[((IOTA - 340) & 511)]) - fVec56[((IOTA - 410) & 511)]) - fVec56[((IOTA - 411) & 511)]) - fVec56[((IOTA - 412) & 511)]) - fVec56[((IOTA - 421) & 511)]) - fVec56[((IOTA - 423) & 511)]) - fVec56[((IOTA - 439) & 511)]) - fVec56[((IOTA - 447) & 511)]) + fVec56[((IOTA - 453) & 511)])) + ((0.00186162908f * (fVec56[((IOTA - 232) & 511)] - fVec56[((IOTA - 450) & 511)])) + ((0.00125125889f * (((((fVec56[((IOTA - 235) & 511)] - fVec56[((IOTA - 317) & 511)]) - fVec56[((IOTA - 358) & 511)]) - fVec56[((IOTA - 359) & 511)]) - fVec56[((IOTA - 399) & 511)]) - fVec56[((IOTA - 431) & 511)])) + ((0.000793481246f * (((((fVec56[((IOTA - 237) & 511)] - fVec56[((IOTA - 313) & 511)]) - fVec56[((IOTA - 416) & 511)]) - fVec56[((IOTA - 424) & 511)]) - fVec56[((IOTA - 425) & 511)]) - fVec56[((IOTA - 426) & 511)])) + ((0.000732444227f * (((((((fVec56[((IOTA - 173) & 511)] - fVec56[((IOTA - 290) & 511)]) - fVec56[((IOTA - 332) & 511)]) - fVec56[((IOTA - 353) & 511)]) - fVec56[((IOTA - 374) & 511)]) - fVec56[((IOTA - 385) & 511)]) - fVec56[((IOTA - 418) & 511)]) - fVec56[((IOTA - 419) & 511)])) + ((0.000610370189f * ((fVec56[((IOTA - 63) & 511)] - fVec56[((IOTA - 351) & 511)]) - fVec56[((IOTA - 406) & 511)])) + ((0.000640888698f * ((((fVec56[((IOTA - 261) & 511)] - fVec56[((IOTA - 276) & 511)]) - fVec56[((IOTA - 280) & 511)]) - fVec56[((IOTA - 352) & 511)]) - fVec56[((IOTA - 386) & 511)])) + ((0.00140385143f * ((((fVec56[((IOTA - 211) & 511)] - fVec56[((IOTA - 258) & 511)]) - fVec56[((IOTA - 269) & 511)]) - fVec56[((IOTA - 309) & 511)]) - fVec56[((IOTA - 381) & 511)])) + ((0.00149540696f * (((fVec56[((IOTA - 221) & 511)] - fVec56[((IOTA - 256) & 511)]) - fVec56[((IOTA - 268) & 511)]) - fVec56[((IOTA - 378) & 511)])) + ((0.00146488845f * (fVec56[((IOTA - 174) & 511)] - fVec56[((IOTA - 344) & 511)])) + ((0.00057985168f * ((fVec56[((IOTA - 191) & 511)] - fVec56[((IOTA - 277) & 511)]) - fVec56[((IOTA - 333) & 511)])) + ((0.00170903653f * (fVec56[((IOTA - 197) & 511)] - fVec56[((IOTA - 255) & 511)])) + ((0.00177007355f * (fVec56[((IOTA - 231) & 511)] + fVec56[((IOTA - 234) & 511)])) + ((0.00183111057f * fVec56[((IOTA - 233) & 511)]) + ((0.00158696249f * fVec56[((IOTA - 230) & 511)]) + ((0.00204474013f * fVec56[((IOTA - 229) & 511)]) + ((0.00219733268f * fVec56[((IOTA - 227) & 511)]) + ((0.00234992523f * (fVec56[((IOTA - 208) & 511)] + fVec56[((IOTA - 226) & 511)])) + ((0.00271614734f * fVec56[((IOTA - 225) & 511)]) + ((0.00332651753f * ((fVec56[((IOTA - 196) & 511)] + fVec56[((IOTA - 209) & 511)]) + fVec56[((IOTA - 223) & 511)])) + ((0.00265511032f * ((fVec56[((IOTA - 177) & 511)] - fVec56[((IOTA - 213) & 511)]) - fVec56[((IOTA - 218) & 511)])) + ((0.0057985168f * fVec56[((IOTA - 195) & 511)]) + ((0.00695822015f * fVec56[((IOTA - 194) & 511)]) + ((0.00479140598f * fVec56[((IOTA - 187) & 511)]) + ((0.00552385021f * fVec56[((IOTA - 186) & 511)]) + ((0.0093691824f * fVec56[((IOTA - 184) & 511)]) + ((0.0100711081f * fVec56[((IOTA - 183) & 511)]) + ((0.00933866389f * fVec56[((IOTA - 182) & 511)]) + ((0.00650044251f * fVec56[((IOTA - 181) & 511)]) + ((0.0019226661f * fVec56[((IOTA - 180) & 511)]) + ((0.00555436872f * fVec56[((IOTA - 176) & 511)]) + ((0.00460829493f * fVec56[((IOTA - 175) & 511)]) + ((0.00402844325f * fVec56[((IOTA - 172) & 511)]) + ((0.0090334788f * fVec56[((IOTA - 171) & 511)]) + ((0.0124210333f * (fVec56[((IOTA - 102) & 511)] + fVec56[((IOTA - 170) & 511)])) + ((0.0107425153f * fVec56[((IOTA - 169) & 511)]) + ((0.0175176244f * fVec56[((IOTA - 158) & 511)]) + ((0.0350047313f * fVec56[((IOTA - 157) & 511)]) + ((0.0311288796f * fVec56[((IOTA - 156) & 511)]) + ((0.0115054781f * fVec56[((IOTA - 155) & 511)]) + ((0.00738547929f * fVec56[((IOTA - 185) & 511)]) + ((0.00988799706f * fVec56[((IOTA - 134) & 511)]) + ((0.0239875484f * fVec56[((IOTA - 133) & 511)]) + ((0.0350657664f * fVec56[((IOTA - 132) & 511)]) + ((0.037018951f * fVec56[((IOTA - 131) & 511)]) + ((0.0309457686f * fVec56[((IOTA - 130) & 511)]) + ((0.0137638478f * fVec56[((IOTA - 124) & 511)]) + ((0.0246284381f * fVec56[((IOTA - 123) & 511)]) + ((0.0289010294f * fVec56[((IOTA - 122) & 511)]) + ((0.024506364f * fVec56[((IOTA - 121) & 511)]) + ((0.024445327f * fVec56[((IOTA - 120) & 511)]) + ((0.0241706595f * fVec56[((IOTA - 119) & 511)]) + ((0.019348735f * fVec56[((IOTA - 118) & 511)]) + ((0.00976592302f * fVec56[((IOTA - 117) & 511)]) + ((0.0038758507f * fVec56[((IOTA - 116) & 511)]) + ((0.0201116987f * fVec56[((IOTA - 106) & 511)]) + ((0.029114658f * fVec56[((IOTA - 105) & 511)]) + ((0.0353404358f * fVec56[((IOTA - 104) & 511)]) + ((0.04031495f * fVec56[((IOTA - 103) & 511)]) + ((0.0300302133f * fVec56[((IOTA - 97) & 511)]) + ((0.0587481298f * fVec56[((IOTA - 96) & 511)]) + ((0.0447096154f * fVec56[((IOTA - 95) & 511)]) + ((0.0190130323f * fVec56[((IOTA - 94) & 511)]) + ((0.00799584948f * fVec56[((IOTA - 93) & 511)]) + ((0.0301217698f * fVec56[((IOTA - 92) & 511)]) + ((0.0216681417f * fVec56[((IOTA - 91) & 511)]) + ((0.0460829511f * fVec56[((IOTA - 90) & 511)]) + ((0.0317697674f * fVec56[((IOTA - 89) & 511)]) + ((0.0339671001f * fVec56[((IOTA - 88) & 511)]) + ((0.0422070995f * fVec56[((IOTA - 87) & 511)]) + ((0.0424817652f * fVec56[((IOTA - 86) & 511)]) + ((0.0206610318f * fVec56[((IOTA - 85) & 511)]) + ((0.0547807254f * fVec56[((IOTA - 80) & 511)]) + ((0.152531505f * fVec56[((IOTA - 79) & 511)]) + ((0.180547506f * fVec56[((IOTA - 78) & 511)]) + ((0.069978945f * fVec56[((IOTA - 77) & 511)]) + ((0.00341807306f * fVec56[((IOTA - 69) & 511)]) + ((0.00866725668f * fVec56[((IOTA - 68) & 511)]) + ((((0.0025940733f * fVec56[((IOTA - 64) & 511)]) + (0.00631733146f * fVec56[((IOTA - 65) & 511)])) + (0.00961333048f * fVec56[((IOTA - 66) & 511)])) + (0.0108035523f * fVec56[((IOTA - 67) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000183111057f * ((((fVec56[((IOTA - 238) & 511)] - fVec56[((IOTA - 264) & 511)]) - fVec56[((IOTA - 274) & 511)]) - fVec56[((IOTA - 373) & 511)]) + fVec56[((IOTA - 506) & 511)])))) : (((0.00054933317f * ((((((fVec55[((IOTA - 195) & 511)] - fVec55[((IOTA - 275) & 511)]) - fVec55[((IOTA - 344) & 511)]) - fVec55[((IOTA - 389) & 511)]) + fVec55[((IOTA - 443) & 511)]) + fVec55[((IOTA - 457) & 511)]) + fVec55[((IOTA - 509) & 511)])) + ((0.000793481246f * ((((fVec55[((IOTA - 390) & 511)] + fVec55[((IOTA - 444) & 511)]) + fVec55[((IOTA - 461) & 511)]) + fVec55[((IOTA - 464) & 511)]) + fVec55[((IOTA - 508) & 511)])) + ((0.000946073793f * (((fVec55[((IOTA - 181) & 511)] - fVec55[((IOTA - 247) & 511)]) + fVec55[((IOTA - 405) & 511)]) + fVec55[((IOTA - 507) & 511)])) + ((0.00109866634f * (((fVec55[((IOTA - 216) & 511)] + fVec55[((IOTA - 309) & 511)]) + fVec55[((IOTA - 499) & 511)]) + fVec55[((IOTA - 504) & 511)])) + ((0.000976592302f * ((((((fVec55[((IOTA - 79) & 511)] - fVec55[((IOTA - 260) & 511)]) + fVec55[((IOTA - 311) & 511)]) - fVec55[((IOTA - 321) & 511)]) - fVec55[((IOTA - 398) & 511)]) + fVec55[((IOTA - 501) & 511)]) + fVec55[((IOTA - 502) & 511)])) + ((0.00131229591f * (((((((fVec55[((IOTA - 204) & 511)] - fVec55[((IOTA - 248) & 511)]) - fVec55[((IOTA - 255) & 511)]) + fVec55[((IOTA - 310) & 511)]) - fVec55[((IOTA - 417) & 511)]) + fVec55[((IOTA - 433) & 511)]) + fVec55[((IOTA - 436) & 511)]) + fVec55[((IOTA - 497) & 511)])) + ((0.00173955504f * ((fVec55[((IOTA - 137) & 511)] - fVec55[((IOTA - 212) & 511)]) + fVec55[((IOTA - 494) & 511)])) + ((0.00180059206f * ((fVec55[((IOTA - 492) & 511)] - (((fVec55[((IOTA - 251) & 511)] + fVec55[((IOTA - 278) & 511)]) - fVec55[((IOTA - 395) & 511)]) + fVec55[((IOTA - 427) & 511)])) + fVec55[((IOTA - 493) & 511)])) + ((0.00103762932f * ((((((((((fVec55[((IOTA - 34) & 511)] + fVec55[((IOTA - 142) & 511)]) + fVec55[((IOTA - 237) & 511)]) + fVec55[((IOTA - 324) & 511)]) - fVec55[((IOTA - 419) & 511)]) - fVec55[((IOTA - 420) & 511)]) + fVec55[((IOTA - 437) & 511)]) + fVec55[((IOTA - 445) & 511)]) + fVec55[((IOTA - 453) & 511)]) + fVec55[((IOTA - 503) & 511)]) + fVec55[((IOTA - 506) & 511)])) + ((0.00143436994f * (((fVec55[((IOTA - 150) & 511)] - fVec55[((IOTA - 270) & 511)]) + fVec55[((IOTA - 406) & 511)]) + fVec55[((IOTA - 490) & 511)])) + ((0.00112918485f * (((fVec55[((IOTA - 18) & 511)] + fVec55[((IOTA - 242) & 511)]) - fVec55[((IOTA - 418) & 511)]) + fVec55[((IOTA - 489) & 511)])) + ((0.000427259132f * ((((((fVec55[((IOTA - 286) & 511)] - fVec55[((IOTA - 359) & 511)]) + fVec55[((IOTA - 379) & 511)]) - fVec55[((IOTA - 403) & 511)]) + fVec55[((IOTA - 439) & 511)]) + fVec55[((IOTA - 484) & 511)]) + fVec55[((IOTA - 486) & 511)])) + ((0.000640888698f * (((((((fVec55[((IOTA - 236) & 511)] + fVec55[((IOTA - 243) & 511)]) - fVec55[((IOTA - 271) & 511)]) - fVec55[((IOTA - 381) & 511)]) + fVec55[((IOTA - 456) & 511)]) + fVec55[((IOTA - 465) & 511)]) + fVec55[((IOTA - 478) & 511)]) + fVec55[((IOTA - 482) & 511)])) + ((0.000762962736f * (((((((fVec55[((IOTA - 119) & 511)] - fVec55[((IOTA - 151) & 511)]) + fVec55[((IOTA - 155) & 511)]) - fVec55[((IOTA - 213) & 511)]) - fVec55[((IOTA - 281) & 511)]) + fVec55[((IOTA - 455) & 511)]) - fVec55[((IOTA - 470) & 511)]) + fVec55[((IOTA - 481) & 511)])) + ((0.000396740623f * ((((fVec55[((IOTA - 224) & 511)] + fVec55[((IOTA - 292) & 511)]) + fVec55[((IOTA - 308) & 511)]) - fVec55[((IOTA - 357) & 511)]) + fVec55[((IOTA - 477) & 511)])) + ((0.000854518265f * (((((((((fVec55[((IOTA - 176) & 511)] + fVec55[((IOTA - 217) & 511)]) - fVec55[((IOTA - 223) & 511)]) - fVec55[((IOTA - 343) & 511)]) - fVec55[((IOTA - 365) & 511)]) - fVec55[((IOTA - 412) & 511)]) + fVec55[((IOTA - 462) & 511)]) + fVec55[((IOTA - 463) & 511)]) - fVec55[((IOTA - 471) & 511)]) - fVec55[((IOTA - 472) & 511)])) + ((0.00164799951f * (((fVec55[((IOTA - 68) & 511)] - fVec55[((IOTA - 153) & 511)]) + fVec55[((IOTA - 199) & 511)]) + fVec55[((IOTA - 491) & 511)])) + ((0.000518814661f * (((((fVec55[((IOTA - 198) & 511)] + fVec55[((IOTA - 290) & 511)]) + fVec55[((IOTA - 291) & 511)]) + fVec55[((IOTA - 323) & 511)]) + fVec55[((IOTA - 410) & 511)]) + fVec55[((IOTA - 458) & 511)])) + ((0.000885036774f * ((fVec55[((IOTA - 215) & 511)] - fVec55[((IOTA - 300) & 511)]) + fVec55[((IOTA - 454) & 511)])) + ((0.000244148076f * ((((((((fVec55[((IOTA - 218) & 511)] - fVec55[((IOTA - 245) & 511)]) - fVec55[((IOTA - 282) & 511)]) + fVec55[((IOTA - 293) & 511)]) + fVec55[((IOTA - 312) & 511)]) - fVec55[((IOTA - 356) & 511)]) + fVec55[((IOTA - 378) & 511)]) + fVec55[((IOTA - 440) & 511)]) + fVec55[((IOTA - 441) & 511)])) + ((0.00210577715f * ((fVec55[((IOTA - 121) & 511)] - fVec55[((IOTA - 424) & 511)]) - fVec55[((IOTA - 426) & 511)])) + ((0.00183111057f * (((fVec55[((IOTA - 123) & 511)] - fVec55[((IOTA - 206) & 511)]) + fVec55[((IOTA - 391) & 511)]) - fVec55[((IOTA - 423) & 511)])) + ((0.00155644398f * ((fVec55[((IOTA - 194) & 511)] + fVec55[((IOTA - 408) & 511)]) - fVec55[((IOTA - 415) & 511)])) + ((0.000213629566f * (fVec55[((IOTA - 284) & 511)] - fVec55[((IOTA - 411) & 511)])) + ((0.001617481f * ((((fVec55[((IOTA - 225) & 511)] - fVec55[((IOTA - 249) & 511)]) - fVec55[((IOTA - 314) & 511)]) - fVec55[((IOTA - 401) & 511)]) + fVec55[((IOTA - 407) & 511)])) + ((0.00177007355f * ((((fVec55[((IOTA - 120) & 511)] - fVec55[((IOTA - 222) & 511)]) - fVec55[((IOTA - 250) & 511)]) - fVec55[((IOTA - 279) & 511)]) - fVec55[((IOTA - 400) & 511)])) + ((0.00152592547f * (((fVec55[((IOTA - 241) & 511)] - fVec55[((IOTA - 253) & 511)]) - fVec55[((IOTA - 340) & 511)]) - fVec55[((IOTA - 399) & 511)])) + ((0.00244148076f * (fVec55[((IOTA - 162) & 511)] + fVec55[((IOTA - 392) & 511)])) + ((0.00372325815f * (((fVec55[((IOTA - 201) & 511)] - fVec55[((IOTA - 332) & 511)]) - fVec55[((IOTA - 370) & 511)]) - fVec55[((IOTA - 384) & 511)])) + ((0.00213629566f * ((fVec55[((IOTA - 85) & 511)] - fVec55[((IOTA - 269) & 511)]) - fVec55[((IOTA - 375) & 511)])) + ((0.00390636921f * (((fVec55[((IOTA - 173) & 511)] - fVec55[((IOTA - 333) & 511)]) - fVec55[((IOTA - 371) & 511)]) - fVec55[((IOTA - 372) & 511)])) + ((0.00335703604f * ((fVec55[((IOTA - 96) & 511)] - fVec55[((IOTA - 210) & 511)]) - fVec55[((IOTA - 369) & 511)])) + ((9.15555283e-05f * ((fVec55[((IOTA - 297) & 511)] - fVec55[((IOTA - 347) & 511)]) + fVec55[((IOTA - 352) & 511)])) + ((0.00167851802f * (((fVec55[((IOTA - 239) & 511)] - fVec55[((IOTA - 301) & 511)]) - fVec55[((IOTA - 320) & 511)]) - fVec55[((IOTA - 339) & 511)])) + ((0.00140385143f * ((fVec55[((IOTA - 238) & 511)] - fVec55[((IOTA - 428) & 511)]) + fVec55[((IOTA - 448) & 511)])) + ((0.00231940672f * (fVec55[((IOTA - 182) & 511)] - fVec55[((IOTA - 330) & 511)])) + ((0.0022583697f * (fVec55[((IOTA - 124) & 511)] - fVec55[((IOTA - 319) & 511)])) + ((0.000457777642f * (fVec55[((IOTA - 287) & 511)] + fVec55[((IOTA - 288) & 511)])) + ((0.00189214759f * fVec55[((IOTA - 230) & 511)]) + ((0.00311288796f * fVec55[((IOTA - 229) & 511)]) + ((0.00363170262f * fVec55[((IOTA - 228) & 511)]) + ((0.00341807306f * (fVec55[((IOTA - 172) & 511)] + fVec55[((IOTA - 227) & 511)])) + ((0.00299081393f * (fVec55[((IOTA - 193) & 511)] - fVec55[((IOTA - 207) & 511)])) + ((0.00277718436f * fVec55[((IOTA - 203) & 511)]) + ((0.00366222113f * fVec55[((IOTA - 202) & 511)]) + ((0.00610370189f * (fVec55[((IOTA - 160) & 511)] + fVec55[((IOTA - 191) & 511)])) + ((0.00708029419f * fVec55[((IOTA - 190) & 511)]) + ((0.00756859034f * fVec55[((IOTA - 189) & 511)]) + ((0.00778221991f * fVec55[((IOTA - 188) & 511)]) + ((0.00766014587f * fVec55[((IOTA - 187) & 511)]) + ((0.00717184972f * fVec55[((IOTA - 186) & 511)]) + ((0.00628681295f * fVec55[((IOTA - 185) & 511)]) + ((0.0051576281f * fVec55[((IOTA - 184) & 511)]) + ((0.00378429517f * fVec55[((IOTA - 183) & 511)]) + ((0.00201422162f * (fVec55[((IOTA - 171) & 511)] + fVec55[((IOTA - 175) & 511)])) + ((0.00454725791f * fVec55[((IOTA - 161) & 511)]) + ((0.00695822015f * (fVec55[((IOTA - 144) & 511)] + fVec55[((IOTA - 159) & 511)])) + ((0.00671407208f * fVec55[((IOTA - 158) & 511)]) + ((0.00521866512f * (fVec55[((IOTA - 127) & 511)] + fVec55[((IOTA - 157) & 511)])) + ((0.00296029542f * fVec55[((IOTA - 156) & 511)]) + ((0.00469985045f * fVec55[((IOTA - 149) & 511)]) + ((0.008087405f * fVec55[((IOTA - 148) & 511)]) + ((0.0102542192f * fVec55[((IOTA - 147) & 511)]) + ((0.0105288858f * fVec55[((IOTA - 146) & 511)]) + ((0.00921658985f * fVec55[((IOTA - 145) & 511)]) + ((0.00411999878f * fVec55[((IOTA - 143) & 511)]) + ((0.00466933195f * fVec55[((IOTA - 136) & 511)]) + ((0.00714133121f * fVec55[((IOTA - 135) & 511)]) + ((0.00891140476f * fVec55[((IOTA - 134) & 511)]) + ((0.0101016266f * fVec55[((IOTA - 133) & 511)]) + ((0.0108951079f * fVec55[((IOTA - 132) & 511)]) + ((0.0109561449f * fVec55[((IOTA - 131) & 511)]) + ((0.00991851557f * fVec55[((IOTA - 130) & 511)]) + ((0.00817896053f * fVec55[((IOTA - 129) & 511)]) + ((0.0042115543f * fVec55[((IOTA - 126) & 511)]) + ((0.00317392498f * fVec55[((IOTA - 125) & 511)]) + ((0.0189214759f * fVec55[((IOTA - 93) & 511)]) + ((0.0221564379f * fVec55[((IOTA - 92) & 511)]) + ((0.00823999755f * fVec55[((IOTA - 95) & 511)]) + ((0.0137638478f * fVec55[((IOTA - 94) & 511)]) + ((0.0228278451f * fVec55[((IOTA - 91) & 511)]) + ((0.0163274035f * fVec55[((IOTA - 88) & 511)]) + ((0.0121768853f * fVec55[((IOTA - 87) & 511)]) + ((0.00698873866f * fVec55[((IOTA - 86) & 511)]) + ((0.0215765871f * fVec55[((IOTA - 90) & 511)]) + ((0.00460829493f * fVec55[((IOTA - 78) & 511)]) + ((0.00830103457f * fVec55[((IOTA - 77) & 511)]) + ((0.0122684408f * fVec55[((IOTA - 76) & 511)]) + ((0.0175176244f * fVec55[((IOTA - 75) & 511)]) + ((0.0241401419f * fVec55[((IOTA - 74) & 511)]) + ((0.0299996957f * fVec55[((IOTA - 73) & 511)]) + ((0.032654807f * fVec55[((IOTA - 72) & 511)]) + ((0.030915251f * fVec55[((IOTA - 71) & 511)]) + ((0.0248420667f * fVec55[((IOTA - 70) & 511)]) + ((0.0148625141f * fVec55[((IOTA - 69) & 511)]) + ((0.0132450331f * fVec55[((IOTA - 60) & 511)]) + ((0.0252082888f * fVec55[((IOTA - 59) & 511)]) + ((0.0284127332f * fVec55[((IOTA - 58) & 511)]) + ((0.0214239936f * fVec55[((IOTA - 57) & 511)]) + ((0.00616473891f * fVec55[((IOTA - 56) & 511)]) + ((0.011444441f * fVec55[((IOTA - 47) & 511)]) + ((0.0289010294f * fVec55[((IOTA - 46) & 511)]) + ((0.0423902087f * fVec55[((IOTA - 45) & 511)]) + ((0.0491958372f * fVec55[((IOTA - 44) & 511)]) + ((0.0488601327f * fVec55[((IOTA - 43) & 511)]) + ((0.0419629514f * fVec55[((IOTA - 42) & 511)]) + ((0.0285348073f * fVec55[((IOTA - 41) & 511)]) + ((0.0110782189f * fVec55[((IOTA - 40) & 511)]) + ((0.015991699f * fVec55[((IOTA - 33) & 511)]) + ((0.0244758446f * fVec55[((IOTA - 32) & 511)]) + ((0.02252266f * fVec55[((IOTA - 31) & 511)]) + (((0.17816706f * fVec55[((IOTA - 6) & 511)]) + ((0.226569414f * fVec55[((IOTA - 5) & 511)]) + ((0.238776818f * fVec55[((IOTA - 4) & 511)]) + ((0.216345713f * fVec55[((IOTA - 3) & 511)]) + ((0.162358478f * fVec55[((IOTA - 2) & 511)]) + ((0.0928373039f * fVec55[((IOTA - 1) & 511)]) + ((fSlow131 * fTemp0) + (0.0958891585f * fVec55[((IOTA - 7) & 511)])))))))) + (0.0112308115f * fVec55[((IOTA - 30) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000305185094f * ((((((fVec55[((IOTA - 118) & 511)] - fVec55[((IOTA - 170) & 511)]) + fVec55[((IOTA - 179) & 511)]) - fVec55[((IOTA - 404) & 511)]) + fVec55[((IOTA - 430) & 511)]) + fVec55[((IOTA - 468) & 511)]) - fVec55[((IOTA - 510) & 511)])) + ((0.00106814783f * ((fVec55[((IOTA - 84) & 511)] + fVec55[((IOTA - 258) & 511)]) - fVec55[((IOTA - 505) & 511)])) + ((0.00100711081f * (((fVec55[((IOTA - 259) & 511)] + fVec55[((IOTA - 261) & 511)]) + fVec55[((IOTA - 276) & 511)]) - fVec55[((IOTA - 500) & 511)])) + ((0.00119022187f * (fVec55[((IOTA - 257) & 511)] - fVec55[((IOTA - 498) & 511)])) + ((0.00146488845f * (((fVec55[((IOTA - 220) & 511)] + fVec55[((IOTA - 263) & 511)]) + fVec55[((IOTA - 416) & 511)]) - fVec55[((IOTA - 496) & 511)])) + ((0.00158696249f * ((fVec55[((IOTA - 114) & 511)] + fVec55[((IOTA - 306) & 511)]) - fVec55[((IOTA - 495) & 511)])) + ((0.000823999755f * ((((fVec55[((IOTA - 154) & 511)] - fVec55[((IOTA - 396) & 511)]) - fVec55[((IOTA - 479) & 511)]) - fVec55[((IOTA - 480) & 511)]) - fVec55[((IOTA - 488) & 511)])) + ((0.00057985168f * (((((fVec55[((IOTA - 219) & 511)] + fVec55[((IOTA - 246) & 511)]) + fVec55[((IOTA - 307) & 511)]) - fVec55[((IOTA - 459) & 511)]) + fVec55[((IOTA - 469) & 511)]) - fVec55[((IOTA - 487) & 511)])) + ((0.000366222113f * ((((fVec55[((IOTA - 234) & 511)] + fVec55[((IOTA - 364) & 511)]) - fVec55[((IOTA - 442) & 511)]) - fVec55[((IOTA - 466) & 511)]) - fVec55[((IOTA - 485) & 511)])) + ((0.000488296151f * ((((((fVec55[((IOTA - 97) & 511)] - fVec55[((IOTA - 231) & 511)]) + fVec55[((IOTA - 232) & 511)]) - fVec55[((IOTA - 289) & 511)]) + fVec55[((IOTA - 358) & 511)]) + fVec55[((IOTA - 474) & 511)]) - fVec55[((IOTA - 483) & 511)])) + ((0.000122074038f * (((fVec55[((IOTA - 272) & 511)] + fVec55[((IOTA - 328) & 511)]) + fVec55[((IOTA - 355) & 511)]) - fVec55[((IOTA - 476) & 511)])) + ((0.000183111057f * ((((fVec55[((IOTA - 178) & 511)] - fVec55[((IOTA - 214) & 511)]) + fVec55[((IOTA - 322) & 511)]) + fVec55[((IOTA - 346) & 511)]) + fVec55[((IOTA - 475) & 511)])) + ((0.000732444227f * ((fVec55[((IOTA - 117) & 511)] + fVec55[((IOTA - 233) & 511)]) + fVec55[((IOTA - 473) & 511)])) + ((0.000671407208f * (fVec55[((IOTA - 313) & 511)] - fVec55[((IOTA - 460) & 511)])) + ((0.00115970336f * ((((((fVec55[((IOTA - 262) & 511)] - fVec55[((IOTA - 326) & 511)]) + fVec55[((IOTA - 342) & 511)]) + fVec55[((IOTA - 376) & 511)]) + fVec55[((IOTA - 402) & 511)]) - fVec55[((IOTA - 409) & 511)]) - fVec55[((IOTA - 452) & 511)])) + ((0.0012817774f * (((fVec55[((IOTA - 169) & 511)] - fVec55[((IOTA - 325) & 511)]) + fVec55[((IOTA - 413) & 511)]) - fVec55[((IOTA - 451) & 511)])) + ((0.00134281442f * ((fVec55[((IOTA - 280) & 511)] - fVec55[((IOTA - 447) & 511)]) - fVec55[((IOTA - 450) & 511)])) + ((0.00137333293f * (((fVec55[((IOTA - 8) & 511)] + fVec55[((IOTA - 254) & 511)]) + fVec55[((IOTA - 341) & 511)]) - fVec55[((IOTA - 449) & 511)])) + ((0.00125125889f * (fVec55[((IOTA - 256) & 511)] - fVec55[((IOTA - 446) & 511)])) + ((0.000701925717f * ((fVec55[((IOTA - 115) & 511)] - fVec55[((IOTA - 327) & 511)]) - fVec55[((IOTA - 438) & 511)])) + ((0.00149540696f * ((((((fVec55[((IOTA - 141) & 511)] + fVec55[((IOTA - 277) & 511)]) + fVec55[((IOTA - 366) & 511)]) + fVec55[((IOTA - 414) & 511)]) + fVec55[((IOTA - 422) & 511)]) - fVec55[((IOTA - 434) & 511)]) - fVec55[((IOTA - 435) & 511)])) + ((0.000915555283f * ((fVec55[((IOTA - 138) & 511)] + fVec55[((IOTA - 429) & 511)]) - fVec55[((IOTA - 432) & 511)])) + ((0.000335703604f * ((((((fVec55[((IOTA - 17) & 511)] + fVec55[((IOTA - 205) & 511)]) - fVec55[((IOTA - 285) & 511)]) + fVec55[((IOTA - 299) & 511)]) + fVec55[((IOTA - 345) & 511)]) + fVec55[((IOTA - 377) & 511)]) - fVec55[((IOTA - 431) & 511)])) + ((0.00219733268f * (fVec55[((IOTA - 265) & 511)] + fVec55[((IOTA - 425) & 511)])) + ((0.00122074038f * (fVec55[((IOTA - 329) & 511)] + fVec55[((IOTA - 421) & 511)])) + ((0.000152592547f * (((((((((fVec55[((IOTA - 163) & 511)] - fVec55[((IOTA - 177) & 511)]) - fVec55[((IOTA - 235) & 511)]) - fVec55[((IOTA - 244) & 511)]) + fVec55[((IOTA - 274) & 511)]) - fVec55[((IOTA - 294) & 511)]) - fVec55[((IOTA - 295) & 511)]) - fVec55[((IOTA - 296) & 511)]) - fVec55[((IOTA - 380) & 511)]) + fVec55[((IOTA - 397) & 511)])) + ((0.00247199927f * ((fVec55[((IOTA - 302) & 511)] + fVec55[((IOTA - 337) & 511)]) - fVec55[((IOTA - 394) & 511)])) + ((0.00268562883f * (fVec55[((IOTA - 168) & 511)] - fVec55[((IOTA - 393) & 511)])) + ((0.00198370311f * (fVec55[((IOTA - 338) & 511)] + fVec55[((IOTA - 388) & 511)])) + ((0.00320444349f * ((fVec55[((IOTA - 98) & 511)] + fVec55[((IOTA - 331) & 511)]) + fVec55[((IOTA - 387) & 511)])) + ((0.00396740623f * fVec55[((IOTA - 386) & 511)]) + ((0.00415051728f * fVec55[((IOTA - 385) & 511)]) + ((0.00283822138f * ((fVec55[((IOTA - 316) & 511)] + fVec55[((IOTA - 368) & 511)]) + fVec55[((IOTA - 383) & 511)])) + ((0.00170903653f * (((fVec55[((IOTA - 152) & 511)] - fVec55[((IOTA - 240) & 511)]) + fVec55[((IOTA - 252) & 511)]) + fVec55[((IOTA - 382) & 511)])) + ((0.00302133244f * fVec55[((IOTA - 374) & 511)]) + ((0.00360118411f * fVec55[((IOTA - 373) & 511)]) + ((0.00216681417f * fVec55[((IOTA - 367) & 511)]) + ((6.10370189e-05f * ((((((fVec55[((IOTA - 197) & 511)] - fVec55[((IOTA - 283) & 511)]) + fVec55[((IOTA - 348) & 511)]) - fVec55[((IOTA - 351) & 511)]) - fVec55[((IOTA - 353) & 511)]) + fVec55[((IOTA - 361) & 511)]) - fVec55[((IOTA - 362) & 511)])) + ((0.000274666585f * fVec55[((IOTA - 360) & 511)]) + ((0.00381481368f * (fVec55[((IOTA - 209) & 511)] + fVec55[((IOTA - 334) & 511)])) + ((0.00271614734f * fVec55[((IOTA - 318) & 511)]) + ((0.00292977691f * ((fVec55[((IOTA - 303) & 511)] + fVec55[((IOTA - 304) & 511)]) + fVec55[((IOTA - 317) & 511)])) + ((0.00238044374f * fVec55[((IOTA - 315) & 511)]) + ((0.00241096225f * (fVec55[((IOTA - 266) & 511)] + fVec55[((IOTA - 305) & 511)])) + ((0.00250251777f * fVec55[((IOTA - 268) & 511)]) + ((0.00253303628f * fVec55[((IOTA - 267) & 511)]) + ((0.00186162908f * fVec55[((IOTA - 264) & 511)]) + ((0.00305185094f * fVec55[((IOTA - 336) & 511)]) + ((0.00265511032f * (fVec55[((IOTA - 83) & 511)] - fVec55[((IOTA - 226) & 511)])) + ((0.0019531846f * fVec55[((IOTA - 221) & 511)]) + ((0.00369273964f * fVec55[((IOTA - 208) & 511)]) + ((0.0028992584f * (fVec55[((IOTA - 113) & 511)] - fVec55[((IOTA - 200) & 511)])) + ((0.00463881344f * (fVec55[((IOTA - 99) & 511)] - fVec55[((IOTA - 192) & 511)])) + ((0.00262459181f * fVec55[((IOTA - 211) & 511)]) + ((0.0035401471f * fVec55[((IOTA - 335) & 511)]) + ((0.00329599902f * (fVec55[((IOTA - 61) & 511)] - fVec55[((IOTA - 174) & 511)])) + ((0.00393688772f * fVec55[((IOTA - 167) & 511)]) + ((0.00473036896f * fVec55[((IOTA - 166) & 511)]) + ((0.00445570238f * (fVec55[((IOTA - 112) & 511)] + fVec55[((IOTA - 165) & 511)])) + ((0.00274666585f * fVec55[((IOTA - 164) & 511)]) + ((0.00280770287f * fVec55[((IOTA - 140) & 511)]) + ((0.0025940733f * fVec55[((IOTA - 139) & 511)]) + ((0.00650044251f * (fVec55[((IOTA - 111) & 511)] - fVec55[((IOTA - 128) & 511)])) + ((0.0019226661f * (fVec55[((IOTA - 80) & 511)] - fVec55[((IOTA - 122) & 511)])) + ((0.000610370189f * fVec55[((IOTA - 116) & 511)]) + ((0.00912503432f * fVec55[((IOTA - 110) & 511)]) + ((0.0113528855f * fVec55[((IOTA - 109) & 511)]) + ((0.0123599963f * fVec55[((IOTA - 108) & 511)]) + ((0.0120242927f * fVec55[((IOTA - 107) & 511)]) + ((0.0111697745f * fVec55[((IOTA - 106) & 511)]) + ((0.0100405896f * fVec55[((IOTA - 105) & 511)]) + ((0.00854518265f * fVec55[((IOTA - 104) & 511)]) + ((0.00680562761f * fVec55[((IOTA - 103) & 511)]) + ((0.00540177617f * fVec55[((IOTA - 102) & 511)]) + ((0.004852443f * fVec55[((IOTA - 101) & 511)]) + ((0.00488296151f * fVec55[((IOTA - 100) & 511)]) + ((0.0193792544f * (fVec55[((IOTA - 62) & 511)] - fVec55[((IOTA - 89) & 511)])) + ((0.00338755455f * fVec55[((IOTA - 82) & 511)]) + ((0.00332651753f * fVec55[((IOTA - 81) & 511)]) + ((0.0128482925f * fVec55[((IOTA - 67) & 511)]) + ((0.0259712525f * fVec55[((IOTA - 66) & 511)]) + ((0.0348216183f * fVec55[((IOTA - 65) & 511)]) + ((0.0368358418f * fVec55[((IOTA - 64) & 511)]) + ((0.0312814713f * fVec55[((IOTA - 63) & 511)]) + ((0.0130924406f * fVec55[((IOTA - 55) & 511)]) + ((0.0325327329f * fVec55[((IOTA - 54) & 511)]) + ((0.0485244319f * fVec55[((IOTA - 53) & 511)]) + ((0.0570085756f * fVec55[((IOTA - 52) & 511)]) + ((0.0554521307f * fVec55[((IOTA - 51) & 511)]) + ((0.0448622108f * fVec55[((IOTA - 50) & 511)]) + ((0.027802363f * fVec55[((IOTA - 49) & 511)]) + ((0.00802636798f * fVec55[((IOTA - 48) & 511)]) + ((0.006469924f * fVec55[((IOTA - 39) & 511)]) + ((0.019348735f * fVec55[((IOTA - 38) & 511)]) + ((0.0245979186f * fVec55[((IOTA - 37) & 511)]) + ((0.0220954008f * fVec55[((IOTA - 36) & 511)]) + ((0.0131534776f * fVec55[((IOTA - 35) & 511)]) + ((0.00927762687f * fVec55[((IOTA - 29) & 511)]) + ((0.0357371755f * fVec55[((IOTA - 28) & 511)]) + ((0.0616168715f * fVec55[((IOTA - 27) & 511)]) + ((0.0805383474f * fVec55[((IOTA - 26) & 511)]) + ((0.0913724154f * fVec55[((IOTA - 25) & 511)]) + ((0.0928678215f * fVec55[((IOTA - 24) & 511)]) + ((0.0851771608f * fVec55[((IOTA - 23) & 511)]) + ((0.0696737543f * fVec55[((IOTA - 22) & 511)]) + ((0.0885647163f * fVec55[((IOTA - 9) & 511)]) + ((0.0503555425f * fVec55[((IOTA - 21) & 511)]) + ((0.0296334736f * fVec55[((IOTA - 20) & 511)]) + ((((0.14743492f * fVec55[((IOTA - 10) & 511)]) + ((0.136936545f * fVec55[((IOTA - 13) & 511)]) + ((0.174871057f * fVec55[((IOTA - 11) & 511)]) + (((0.170262769f * fVec55[((IOTA - 12) & 511)]) + (0.0904263407f * fVec55[((IOTA - 14) & 511)])) + (0.0471205786f * fVec55[((IOTA - 15) & 511)]))))) + (0.0172734763f * fVec55[((IOTA - 16) & 511)])) + (0.0102237007f * fVec55[((IOTA - 19) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (3.05185094e-05f * ((((fVec55[((IOTA - 298) & 511)] + fVec55[((IOTA - 349) & 511)]) + fVec55[((IOTA - 363) & 511)]) - fVec55[((IOTA - 467) & 511)]) - fVec55[((IOTA - 511) & 511)]))))) : (iSlow126 ? (((0.000244148076f * (((((((fVec54[((IOTA - 290) & 511)] - ((((fVec54[((IOTA - 32) & 511)] + fVec54[((IOTA - 37) & 511)]) + fVec54[((IOTA - 191) & 511)]) + fVec54[((IOTA - 274) & 511)]) + fVec54[((IOTA - 283) & 511)])) + fVec54[((IOTA - 317) & 511)]) + fVec54[((IOTA - 432) & 511)]) - fVec54[((IOTA - 435) & 511)]) + fVec54[((IOTA - 463) & 511)]) - fVec54[((IOTA - 464) & 511)]) - fVec54[((IOTA - 511) & 511)])) + ((0.000335703604f * ((((fVec54[((IOTA - 43) & 511)] - fVec54[((IOTA - 49) & 511)]) - fVec54[((IOTA - 328) & 511)]) + fVec54[((IOTA - 459) & 511)]) - fVec54[((IOTA - 510) & 511)])) + ((0.000366222113f * ((((((fVec54[((IOTA - 18) & 511)] - fVec54[((IOTA - 20) & 511)]) + fVec54[((IOTA - 272) & 511)]) + fVec54[((IOTA - 296) & 511)]) - fVec54[((IOTA - 437) & 511)]) - fVec54[((IOTA - 488) & 511)]) - fVec54[((IOTA - 509) & 511)])) + ((0.000427259132f * (((((((fVec54[((IOTA - 14) & 511)] + fVec54[((IOTA - 51) & 511)]) + fVec54[((IOTA - 219) & 511)]) - fVec54[((IOTA - 275) & 511)]) + fVec54[((IOTA - 314) & 511)]) + fVec54[((IOTA - 315) & 511)]) - fVec54[((IOTA - 458) & 511)]) - fVec54[((IOTA - 507) & 511)])) + ((0.000762962736f * ((((((fVec54[((IOTA - 16) & 511)] - fVec54[((IOTA - 277) & 511)]) - fVec54[((IOTA - 279) & 511)]) - fVec54[((IOTA - 320) & 511)]) - fVec54[((IOTA - 321) & 511)]) - fVec54[((IOTA - 339) & 511)]) - fVec54[((IOTA - 505) & 511)])) + ((0.000915555283f * ((((((((fVec54[((IOTA - 239) & 511)] + fVec54[((IOTA - 305) & 511)]) + fVec54[((IOTA - 309) & 511)]) + fVec54[((IOTA - 477) & 511)]) + fVec54[((IOTA - 478) & 511)]) + fVec54[((IOTA - 479) & 511)]) - fVec54[((IOTA - 495) & 511)]) - fVec54[((IOTA - 503) & 511)]) - fVec54[((IOTA - 504) & 511)])) + ((0.000488296151f * ((((((((((fVec54[((IOTA - 5) & 511)] + fVec54[((IOTA - 30) & 511)]) - fVec54[((IOTA - 45) & 511)]) + fVec54[((IOTA - 55) & 511)]) + fVec54[((IOTA - 187) & 511)]) + fVec54[((IOTA - 313) & 511)]) - fVec54[((IOTA - 319) & 511)]) - fVec54[((IOTA - 337) & 511)]) - fVec54[((IOTA - 438) & 511)]) - fVec54[((IOTA - 498) & 511)]) - fVec54[((IOTA - 501) & 511)])) + ((0.000305185094f * ((((((((fVec54[((IOTA - 26) & 511)] - fVec54[((IOTA - 282) & 511)]) + fVec54[((IOTA - 291) & 511)]) + fVec54[((IOTA - 372) & 511)]) - fVec54[((IOTA - 408) & 511)]) - fVec54[((IOTA - 418) & 511)]) + fVec54[((IOTA - 482) & 511)]) - fVec54[((IOTA - 499) & 511)]) - fVec54[((IOTA - 500) & 511)])) + ((0.000701925717f * ((((((((((((((((fVec54[((IOTA - 15) & 511)] + fVec54[((IOTA - 29) & 511)]) + fVec54[((IOTA - 54) & 511)]) - fVec54[((IOTA - 59) & 511)]) + fVec54[((IOTA - 271) & 511)]) + fVec54[((IOTA - 297) & 511)]) + fVec54[((IOTA - 306) & 511)]) + fVec54[((IOTA - 312) & 511)]) - fVec54[((IOTA - 338) & 511)]) - fVec54[((IOTA - 340) & 511)]) + fVec54[((IOTA - 364) & 511)]) + fVec54[((IOTA - 400) & 511)]) + fVec54[((IOTA - 413) & 511)]) - fVec54[((IOTA - 419) & 511)]) - fVec54[((IOTA - 441) & 511)]) - fVec54[((IOTA - 490) & 511)]) - fVec54[((IOTA - 497) & 511)])) + ((0.000854518265f * (((((fVec54[((IOTA - 41) & 511)] - fVec54[((IOTA - 60) & 511)]) - fVec54[((IOTA - 146) & 511)]) - fVec54[((IOTA - 331) & 511)]) + fVec54[((IOTA - 480) & 511)]) - fVec54[((IOTA - 496) & 511)])) + ((0.00057985168f * (((((fVec54[((IOTA - 27) & 511)] - fVec54[((IOTA - 322) & 511)]) - fVec54[((IOTA - 329) & 511)]) - fVec54[((IOTA - 358) & 511)]) + fVec54[((IOTA - 425) & 511)]) - fVec54[((IOTA - 489) & 511)])) + ((0.000213629566f * ((((((fVec54[((IOTA - 1) & 511)] + fVec54[((IOTA - 56) & 511)]) - fVec54[((IOTA - 285) & 511)]) + fVec54[((IOTA - 292) & 511)]) + fVec54[((IOTA - 359) & 511)]) + fVec54[((IOTA - 472) & 511)]) - fVec54[((IOTA - 487) & 511)])) + ((0.000152592547f * ((((fVec54[((IOTA - 38) & 511)] - (fVec54[((IOTA - 7) & 511)] - fVec54[((IOTA - 31) & 511)])) - fVec54[((IOTA - 170) & 511)]) - fVec54[((IOTA - 286) & 511)]) - fVec54[((IOTA - 486) & 511)])) + ((0.000183111057f * (((((fVec54[((IOTA - 6) & 511)] + fVec54[((IOTA - 417) & 511)]) - fVec54[((IOTA - 434) & 511)]) - fVec54[((IOTA - 444) & 511)]) - fVec54[((IOTA - 484) & 511)]) - fVec54[((IOTA - 485) & 511)])) + ((0.00106814783f * (((((((fVec54[((IOTA - 192) & 511)] + fVec54[((IOTA - 221) & 511)]) + fVec54[((IOTA - 255) & 511)]) + fVec54[((IOTA - 377) & 511)]) + fVec54[((IOTA - 396) & 511)]) - fVec54[((IOTA - 466) & 511)]) + fVec54[((IOTA - 474) & 511)]) + fVec54[((IOTA - 475) & 511)])) + ((0.000671407208f * (((((((((fVec54[((IOTA - 3) & 511)] + fVec54[((IOTA - 4) & 511)]) - fVec54[((IOTA - 10) & 511)]) + fVec54[((IOTA - 42) & 511)]) + fVec54[((IOTA - 52) & 511)]) - fVec54[((IOTA - 341) & 511)]) - fVec54[((IOTA - 403) & 511)]) + fVec54[((IOTA - 415) & 511)]) - fVec54[((IOTA - 423) & 511)]) - fVec54[((IOTA - 465) & 511)])) + ((0.000793481246f * ((((((fVec54[((IOTA - 40) & 511)] - fVec54[((IOTA - 47) & 511)]) + fVec54[((IOTA - 53) & 511)]) - fVec54[((IOTA - 334) & 511)]) - fVec54[((IOTA - 365) & 511)]) + fVec54[((IOTA - 411) & 511)]) + fVec54[((IOTA - 462) & 511)])) + ((0.00119022187f * ((fVec54[((IOTA - 254) & 511)] + fVec54[((IOTA - 262) & 511)]) - fVec54[((IOTA - 456) & 511)])) + ((0.00308236945f * ((fVec54[((IOTA - 375) & 511)] - fVec54[((IOTA - 383) & 511)]) - fVec54[((IOTA - 451) & 511)])) + ((9.15555283e-05f * (((((fVec54[((IOTA - 13) & 511)] - fVec54[((IOTA - 44) & 511)]) - fVec54[((IOTA - 57) & 511)]) + fVec54[((IOTA - 295) & 511)]) - fVec54[((IOTA - 327) & 511)]) - fVec54[((IOTA - 449) & 511)])) + ((0.00131229591f * ((((((fVec54[((IOTA - 142) & 511)] - fVec54[((IOTA - 344) & 511)]) - fVec54[((IOTA - 345) & 511)]) - fVec54[((IOTA - 348) & 511)]) - fVec54[((IOTA - 357) & 511)]) + fVec54[((IOTA - 426) & 511)]) + fVec54[((IOTA - 448) & 511)])) + ((0.00183111057f * ((((fVec54[((IOTA - 222) & 511)] + fVec54[((IOTA - 267) & 511)]) - fVec54[((IOTA - 350) & 511)]) - fVec54[((IOTA - 352) & 511)]) + fVec54[((IOTA - 447) & 511)])) + ((0.000610370189f * (((((fVec54[((IOTA - 163) & 511)] - fVec54[((IOTA - 276) & 511)]) + fVec54[((IOTA - 307) & 511)]) - fVec54[((IOTA - 335) & 511)]) + fVec54[((IOTA - 397) & 511)]) - fVec54[((IOTA - 443) & 511)])) + ((0.00152592547f * (((fVec54[((IOTA - 68) & 511)] + fVec54[((IOTA - 253) & 511)]) + fVec54[((IOTA - 301) & 511)]) + fVec54[((IOTA - 429) & 511)])) + ((0.00103762932f * (((fVec54[((IOTA - 237) & 511)] + fVec54[((IOTA - 240) & 511)]) - fVec54[((IOTA - 404) & 511)]) - fVec54[((IOTA - 421) & 511)])) + ((0.000518814661f * ((fVec54[((IOTA - 2) & 511)] - fVec54[((IOTA - 378) & 511)]) - fVec54[((IOTA - 407) & 511)])) + ((6.10370189e-05f * ((((((fVec54[((IOTA - 50) & 511)] - fVec54[((IOTA - 184) & 511)]) + fVec54[((IOTA - 288) & 511)]) + fVec54[((IOTA - 293) & 511)]) - fVec54[((IOTA - 324) & 511)]) + fVec54[((IOTA - 325) & 511)]) - fVec54[((IOTA - 402) & 511)])) + ((0.00180059206f * (((fVec54[((IOTA - 243) & 511)] - fVec54[((IOTA - 354) & 511)]) - fVec54[((IOTA - 381) & 511)]) + fVec54[((IOTA - 395) & 511)])) + ((0.003234962f * (fVec54[((IOTA - 390) & 511)] + fVec54[((IOTA - 393) & 511)])) + ((0.00363170262f * fVec54[((IOTA - 392) & 511)]) + ((0.00204474013f * fVec54[((IOTA - 389) & 511)]) + ((0.0012817774f * ((fVec54[((IOTA - 228) & 511)] + fVec54[((IOTA - 256) & 511)]) - fVec54[((IOTA - 387) & 511)])) + ((0.00262459181f * fVec54[((IOTA - 374) & 511)]) + ((0.00158696249f * ((fVec54[((IOTA - 265) & 511)] - fVec54[((IOTA - 349) & 511)]) + fVec54[((IOTA - 373) & 511)])) + ((0.00115970336f * (((fVec54[((IOTA - 241) & 511)] - fVec54[((IOTA - 346) & 511)]) - fVec54[((IOTA - 347) & 511)]) - fVec54[((IOTA - 371) & 511)])) + ((0.00418103579f * ((fVec54[((IOTA - 150) & 511)] - fVec54[((IOTA - 166) & 511)]) - fVec54[((IOTA - 369) & 511)])) + ((0.00164799951f * ((fVec54[((IOTA - 257) & 511)] + fVec54[((IOTA - 361) & 511)]) + fVec54[((IOTA - 363) & 511)])) + ((0.0019226661f * ((fVec54[((IOTA - 252) & 511)] - fVec54[((IOTA - 351) & 511)]) + fVec54[((IOTA - 362) & 511)])) + ((0.00100711081f * (fVec54[((IOTA - 310) & 511)] + fVec54[((IOTA - 360) & 511)])) + ((0.000885036774f * ((fVec54[((IOTA - 311) & 511)] - fVec54[((IOTA - 332) & 511)]) - fVec54[((IOTA - 333) & 511)])) + ((0.00125125889f * (((fVec54[((IOTA - 261) & 511)] + fVec54[((IOTA - 263) & 511)]) + fVec54[((IOTA - 269) & 511)]) + fVec54[((IOTA - 304) & 511)])) + ((0.00155644398f * ((fVec54[((IOTA - 147) & 511)] + fVec54[((IOTA - 268) & 511)]) + fVec54[((IOTA - 303) & 511)])) + ((0.00167851802f * (fVec54[((IOTA - 259) & 511)] + fVec54[((IOTA - 302) & 511)])) + ((0.00122074038f * fVec54[((IOTA - 300) & 511)]) + ((0.00140385143f * (fVec54[((IOTA - 242) & 511)] + fVec54[((IOTA - 260) & 511)])) + ((0.00234992523f * fVec54[((IOTA - 251) & 511)]) + ((0.00265511032f * (fVec54[((IOTA - 206) & 511)] + fVec54[((IOTA - 250) & 511)])) + ((0.00299081393f * ((fVec54[((IOTA - 172) & 511)] + fVec54[((IOTA - 232) & 511)]) + fVec54[((IOTA - 248) & 511)])) + ((0.00311288796f * fVec54[((IOTA - 247) & 511)]) + ((0.00302133244f * (fVec54[((IOTA - 100) & 511)] + fVec54[((IOTA - 246) & 511)])) + ((0.00271614734f * (fVec54[((IOTA - 226) & 511)] + fVec54[((IOTA - 245) & 511)])) + ((0.00222785119f * (fVec54[((IOTA - 231) & 511)] + fVec54[((IOTA - 244) & 511)])) + ((0.00280770287f * fVec54[((IOTA - 235) & 511)]) + ((0.00350962859f * fVec54[((IOTA - 234) & 511)]) + ((0.00357066561f * fVec54[((IOTA - 233) & 511)]) + ((0.0019531846f * fVec54[((IOTA - 227) & 511)]) + ((0.00332651753f * fVec54[((IOTA - 225) & 511)]) + ((0.00329599902f * fVec54[((IOTA - 224) & 511)]) + ((0.00274666585f * fVec54[((IOTA - 223) & 511)]) + ((0.00305185094f * fVec54[((IOTA - 216) & 511)]) + ((0.0057985168f * fVec54[((IOTA - 214) & 511)]) + ((0.00708029419f * fVec54[((IOTA - 213) & 511)]) + ((0.00772118289f * fVec54[((IOTA - 212) & 511)]) + ((0.00796533097f * fVec54[((IOTA - 211) & 511)]) + ((0.00415051728f * fVec54[((IOTA - 207) & 511)]) + ((0.00317392498f * (fVec54[((IOTA - 173) & 511)] + fVec54[((IOTA - 203) & 511)])) + ((0.00500503555f * fVec54[((IOTA - 202) & 511)]) + ((0.00717184972f * fVec54[((IOTA - 201) & 511)]) + ((0.00888088625f * fVec54[((IOTA - 200) & 511)]) + ((0.00958281197f * fVec54[((IOTA - 199) & 511)]) + ((0.00906399731f * fVec54[((IOTA - 198) & 511)]) + ((0.00799584948f * fVec54[((IOTA - 197) & 511)]) + ((0.00634784997f * fVec54[((IOTA - 196) & 511)]) + ((0.0051576281f * fVec54[((IOTA - 195) & 511)]) + ((0.00366222113f * fVec54[((IOTA - 194) & 511)]) + ((0.00256355479f * fVec54[((IOTA - 193) & 511)]) + ((0.00671407208f * fVec54[((IOTA - 209) & 511)]) + ((0.001617481f * fVec54[((IOTA - 174) & 511)]) + ((0.00189214759f * fVec54[((IOTA - 171) & 511)]) + ((0.00384533219f * fVec54[((IOTA - 162) & 511)]) + ((0.00927762687f * fVec54[((IOTA - 161) & 511)]) + ((0.0156865139f * fVec54[((IOTA - 160) & 511)]) + ((0.0197454765f * fVec54[((IOTA - 159) & 511)]) + ((0.0185247362f * fVec54[((IOTA - 158) & 511)]) + ((0.0103457747f * fVec54[((IOTA - 157) & 511)]) + ((0.00665303506f * (fVec54[((IOTA - 126) & 511)] + fVec54[((IOTA - 149) & 511)])) + ((0.00512710959f * fVec54[((IOTA - 141) & 511)]) + ((0.00753807183f * fVec54[((IOTA - 140) & 511)]) + ((0.00875881221f * fVec54[((IOTA - 139) & 511)]) + ((0.00817896053f * fVec54[((IOTA - 138) & 511)]) + ((0.00726340525f * fVec54[((IOTA - 137) & 511)]) + ((0.00695822015f * fVec54[((IOTA - 136) & 511)]) + ((0.00592059083f * fVec54[((IOTA - 135) & 511)]) + ((0.00442518387f * fVec54[((IOTA - 148) & 511)]) + ((0.00555436872f * fVec54[((IOTA - 208) & 511)]) + ((0.0208746605f * fVec54[((IOTA - 125) & 511)]) + ((0.0197759941f * fVec54[((IOTA - 124) & 511)]) + ((0.00625629444f * fVec54[((IOTA - 123) & 511)]) + ((0.00402844325f * fVec54[((IOTA - 113) & 511)]) + ((0.0116885891f * fVec54[((IOTA - 112) & 511)]) + ((0.00961333048f * fVec54[((IOTA - 111) & 511)]) + ((0.0118106632f * fVec54[((IOTA - 110) & 511)]) + ((0.0171208847f * fVec54[((IOTA - 109) & 511)]) + ((0.0172124393f * fVec54[((IOTA - 108) & 511)]) + ((0.0179448836f * fVec54[((IOTA - 107) & 511)]) + ((0.0118411817f * fVec54[((IOTA - 106) & 511)]) + ((0.0274361409f * fVec54[((IOTA - 99) & 511)]) + ((0.028931547f * fVec54[((IOTA - 98) & 511)]) + ((0.0123599963f * fVec54[((IOTA - 97) & 511)]) + ((0.0121768853f * fVec54[((IOTA - 82) & 511)]) + ((0.0424817652f * fVec54[((IOTA - 81) & 511)]) + ((0.039124731f * fVec54[((IOTA - 80) & 511)]) + ((0.0273445845f * fVec54[((IOTA - 75) & 511)]) + ((0.225898013f * fVec54[((IOTA - 74) & 511)]) + ((0.308297992f * fVec54[((IOTA - 73) & 511)]) + ((0.225501269f * fVec54[((IOTA - 72) & 511)]) + ((0.0917691588f * fVec54[((IOTA - 71) & 511)]) + ((0.00643940549f * fVec54[((IOTA - 69) & 511)]) + (0.0210577715f * fVec54[((IOTA - 70) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00054933317f * (((((((((fVec54[((IOTA - 11) & 511)] + fVec54[((IOTA - 33) & 511)]) + fVec54[((IOTA - 36) & 511)]) - fVec54[((IOTA - 39) & 511)]) + fVec54[((IOTA - 188) & 511)]) + fVec54[((IOTA - 280) & 511)]) - fVec54[((IOTA - 398) & 511)]) - fVec54[((IOTA - 416) & 511)]) + fVec54[((IOTA - 439) & 511)]) + fVec54[((IOTA - 506) & 511)])) + ((0.000732444227f * (((((((((fVec54[((IOTA - 22) & 511)] - fVec54[((IOTA - 28) & 511)]) + fVec54[((IOTA - 34) & 511)]) + fVec54[((IOTA - 35) & 511)]) + fVec54[((IOTA - 46) & 511)]) - fVec54[((IOTA - 308) & 511)]) + fVec54[((IOTA - 406) & 511)]) + fVec54[((IOTA - 442) & 511)]) - fVec54[((IOTA - 473) & 511)]) + fVec54[((IOTA - 502) & 511)])) + ((0.000946073793f * (((((((fVec54[((IOTA - 61) & 511)] - fVec54[((IOTA - 298) & 511)]) + fVec54[((IOTA - 420) & 511)]) + fVec54[((IOTA - 422) & 511)]) + fVec54[((IOTA - 457) & 511)]) + fVec54[((IOTA - 470) & 511)]) + fVec54[((IOTA - 492) & 511)]) + fVec54[((IOTA - 494) & 511)])) + ((0.000976592302f * (((((fVec54[((IOTA - 190) & 511)] - fVec54[((IOTA - 270) & 511)]) + fVec54[((IOTA - 405) & 511)]) - fVec54[((IOTA - 460) & 511)]) - fVec54[((IOTA - 476) & 511)]) + fVec54[((IOTA - 493) & 511)])) + ((0.000640888698f * ((((((((((fVec54[((IOTA - 9) & 511)] - fVec54[((IOTA - 17) & 511)]) + fVec54[((IOTA - 21) & 511)]) + fVec54[((IOTA - 23) & 511)]) + fVec54[((IOTA - 48) & 511)]) - fVec54[((IOTA - 399) & 511)]) - fVec54[((IOTA - 414) & 511)]) - fVec54[((IOTA - 431) & 511)]) + fVec54[((IOTA - 440) & 511)]) - fVec54[((IOTA - 445) & 511)]) - fVec54[((IOTA - 481) & 511)])) + ((0.00149540696f * ((fVec54[((IOTA - 105) & 511)] - fVec54[((IOTA - 230) & 511)]) + fVec54[((IOTA - 468) & 511)])) + ((0.000823999755f * (fVec54[((IOTA - 491) & 511)] - (((((((fVec54[((IOTA - 185) & 511)] + fVec54[((IOTA - 186) & 511)]) + fVec54[((IOTA - 218) & 511)]) + fVec54[((IOTA - 238) & 511)]) - fVec54[((IOTA - 278) & 511)]) - fVec54[((IOTA - 330) & 511)]) - fVec54[((IOTA - 342) & 511)]) + fVec54[((IOTA - 412) & 511)]))) + ((0.00109866634f * (((((fVec54[((IOTA - 189) & 511)] - fVec54[((IOTA - 229) & 511)]) - fVec54[((IOTA - 299) & 511)]) + fVec54[((IOTA - 343) & 511)]) - fVec54[((IOTA - 430) & 511)]) - fVec54[((IOTA - 461) & 511)])) + ((0.00143436994f * fVec54[((IOTA - 455) & 511)]) + ((0.00207525864f * fVec54[((IOTA - 454) & 511)]) + ((0.00292977691f * fVec54[((IOTA - 453) & 511)]) + ((0.00344859157f * fVec54[((IOTA - 452) & 511)]) + ((0.00137333293f * (fVec54[((IOTA - 469) & 511)] - (fVec54[((IOTA - 264) & 511)] - fVec54[((IOTA - 467) & 511)]))) + ((0.00146488845f * (fVec54[((IOTA - 379) & 511)] - fVec54[((IOTA - 446) & 511)])) + ((0.000274666585f * ((((fVec54[((IOTA - 12) & 511)] + fVec54[((IOTA - 133) & 511)]) + fVec54[((IOTA - 284) & 511)]) + fVec54[((IOTA - 323) & 511)]) + fVec54[((IOTA - 436) & 511)])) + ((3.05185094e-05f * ((((((fVec54[((IOTA - 25) & 511)] - fVec54[((IOTA - 273) & 511)]) + fVec54[((IOTA - 287) & 511)]) + fVec54[((IOTA - 294) & 511)]) - fVec54[((IOTA - 326) & 511)]) - fVec54[((IOTA - 409) & 511)]) + fVec54[((IOTA - 433) & 511)])) + ((0.00170903653f * (((fVec54[((IOTA - 143) & 511)] - fVec54[((IOTA - 205) & 511)]) - fVec54[((IOTA - 217) & 511)]) - fVec54[((IOTA - 427) & 511)])) + ((0.000122074038f * (((fTemp55 - fVec54[((IOTA - 289) & 511)]) + fVec54[((IOTA - 318) & 511)]) + fVec54[((IOTA - 424) & 511)])) + ((0.000457777642f * (((((fVec54[((IOTA - 8) & 511)] + fVec54[((IOTA - 175) & 511)]) - fVec54[((IOTA - 220) & 511)]) + fVec54[((IOTA - 336) & 511)]) - fVec54[((IOTA - 401) & 511)]) - fVec54[((IOTA - 410) & 511)])) + ((0.0025940733f * (fVec54[((IOTA - 169) & 511)] - fVec54[((IOTA - 394) & 511)])) + ((0.00369273964f * (fVec54[((IOTA - 384) & 511)] - fVec54[((IOTA - 391) & 511)])) + ((0.00268562883f * fVec54[((IOTA - 386) & 511)]) + ((0.0035401471f * fVec54[((IOTA - 385) & 511)]) + ((0.0022583697f * (fVec54[((IOTA - 145) & 511)] + fVec54[((IOTA - 382) & 511)])) + ((0.00173955504f * (fVec54[((IOTA - 176) & 511)] + fVec54[((IOTA - 380) & 511)])) + ((0.00250251777f * (fVec54[((IOTA - 366) & 511)] - fVec54[((IOTA - 376) & 511)])) + ((0.00277718436f * (fVec54[((IOTA - 144) & 511)] + fVec54[((IOTA - 370) & 511)])) + ((0.00463881344f * fVec54[((IOTA - 368) & 511)]) + ((0.00396740623f * fVec54[((IOTA - 367) & 511)]) + ((0.00186162908f * ((fVec54[((IOTA - 62) & 511)] - fVec54[((IOTA - 204) & 511)]) + fVec54[((IOTA - 355) & 511)])) + ((0.00177007355f * (((fVec54[((IOTA - 356) & 511)] - (((fVec54[((IOTA - 236) & 511)] + fVec54[((IOTA - 258) & 511)]) + fVec54[((IOTA - 266) & 511)]) - fVec54[((IOTA - 353) & 511)])) - fVec54[((IOTA - 428) & 511)]) + fVec54[((IOTA - 450) & 511)])) + ((0.00286873989f * (fVec54[((IOTA - 178) & 511)] - fVec54[((IOTA - 249) & 511)])) + ((0.00436414685f * ((fVec54[((IOTA - 63) & 511)] - fVec54[((IOTA - 134) & 511)]) - fVec54[((IOTA - 215) & 511)])) + ((0.00747703481f * (fVec54[((IOTA - 64) & 511)] - fVec54[((IOTA - 210) & 511)])) + ((0.00238044374f * (fVec54[((IOTA - 156) & 511)] + fVec54[((IOTA - 183) & 511)])) + ((0.00469985045f * fVec54[((IOTA - 182) & 511)]) + ((0.00589007232f * fVec54[((IOTA - 181) & 511)]) + ((0.00537125766f * fVec54[((IOTA - 180) & 511)]) + ((0.00390636921f * fVec54[((IOTA - 179) & 511)]) + ((0.00228888821f * fVec54[((IOTA - 177) & 511)]) + ((0.00482192449f * fVec54[((IOTA - 168) & 511)]) + ((0.00527970213f * fVec54[((IOTA - 167) & 511)]) + ((0.00219733268f * fVec54[((IOTA - 165) & 511)]) + ((0.00112918485f * fVec54[((IOTA - 164) & 511)]) + ((0.0148930326f * (fVec54[((IOTA - 127) & 511)] + fVec54[((IOTA - 155) & 511)])) + ((0.0226752535f * fVec54[((IOTA - 154) & 511)]) + ((0.0223700684f * fVec54[((IOTA - 153) & 511)]) + ((0.0150761437f * fVec54[((IOTA - 152) & 511)]) + ((0.00439466536f * fVec54[((IOTA - 151) & 511)]) + ((0.0101016266f * fVec54[((IOTA - 132) & 511)]) + ((0.0241096225f * fVec54[((IOTA - 131) & 511)]) + ((0.0363475457f * fVec54[((IOTA - 130) & 511)]) + ((0.0409558415f * fVec54[((IOTA - 129) & 511)]) + ((0.0335398428f * fVec54[((IOTA - 128) & 511)]) + ((0.0119022187f * fVec54[((IOTA - 122) & 511)]) + ((0.0249336231f * fVec54[((IOTA - 121) & 511)]) + ((0.0294198431f * fVec54[((IOTA - 120) & 511)]) + ((0.0273140669f * fVec54[((IOTA - 119) & 511)]) + ((0.0255745109f * fVec54[((IOTA - 118) & 511)]) + ((0.0267036967f * fVec54[((IOTA - 117) & 511)]) + ((0.0241401419f * fVec54[((IOTA - 116) & 511)]) + ((0.0178838465f * fVec54[((IOTA - 115) & 511)]) + ((0.0077517014f * fVec54[((IOTA - 114) & 511)]) + ((0.0234992523f * fVec54[((IOTA - 104) & 511)]) + ((0.0395825058f * fVec54[((IOTA - 103) & 511)]) + ((0.0464186519f * fVec54[((IOTA - 102) & 511)]) + ((0.0299691763f * fVec54[((IOTA - 101) & 511)]) + ((0.0122684408f * fVec54[((IOTA - 96) & 511)]) + ((0.0320139155f * fVec54[((IOTA - 95) & 511)]) + ((0.0396130271f * fVec54[((IOTA - 94) & 511)]) + ((0.0313119926f * fVec54[((IOTA - 93) & 511)]) + ((0.0249946602f * fVec54[((IOTA - 92) & 511)]) + ((0.0223395489f * fVec54[((IOTA - 91) & 511)]) + ((0.0405590981f * fVec54[((IOTA - 90) & 511)]) + ((0.042115543f * fVec54[((IOTA - 89) & 511)]) + ((0.0343333222f * fVec54[((IOTA - 88) & 511)]) + ((0.0166020691f * fVec54[((IOTA - 87) & 511)]) + ((0.00946073793f * fVec54[((IOTA - 86) & 511)]) + ((0.0176396985f * fVec54[((IOTA - 85) & 511)]) + ((0.0196234025f * fVec54[((IOTA - 84) & 511)]) + ((0.0238959938f * fVec54[((IOTA - 83) & 511)]) + ((0.0336313993f * fVec54[((IOTA - 79) & 511)]) + ((0.138493001f * fVec54[((IOTA - 78) & 511)]) + ((0.209265426f * fVec54[((IOTA - 77) & 511)]) + ((0.15781121f * fVec54[((IOTA - 76) & 511)]) + ((0.00503555406f * fVec54[((IOTA - 67) & 511)]) + ((0.00964384899f * fVec54[((IOTA - 65) & 511)]) + (0.00900296029f * fVec54[((IOTA - 66) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000396740623f * ((((((fVec54[((IOTA - 24) & 511)] + fVec54[((IOTA - 58) & 511)]) + fVec54[((IOTA - 281) & 511)]) - fVec54[((IOTA - 316) & 511)]) - fVec54[((IOTA - 388) & 511)]) + fVec54[((IOTA - 471) & 511)]) + fVec54[((IOTA - 508) & 511)])))) : (((0.00143436994f * (((((((fVec53[((IOTA - 201) & 511)] + fVec53[((IOTA - 235) & 511)]) - fVec53[((IOTA - 424) & 511)]) - fVec53[((IOTA - 442) & 511)]) - fVec53[((IOTA - 444) & 511)]) - fVec53[((IOTA - 497) & 511)]) - fVec53[((IOTA - 503) & 511)]) - fVec53[((IOTA - 509) & 511)])) + ((0.001617481f * ((((((fVec53[((IOTA - 214) & 511)] + fVec53[((IOTA - 223) & 511)]) + fVec53[((IOTA - 226) & 511)]) - fVec53[((IOTA - 467) & 511)]) - fVec53[((IOTA - 493) & 511)]) - fVec53[((IOTA - 494) & 511)]) - fVec53[((IOTA - 508) & 511)])) + ((0.00180059206f * ((((fVec53[((IOTA - 367) & 511)] - fVec53[((IOTA - 383) & 511)]) - fVec53[((IOTA - 452) & 511)]) - fVec53[((IOTA - 473) & 511)]) - fVec53[((IOTA - 507) & 511)])) + ((0.00170903653f * ((fVec53[((IOTA - 339) & 511)] + fVec53[((IOTA - 399) & 511)]) - fVec53[((IOTA - 504) & 511)])) + ((0.00122074038f * (((((fVec53[((IOTA - 219) & 511)] + fVec53[((IOTA - 341) & 511)]) - fVec53[((IOTA - 382) & 511)]) - fVec53[((IOTA - 409) & 511)]) - fVec53[((IOTA - 499) & 511)]) - fVec53[((IOTA - 502) & 511)])) + ((0.00109866634f * (((fVec53[((IOTA - 218) & 511)] + fVec53[((IOTA - 431) & 511)]) - fVec53[((IOTA - 500) & 511)]) - fVec53[((IOTA - 501) & 511)])) + ((0.000854518265f * (fVec53[((IOTA - 430) & 511)] - fVec53[((IOTA - 489) & 511)])) + ((0.000823999755f * (((((((fVec53[((IOTA - 3) & 511)] + fVec53[((IOTA - 15) & 511)]) - fVec53[((IOTA - 21) & 511)]) - fVec53[((IOTA - 35) & 511)]) + fVec53[((IOTA - 216) & 511)]) + fVec53[((IOTA - 350) & 511)]) - fVec53[((IOTA - 487) & 511)]) - fVec53[((IOTA - 488) & 511)])) + ((0.000457777642f * ((fVec53[((IOTA - 30) & 511)] + fVec53[((IOTA - 351) & 511)]) - fVec53[((IOTA - 485) & 511)])) + ((0.000183111057f * ((((fVec53[((IOTA - 6) & 511)] - fVec53[((IOTA - 204) & 511)]) + fVec53[((IOTA - 381) & 511)]) - fVec53[((IOTA - 428) & 511)]) - fVec53[((IOTA - 484) & 511)])) + ((0.000152592547f * ((((fVec53[((IOTA - 13) & 511)] + fVec53[((IOTA - 202) & 511)]) - fVec53[((IOTA - 477) & 511)]) - fVec53[((IOTA - 478) & 511)]) - fVec53[((IOTA - 479) & 511)])) + ((0.000366222113f * (((((((fVec53[((IOTA - 18) & 511)] - fVec53[((IOTA - 24) & 511)]) + fVec53[((IOTA - 38) & 511)]) - fVec53[((IOTA - 57) & 511)]) - fVec53[((IOTA - 353) & 511)]) - fVec53[((IOTA - 420) & 511)]) + fVec53[((IOTA - 429) & 511)]) - fVec53[((IOTA - 476) & 511)])) + ((0.00222785119f * ((((fVec53[((IOTA - 234) & 511)] + fVec53[((IOTA - 286) & 511)]) + fVec53[((IOTA - 334) & 511)]) - fVec53[((IOTA - 386) & 511)]) - fVec53[((IOTA - 472) & 511)])) + ((0.00238044374f * ((fVec53[((IOTA - 325) & 511)] + fVec53[((IOTA - 330) & 511)]) - fVec53[((IOTA - 469) & 511)])) + ((0.00054933317f * (((fVec53[((IOTA - 5) & 511)] - fVec53[((IOTA - 36) & 511)]) - fVec53[((IOTA - 203) & 511)]) - fVec53[((IOTA - 465) & 511)])) + ((3.05185094e-05f * (((fVec53[((IOTA - 56) & 511)] + fVec53[((IOTA - 352) & 511)]) + fVec53[((IOTA - 435) & 511)]) + fVec53[((IOTA - 464) & 511)])) + ((0.000305185094f * (((((fVec53[((IOTA - 1) & 511)] + fVec53[((IOTA - 50) & 511)]) - fVec53[((IOTA - 360) & 511)]) - fVec53[((IOTA - 418) & 511)]) - fVec53[((IOTA - 436) & 511)]) + fVec53[((IOTA - 463) & 511)])) + ((0.00241096225f * (fVec53[((IOTA - 277) & 511)] - fVec53[((IOTA - 457) & 511)])) + ((0.00308236945f * ((fVec53[((IOTA - 240) & 511)] + fVec53[((IOTA - 279) & 511)]) - fVec53[((IOTA - 456) & 511)])) + ((0.00415051728f * (((fVec53[((IOTA - 248) & 511)] + fVec53[((IOTA - 263) & 511)]) + fVec53[((IOTA - 298) & 511)]) - fVec53[((IOTA - 454) & 511)])) + ((0.00338755455f * (((fVec53[((IOTA - 312) & 511)] + fVec53[((IOTA - 313) & 511)]) + fVec53[((IOTA - 314) & 511)]) - fVec53[((IOTA - 453) & 511)])) + ((0.00140385143f * fVec53[((IOTA - 449) & 511)]) + ((0.000915555283f * (((((((fVec53[((IOTA - 16) & 511)] - fVec53[((IOTA - 22) & 511)]) + fVec53[((IOTA - 28) & 511)]) + fVec53[((IOTA - 347) & 511)]) + fVec53[((IOTA - 349) & 511)]) + fVec53[((IOTA - 433) & 511)]) - fVec53[((IOTA - 439) & 511)]) + fVec53[((IOTA - 448) & 511)])) + ((0.00115970336f * (((fVec53[((IOTA - 205) & 511)] + fVec53[((IOTA - 432) & 511)]) - fVec53[((IOTA - 440) & 511)]) - fVec53[((IOTA - 445) & 511)])) + ((0.00186162908f * ((fVec53[((IOTA - 237) & 511)] + fVec53[((IOTA - 337) & 511)]) - fVec53[((IOTA - 505) & 511)])) + ((0.000488296151f * fVec53[((IOTA - 434) & 511)]) + ((0.000732444227f * (((((((fVec53[((IOTA - 17) & 511)] - fVec53[((IOTA - 23) & 511)]) - fVec53[((IOTA - 45) & 511)]) + fVec53[((IOTA - 51) & 511)]) + fVec53[((IOTA - 137) & 511)]) - fVec53[((IOTA - 355) & 511)]) - fVec53[((IOTA - 357) & 511)]) - fVec53[((IOTA - 427) & 511)])) + ((0.000335703604f * (((fVec53[((IOTA - 361) & 511)] + fVec53[((IOTA - 404) & 511)]) - fVec53[((IOTA - 413) & 511)]) - fVec53[((IOTA - 417) & 511)])) + ((0.00256355479f * ((((fVec53[((IOTA - 148) & 511)] + fVec53[((IOTA - 285) & 511)]) + fVec53[((IOTA - 329) & 511)]) + fVec53[((IOTA - 366) & 511)]) + fVec53[((IOTA - 398) & 511)])) + ((0.00204474013f * (fVec53[((IOTA - 377) & 511)] - fVec53[((IOTA - 468) & 511)])) + ((0.00329599902f * fVec53[((IOTA - 397) & 511)]) + ((0.00366222113f * (fVec53[((IOTA - 396) & 511)] - ((fVec53[((IOTA - 149) & 511)] - fVec53[((IOTA - 258) & 511)]) - fVec53[((IOTA - 395) & 511)]))) + ((0.00317392498f * ((fVec53[((IOTA - 198) & 511)] + fVec53[((IOTA - 320) & 511)]) + fVec53[((IOTA - 394) & 511)])) + ((0.00207525864f * ((fVec53[((IOTA - 275) & 511)] + fVec53[((IOTA - 332) & 511)]) + fVec53[((IOTA - 393) & 511)])) + ((0.00106814783f * ((fVec53[((IOTA - 343) & 511)] + fVec53[((IOTA - 346) & 511)]) - fVec53[((IOTA - 391) & 511)])) + ((0.00244148076f * ((fVec53[((IOTA - 228) & 511)] + fVec53[((IOTA - 238) & 511)]) - fVec53[((IOTA - 390) & 511)])) + ((0.00332651753f * ((((fVec53[((IOTA - 197) & 511)] + fVec53[((IOTA - 251) & 511)]) + fVec53[((IOTA - 315) & 511)]) + fVec53[((IOTA - 317) & 511)]) - fVec53[((IOTA - 389) & 511)])) + ((0.00173955504f * (((fVec53[((IOTA - 338) & 511)] + fVec53[((IOTA - 363) & 511)]) - fVec53[((IOTA - 384) & 511)]) - fVec53[((IOTA - 385) & 511)])) + ((0.00292977691f * fVec53[((IOTA - 379) & 511)]) + ((0.00286873989f * (fVec53[((IOTA - 206) & 511)] + fVec53[((IOTA - 378) & 511)])) + ((0.000976592302f * (((fVec53[((IOTA - 41) & 511)] - fVec53[((IOTA - 46) & 511)]) + fVec53[((IOTA - 52) & 511)]) + fVec53[((IOTA - 376) & 511)])) + ((0.000244148076f * ((fVec53[((IOTA - 43) & 511)] - fVec53[((IOTA - 136) & 511)]) - fVec53[((IOTA - 375) & 511)])) + ((0.00311288796f * ((fVec53[((IOTA - 159) & 511)] + fVec53[((IOTA - 289) & 511)]) - fVec53[((IOTA - 373) & 511)])) + ((0.00390636921f * (fVec53[((IOTA - 262) & 511)] - fVec53[((IOTA - 372) & 511)])) + ((0.00363170262f * (fVec53[((IOTA - 261) & 511)] - fVec53[((IOTA - 371) & 511)])) + ((0.00268562883f * ((fVec53[((IOTA - 138) & 511)] + fVec53[((IOTA - 328) & 511)]) + fVec53[((IOTA - 365) & 511)])) + ((0.000762962736f * ((((((fVec53[((IOTA - 4) & 511)] - fVec53[((IOTA - 9) & 511)]) + fVec53[((IOTA - 29) & 511)]) - fVec53[((IOTA - 33) & 511)]) + fVec53[((IOTA - 39) & 511)]) + fVec53[((IOTA - 54) & 511)]) - fVec53[((IOTA - 358) & 511)])) + ((0.00119022187f * ((fVec53[((IOTA - 193) & 511)] + fVec53[((IOTA - 344) & 511)]) + fVec53[((IOTA - 345) & 511)])) + ((0.00210577715f * (fVec53[((IOTA - 333) & 511)] + fVec53[((IOTA - 336) & 511)])) + ((0.0022583697f * fVec53[((IOTA - 335) & 511)]) + ((0.00219733268f * (fVec53[((IOTA - 276) & 511)] + fVec53[((IOTA - 331) & 511)])) + ((0.00271614734f * (fVec53[((IOTA - 278) & 511)] + fVec53[((IOTA - 327) & 511)])) + ((0.00262459181f * fVec53[((IOTA - 326) & 511)]) + ((0.00213629566f * (fVec53[((IOTA - 139) & 511)] + fVec53[((IOTA - 323) & 511)])) + ((0.00341807306f * (fVec53[((IOTA - 318) & 511)] + fVec53[((IOTA - 319) & 511)])) + ((0.00326548051f * fVec53[((IOTA - 316) & 511)]) + ((0.00344859157f * ((((fVec53[((IOTA - 233) & 511)] + fVec53[((IOTA - 260) & 511)]) + fVec53[((IOTA - 280) & 511)]) + fVec53[((IOTA - 283) & 511)]) + fVec53[((IOTA - 311) & 511)])) + ((0.00375377666f * fVec53[((IOTA - 310) & 511)]) + ((0.00418103579f * fVec53[((IOTA - 309) & 511)]) + ((0.00436414685f * fVec53[((IOTA - 306) & 511)]) + ((0.00433362834f * ((fVec53[((IOTA - 243) & 511)] + fVec53[((IOTA - 264) & 511)]) + fVec53[((IOTA - 305) & 511)])) + ((0.00137333293f * ((fVec53[((IOTA - 220) & 511)] + fVec53[((IOTA - 236) & 511)]) - fVec53[((IOTA - 425) & 511)])) + ((0.0042115543f * fVec53[((IOTA - 303) & 511)]) + ((0.00393688772f * ((fVec53[((IOTA - 270) & 511)] + fVec53[((IOTA - 300) & 511)]) + fVec53[((IOTA - 301) & 511)])) + ((0.00402844325f * ((((fVec53[((IOTA - 230) & 511)] + fVec53[((IOTA - 255) & 511)]) + fVec53[((IOTA - 256) & 511)]) + fVec53[((IOTA - 294) & 511)]) + fVec53[((IOTA - 299) & 511)])) + ((0.00427259132f * (fVec53[((IOTA - 207) & 511)] + fVec53[((IOTA - 296) & 511)])) + ((0.00369273964f * (((fVec53[((IOTA - 249) & 511)] + fVec53[((IOTA - 253) & 511)]) + fVec53[((IOTA - 282) & 511)]) + fVec53[((IOTA - 290) & 511)])) + ((0.00250251777f * (fVec53[((IOTA - 273) & 511)] + fVec53[((IOTA - 288) & 511)])) + ((0.00305185094f * fVec53[((IOTA - 284) & 511)]) + ((0.00299081393f * (fVec53[((IOTA - 194) & 511)] + fVec53[((IOTA - 272) & 511)])) + ((0.00347911008f * (fVec53[((IOTA - 252) & 511)] + fVec53[((IOTA - 271) & 511)])) + ((0.00457777642f * ((fVec53[((IOTA - 231) & 511)] + fVec53[((IOTA - 245) & 511)]) + fVec53[((IOTA - 268) & 511)])) + ((0.00473036896f * fVec53[((IOTA - 267) & 511)]) + ((0.00350962859f * fVec53[((IOTA - 259) & 511)]) + ((0.00335703604f * (fVec53[((IOTA - 241) & 511)] + fVec53[((IOTA - 250) & 511)])) + ((0.00454725791f * fVec53[((IOTA - 244) & 511)]) + ((0.00384533219f * fVec53[((IOTA - 242) & 511)]) + ((0.00283822138f * (fVec53[((IOTA - 213) & 511)] + fVec53[((IOTA - 239) & 511)])) + ((0.00320444349f * fVec53[((IOTA - 229) & 511)]) + ((0.0019531846f * fVec53[((IOTA - 227) & 511)]) + ((0.00158696249f * fVec53[((IOTA - 225) & 511)]) + ((0.00146488845f * fVec53[((IOTA - 221) & 511)]) + ((0.00506607257f * fVec53[((IOTA - 211) & 511)]) + ((0.00546281319f * fVec53[((IOTA - 210) & 511)]) + ((0.00537125766f * (fVec53[((IOTA - 96) & 511)] + fVec53[((IOTA - 209) & 511)])) + ((0.00500503555f * fVec53[((IOTA - 208) & 511)]) + ((0.00378429517f * fVec53[((IOTA - 195) & 511)]) + ((0.0111392559f * (fVec53[((IOTA - 111) & 511)] - fVec53[((IOTA - 165) & 511)])) + ((0.00723288674f * fVec53[((IOTA - 158) & 511)]) + ((0.00952177495f * fVec53[((IOTA - 157) & 511)]) + ((0.00817896053f * fVec53[((IOTA - 156) & 511)]) + ((0.0159611814f * (fVec53[((IOTA - 124) & 511)] - fVec53[((IOTA - 150) & 511)])) + ((0.0012817774f * fVec53[((IOTA - 147) & 511)]) + ((0.017975403f * fVec53[((IOTA - 123) & 511)]) + ((0.00656147953f * fVec53[((IOTA - 122) & 511)]) + ((0.00601214636f * fVec53[((IOTA - 112) & 511)]) + ((0.00979644153f * fVec53[((IOTA - 110) & 511)]) + ((0.0133365886f * fVec53[((IOTA - 109) & 511)]) + ((0.0155339213f * fVec53[((IOTA - 108) & 511)]) + ((0.0165410321f * fVec53[((IOTA - 107) & 511)]) + ((0.018097477f * fVec53[((IOTA - 106) & 511)]) + ((0.0110477004f * fVec53[((IOTA - 105) & 511)]) + ((0.0103152562f * fVec53[((IOTA - 99) & 511)]) + ((0.0265205856f * fVec53[((IOTA - 98) & 511)]) + ((0.0221869573f * fVec53[((IOTA - 97) & 511)]) + ((0.0363170281f * fVec53[((IOTA - 81) & 511)]) + ((0.0568254665f * fVec53[((IOTA - 80) & 511)]) + ((0.0332041383f * fVec53[((IOTA - 79) & 511)]) + ((0.112521745f * fVec53[((IOTA - 74) & 511)]) + ((0.282143623f * fVec53[((IOTA - 73) & 511)]) + ((0.303933829f * fVec53[((IOTA - 72) & 511)]) + ((0.183538318f * fVec53[((IOTA - 71) & 511)]) + ((0.061525315f * fVec53[((IOTA - 70) & 511)]) + ((0.0128482925f * fVec53[((IOTA - 69) & 511)]) + ((0.00100711081f * (fVec53[((IOTA - 40) & 511)] + fVec53[((IOTA - 53) & 511)])) + (0.00445570238f * fVec53[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.00149540696f * (fVec53[((IOTA - 443) & 511)] + fVec53[((IOTA - 496) & 511)])) + ((0.00155644398f * fVec53[((IOTA - 495) & 511)]) + ((0.00152592547f * (((((fVec53[((IOTA - 61) & 511)] + fVec53[((IOTA - 135) & 511)]) - fVec53[((IOTA - 222) & 511)]) - fVec53[((IOTA - 340) & 511)]) + fVec53[((IOTA - 460) & 511)]) + fVec53[((IOTA - 492) & 511)])) + ((0.00131229591f * ((fVec53[((IOTA - 67) & 511)] + fVec53[((IOTA - 474) & 511)]) + fVec53[((IOTA - 491) & 511)])) + ((0.00103762932f * (((((fVec53[((IOTA - 60) & 511)] - fVec53[((IOTA - 342) & 511)]) - fVec53[((IOTA - 362) & 511)]) - fVec53[((IOTA - 400) & 511)]) + fVec53[((IOTA - 410) & 511)]) + fVec53[((IOTA - 490) & 511)])) + ((0.000701925717f * (((fVec53[((IOTA - 438) & 511)] - (((fVec53[((IOTA - 42) & 511)] - fVec53[((IOTA - 58) & 511)]) - fVec53[((IOTA - 356) & 511)]) + fVec53[((IOTA - 401) & 511)])) + fVec53[((IOTA - 461) & 511)]) + fVec53[((IOTA - 486) & 511)])) + ((6.10370189e-05f * (((fVec53[((IOTA - 19) & 511)] + fVec53[((IOTA - 451) & 511)]) - fVec53[((IOTA - 462) & 511)]) - fVec53[((IOTA - 482) & 511)])) + ((0.000122074038f * ((fVec53[((IOTA - 37) & 511)] + fVec53[((IOTA - 414) & 511)]) + fVec53[((IOTA - 480) & 511)])) + ((0.000793481246f * ((((fVec53[((IOTA - 10) & 511)] - fVec53[((IOTA - 27) & 511)]) - fVec53[((IOTA - 140) & 511)]) + fVec53[((IOTA - 406) & 511)]) + fVec53[((IOTA - 475) & 511)])) + ((0.00247199927f * (fVec53[((IOTA - 370) & 511)] + fVec53[((IOTA - 471) & 511)])) + ((0.00253303628f * ((fVec53[((IOTA - 161) & 511)] - fVec53[((IOTA - 200) & 511)]) + fVec53[((IOTA - 470) & 511)])) + ((0.00112918485f * ((fVec53[((IOTA - 426) & 511)] - fVec53[((IOTA - 450) & 511)]) + fVec53[((IOTA - 466) & 511)])) + ((0.00198370311f * fVec53[((IOTA - 459) & 511)]) + ((0.00216681417f * ((((fVec53[((IOTA - 125) & 511)] - fVec53[((IOTA - 274) & 511)]) - fVec53[((IOTA - 287) & 511)]) - fVec53[((IOTA - 324) & 511)]) + fVec53[((IOTA - 458) & 511)])) + ((0.0038758507f * ((((fVec53[((IOTA - 168) & 511)] + fVec53[((IOTA - 169) & 511)]) - fVec53[((IOTA - 254) & 511)]) - fVec53[((IOTA - 257) & 511)]) + fVec53[((IOTA - 455) & 511)])) + ((9.15555283e-05f * ((((fTemp54 - fVec53[((IOTA - 25) & 511)]) - fVec53[((IOTA - 160) & 511)]) + fVec53[((IOTA - 415) & 511)]) - fVec53[((IOTA - 447) & 511)])) + ((0.000671407208f * ((fVec53[((IOTA - 48) & 511)] + fVec53[((IOTA - 359) & 511)]) + fVec53[((IOTA - 446) & 511)])) + ((0.000518814661f * (((fVec53[((IOTA - 20) & 511)] - fVec53[((IOTA - 26) & 511)]) - fVec53[((IOTA - 392) & 511)]) + fVec53[((IOTA - 437) & 511)])) + ((0.00125125889f * (fVec53[((IOTA - 407) & 511)] + fVec53[((IOTA - 423) & 511)])) + ((0.000946073793f * ((((fVec53[((IOTA - 47) & 511)] + fVec53[((IOTA - 59) & 511)]) - fVec53[((IOTA - 215) & 511)]) - fVec53[((IOTA - 217) & 511)]) + fVec53[((IOTA - 422) & 511)])) + ((0.000610370189f * ((fVec53[((IOTA - 11) & 511)] - fVec53[((IOTA - 403) & 511)]) + fVec53[((IOTA - 421) & 511)])) + ((0.000274666585f * ((fVec53[((IOTA - 12) & 511)] + fVec53[((IOTA - 44) & 511)]) + fVec53[((IOTA - 419) & 511)])) + ((0.000213629566f * ((((fVec53[((IOTA - 7) & 511)] + fVec53[((IOTA - 49) & 511)]) + fVec53[((IOTA - 155) & 511)]) + fVec53[((IOTA - 405) & 511)]) + fVec53[((IOTA - 416) & 511)])) + ((0.000885036774f * (((fVec53[((IOTA - 34) & 511)] - fVec53[((IOTA - 348) & 511)]) + fVec53[((IOTA - 369) & 511)]) + fVec53[((IOTA - 411) & 511)])) + ((0.0035401471f * fVec53[((IOTA - 388) & 511)]) + ((0.00302133244f * fVec53[((IOTA - 387) & 511)]) + ((0.000640888698f * (fVec53[((IOTA - 412) & 511)] - ((fVec53[((IOTA - 2) & 511)] - fVec53[((IOTA - 354) & 511)]) + fVec53[((IOTA - 402) & 511)]))) + ((0.00167851802f * fVec53[((IOTA - 374) & 511)]) + ((0.00057985168f * ((fVec53[((IOTA - 8) & 511)] - fVec53[((IOTA - 14) & 511)]) - fVec53[((IOTA - 368) & 511)])) + ((0.00234992523f * ((fVec53[((IOTA - 146) & 511)] - fVec53[((IOTA - 322) & 511)]) - fVec53[((IOTA - 364) & 511)])) + ((0.00274666585f * (fVec53[((IOTA - 141) & 511)] - fVec53[((IOTA - 321) & 511)])) + ((0.00448622089f * (((fVec53[((IOTA - 162) & 511)] - fVec53[((IOTA - 247) & 511)]) - fVec53[((IOTA - 265) & 511)]) - fVec53[((IOTA - 308) & 511)])) + ((0.0045167394f * (fVec53[((IOTA - 186) & 511)] - fVec53[((IOTA - 307) & 511)])) + ((0.00430310983f * (((fVec53[((IOTA - 191) & 511)] - fVec53[((IOTA - 269) & 511)]) - fVec53[((IOTA - 297) & 511)]) - fVec53[((IOTA - 304) & 511)])) + ((0.00405896176f * ((((fVec53[((IOTA - 82) & 511)] - fVec53[((IOTA - 212) & 511)]) - fVec53[((IOTA - 291) & 511)]) - fVec53[((IOTA - 293) & 511)]) - fVec53[((IOTA - 302) & 511)])) + ((0.00411999878f * ((fVec53[((IOTA - 174) & 511)] - fVec53[((IOTA - 292) & 511)]) - fVec53[((IOTA - 295) & 511)])) + ((0.00372325815f * (fVec53[((IOTA - 172) & 511)] - fVec53[((IOTA - 281) & 511)])) + ((0.00466933195f * (fVec53[((IOTA - 187) & 511)] - fVec53[((IOTA - 266) & 511)])) + ((0.00460829493f * (fVec53[((IOTA - 171) & 511)] - fVec53[((IOTA - 246) & 511)])) + ((0.00439466536f * (fVec53[((IOTA - 170) & 511)] - fVec53[((IOTA - 232) & 511)])) + ((0.00164799951f * (fVec53[((IOTA - 192) & 511)] - fVec53[((IOTA - 224) & 511)])) + ((0.00314340647f * (fVec53[((IOTA - 133) & 511)] - fVec53[((IOTA - 199) & 511)])) + ((0.00357066561f * (fVec53[((IOTA - 62) & 511)] - fVec53[((IOTA - 196) & 511)])) + ((0.00595110934f * fVec53[((IOTA - 190) & 511)]) + ((0.00604266487f * fVec53[((IOTA - 189) & 511)]) + ((0.00531022064f * fVec53[((IOTA - 188) & 511)]) + ((0.00540177617f * fVec53[((IOTA - 185) & 511)]) + ((0.00634784997f * fVec53[((IOTA - 184) & 511)]) + ((0.00692770164f * fVec53[((IOTA - 183) & 511)]) + ((0.00753807183f * (fVec53[((IOTA - 144) & 511)] + fVec53[((IOTA - 182) & 511)])) + ((0.00778221991f * fVec53[((IOTA - 181) & 511)]) + ((0.00823999755f * fVec53[((IOTA - 180) & 511)]) + ((0.00878933072f * fVec53[((IOTA - 179) & 511)]) + ((0.00924710836f * fVec53[((IOTA - 178) & 511)]) + ((0.00915555283f * fVec53[((IOTA - 177) & 511)]) + ((0.00814844202f * fVec53[((IOTA - 176) & 511)]) + ((0.00628681295f * fVec53[((IOTA - 175) & 511)]) + ((0.003234962f * fVec53[((IOTA - 173) & 511)]) + ((0.00622577593f * fVec53[((IOTA - 167) & 511)]) + ((0.009704886f * (fVec53[((IOTA - 164) & 511)] + fVec53[((IOTA - 166) & 511)])) + ((0.00720236823f * fVec53[((IOTA - 163) & 511)]) + ((0.0254524369f * fVec53[((IOTA - 153) & 511)]) + ((0.0311593991f * fVec53[((IOTA - 152) & 511)]) + ((0.0274971779f * (fVec53[((IOTA - 92) & 511)] + fVec53[((IOTA - 151) & 511)])) + ((0.00610370189f * fVec53[((IOTA - 145) & 511)]) + ((0.00787377544f * fVec53[((IOTA - 143) & 511)]) + ((0.00592059083f * fVec53[((IOTA - 142) & 511)]) + ((0.0127567369f * fVec53[((IOTA - 154) & 511)]) + ((0.00650044251f * fVec53[((IOTA - 132) & 511)]) + ((0.0152592547f * fVec53[((IOTA - 131) & 511)]) + ((0.0273751039f * fVec53[((IOTA - 130) & 511)]) + ((0.0394604318f * fVec53[((IOTA - 129) & 511)]) + ((0.0456556901f * fVec53[((IOTA - 128) & 511)]) + ((0.0414441377f * fVec53[((IOTA - 127) & 511)]) + ((0.0247199927f * fVec53[((IOTA - 126) & 511)]) + ((0.0124515519f * fVec53[((IOTA - 121) & 511)]) + ((0.0258491784f * fVec53[((IOTA - 120) & 511)]) + ((0.0301217698f * fVec53[((IOTA - 119) & 511)]) + ((0.0260322895f * fVec53[((IOTA - 118) & 511)]) + ((0.0255439933f * fVec53[((IOTA - 117) & 511)]) + ((0.025879696f * fVec53[((IOTA - 116) & 511)]) + ((0.0244758446f * fVec53[((IOTA - 115) & 511)]) + ((0.0184026621f * fVec53[((IOTA - 114) & 511)]) + ((0.0074159978f * fVec53[((IOTA - 113) & 511)]) + ((0.00558488723f * fVec53[((IOTA - 104) & 511)]) + ((0.0277718436f * fVec53[((IOTA - 103) & 511)]) + ((0.0415662117f * fVec53[((IOTA - 102) & 511)]) + ((0.0424512476f * fVec53[((IOTA - 101) & 511)]) + ((0.0186468102f * fVec53[((IOTA - 100) & 511)]) + ((0.0140995514f * fVec53[((IOTA - 95) & 511)]) + ((0.0299081393f * fVec53[((IOTA - 94) & 511)]) + ((0.0341196954f * fVec53[((IOTA - 93) & 511)]) + ((0.0196844395f * fVec53[((IOTA - 91) & 511)]) + ((0.0207831059f * fVec53[((IOTA - 90) & 511)]) + ((0.0384533219f * fVec53[((IOTA - 89) & 511)]) + ((0.0332651772f * fVec53[((IOTA - 88) & 511)]) + ((0.0250862148f * fVec53[((IOTA - 87) & 511)]) + ((0.00497451704f * fVec53[((IOTA - 86) & 511)]) + ((0.00555436872f * fVec53[((IOTA - 85) & 511)]) + ((0.00616473891f * fVec53[((IOTA - 84) & 511)]) + ((0.0114749596f * fVec53[((IOTA - 83) & 511)]) + ((0.0552995391f * fVec53[((IOTA - 78) & 511)]) + ((0.154271066f * fVec53[((IOTA - 77) & 511)]) + ((0.193273723f * fVec53[((IOTA - 76) & 511)]) + ((0.0898159742f * fVec53[((IOTA - 75) & 511)]) + ((0.00714133121f * fVec53[((IOTA - 66) & 511)]) + ((0.00988799706f * fVec53[((IOTA - 65) & 511)]) + ((0.0093691824f * fVec53[((IOTA - 64) & 511)]) + ((0.000427259132f * (fVec53[((IOTA - 32) & 511)] - fVec53[((IOTA - 55) & 511)])) + (0.00668355357f * fVec53[((IOTA - 63) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00189214759f * ((fVec53[((IOTA - 134) & 511)] - fVec53[((IOTA - 380) & 511)]) + fVec53[((IOTA - 506) & 511)]))) + (0.00134281442f * ((((fVec53[((IOTA - 408) & 511)] + fVec53[((IOTA - 441) & 511)]) + fVec53[((IOTA - 498) & 511)]) + fVec53[((IOTA - 510) & 511)]) + fVec53[((IOTA - 511) & 511)])))))) : (iSlow117 ? (iSlow121 ? (((0.00183111057f * (((((((((fVec52[((IOTA - 26) & 511)] - fVec52[((IOTA - 53) & 511)]) + fVec52[((IOTA - 304) & 511)]) - fVec52[((IOTA - 364) & 511)]) - fVec52[((IOTA - 380) & 511)]) - fVec52[((IOTA - 395) & 511)]) - fVec52[((IOTA - 398) & 511)]) + fVec52[((IOTA - 424) & 511)]) + fVec52[((IOTA - 425) & 511)]) + fVec52[((IOTA - 511) & 511)])) + ((0.000823999755f * ((fVec52[((IOTA - 495) & 511)] - ((((fVec52[((IOTA - 223) & 511)] - fVec52[((IOTA - 342) & 511)]) - fVec52[((IOTA - 401) & 511)]) + fVec52[((IOTA - 432) & 511)]) - fVec52[((IOTA - 490) & 511)])) + fVec52[((IOTA - 507) & 511)])) + ((0.000976592302f * ((((fVec52[((IOTA - 31) & 511)] - fVec52[((IOTA - 298) & 511)]) + fVec52[((IOTA - 310) & 511)]) + fVec52[((IOTA - 335) & 511)]) + fVec52[((IOTA - 506) & 511)])) + ((0.001617481f * ((fVec52[((IOTA - 334) & 511)] - fVec52[((IOTA - 429) & 511)]) + fVec52[((IOTA - 505) & 511)])) + ((0.00335703604f * (fVec52[((IOTA - 189) & 511)] + fVec52[((IOTA - 503) & 511)])) + ((0.00363170262f * fVec52[((IOTA - 502) & 511)]) + ((0.00305185094f * fVec52[((IOTA - 501) & 511)]) + ((0.00186162908f * ((((((fVec52[((IOTA - 28) & 511)] - fVec52[((IOTA - 204) & 511)]) + fVec52[((IOTA - 307) & 511)]) - fVec52[((IOTA - 396) & 511)]) + fVec52[((IOTA - 435) & 511)]) + fVec52[((IOTA - 436) & 511)]) + fVec52[((IOTA - 500) & 511)])) + ((0.00054933317f * ((((fVec52[((IOTA - 41) & 511)] - fVec52[((IOTA - 171) & 511)]) - fVec52[((IOTA - 480) & 511)]) - fVec52[((IOTA - 482) & 511)]) - fVec52[((IOTA - 497) & 511)])) + ((0.000518814661f * ((fVec52[((IOTA - 339) & 511)] - fVec52[((IOTA - 400) & 511)]) + fVec52[((IOTA - 489) & 511)])) + ((0.000335703604f * ((((fVec52[((IOTA - 20) & 511)] + fVec52[((IOTA - 168) & 511)]) + fVec52[((IOTA - 193) & 511)]) - fVec52[((IOTA - 479) & 511)]) + fVec52[((IOTA - 488) & 511)])) + ((0.000366222113f * (((fVec52[((IOTA - 21) & 511)] - fVec52[((IOTA - 412) & 511)]) + fVec52[((IOTA - 485) & 511)]) + fVec52[((IOTA - 487) & 511)])) + ((0.000274666585f * (fVec52[((IOTA - 433) & 511)] - fVec52[((IOTA - 483) & 511)])) + ((0.00277718436f * ((fVec52[((IOTA - 321) & 511)] - fVec52[((IOTA - 456) & 511)]) - fVec52[((IOTA - 471) & 511)])) + ((0.00241096225f * ((((fVec52[((IOTA - 84) & 511)] - fVec52[((IOTA - 257) & 511)]) + fVec52[((IOTA - 421) & 511)]) - fVec52[((IOTA - 460) & 511)]) - fVec52[((IOTA - 468) & 511)])) + ((0.00134281442f * (fVec52[((IOTA - 426) & 511)] - fVec52[((IOTA - 466) & 511)])) + ((0.00103762932f * ((fVec52[((IOTA - 22) & 511)] - fVec52[((IOTA - 301) & 511)]) - fVec52[((IOTA - 465) & 511)])) + ((0.00201422162f * ((fVec52[((IOTA - 319) & 511)] + fVec52[((IOTA - 325) & 511)]) - fVec52[((IOTA - 461) & 511)])) + ((0.0025940733f * ((fVec52[((IOTA - 318) & 511)] - fVec52[((IOTA - 357) & 511)]) - fVec52[((IOTA - 459) & 511)])) + ((0.00265511032f * ((fVec52[((IOTA - 408) & 511)] - fVec52[((IOTA - 457) & 511)]) - fVec52[((IOTA - 458) & 511)])) + ((0.00271614734f * (fVec52[((IOTA - 225) & 511)] - fVec52[((IOTA - 454) & 511)])) + ((0.00247199927f * (fVec52[((IOTA - 233) & 511)] - fVec52[((IOTA - 453) & 511)])) + ((0.00207525864f * (((fVec52[((IOTA - 32) & 511)] - fVec52[((IOTA - 55) & 511)]) - fVec52[((IOTA - 57) & 511)]) - fVec52[((IOTA - 452) & 511)])) + ((0.00106814783f * ((((fVec52[((IOTA - 29) & 511)] - fVec52[((IOTA - 63) & 511)]) - fVec52[((IOTA - 259) & 511)]) - fVec52[((IOTA - 367) & 511)]) - fVec52[((IOTA - 442) & 511)])) + ((0.0012817774f * fVec52[((IOTA - 437) & 511)]) + ((0.000946073793f * (((fVec52[((IOTA - 23) & 511)] - fVec52[((IOTA - 354) & 511)]) - fVec52[((IOTA - 411) & 511)]) - fVec52[((IOTA - 464) & 511)])) + ((0.00198370311f * ((((fVec52[((IOTA - 30) & 511)] + fVec52[((IOTA - 101) & 511)]) - fVec52[((IOTA - 215) & 511)]) - fVec52[((IOTA - 363) & 511)]) - fVec52[((IOTA - 430) & 511)])) + ((0.000457777642f * (((fVec52[((IOTA - 217) & 511)] - fVec52[((IOTA - 302) & 511)]) - fVec52[((IOTA - 410) & 511)]) + fVec52[((IOTA - 427) & 511)])) + ((0.00177007355f * (fVec52[((IOTA - 326) & 511)] + fVec52[((IOTA - 422) & 511)])) + ((0.00366222113f * (fVec52[((IOTA - 267) & 511)] + fVec52[((IOTA - 420) & 511)])) + ((0.00537125766f * (fVec52[((IOTA - 219) & 511)] + fVec52[((IOTA - 419) & 511)])) + ((0.00729392376f * fVec52[((IOTA - 416) & 511)]) + ((0.00567644276f * ((fVec52[((IOTA - 81) & 511)] - fVec52[((IOTA - 292) & 511)]) + fVec52[((IOTA - 415) & 511)])) + ((0.00344859157f * fVec52[((IOTA - 414) & 511)]) + ((0.00119022187f * ((((((fVec52[((IOTA - 27) & 511)] - fVec52[((IOTA - 5) & 511)]) - fVec52[((IOTA - 46) & 511)]) - fVec52[((IOTA - 47) & 511)]) - fVec52[((IOTA - 297) & 511)]) + fVec52[((IOTA - 311) & 511)]) + fVec52[((IOTA - 413) & 511)])) + ((0.000854518265f * ((fVec52[((IOTA - 135) & 511)] + fVec52[((IOTA - 309) & 511)]) + fVec52[((IOTA - 409) & 511)])) + ((0.00445570238f * fVec52[((IOTA - 407) & 511)]) + ((0.00561540574f * fVec52[((IOTA - 406) & 511)]) + ((0.00592059083f * fVec52[((IOTA - 405) & 511)]) + ((0.00527970213f * (((fVec52[((IOTA - 74) & 511)] - fVec52[((IOTA - 199) & 511)]) - fVec52[((IOTA - 240) & 511)]) + fVec52[((IOTA - 404) & 511)])) + ((0.00405896176f * (fVec52[((IOTA - 83) & 511)] + fVec52[((IOTA - 403) & 511)])) + ((0.0019226661f * ((fVec52[((IOTA - 34) & 511)] - fVec52[((IOTA - 54) & 511)]) - fVec52[((IOTA - 397) & 511)])) + ((0.00256355479f * ((fVec52[((IOTA - 182) & 511)] + fVec52[((IOTA - 305) & 511)]) - fVec52[((IOTA - 389) & 511)])) + ((0.00262459181f * (fVec52[((IOTA - 206) & 511)] - fVec52[((IOTA - 388) & 511)])) + ((0.00219733268f * (fVec52[((IOTA - 273) & 511)] - fVec52[((IOTA - 385) & 511)])) + ((0.00228888821f * (fVec52[((IOTA - 330) & 511)] - fVec52[((IOTA - 384) & 511)])) + ((0.00216681417f * ((((fVec52[((IOTA - 36) & 511)] - fVec52[((IOTA - 238) & 511)]) + fVec52[((IOTA - 320) & 511)]) - fVec52[((IOTA - 362) & 511)]) - fVec52[((IOTA - 381) & 511)])) + ((0.00057985168f * ((fVec52[((IOTA - 33) & 511)] - fVec52[((IOTA - 42) & 511)]) - fVec52[((IOTA - 373) & 511)])) + ((0.00158696249f * ((fVec52[((IOTA - 24) & 511)] - fVec52[((IOTA - 60) & 511)]) - fVec52[((IOTA - 365) & 511)])) + ((0.0019531846f * ((fVec52[((IOTA - 39) & 511)] - fVec52[((IOTA - 296) & 511)]) - fVec52[((IOTA - 356) & 511)])) + ((0.000762962736f * (((fVec52[((IOTA - 85) & 511)] + fVec52[((IOTA - 205) & 511)]) + fVec52[((IOTA - 340) & 511)]) - fVec52[((IOTA - 353) & 511)])) + ((0.000213629566f * fVec52[((IOTA - 337) & 511)]) + ((0.00213629566f * fVec52[((IOTA - 329) & 511)]) + ((0.00302133244f * fVec52[((IOTA - 323) & 511)]) + ((0.00311288796f * fVec52[((IOTA - 322) & 511)]) + ((0.00692770164f * fVec52[((IOTA - 418) & 511)]) + ((0.00122074038f * (((((fVec52[((IOTA - 25) & 511)] - fVec52[((IOTA - 12) & 511)]) - fVec52[((IOTA - 62) & 511)]) + fVec52[((IOTA - 274) & 511)]) - fVec52[((IOTA - 300) & 511)]) + fVec52[((IOTA - 308) & 511)])) + ((0.00250251777f * fVec52[((IOTA - 306) & 511)]) + ((0.00372325815f * fVec52[((IOTA - 317) & 511)]) + ((0.00585955381f * (((fVec52[((IOTA - 79) & 511)] - fVec52[((IOTA - 241) & 511)]) - fVec52[((IOTA - 252) & 511)]) - fVec52[((IOTA - 291) & 511)])) + ((0.00320444349f * fVec52[((IOTA - 272) & 511)]) + ((0.00418103579f * fVec52[((IOTA - 271) & 511)]) + ((0.00436414685f * fVec52[((IOTA - 270) & 511)]) + ((0.00347911008f * ((fVec52[((IOTA - 71) & 511)] + fVec52[((IOTA - 209) & 511)]) + fVec52[((IOTA - 268) & 511)])) + ((0.00454725791f * fVec52[((IOTA - 266) & 511)]) + ((0.0045167394f * fVec52[((IOTA - 316) & 511)]) + ((0.00552385021f * fVec52[((IOTA - 264) & 511)]) + ((0.00439466536f * fVec52[((IOTA - 263) & 511)]) + ((0.00357066561f * fVec52[((IOTA - 314) & 511)]) + ((0.00442518387f * fVec52[((IOTA - 315) & 511)]) + ((0.00268562883f * (fVec52[((IOTA - 70) & 511)] - fVec52[((IOTA - 245) & 511)])) + ((0.003234962f * (fVec52[((IOTA - 183) & 511)] - fVec52[((IOTA - 243) & 511)])) + ((0.00662251655f * fVec52[((IOTA - 230) & 511)]) + ((0.00735496078f * fVec52[((IOTA - 229) & 511)]) + ((0.00726340525f * ((fVec52[((IOTA - 145) & 511)] + fVec52[((IOTA - 176) & 511)]) + fVec52[((IOTA - 228) & 511)])) + ((0.00616473891f * fVec52[((IOTA - 227) & 511)]) + ((0.00479140598f * fVec52[((IOTA - 226) & 511)]) + ((0.00411999878f * fVec52[((IOTA - 220) & 511)]) + ((0.00222785119f * fVec52[((IOTA - 213) & 511)]) + ((0.00350962859f * (fVec52[((IOTA - 175) & 511)] + fVec52[((IOTA - 212) & 511)])) + ((0.00448622089f * (fVec52[((IOTA - 37) & 511)] + fVec52[((IOTA - 211) & 511)])) + ((0.00308236945f * fVec52[((IOTA - 208) & 511)]) + ((0.00283822138f * fVec52[((IOTA - 207) & 511)]) + ((0.0051576281f * fVec52[((IOTA - 196) & 511)]) + ((0.00717184972f * (fVec52[((IOTA - 136) & 511)] + fVec52[((IOTA - 195) & 511)])) + ((0.00497451704f * fVec52[((IOTA - 194) & 511)]) + ((0.00927762687f * fVec52[((IOTA - 188) & 511)]) + ((0.0137028107f * fVec52[((IOTA - 187) & 511)]) + ((0.0150456252f * fVec52[((IOTA - 186) & 511)]) + ((0.0125736259f * fVec52[((IOTA - 185) & 511)]) + ((0.0071108127f * fVec52[((IOTA - 184) & 511)]) + ((0.00683614612f * fVec52[((IOTA - 181) & 511)]) + ((0.0119022187f * fVec52[((IOTA - 180) & 511)]) + ((0.0142826624f * fVec52[((IOTA - 179) & 511)]) + ((0.0134891812f * fVec52[((IOTA - 178) & 511)]) + ((0.0102542192f * fVec52[((IOTA - 177) & 511)]) + ((0.00753807183f * fVec52[((IOTA - 149) & 511)]) + ((0.0165410321f * fVec52[((IOTA - 148) & 511)]) + ((0.0196234025f * fVec52[((IOTA - 147) & 511)]) + ((0.013061922f * fVec52[((IOTA - 146) & 511)]) + ((0.00796533097f * fVec52[((IOTA - 144) & 511)]) + ((0.0122989593f * fVec52[((IOTA - 143) & 511)]) + ((0.015991699f * fVec52[((IOTA - 142) & 511)]) + ((0.0167241432f * fVec52[((IOTA - 141) & 511)]) + ((0.0154118473f * fVec52[((IOTA - 140) & 511)]) + ((0.014557329f * fVec52[((IOTA - 139) & 511)]) + ((0.00857570115f * fVec52[((IOTA - 138) & 511)]) + ((0.00836207159f * fVec52[((IOTA - 137) & 511)]) + ((0.0231635496f * fVec52[((IOTA - 129) & 511)]) + ((0.0201116987f * fVec52[((IOTA - 128) & 511)]) + ((0.0312814713f * fVec52[((IOTA - 119) & 511)]) + ((0.0484023578f * fVec52[((IOTA - 118) & 511)]) + ((0.0487990975f * fVec52[((IOTA - 117) & 511)]) + ((0.0172124393f * fVec52[((IOTA - 116) & 511)]) + ((0.0331736207f * fVec52[((IOTA - 110) & 511)]) + ((0.0912808627f * fVec52[((IOTA - 109) & 511)]) + ((0.123142183f * fVec52[((IOTA - 108) & 511)]) + ((0.122959077f * fVec52[((IOTA - 107) & 511)]) + ((0.0642109439f * fVec52[((IOTA - 106) & 511)]) + ((0.0668355376f * fVec52[((IOTA - 100) & 511)]) + ((0.137089148f * fVec52[((IOTA - 99) & 511)]) + ((0.198370308f * fVec52[((IOTA - 98) & 511)]) + ((0.202948093f * fVec52[((IOTA - 97) & 511)]) + ((0.0982085615f * fVec52[((IOTA - 96) & 511)]) + ((0.00115970336f * (fVec52[((IOTA - 68) & 511)] - fVec52[((IOTA - 86) & 511)])) + ((0.00503555406f * fVec52[((IOTA - 82) & 511)]) + ((0.0057985168f * fVec52[((IOTA - 80) & 511)]) + ((0.00573747978f * (fVec52[((IOTA - 77) & 511)] + fVec52[((IOTA - 78) & 511)])) + ((0.0122379223f * fVec52[((IOTA - 127) & 511)]) + ((0.00564592425f * fVec52[((IOTA - 76) & 511)]) + ((0.00555436872f * fVec52[((IOTA - 75) & 511)]) + ((0.0042115543f * fVec52[((IOTA - 72) & 511)]) + (0.00482192449f * fVec52[((IOTA - 73) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00112918485f * ((((fVec52[((IOTA - 13) & 511)] + fVec52[((IOTA - 120) & 511)]) + fVec52[((IOTA - 378) & 511)]) + fVec52[((IOTA - 463) & 511)]) - fVec52[((IOTA - 509) & 511)])) + ((0.000885036774f * (((fVec52[((IOTA - 3) & 511)] + fVec52[((IOTA - 283) & 511)]) - fVec52[((IOTA - 341) & 511)]) - fVec52[((IOTA - 508) & 511)])) + ((0.00253303628f * ((fVec52[((IOTA - 87) & 511)] - fVec52[((IOTA - 262) & 511)]) - fVec52[((IOTA - 504) & 511)])) + ((0.000488296151f * (((((((((fVec52[((IOTA - 1) & 511)] + fVec52[((IOTA - 17) & 511)]) + fVec52[((IOTA - 65) & 511)]) - fVec52[((IOTA - 67) & 511)]) - fVec52[((IOTA - 336) & 511)]) + fVec52[((IOTA - 350) & 511)]) + fVec52[((IOTA - 375) & 511)]) + fVec52[((IOTA - 443) & 511)]) + fVec52[((IOTA - 448) & 511)]) - fVec52[((IOTA - 499) & 511)])) + ((0.000427259132f * ((fVec52[((IOTA - 16) & 511)] - fVec52[((IOTA - 486) & 511)]) + fVec52[((IOTA - 498) & 511)])) + ((3.05185094e-05f * (((fVec52[((IOTA - 66) & 511)] - fVec52[((IOTA - 282) & 511)]) + fVec52[((IOTA - 444) & 511)]) - fVec52[((IOTA - 496) & 511)])) + ((0.00180059206f * (((fVec52[((IOTA - 59) & 511)] + fVec52[((IOTA - 392) & 511)]) + fVec52[((IOTA - 473) & 511)]) - fVec52[((IOTA - 493) & 511)])) + ((0.00164799951f * ((fVec52[((IOTA - 52) & 511)] - fVec52[((IOTA - 169) & 511)]) - fVec52[((IOTA - 492) & 511)])) + ((0.00131229591f * ((((fVec52[((IOTA - 366) & 511)] - fVec52[((IOTA - 434) & 511)]) + fVec52[((IOTA - 440) & 511)]) + fVec52[((IOTA - 450) & 511)]) - fVec52[((IOTA - 491) & 511)])) + ((0.000122074038f * ((((((fVec52[((IOTA - 214) & 511)] + fVec52[((IOTA - 281) & 511)]) + fVec52[((IOTA - 347) & 511)]) - fVec52[((IOTA - 446) & 511)]) + fVec52[((IOTA - 447) & 511)]) + fVec52[((IOTA - 478) & 511)]) - fVec52[((IOTA - 484) & 511)])) + ((0.000671407208f * (((((((fVec52[((IOTA - 2) & 511)] + fVec52[((IOTA - 235) & 511)]) - fVec52[((IOTA - 303) & 511)]) - fVec52[((IOTA - 343) & 511)]) + fVec52[((IOTA - 428) & 511)]) + fVec52[((IOTA - 439) & 511)]) + fVec52[((IOTA - 475) & 511)]) + fVec52[((IOTA - 481) & 511)])) + ((9.15555283e-05f * (fVec52[((IOTA - 348) & 511)] + fVec52[((IOTA - 477) & 511)])) + ((0.000305185094f * (((fVec52[((IOTA - 260) & 511)] - fVec52[((IOTA - 338) & 511)]) - fVec52[((IOTA - 438) & 511)]) + fVec52[((IOTA - 476) & 511)])) + ((0.00125125889f * (((((fVec52[((IOTA - 6) & 511)] + fVec52[((IOTA - 173) & 511)]) + fVec52[((IOTA - 236) & 511)]) + fVec52[((IOTA - 369) & 511)]) + fVec52[((IOTA - 371) & 511)]) + fVec52[((IOTA - 474) & 511)])) + ((0.00238044374f * ((((((fVec52[((IOTA - 244) & 511)] - fVec52[((IOTA - 331) & 511)]) - fVec52[((IOTA - 332) & 511)]) + fVec52[((IOTA - 382) & 511)]) + fVec52[((IOTA - 383) & 511)]) + fVec52[((IOTA - 390) & 511)]) + fVec52[((IOTA - 472) & 511)])) + ((0.00292977691f * fVec52[((IOTA - 470) & 511)]) + ((0.00280770287f * (fVec52[((IOTA - 455) & 511)] + fVec52[((IOTA - 469) & 511)])) + ((0.00189214759f * (((fVec52[((IOTA - 58) & 511)] - fVec52[((IOTA - 69) & 511)]) - fVec52[((IOTA - 327) & 511)]) + fVec52[((IOTA - 467) & 511)])) + ((0.00152592547f * fVec52[((IOTA - 462) & 511)]) + ((0.00149540696f * (((fVec52[((IOTA - 10) & 511)] + fVec52[((IOTA - 50) & 511)]) + fVec52[((IOTA - 379) & 511)]) - fVec52[((IOTA - 494) & 511)])) + ((0.00173955504f * ((fVec52[((IOTA - 216) & 511)] - fVec52[((IOTA - 423) & 511)]) + fVec52[((IOTA - 451) & 511)])) + ((0.000915555283f * ((fVec52[((IOTA - 372) & 511)] + fVec52[((IOTA - 377) & 511)]) + fVec52[((IOTA - 449) & 511)])) + ((0.000183111057f * (((fVec52[((IOTA - 19) & 511)] - fVec52[((IOTA - 159) & 511)]) + fVec52[((IOTA - 349) & 511)]) - fVec52[((IOTA - 445) & 511)])) + ((0.00137333293f * fVec52[((IOTA - 441) & 511)]) + ((0.00766014587f * (fVec52[((IOTA - 202) & 511)] - fVec52[((IOTA - 417) & 511)])) + ((0.00244148076f * (((((fVec52[((IOTA - 158) & 511)] - fVec52[((IOTA - 313) & 511)]) - fVec52[((IOTA - 324) & 511)]) + fVec52[((IOTA - 361) & 511)]) + fVec52[((IOTA - 387) & 511)]) - fVec52[((IOTA - 402) & 511)])) + ((0.00143436994f * (((fVec52[((IOTA - 8) & 511)] + fVec52[((IOTA - 61) & 511)]) + fVec52[((IOTA - 355) & 511)]) + fVec52[((IOTA - 399) & 511)])) + ((0.00167851802f * (fVec52[((IOTA - 172) & 511)] + fVec52[((IOTA - 393) & 511)])) + ((0.00170903653f * (((fVec52[((IOTA - 190) & 511)] - fVec52[((IOTA - 312) & 511)]) + fVec52[((IOTA - 394) & 511)]) + fVec52[((IOTA - 431) & 511)])) + ((0.00204474013f * (((fVec52[((IOTA - 56) & 511)] - fVec52[((IOTA - 328) & 511)]) - fVec52[((IOTA - 333) & 511)]) + fVec52[((IOTA - 391) & 511)])) + ((0.0022583697f * fVec52[((IOTA - 386) & 511)]) + ((0.000640888698f * ((fVec52[((IOTA - 222) & 511)] + fVec52[((IOTA - 280) & 511)]) + fVec52[((IOTA - 376) & 511)])) + ((0.000396740623f * (fVec52[((IOTA - 35) & 511)] + fVec52[((IOTA - 374) & 511)])) + ((0.00140385143f * (((fVec52[((IOTA - 7) & 511)] + fVec52[((IOTA - 48) & 511)]) + fVec52[((IOTA - 49) & 511)]) + fVec52[((IOTA - 370) & 511)])) + ((0.00109866634f * ((fVec52[((IOTA - 105) & 511)] - fVec52[((IOTA - 170) & 511)]) + fVec52[((IOTA - 368) & 511)])) + ((0.00274666585f * fVec52[((IOTA - 360) & 511)]) + ((0.00299081393f * (fVec52[((IOTA - 198) & 511)] + fVec52[((IOTA - 359) & 511)])) + ((0.00286873989f * (fVec52[((IOTA - 256) & 511)] + fVec52[((IOTA - 358) & 511)])) + ((0.000732444227f * ((fVec52[((IOTA - 15) & 511)] - fVec52[((IOTA - 174) & 511)]) + fVec52[((IOTA - 352) & 511)])) + ((0.000701925717f * ((((fVec52[((IOTA - 45) & 511)] - fVec52[((IOTA - 234) & 511)]) - fVec52[((IOTA - 275) & 511)]) + fVec52[((IOTA - 278) & 511)]) + fVec52[((IOTA - 351) & 511)])) + ((0.000244148076f * (((fTemp53 - fVec52[((IOTA - 276) & 511)]) - fVec52[((IOTA - 344) & 511)]) + fVec52[((IOTA - 346) & 511)])) + ((6.10370189e-05f * (fVec52[((IOTA - 43) & 511)] + fVec52[((IOTA - 345) & 511)])) + ((0.00100711081f * (((fVec52[((IOTA - 4) & 511)] + fVec52[((IOTA - 40) & 511)]) + fVec52[((IOTA - 279) & 511)]) + fVec52[((IOTA - 299) & 511)])) + ((0.0028992584f * fVec52[((IOTA - 295) & 511)]) + ((0.00399792474f * fVec52[((IOTA - 294) & 511)]) + ((0.00491348002f * fVec52[((IOTA - 293) & 511)]) + ((0.00531022064f * fVec52[((IOTA - 290) & 511)]) + ((0.00430310983f * fVec52[((IOTA - 289) & 511)]) + ((0.00341807306f * (fVec52[((IOTA - 285) & 511)] + fVec52[((IOTA - 288) & 511)])) + ((0.00332651753f * (fVec52[((IOTA - 255) & 511)] + fVec52[((IOTA - 287) & 511)])) + ((0.0035401471f * fVec52[((IOTA - 286) & 511)]) + ((0.00231940672f * fVec52[((IOTA - 284) & 511)]) + ((0.000152592547f * (fVec52[((IOTA - 18) & 511)] + fVec52[((IOTA - 277) & 511)])) + ((0.00393688772f * (fVec52[((IOTA - 160) & 511)] - fVec52[((IOTA - 269) & 511)])) + ((0.000793481246f * (((((fVec52[((IOTA - 14) & 511)] + fVec52[((IOTA - 44) & 511)]) + fVec52[((IOTA - 64) & 511)]) - fVec52[((IOTA - 197) & 511)]) - fVec52[((IOTA - 224) & 511)]) - fVec52[((IOTA - 261) & 511)])) + ((0.00155644398f * (((fVec52[((IOTA - 9) & 511)] + fVec52[((IOTA - 51) & 511)]) + fVec52[((IOTA - 237) & 511)]) + fVec52[((IOTA - 258) & 511)])) + ((0.0038758507f * fVec52[((IOTA - 254) & 511)]) + ((0.00473036896f * (fVec52[((IOTA - 126) & 511)] + fVec52[((IOTA - 253) & 511)])) + ((0.00659199804f * fVec52[((IOTA - 251) & 511)]) + ((0.00680562761f * (fVec52[((IOTA - 249) & 511)] + fVec52[((IOTA - 250) & 511)])) + ((0.00653096102f * fVec52[((IOTA - 248) & 511)]) + ((0.0058290353f * fVec52[((IOTA - 247) & 511)]) + ((0.00518814661f * fVec52[((IOTA - 242) & 511)]) + ((0.00369273964f * fVec52[((IOTA - 239) & 511)]) + ((0.00390636921f * (((fVec52[((IOTA - 192) & 511)] - fVec52[((IOTA - 210) & 511)]) - fVec52[((IOTA - 218) & 511)]) - fVec52[((IOTA - 232) & 511)])) + ((0.00540177617f * (fVec52[((IOTA - 167) & 511)] - fVec52[((IOTA - 231) & 511)])) + ((0.00524918362f * fVec52[((IOTA - 203) & 511)]) + ((0.00781273842f * fVec52[((IOTA - 201) & 511)]) + ((0.00686666463f * fVec52[((IOTA - 200) & 511)]) + ((0.00546281319f * (fVec52[((IOTA - 89) & 511)] - fVec52[((IOTA - 265) & 511)])) + ((0.00427259132f * fVec52[((IOTA - 246) & 511)]) + ((0.00469985045f * fVec52[((IOTA - 191) & 511)]) + ((0.0126956999f * fVec52[((IOTA - 166) & 511)]) + ((0.0216071047f * fVec52[((IOTA - 165) & 511)]) + ((0.0249336231f * fVec52[((IOTA - 164) & 511)]) + ((0.0234076977f * fVec52[((IOTA - 163) & 511)]) + ((0.0171514023f * fVec52[((IOTA - 162) & 511)]) + ((0.00955229346f * fVec52[((IOTA - 161) & 511)]) + ((0.00991851557f * fVec52[((IOTA - 157) & 511)]) + ((0.0185857732f * fVec52[((IOTA - 156) & 511)]) + ((0.0252998453f * fVec52[((IOTA - 155) & 511)]) + ((0.0274666585f * fVec52[((IOTA - 154) & 511)]) + ((0.0278939176f * fVec52[((IOTA - 153) & 511)]) + ((0.0264290292f * fVec52[((IOTA - 152) & 511)]) + ((0.0203558467f * fVec52[((IOTA - 151) & 511)]) + ((0.00985747855f * fVec52[((IOTA - 150) & 511)]) + ((0.0102237007f * fVec52[((IOTA - 134) & 511)]) + ((0.0222479943f * fVec52[((IOTA - 133) & 511)]) + ((0.016113773f * fVec52[((IOTA - 132) & 511)]) + ((0.00488296151f * fVec52[((IOTA - 131) & 511)]) + ((0.0156254768f * (fVec52[((IOTA - 90) & 511)] - fVec52[((IOTA - 130) & 511)])) + ((0.0261238441f * fVec52[((IOTA - 125) & 511)]) + ((0.0563676879f * fVec52[((IOTA - 124) & 511)]) + ((0.0787987933f * fVec52[((IOTA - 123) & 511)]) + ((0.0682088658f * fVec52[((IOTA - 122) & 511)]) + ((0.0448927283f * fVec52[((IOTA - 121) & 511)]) + ((0.0174260698f * fVec52[((IOTA - 115) & 511)]) + ((0.0513626523f * fVec52[((IOTA - 114) & 511)]) + ((0.0693380535f * fVec52[((IOTA - 113) & 511)]) + ((0.0514542088f * fVec52[((IOTA - 112) & 511)]) + ((0.0215460677f * fVec52[((IOTA - 111) & 511)]) + ((0.049958799f * fVec52[((IOTA - 104) & 511)]) + ((0.0626545027f * fVec52[((IOTA - 103) & 511)]) + ((0.0367137678f * fVec52[((IOTA - 102) & 511)]) + ((0.0736106485f * fVec52[((IOTA - 95) & 511)]) + ((0.208044678f * fVec52[((IOTA - 94) & 511)]) + ((0.221503347f * fVec52[((IOTA - 93) & 511)]) + ((0.140629292f * fVec52[((IOTA - 92) & 511)]) + ((0.0562761314f * fVec52[((IOTA - 91) & 511)]) + ((0.00668355357f * fVec52[((IOTA - 38) & 511)]) + (0.00396740623f * fVec52[((IOTA - 88) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00146488845f * ((fVec52[((IOTA - 11) & 511)] - fVec52[((IOTA - 221) & 511)]) - fVec52[((IOTA - 510) & 511)])))) : ((((0.000396740623f * (((((((((((((fVec51[((IOTA - 140) & 511)] + fVec51[((IOTA - 196) & 511)]) - fVec51[((IOTA - 230) & 511)]) + fVec51[((IOTA - 333) & 511)]) + fVec51[((IOTA - 442) & 511)]) - fVec51[((IOTA - 471) & 511)]) - fVec51[((IOTA - 474) & 511)]) + fVec51[((IOTA - 486) & 511)]) + fVec51[((IOTA - 487) & 511)]) + fVec51[((IOTA - 488) & 511)]) + fVec51[((IOTA - 489) & 511)]) + fVec51[((IOTA - 496) & 511)]) + fVec51[((IOTA - 498) & 511)]) + fVec51[((IOTA - 503) & 511)])) + ((0.000427259132f * ((((((((((((fVec51[((IOTA - 119) & 511)] - fVec51[((IOTA - 124) & 511)]) + fVec51[((IOTA - 126) & 511)]) + fVec51[((IOTA - 139) & 511)]) + fVec51[((IOTA - 213) & 511)]) + fVec51[((IOTA - 282) & 511)]) + fVec51[((IOTA - 283) & 511)]) - fVec51[((IOTA - 323) & 511)]) + fVec51[((IOTA - 452) & 511)]) + fVec51[((IOTA - 490) & 511)]) + fVec51[((IOTA - 491) & 511)]) + fVec51[((IOTA - 495) & 511)]) + fVec51[((IOTA - 499) & 511)])) + ((0.000366222113f * ((((((((((((((fVec51[((IOTA - 150) & 511)] - fVec51[((IOTA - 190) & 511)]) + fVec51[((IOTA - 197) & 511)]) + fVec51[((IOTA - 227) & 511)]) - fVec51[((IOTA - 314) & 511)]) + fVec51[((IOTA - 344) & 511)]) + fVec51[((IOTA - 345) & 511)]) + fVec51[((IOTA - 360) & 511)]) + fVec51[((IOTA - 369) & 511)]) + fVec51[((IOTA - 372) & 511)]) - fVec51[((IOTA - 391) & 511)]) - fVec51[((IOTA - 420) & 511)]) + fVec51[((IOTA - 443) & 511)]) - fVec51[((IOTA - 470) & 511)]) + fVec51[((IOTA - 497) & 511)])) + ((0.000518814661f * ((((((((fVec51[((IOTA - 121) & 511)] - fVec51[((IOTA - 191) & 511)]) - fVec51[((IOTA - 207) & 511)]) + fVec51[((IOTA - 226) & 511)]) + fVec51[((IOTA - 324) & 511)]) + fVec51[((IOTA - 347) & 511)]) + fVec51[((IOTA - 354) & 511)]) + fVec51[((IOTA - 412) & 511)]) + fVec51[((IOTA - 493) & 511)])) + ((0.000213629566f * ((((((((((((fVec51[((IOTA - 31) & 511)] + fVec51[((IOTA - 164) & 511)]) + fVec51[((IOTA - 195) & 511)]) + fVec51[((IOTA - 198) & 511)]) - fVec51[((IOTA - 203) & 511)]) - fVec51[((IOTA - 401) & 511)]) - fVec51[((IOTA - 408) & 511)]) + fVec51[((IOTA - 445) & 511)]) + fVec51[((IOTA - 446) & 511)]) + fVec51[((IOTA - 448) & 511)]) + fVec51[((IOTA - 450) & 511)]) + fVec51[((IOTA - 461) & 511)]) - fVec51[((IOTA - 479) & 511)])) + ((0.00106814783f * (((fVec51[((IOTA - 141) & 511)] - fVec51[((IOTA - 322) & 511)]) + fVec51[((IOTA - 330) & 511)]) + fVec51[((IOTA - 458) & 511)])) + ((0.00057985168f * ((((((((fVec51[((IOTA - 120) & 511)] + fVec51[((IOTA - 137) & 511)]) + fVec51[((IOTA - 138) & 511)]) + fVec51[((IOTA - 210) & 511)]) - fVec51[((IOTA - 238) & 511)]) + fVec51[((IOTA - 342) & 511)]) - fVec51[((IOTA - 358) & 511)]) + fVec51[((IOTA - 403) & 511)]) + fVec51[((IOTA - 453) & 511)])) + ((0.00173955504f * ((fVec51[((IOTA - 179) & 511)] + fVec51[((IOTA - 220) & 511)]) - fVec51[((IOTA - 436) & 511)])) + ((0.00170903653f * (((fVec51[((IOTA - 127) & 511)] + fVec51[((IOTA - 175) & 511)]) + fVec51[((IOTA - 388) & 511)]) - fVec51[((IOTA - 435) & 511)])) + ((0.00146488845f * ((((fVec51[((IOTA - 176) & 511)] + fVec51[((IOTA - 178) & 511)]) + fVec51[((IOTA - 186) & 511)]) + fVec51[((IOTA - 219) & 511)]) - fVec51[((IOTA - 434) & 511)])) + ((0.00103762932f * (((((fVec51[((IOTA - 263) & 511)] + fVec51[((IOTA - 272) & 511)]) - fVec51[((IOTA - 315) & 511)]) + fVec51[((IOTA - 340) & 511)]) + fVec51[((IOTA - 417) & 511)]) - fVec51[((IOTA - 433) & 511)])) + ((0.000915555283f * ((((fVec51[((IOTA - 108) & 511)] - fVec51[((IOTA - 161) & 511)]) - fVec51[((IOTA - 242) & 511)]) - fVec51[((IOTA - 422) & 511)]) - fVec51[((IOTA - 426) & 511)])) + ((0.00119022187f * ((((((fVec51[((IOTA - 71) & 511)] - fVec51[((IOTA - 156) & 511)]) + fVec51[((IOTA - 222) & 511)]) + fVec51[((IOTA - 262) & 511)]) + fVec51[((IOTA - 336) & 511)]) + fVec51[((IOTA - 366) & 511)]) + fVec51[((IOTA - 416) & 511)])) + ((0.00122074038f * ((fVec51[((IOTA - 261) & 511)] + fVec51[((IOTA - 387) & 511)]) + fVec51[((IOTA - 415) & 511)])) + ((0.00054933317f * ((((fVec51[((IOTA - 42) & 511)] - fVec51[((IOTA - 107) & 511)]) + fVec51[((IOTA - 313) & 511)]) + fVec51[((IOTA - 390) & 511)]) + fVec51[((IOTA - 405) & 511)])) + ((0.000671407208f * ((((((fVec51[((IOTA - 111) & 511)] + fVec51[((IOTA - 136) & 511)]) + fVec51[((IOTA - 212) & 511)]) + fVec51[((IOTA - 274) & 511)]) + fVec51[((IOTA - 334) & 511)]) + fVec51[((IOTA - 368) & 511)]) + fVec51[((IOTA - 404) & 511)])) + ((0.00155644398f * ((fVec51[((IOTA - 221) & 511)] + fVec51[((IOTA - 325) & 511)]) - fVec51[((IOTA - 399) & 511)])) + ((0.00210577715f * (fVec51[((IOTA - 173) & 511)] - fVec51[((IOTA - 398) & 511)])) + ((0.0019226661f * ((fVec51[((IOTA - 174) & 511)] + fVec51[((IOTA - 300) & 511)]) - fVec51[((IOTA - 395) & 511)])) + ((0.00115970336f * (fVec51[((IOTA - 457) & 511)] - (fVec51[((IOTA - 385) & 511)] - fVec51[((IOTA - 456) & 511)]))) + ((0.00137333293f * (((((((fVec51[((IOTA - 135) & 511)] + fVec51[((IOTA - 177) & 511)]) - fVec51[((IOTA - 316) & 511)]) - fVec51[((IOTA - 318) & 511)]) - fVec51[((IOTA - 319) & 511)]) + fVec51[((IOTA - 337) & 511)]) + fVec51[((IOTA - 365) & 511)]) - fVec51[((IOTA - 393) & 511)])) + ((0.00140385143f * (((((fVec51[((IOTA - 81) & 511)] + fVec51[((IOTA - 307) & 511)]) - fVec51[((IOTA - 320) & 511)]) - fVec51[((IOTA - 321) & 511)]) + fVec51[((IOTA - 374) & 511)]) + fVec51[((IOTA - 389) & 511)])) + ((0.00241096225f * ((fVec51[((IOTA - 110) & 511)] + fVec51[((IOTA - 328) & 511)]) - fVec51[((IOTA - 383) & 511)])) + ((0.00216681417f * (fVec51[((IOTA - 180) & 511)] - fVec51[((IOTA - 382) & 511)])) + ((0.00131229591f * fVec51[((IOTA - 379) & 511)]) + ((0.00247199927f * fVec51[((IOTA - 378) & 511)]) + ((0.00302133244f * fVec51[((IOTA - 377) & 511)]) + ((0.00286873989f * ((fVec51[((IOTA - 128) & 511)] + fVec51[((IOTA - 182) & 511)]) + fVec51[((IOTA - 376) & 511)])) + ((0.00219733268f * fVec51[((IOTA - 375) & 511)]) + ((0.00149540696f * (fVec51[((IOTA - 312) & 511)] + fVec51[((IOTA - 364) & 511)])) + ((0.00125125889f * fVec51[((IOTA - 362) & 511)]) + ((0.0012817774f * fVec51[((IOTA - 339) & 511)]) + ((0.00177007355f * fVec51[((IOTA - 329) & 511)]) + ((0.00231940672f * fVec51[((IOTA - 311) & 511)]) + ((0.00277718436f * fVec51[((IOTA - 310) & 511)]) + ((0.00253303628f * ((fVec51[((IOTA - 297) & 511)] + fVec51[((IOTA - 299) & 511)]) + fVec51[((IOTA - 308) & 511)])) + ((0.00250251777f * (fVec51[((IOTA - 184) & 511)] - fVec51[((IOTA - 304) & 511)])) + ((0.00201422162f * (fVec51[((IOTA - 185) & 511)] - fVec51[((IOTA - 303) & 511)])) + ((0.00271614734f * fVec51[((IOTA - 298) & 511)]) + ((0.00213629566f * fVec51[((IOTA - 296) & 511)]) + ((0.000885036774f * ((((fVec51[((IOTA - 218) & 511)] - fVec51[((IOTA - 243) & 511)]) - fVec51[((IOTA - 244) & 511)]) + fVec51[((IOTA - 267) & 511)]) + fVec51[((IOTA - 271) & 511)])) + ((0.000823999755f * (fVec51[((IOTA - 167) & 511)] + fVec51[((IOTA - 266) & 511)])) + ((0.00283822138f * fVec51[((IOTA - 183) & 511)]) + ((0.0025940733f * ((fVec51[((IOTA - 83) & 511)] + fVec51[((IOTA - 147) & 511)]) + fVec51[((IOTA - 181) & 511)])) + ((0.00198370311f * fVec51[((IOTA - 172) & 511)]) + ((0.00158696249f * fVec51[((IOTA - 171) & 511)]) + ((0.00228888821f * ((fVec51[((IOTA - 95) & 511)] - fVec51[((IOTA - 97) & 511)]) - fVec51[((IOTA - 153) & 511)])) + ((0.00180059206f * fVec51[((IOTA - 148) & 511)]) + ((0.00360118411f * fVec51[((IOTA - 146) & 511)]) + ((0.00463881344f * fVec51[((IOTA - 145) & 511)]) + ((0.00506607257f * fVec51[((IOTA - 144) & 511)]) + ((0.00427259132f * fVec51[((IOTA - 143) & 511)]) + ((0.00265511032f * fVec51[((IOTA - 142) & 511)]) + ((0.00256355479f * fVec51[((IOTA - 134) & 511)]) + ((0.0035401471f * (fVec51[((IOTA - 129) & 511)] + fVec51[((IOTA - 133) & 511)])) + ((0.00399792474f * fVec51[((IOTA - 132) & 511)]) + ((0.00393688772f * fVec51[((IOTA - 131) & 511)]) + ((0.00381481368f * fVec51[((IOTA - 130) & 511)]) + ((0.00546281319f * (fVec51[((IOTA - 70) & 511)] - fVec51[((IOTA - 113) & 511)])) + ((0.0022583697f * fVec51[((IOTA - 109) & 511)]) + ((0.00787377544f * fVec51[((IOTA - 94) & 511)]) + ((0.0139774773f * fVec51[((IOTA - 93) & 511)]) + ((0.0170293283f * fVec51[((IOTA - 92) & 511)]) + ((0.014618366f * fVec51[((IOTA - 91) & 511)]) + ((0.00656147953f * fVec51[((IOTA - 90) & 511)]) + ((0.00338755455f * fVec51[((IOTA - 82) & 511)]) + ((0.0100100711f * fVec51[((IOTA - 69) & 511)]) + ((0.0143436994f * fVec51[((IOTA - 68) & 511)]) + ((0.0184942167f * fVec51[((IOTA - 67) & 511)]) + ((0.0204779208f * fVec51[((IOTA - 66) & 511)]) + ((0.0170903653f * fVec51[((IOTA - 65) & 511)]) + ((0.00753807183f * fVec51[((IOTA - 64) & 511)]) + ((0.0028992584f * fVec51[((IOTA - 58) & 511)]) + ((0.0234382153f * fVec51[((IOTA - 57) & 511)]) + ((0.0311593991f * fVec51[((IOTA - 56) & 511)]) + ((0.0238959938f * fVec51[((IOTA - 55) & 511)]) + ((0.00878933072f * fVec51[((IOTA - 54) & 511)]) + ((0.0120242927f * fVec51[((IOTA - 41) & 511)]) + ((0.0260933265f * fVec51[((IOTA - 40) & 511)]) + ((0.0366222113f * fVec51[((IOTA - 39) & 511)]) + ((0.0377513953f * fVec51[((IOTA - 38) & 511)]) + ((0.0297555476f * fVec51[((IOTA - 37) & 511)]) + (((((((((((((((fSlow123 * fTemp0) + (0.0967131555f * fVec51[((IOTA - 1) & 511)])) + (0.210486159f * fVec51[((IOTA - 2) & 511)])) + (0.289864808f * fVec51[((IOTA - 3) & 511)])) + (0.235969111f * fVec51[((IOTA - 4) & 511)])) + (0.0532853194f * fVec51[((IOTA - 5) & 511)])) + (0.0321970284f * fVec51[((IOTA - 10) & 511)])) + (0.0985747874f * fVec51[((IOTA - 11) & 511)])) + (0.0974761173f * fVec51[((IOTA - 12) & 511)])) + (0.0352488793f * fVec51[((IOTA - 13) & 511)])) + (0.0246894751f * fVec51[((IOTA - 27) & 511)])) + (0.0592364259f * fVec51[((IOTA - 28) & 511)])) + (0.0693075359f * fVec51[((IOTA - 29) & 511)])) + (0.0455030985f * fVec51[((IOTA - 30) & 511)])) + (0.0104983672f * fVec51[((IOTA - 36) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000305185094f * (((((((((((((fVec51[((IOTA - 122) & 511)] - fVec51[((IOTA - 125) & 511)]) + fVec51[((IOTA - 217) & 511)]) - fVec51[((IOTA - 252) & 511)]) + fVec51[((IOTA - 257) & 511)]) - fVec51[((IOTA - 277) & 511)]) + fVec51[((IOTA - 284) & 511)]) + fVec51[((IOTA - 332) & 511)]) + fVec51[((IOTA - 402) & 511)]) + fVec51[((IOTA - 406) & 511)]) + fVec51[((IOTA - 451) & 511)]) - fVec51[((IOTA - 469) & 511)]) + fVec51[((IOTA - 505) & 511)]) + fVec51[((IOTA - 510) & 511)]))) - ((((0.000457777642f * ((((((((((((fVec51[((IOTA - 246) & 511)] + fVec51[((IOTA - 288) & 511)]) + fVec51[((IOTA - 289) & 511)]) - fVec51[((IOTA - 343) & 511)]) - fVec51[((IOTA - 346) & 511)]) - fVec51[((IOTA - 349) & 511)]) + fVec51[((IOTA - 356) & 511)]) + fVec51[((IOTA - 472) & 511)]) + fVec51[((IOTA - 473) & 511)]) - fVec51[((IOTA - 492) & 511)]) - fVec51[((IOTA - 500) & 511)]) - fVec51[((IOTA - 501) & 511)]) - fVec51[((IOTA - 502) & 511)])) + ((0.000488296151f * (((((((((fVec51[((IOTA - 192) & 511)] - fVec51[((IOTA - 188) & 511)]) + fVec51[((IOTA - 204) & 511)]) + fVec51[((IOTA - 231) & 511)]) - fVec51[((IOTA - 331) & 511)]) - fVec51[((IOTA - 348) & 511)]) - fVec51[((IOTA - 350) & 511)]) + fVec51[((IOTA - 428) & 511)]) - fVec51[((IOTA - 460) & 511)]) - fVec51[((IOTA - 494) & 511)])) + ((0.000274666585f * (((((((((((fVec51[((IOTA - 163) & 511)] + fVec51[((IOTA - 237) & 511)]) + fVec51[((IOTA - 278) & 511)]) - fVec51[((IOTA - 281) & 511)]) + fVec51[((IOTA - 429) & 511)]) + fVec51[((IOTA - 431) & 511)]) - fVec51[((IOTA - 444) & 511)]) + fVec51[((IOTA - 466) & 511)]) + fVec51[((IOTA - 467) & 511)]) + fVec51[((IOTA - 468) & 511)]) + fVec51[((IOTA - 475) & 511)]) - fVec51[((IOTA - 484) & 511)])) + ((0.000152592547f * ((((fVec51[((IOTA - 229) & 511)] - fVec51[((IOTA - 234) & 511)]) + fVec51[((IOTA - 276) & 511)]) + fVec51[((IOTA - 286) & 511)]) - fVec51[((IOTA - 483) & 511)])) + ((9.15555283e-05f * ((((((((((((((fVec51[((IOTA - 194) & 511)] - fVec51[((IOTA - 199) & 511)]) + fVec51[((IOTA - 233) & 511)]) + fVec51[((IOTA - 247) & 511)]) - fVec51[((IOTA - 248) & 511)]) - fVec51[((IOTA - 249) & 511)]) + fVec51[((IOTA - 250) & 511)]) + fVec51[((IOTA - 255) & 511)]) - fVec51[((IOTA - 256) & 511)]) - fVec51[((IOTA - 280) & 511)]) - fVec51[((IOTA - 285) & 511)]) + fVec51[((IOTA - 380) & 511)]) - fVec51[((IOTA - 386) & 511)]) + fVec51[((IOTA - 440) & 511)]) + fVec51[((IOTA - 481) & 511)])) + ((0.000183111057f * (((((((((((((((((fVec51[((IOTA - 118) & 511)] + fVec51[((IOTA - 208) & 511)]) - fVec51[((IOTA - 214) & 511)]) - fVec51[((IOTA - 235) & 511)]) + fVec51[((IOTA - 254) & 511)]) - fVec51[((IOTA - 275) & 511)]) - fVec51[((IOTA - 292) & 511)]) + fVec51[((IOTA - 359) & 511)]) - fVec51[((IOTA - 370) & 511)]) - fVec51[((IOTA - 371) & 511)]) - fVec51[((IOTA - 411) & 511)]) + fVec51[((IOTA - 430) & 511)]) - fVec51[((IOTA - 449) & 511)]) + fVec51[((IOTA - 463) & 511)]) + fVec51[((IOTA - 476) & 511)]) + fVec51[((IOTA - 477) & 511)]) + fVec51[((IOTA - 478) & 511)]) + fVec51[((IOTA - 480) & 511)])) + ((3.05185094e-05f * (((((((fVec51[((IOTA - 189) & 511)] - fVec51[((IOTA - 200) & 511)]) - fVec51[((IOTA - 201) & 511)]) + fVec51[((IOTA - 202) & 511)]) - fVec51[((IOTA - 236) & 511)]) - fVec51[((IOTA - 355) & 511)]) - fVec51[((IOTA - 407) & 511)]) + fVec51[((IOTA - 462) & 511)])) + ((0.000793481246f * ((((((((fVec51[((IOTA - 104) & 511)] + fVec51[((IOTA - 239) & 511)]) + fVec51[((IOTA - 245) & 511)]) - fVec51[((IOTA - 265) & 511)]) - fVec51[((IOTA - 268) & 511)]) - fVec51[((IOTA - 341) & 511)]) - fVec51[((IOTA - 352) & 511)]) - fVec51[((IOTA - 454) & 511)]) - fVec51[((IOTA - 459) & 511)])) + ((0.00100711081f * (fVec51[((IOTA - 392) & 511)] - fVec51[((IOTA - 455) & 511)])) + ((0.000610370189f * (((fVec51[((IOTA - 151) & 511)] - fVec51[((IOTA - 293) & 511)]) + fVec51[((IOTA - 432) & 511)]) + fVec51[((IOTA - 439) & 511)])) + ((0.00112918485f * (((fVec51[((IOTA - 106) & 511)] - fVec51[((IOTA - 149) & 511)]) - fVec51[((IOTA - 260) & 511)]) + fVec51[((IOTA - 438) & 511)])) + ((0.00152592547f * fVec51[((IOTA - 437) & 511)]) + ((0.000732444227f * ((((((fVec51[((IOTA - 205) & 511)] - fVec51[((IOTA - 269) & 511)]) - fVec51[((IOTA - 270) & 511)]) - fVec51[((IOTA - 301) & 511)]) + fVec51[((IOTA - 302) & 511)]) + fVec51[((IOTA - 421) & 511)]) + fVec51[((IOTA - 427) & 511)])) + ((0.000976592302f * (((((fVec51[((IOTA - 160) & 511)] - fVec51[((IOTA - 170) & 511)]) - fVec51[((IOTA - 187) & 511)]) - fVec51[((IOTA - 273) & 511)]) + fVec51[((IOTA - 424) & 511)]) + fVec51[((IOTA - 425) & 511)])) + ((0.000946073793f * (((((fVec51[((IOTA - 240) & 511)] + fVec51[((IOTA - 241) & 511)]) - fVec51[((IOTA - 259) & 511)]) - fVec51[((IOTA - 335) & 511)]) - fVec51[((IOTA - 367) & 511)]) + fVec51[((IOTA - 423) & 511)])) + ((0.000122074038f * (((((fVec51[((IOTA - 123) & 511)] - fVec51[((IOTA - 228) & 511)]) + fVec51[((IOTA - 279) & 511)]) + fVec51[((IOTA - 291) & 511)]) + fVec51[((IOTA - 410) & 511)]) - fVec51[((IOTA - 419) & 511)])) + ((0.000640888698f * (((((((fVec51[((IOTA - 158) & 511)] + fVec51[((IOTA - 162) & 511)]) - fVec51[((IOTA - 165) & 511)]) - fVec51[((IOTA - 168) & 511)]) - fVec51[((IOTA - 225) & 511)]) - fVec51[((IOTA - 258) & 511)]) - fVec51[((IOTA - 351) & 511)]) - fVec51[((IOTA - 418) & 511)])) + ((0.00109866634f * ((fVec51[((IOTA - 84) & 511)] - fVec51[((IOTA - 294) & 511)]) - fVec51[((IOTA - 414) & 511)])) + ((0.000854518265f * ((((((((fVec51[((IOTA - 96) & 511)] + fVec51[((IOTA - 105) & 511)]) + fVec51[((IOTA - 159) & 511)]) - fVec51[((IOTA - 166) & 511)]) - fVec51[((IOTA - 223) & 511)]) - fVec51[((IOTA - 264) & 511)]) - fVec51[((IOTA - 361) & 511)]) + fVec51[((IOTA - 400) & 511)]) - fVec51[((IOTA - 413) & 511)])) + ((0.00222785119f * fVec51[((IOTA - 396) & 511)]) + ((0.00164799951f * (fVec51[((IOTA - 117) & 511)] + fVec51[((IOTA - 394) & 511)])) + ((0.00207525864f * fVec51[((IOTA - 384) & 511)]) + ((0.00134281442f * fVec51[((IOTA - 381) & 511)]) + ((0.000762962736f * ((fVec51[((IOTA - 206) & 511)] - fVec51[((IOTA - 353) & 511)]) - fVec51[((IOTA - 373) & 511)])) + ((0.00143436994f * ((fVec51[((IOTA - 317) & 511)] - fVec51[((IOTA - 338) & 511)]) - fVec51[((IOTA - 363) & 511)])) + ((0.000701925717f * ((((fVec51[((IOTA - 157) & 511)] - fVec51[((IOTA - 169) & 511)]) - fVec51[((IOTA - 211) & 511)]) - fVec51[((IOTA - 224) & 511)]) + fVec51[((IOTA - 357) & 511)])) + ((0.00268562883f * (fVec51[((IOTA - 80) & 511)] - fVec51[((IOTA - 327) & 511)])) + ((0.00238044374f * (fVec51[((IOTA - 154) & 511)] - fVec51[((IOTA - 326) & 511)])) + ((0.00292977691f * (fVec51[((IOTA - 22) & 511)] - fVec51[((IOTA - 309) & 511)])) + ((0.00189214759f * fVec51[((IOTA - 305) & 511)]) + ((0.001617481f * (fVec51[((IOTA - 152) & 511)] - fVec51[((IOTA - 295) & 511)])) + (((0.00186162908f * fVec51[((IOTA - 155) & 511)]) + ((0.00384533219f * fVec51[((IOTA - 116) & 511)]) + ((0.00601214636f * fVec51[((IOTA - 115) & 511)]) + ((0.00689718314f * fVec51[((IOTA - 114) & 511)]) + ((0.00262459181f * fVec51[((IOTA - 112) & 511)]) + ((0.00244148076f * fVec51[((IOTA - 103) & 511)]) + ((0.00521866512f * fVec51[((IOTA - 102) & 511)]) + ((0.00729392376f * fVec51[((IOTA - 101) & 511)]) + ((0.00723288674f * fVec51[((IOTA - 100) & 511)]) + ((0.00527970213f * fVec51[((IOTA - 99) & 511)]) + ((0.00335703604f * (fVec51[((IOTA - 72) & 511)] + fVec51[((IOTA - 98) & 511)])) + ((0.00375377666f * fVec51[((IOTA - 89) & 511)]) + ((0.0115970336f * fVec51[((IOTA - 88) & 511)]) + ((0.014496292f * fVec51[((IOTA - 87) & 511)]) + ((0.0118411817f * fVec51[((IOTA - 86) & 511)]) + ((0.00643940549f * fVec51[((IOTA - 85) & 511)]) + ((0.00686666463f * (fVec51[((IOTA - 73) & 511)] + fVec51[((IOTA - 79) & 511)])) + ((0.00924710836f * fVec51[((IOTA - 78) & 511)]) + ((0.00909451582f * fVec51[((IOTA - 77) & 511)]) + ((0.00848414563f * fVec51[((IOTA - 76) & 511)]) + ((0.00885036774f * fVec51[((IOTA - 75) & 511)]) + ((0.00869777519f * fVec51[((IOTA - 74) & 511)]) + ((0.00891140476f * fVec51[((IOTA - 63) & 511)]) + ((0.0268257707f * fVec51[((IOTA - 62) & 511)]) + ((0.0386669524f * fVec51[((IOTA - 61) & 511)]) + ((0.0371715464f * fVec51[((IOTA - 60) & 511)]) + ((0.00555436872f * fVec51[((IOTA - 53) & 511)]) + ((0.0167241432f * fVec51[((IOTA - 52) & 511)]) + ((0.0251167342f * fVec51[((IOTA - 51) & 511)]) + ((0.0325327329f * fVec51[((IOTA - 50) & 511)]) + ((0.03869747f * fVec51[((IOTA - 49) & 511)]) + ((0.0402233973f * fVec51[((IOTA - 48) & 511)]) + ((0.0366832502f * fVec51[((IOTA - 47) & 511)]) + ((0.0285042878f * fVec51[((IOTA - 46) & 511)]) + ((0.0203253273f * fVec51[((IOTA - 45) & 511)]) + ((0.0141605884f * fVec51[((IOTA - 44) & 511)]) + ((0.00830103457f * fVec51[((IOTA - 43) & 511)]) + ((0.0135502182f * fVec51[((IOTA - 35) & 511)]) + ((0.0381481387f * fVec51[((IOTA - 34) & 511)]) + ((0.0471816175f * fVec51[((IOTA - 33) & 511)]) + ((0.0344248787f * fVec51[((IOTA - 32) & 511)]) + ((0.0164189581f * fVec51[((IOTA - 26) & 511)]) + ((0.0397045799f * fVec51[((IOTA - 25) & 511)]) + ((0.0378124341f * fVec51[((IOTA - 24) & 511)]) + ((0.0158085879f * fVec51[((IOTA - 23) & 511)]) + ((0.0077517014f * fVec51[((IOTA - 21) & 511)]) + ((0.0287789553f * fVec51[((IOTA - 20) & 511)]) + ((0.0399182104f * fVec51[((IOTA - 19) & 511)]) + ((0.0450758375f * fVec51[((IOTA - 18) & 511)]) + ((0.0464186519f * fVec51[((IOTA - 17) & 511)]) + ((0.0471510962f * fVec51[((IOTA - 16) & 511)]) + ((0.046967987f * fVec51[((IOTA - 15) & 511)]) + ((0.0185552537f * fVec51[((IOTA - 14) & 511)]) + ((0.106082343f * fVec51[((IOTA - 9) & 511)]) + ((0.236457407f * fVec51[((IOTA - 8) & 511)]) + ((0.271248519f * fVec51[((IOTA - 7) & 511)]) + ((0.163060397f * fVec51[((IOTA - 6) & 511)]) + (0.0211188085f * fVec51[((IOTA - 59) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00234992523f * fVec51[((IOTA - 397) & 511)]))))))))))))))))))))))))))))))))) + (0.000244148076f * (((((((((((fVec51[((IOTA - 251) & 511)] - fVec51[((IOTA - 209) & 511)]) + fVec51[((IOTA - 253) & 511)]) + fVec51[((IOTA - 409) & 511)]) - fVec51[((IOTA - 441) & 511)]) - fVec51[((IOTA - 447) & 511)]) + fVec51[((IOTA - 464) & 511)]) + fVec51[((IOTA - 465) & 511)]) - fVec51[((IOTA - 506) & 511)]) - fVec51[((IOTA - 507) & 511)]) - fVec51[((IOTA - 508) & 511)]) - fVec51[((IOTA - 509) & 511)]))) + (0.000335703604f * (((((((fVec51[((IOTA - 193) & 511)] + fVec51[((IOTA - 232) & 511)]) + fVec51[((IOTA - 287) & 511)]) + fVec51[((IOTA - 290) & 511)]) + fVec51[((IOTA - 306) & 511)]) - fVec51[((IOTA - 485) & 511)]) - fVec51[((IOTA - 504) & 511)]) - fVec51[((IOTA - 511) & 511)]))))) : (iSlow118 ? ((((0.000518814661f * (((((fVec50[((IOTA - 193) & 511)] - fVec50[((IOTA - 200) & 511)]) + fVec50[((IOTA - 351) & 511)]) + fVec50[((IOTA - 493) & 511)]) + fVec50[((IOTA - 494) & 511)]) + fVec50[((IOTA - 505) & 511)])) + ((0.000305185094f * ((((fVec50[((IOTA - 54) & 511)] + fVec50[((IOTA - 352) & 511)]) - fVec50[((IOTA - 386) & 511)]) - fVec50[((IOTA - 498) & 511)]) + fVec50[((IOTA - 504) & 511)])) + ((0.000122074038f * (((((((((((fVec50[((IOTA - 15) & 511)] + fVec50[((IOTA - 16) & 511)]) + fVec50[((IOTA - 31) & 511)]) - fVec50[((IOTA - 34) & 511)]) - fVec50[((IOTA - 38) & 511)]) - fVec50[((IOTA - 39) & 511)]) - fVec50[((IOTA - 40) & 511)]) + fVec50[((IOTA - 52) & 511)]) - fVec50[((IOTA - 341) & 511)]) - fVec50[((IOTA - 382) & 511)]) - fVec50[((IOTA - 385) & 511)]) + fVec50[((IOTA - 503) & 511)])) + ((3.05185094e-05f * ((((((((((((((((fVec50[((IOTA - 6) & 511)] - fVec50[((IOTA - 13) & 511)]) - fVec50[((IOTA - 18) & 511)]) - fVec50[((IOTA - 21) & 511)]) - fVec50[((IOTA - 26) & 511)]) + fVec50[((IOTA - 27) & 511)]) - fVec50[((IOTA - 42) & 511)]) + fVec50[((IOTA - 43) & 511)]) + fVec50[((IOTA - 44) & 511)]) + fVec50[((IOTA - 45) & 511)]) - fVec50[((IOTA - 46) & 511)]) - fVec50[((IOTA - 50) & 511)]) + fVec50[((IOTA - 51) & 511)]) + fVec50[((IOTA - 56) & 511)]) - fVec50[((IOTA - 447) & 511)]) + fVec50[((IOTA - 458) & 511)]) - fVec50[((IOTA - 502) & 511)])) + ((0.000152592547f * ((((((fVec50[((IOTA - 153) & 511)] - fVec50[((IOTA - 338) & 511)]) + fVec50[((IOTA - 349) & 511)]) - fVec50[((IOTA - 353) & 511)]) + fVec50[((IOTA - 490) & 511)]) - fVec50[((IOTA - 497) & 511)]) - fVec50[((IOTA - 501) & 511)])) + ((0.000244148076f * (((((fVec50[((IOTA - 29) & 511)] + fVec50[((IOTA - 30) & 511)]) + fVec50[((IOTA - 53) & 511)]) + fVec50[((IOTA - 55) & 511)]) - fVec50[((IOTA - 346) & 511)]) - fVec50[((IOTA - 500) & 511)])) + ((0.000335703604f * (fVec50[((IOTA - 487) & 511)] - fVec50[((IOTA - 499) & 511)])) + ((9.15555283e-05f * (((((((((((((fVec50[((IOTA - 2) & 511)] + fVec50[((IOTA - 7) & 511)]) + fVec50[((IOTA - 8) & 511)]) - fVec50[((IOTA - 11) & 511)]) - fVec50[((IOTA - 12) & 511)]) - fVec50[((IOTA - 33) & 511)]) - fVec50[((IOTA - 35) & 511)]) - fVec50[((IOTA - 41) & 511)]) - fVec50[((IOTA - 48) & 511)]) - fVec50[((IOTA - 132) & 511)]) + fVec50[((IOTA - 340) & 511)]) - fVec50[((IOTA - 348) & 511)]) - fVec50[((IOTA - 374) & 511)]) + fVec50[((IOTA - 496) & 511)])) + ((0.000274666585f * (((fVec50[((IOTA - 133) & 511)] - fVec50[((IOTA - 337) & 511)]) + fVec50[((IOTA - 368) & 511)]) + fVec50[((IOTA - 488) & 511)])) + ((0.00103762932f * ((((((fVec50[((IOTA - 212) & 511)] - fVec50[((IOTA - 241) & 511)]) - fVec50[((IOTA - 250) & 511)]) - fVec50[((IOTA - 334) & 511)]) + fVec50[((IOTA - 426) & 511)]) + fVec50[((IOTA - 479) & 511)]) + fVec50[((IOTA - 484) & 511)])) + ((0.0022583697f * (fVec50[((IOTA - 468) & 511)] + fVec50[((IOTA - 469) & 511)])) + ((0.000183111057f * ((((fVec50[((IOTA - 28) & 511)] - fVec50[((IOTA - 329) & 511)]) - fVec50[((IOTA - 330) & 511)]) - fVec50[((IOTA - 347) & 511)]) + fVec50[((IOTA - 465) & 511)])) + ((0.000427259132f * (((fVec50[((IOTA - 350) & 511)] - fVec50[((IOTA - 384) & 511)]) + fVec50[((IOTA - 409) & 511)]) - fVec50[((IOTA - 464) & 511)])) + ((0.001617481f * (((fVec50[((IOTA - 399) & 511)] + fVec50[((IOTA - 400) & 511)]) + fVec50[((IOTA - 451) & 511)]) + fVec50[((IOTA - 456) & 511)])) + ((0.00198370311f * (((fVec50[((IOTA - 211) & 511)] - fVec50[((IOTA - 273) & 511)]) + fVec50[((IOTA - 414) & 511)]) + fVec50[((IOTA - 455) & 511)])) + ((0.00164799951f * (((((fVec50[((IOTA - 155) & 511)] - fVec50[((IOTA - 259) & 511)]) - fVec50[((IOTA - 292) & 511)]) - fVec50[((IOTA - 293) & 511)]) - fVec50[((IOTA - 324) & 511)]) + fVec50[((IOTA - 450) & 511)])) + ((0.00305185094f * fVec50[((IOTA - 443) & 511)]) + ((0.00357066561f * fVec50[((IOTA - 442) & 511)]) + ((0.00296029542f * fVec50[((IOTA - 440) & 511)]) + ((0.00238044374f * fVec50[((IOTA - 439) & 511)]) + ((0.00329599902f * fVec50[((IOTA - 432) & 511)]) + ((0.00369273964f * (fVec50[((IOTA - 430) & 511)] + fVec50[((IOTA - 431) & 511)])) + ((0.00332651753f * fVec50[((IOTA - 429) & 511)]) + ((0.00262459181f * (fVec50[((IOTA - 364) & 511)] + fVec50[((IOTA - 428) & 511)])) + ((0.00180059206f * (((fVec50[((IOTA - 196) & 511)] - fVec50[((IOTA - 214) & 511)]) - fVec50[((IOTA - 234) & 511)]) + fVec50[((IOTA - 422) & 511)])) + ((0.00222785119f * fVec50[((IOTA - 421) & 511)]) + ((0.00244148076f * fVec50[((IOTA - 420) & 511)]) + ((0.00250251777f * ((((fVec50[((IOTA - 154) & 511)] - fVec50[((IOTA - 227) & 511)]) - fVec50[((IOTA - 228) & 511)]) + fVec50[((IOTA - 375) & 511)]) + fVec50[((IOTA - 419) & 511)])) + ((0.00256355479f * fVec50[((IOTA - 418) & 511)]) + ((0.00268562883f * ((fVec50[((IOTA - 129) & 511)] + fVec50[((IOTA - 134) & 511)]) + fVec50[((IOTA - 417) & 511)])) + ((0.00241096225f * fVec50[((IOTA - 405) & 511)]) + ((0.000213629566f * (fVec50[((IOTA - 491) & 511)] - ((fVec50[((IOTA - 192) & 511)] - fVec50[((IOTA - 208) & 511)]) - fVec50[((IOTA - 489) & 511)]))) + ((0.0051576281f * fVec50[((IOTA - 395) & 511)]) + ((0.00543229468f * fVec50[((IOTA - 394) & 511)]) + ((0.00463881344f * fVec50[((IOTA - 393) & 511)]) + ((0.0028992584f * fVec50[((IOTA - 392) & 511)]) + ((0.00057985168f * (((fVec50[((IOTA - 171) & 511)] - fVec50[((IOTA - 202) & 511)]) - fVec50[((IOTA - 203) & 511)]) - fVec50[((IOTA - 383) & 511)])) + ((0.00326548051f * fVec50[((IOTA - 379) & 511)]) + ((0.00457777642f * fVec50[((IOTA - 377) & 511)]) + ((0.00411999878f * fVec50[((IOTA - 376) & 511)]) + ((0.00292977691f * fVec50[((IOTA - 365) & 511)]) + ((0.00302133244f * (fVec50[((IOTA - 157) & 511)] + fVec50[((IOTA - 397) & 511)])) + ((0.000396740623f * (fVec50[((IOTA - 199) & 511)] - fVec50[((IOTA - 345) & 511)])) + ((0.00152592547f * (((fVec50[((IOTA - 195) & 511)] - fVec50[((IOTA - 282) & 511)]) - fVec50[((IOTA - 295) & 511)]) - fVec50[((IOTA - 312) & 511)])) + ((0.00137333293f * ((((fVec50[((IOTA - 209) & 511)] - fVec50[((IOTA - 224) & 511)]) - fVec50[((IOTA - 296) & 511)]) - fVec50[((IOTA - 313) & 511)]) - fVec50[((IOTA - 318) & 511)])) + ((0.0019226661f * (((fVec50[((IOTA - 137) & 511)] - fVec50[((IOTA - 257) & 511)]) - fVec50[((IOTA - 284) & 511)]) - fVec50[((IOTA - 289) & 511)])) + ((0.00204474013f * (((((fVec50[((IOTA - 172) & 511)] - fVec50[((IOTA - 174) & 511)]) - fVec50[((IOTA - 231) & 511)]) - fVec50[((IOTA - 258) & 511)]) - fVec50[((IOTA - 285) & 511)]) - fVec50[((IOTA - 288) & 511)])) + ((0.000915555283f * ((fVec50[((IOTA - 131) & 511)] - fVec50[((IOTA - 249) & 511)]) - fVec50[((IOTA - 255) & 511)])) + ((0.00341807306f * (fVec50[((IOTA - 130) & 511)] - fVec50[((IOTA - 221) & 511)])) + ((0.00439466536f * (fVec50[((IOTA - 136) & 511)] - fVec50[((IOTA - 164) & 511)])) + ((0.0038758507f * fVec50[((IOTA - 160) & 511)]) + ((0.00640888698f * fVec50[((IOTA - 159) & 511)]) + ((0.00531022064f * fVec50[((IOTA - 158) & 511)]) + ((0.0104678487f * fVec50[((IOTA - 147) & 511)]) + ((0.0148319956f * fVec50[((IOTA - 146) & 511)]) + ((0.0061342204f * fVec50[((IOTA - 145) & 511)]) + ((0.00390636921f * fVec50[((IOTA - 135) & 511)]) + ((0.00762962736f * fVec50[((IOTA - 122) & 511)]) + ((0.0205999948f * fVec50[((IOTA - 121) & 511)]) + ((0.019226661f * fVec50[((IOTA - 120) & 511)]) + ((0.00570696127f * fVec50[((IOTA - 119) & 511)]) + ((0.00781273842f * fVec50[((IOTA - 109) & 511)]) + ((0.013061922f * fVec50[((IOTA - 108) & 511)]) + ((0.0124210333f * fVec50[((IOTA - 107) & 511)]) + ((0.00933866389f * fVec50[((IOTA - 106) & 511)]) + ((0.0125125889f * fVec50[((IOTA - 105) & 511)]) + ((0.0172734763f * fVec50[((IOTA - 104) & 511)]) + ((0.0230414756f * fVec50[((IOTA - 103) & 511)]) + ((0.0243537705f * fVec50[((IOTA - 102) & 511)]) + ((0.0120548112f * fVec50[((IOTA - 101) & 511)]) + ((0.0316476934f * fVec50[((IOTA - 95) & 511)]) + ((0.0459608771f * fVec50[((IOTA - 94) & 511)]) + ((0.0329905078f * fVec50[((IOTA - 93) & 511)]) + ((0.00778221991f * fVec50[((IOTA - 82) & 511)]) + ((0.0621967241f * fVec50[((IOTA - 77) & 511)]) + ((0.100405894f * fVec50[((IOTA - 76) & 511)]) + ((0.0761131644f * fVec50[((IOTA - 75) & 511)]) + ((0.097750783f * fVec50[((IOTA - 70) & 511)]) + ((0.270119339f * fVec50[((IOTA - 69) & 511)]) + ((0.280587167f * fVec50[((IOTA - 68) & 511)]) + ((0.161839649f * fVec50[((IOTA - 67) & 511)]) + ((0.0538651682f * fVec50[((IOTA - 66) & 511)]) + ((0.0136112552f * fVec50[((IOTA - 65) & 511)]) + ((6.10370189e-05f * ((((((((((((fVec50[((IOTA - 1) & 511)] + fVec50[((IOTA - 3) & 511)]) + fVec50[((IOTA - 9) & 511)]) + fVec50[((IOTA - 14) & 511)]) + fVec50[((IOTA - 17) & 511)]) - fVec50[((IOTA - 19) & 511)]) - fVec50[((IOTA - 20) & 511)]) - fVec50[((IOTA - 24) & 511)]) - fVec50[((IOTA - 25) & 511)]) - fVec50[((IOTA - 36) & 511)]) - fVec50[((IOTA - 37) & 511)]) - fVec50[((IOTA - 47) & 511)]) - fVec50[((IOTA - 49) & 511)])) + (0.00534073915f * fVec50[((IOTA - 64) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000732444227f * (fVec50[((IOTA - 509) & 511)] - (((((fVec50[((IOTA - 247) & 511)] - (((fVec50[((IOTA - 173) & 511)] - fVec50[((IOTA - 201) & 511)]) - fVec50[((IOTA - 237) & 511)]) - fVec50[((IOTA - 244) & 511)])) + fVec50[((IOTA - 332) & 511)]) - fVec50[((IOTA - 424) & 511)]) - fVec50[((IOTA - 485) & 511)]) - fVec50[((IOTA - 507) & 511)])))) - (((0.000701925717f * (fVec50[((IOTA - 459) & 511)] - fVec50[((IOTA - 510) & 511)])) + ((0.000762962736f * (fVec50[((IOTA - 343) & 511)] - fVec50[((IOTA - 508) & 511)])) + ((0.000671407208f * ((((((((fVec50[((IOTA - 92) & 511)] + fVec50[((IOTA - 191) & 511)]) + fVec50[((IOTA - 246) & 511)]) + fVec50[((IOTA - 254) & 511)]) + fVec50[((IOTA - 261) & 511)]) + fVec50[((IOTA - 308) & 511)]) - fVec50[((IOTA - 361) & 511)]) - fVec50[((IOTA - 411) & 511)]) - fVec50[((IOTA - 506) & 511)])) + ((0.000366222113f * ((((fVec50[((IOTA - 213) & 511)] + fVec50[((IOTA - 328) & 511)]) + fVec50[((IOTA - 331) & 511)]) - fVec50[((IOTA - 492) & 511)]) - fVec50[((IOTA - 495) & 511)])) + ((0.000457777642f * ((fVec50[((IOTA - 263) & 511)] + fVec50[((IOTA - 336) & 511)]) - fVec50[((IOTA - 486) & 511)])) + ((0.00131229591f * ((((fVec50[((IOTA - 301) & 511)] + fVec50[((IOTA - 310) & 511)]) + fVec50[((IOTA - 316) & 511)]) - fVec50[((IOTA - 449) & 511)]) - fVec50[((IOTA - 483) & 511)])) + ((0.00146488845f * ((fVec50[((IOTA - 206) & 511)] + fVec50[((IOTA - 369) & 511)]) - fVec50[((IOTA - 482) & 511)])) + ((0.00143436994f * (((((fVec50[((IOTA - 256) & 511)] + fVec50[((IOTA - 267) & 511)]) + fVec50[((IOTA - 303) & 511)]) - fVec50[((IOTA - 413) & 511)]) - fVec50[((IOTA - 436) & 511)]) - fVec50[((IOTA - 481) & 511)])) + ((0.0012817774f * (fVec50[((IOTA - 461) & 511)] - fVec50[((IOTA - 480) & 511)])) + ((0.000823999755f * (((fVec50[((IOTA - 63) & 511)] + fVec50[((IOTA - 248) & 511)]) - fVec50[((IOTA - 476) & 511)]) - fVec50[((IOTA - 478) & 511)])) + ((0.000793481246f * (((((((fVec50[((IOTA - 57) & 511)] + fVec50[((IOTA - 236) & 511)]) + fVec50[((IOTA - 253) & 511)]) + fVec50[((IOTA - 335) & 511)]) + fVec50[((IOTA - 358) & 511)]) - fVec50[((IOTA - 391) & 511)]) - fVec50[((IOTA - 445) & 511)]) - fVec50[((IOTA - 477) & 511)])) + ((0.000854518265f * (((fVec50[((IOTA - 265) & 511)] - fVec50[((IOTA - 381) & 511)]) - fVec50[((IOTA - 473) & 511)]) - fVec50[((IOTA - 475) & 511)])) + ((0.000885036774f * (((((((fVec50[((IOTA - 207) & 511)] + fVec50[((IOTA - 242) & 511)]) + fVec50[((IOTA - 243) & 511)]) + fVec50[((IOTA - 320) & 511)]) + fVec50[((IOTA - 321) & 511)]) - fVec50[((IOTA - 457) & 511)]) + fVec50[((IOTA - 463) & 511)]) - fVec50[((IOTA - 474) & 511)])) + ((0.000976592302f * (((((fVec50[((IOTA - 252) & 511)] + fVec50[((IOTA - 355) & 511)]) + fVec50[((IOTA - 357) & 511)]) + fVec50[((IOTA - 390) & 511)]) - fVec50[((IOTA - 466) & 511)]) - fVec50[((IOTA - 472) & 511)])) + ((0.00134281442f * ((fVec50[((IOTA - 304) & 511)] + fVec50[((IOTA - 325) & 511)]) - fVec50[((IOTA - 471) & 511)])) + ((0.00186162908f * (((((fVec50[((IOTA - 230) & 511)] + fVec50[((IOTA - 280) & 511)]) + fVec50[((IOTA - 389) & 511)]) - fVec50[((IOTA - 401) & 511)]) - fVec50[((IOTA - 438) & 511)]) - fVec50[((IOTA - 470) & 511)])) + ((0.00173955504f * (((fVec50[((IOTA - 388) & 511)] - fVec50[((IOTA - 406) & 511)]) - fVec50[((IOTA - 453) & 511)]) - fVec50[((IOTA - 467) & 511)])) + ((0.00115970336f * (((fVec50[((IOTA - 298) & 511)] - (fVec50[((IOTA - 198) & 511)] - fVec50[((IOTA - 238) & 511)])) + fVec50[((IOTA - 460) & 511)]) + fVec50[((IOTA - 462) & 511)])) + ((0.0019531846f * (fVec50[((IOTA - 189) & 511)] - fVec50[((IOTA - 454) & 511)])) + ((0.00158696249f * (((((((fVec50[((IOTA - 83) & 511)] - fVec50[((IOTA - 156) & 511)]) - fVec50[((IOTA - 197) & 511)]) + fVec50[((IOTA - 281) & 511)]) + fVec50[((IOTA - 294) & 511)]) + fVec50[((IOTA - 323) & 511)]) - fVec50[((IOTA - 435) & 511)]) - fVec50[((IOTA - 452) & 511)])) + ((0.000640888698f * (((fVec50[((IOTA - 306) & 511)] + fVec50[((IOTA - 344) & 511)]) - fVec50[((IOTA - 425) & 511)]) - fVec50[((IOTA - 448) & 511)])) + ((0.00201422162f * (((fVec50[((IOTA - 226) & 511)] + fVec50[((IOTA - 272) & 511)]) - fVec50[((IOTA - 434) & 511)]) - fVec50[((IOTA - 444) & 511)])) + ((0.00347911008f * (fVec50[((IOTA - 148) & 511)] - fVec50[((IOTA - 441) & 511)])) + ((0.00155644398f * ((fVec50[((IOTA - 205) & 511)] + fVec50[((IOTA - 239) & 511)]) - fVec50[((IOTA - 437) & 511)])) + ((0.00265511032f * ((fVec50[((IOTA - 161) & 511)] + fVec50[((IOTA - 373) & 511)]) - fVec50[((IOTA - 433) & 511)])) + ((0.00177007355f * (((((fVec50[((IOTA - 170) & 511)] + fVec50[((IOTA - 184) & 511)]) + fVec50[((IOTA - 219) & 511)]) + fVec50[((IOTA - 290) & 511)]) - fVec50[((IOTA - 367) & 511)]) - fVec50[((IOTA - 427) & 511)])) + ((0.00122074038f * (((fVec50[((IOTA - 297) & 511)] + fVec50[((IOTA - 300) & 511)]) + fVec50[((IOTA - 322) & 511)]) - fVec50[((IOTA - 423) & 511)])) + ((0.00271614734f * (((fVec50[((IOTA - 220) & 511)] - fVec50[((IOTA - 366) & 511)]) - fVec50[((IOTA - 403) & 511)]) - fVec50[((IOTA - 416) & 511)])) + ((0.00247199927f * (fVec50[((IOTA - 188) & 511)] - fVec50[((IOTA - 415) & 511)])) + ((0.00100711081f * ((((fVec50[((IOTA - 305) & 511)] + fVec50[((IOTA - 309) & 511)]) + fVec50[((IOTA - 333) & 511)]) + fVec50[((IOTA - 387) & 511)]) - fVec50[((IOTA - 412) & 511)])) + ((0.000488296151f * (((fVec50[((IOTA - 262) & 511)] + fVec50[((IOTA - 307) & 511)]) + fVec50[((IOTA - 359) & 511)]) - fVec50[((IOTA - 410) & 511)])) + ((0.00106814783f * ((fVec50[((IOTA - 251) & 511)] + fVec50[((IOTA - 260) & 511)]) - fVec50[((IOTA - 407) & 511)])) + ((0.00277718436f * (fVec50[((IOTA - 215) & 511)] - fVec50[((IOTA - 404) & 511)])) + ((0.00234992523f * (fVec50[((IOTA - 277) & 511)] - fVec50[((IOTA - 402) & 511)])) + ((0.00210577715f * ((fVec50[((IOTA - 186) & 511)] - fVec50[((IOTA - 380) & 511)]) - fVec50[((IOTA - 398) & 511)])) + ((0.00415051728f * ((fVec50[((IOTA - 372) & 511)] - fVec50[((IOTA - 378) & 511)]) - fVec50[((IOTA - 396) & 511)])) + ((0.00418103579f * fVec50[((IOTA - 371) & 511)]) + ((0.00308236945f * (fVec50[((IOTA - 222) & 511)] + fVec50[((IOTA - 370) & 511)])) + ((0.00207525864f * ((((((fVec50[((IOTA - 185) & 511)] + fVec50[((IOTA - 223) & 511)]) + fVec50[((IOTA - 229) & 511)]) + fVec50[((IOTA - 270) & 511)]) + fVec50[((IOTA - 271) & 511)]) + fVec50[((IOTA - 274) & 511)]) - fVec50[((IOTA - 363) & 511)])) + ((0.00140385143f * ((fVec50[((IOTA - 225) & 511)] + fVec50[((IOTA - 302) & 511)]) - fVec50[((IOTA - 362) & 511)])) + ((0.00109866634f * ((((fVec50[((IOTA - 204) & 511)] + fVec50[((IOTA - 314) & 511)]) + fVec50[((IOTA - 315) & 511)]) + fVec50[((IOTA - 319) & 511)]) + fVec50[((IOTA - 356) & 511)])) + ((0.00054933317f * fVec50[((IOTA - 342) & 511)]) + ((0.000946073793f * fVec50[((IOTA - 326) & 511)]) + ((0.00149540696f * (((fVec50[((IOTA - 218) & 511)] + fVec50[((IOTA - 240) & 511)]) + fVec50[((IOTA - 311) & 511)]) + fVec50[((IOTA - 317) & 511)])) + ((0.00119022187f * ((fVec50[((IOTA - 190) & 511)] - fVec50[((IOTA - 194) & 511)]) + fVec50[((IOTA - 299) & 511)])) + ((0.00170903653f * ((fVec50[((IOTA - 138) & 511)] + fVec50[((IOTA - 283) & 511)]) + fVec50[((IOTA - 291) & 511)])) + ((0.00213629566f * ((((fVec50[((IOTA - 187) & 511)] - fVec50[((IOTA - 210) & 511)]) + fVec50[((IOTA - 217) & 511)]) + fVec50[((IOTA - 286) & 511)]) + fVec50[((IOTA - 287) & 511)])) + ((0.00216681417f * (fVec50[((IOTA - 275) & 511)] + fVec50[((IOTA - 279) & 511)])) + ((0.00231940672f * fVec50[((IOTA - 278) & 511)]) + ((0.00228888821f * (fVec50[((IOTA - 232) & 511)] + fVec50[((IOTA - 276) & 511)])) + ((0.00189214759f * fVec50[((IOTA - 269) & 511)]) + ((0.00167851802f * fVec50[((IOTA - 268) & 511)]) + ((0.00112918485f * fVec50[((IOTA - 266) & 511)]) + ((0.00125125889f * fVec50[((IOTA - 235) & 511)]) + ((0.00219733268f * fVec50[((IOTA - 233) & 511)]) + ((0.00280770287f * fVec50[((IOTA - 216) & 511)]) + ((0.00183111057f * fVec50[((IOTA - 183) & 511)]) + ((0.00350962859f * fVec50[((IOTA - 182) & 511)]) + ((0.006469924f * (fVec50[((IOTA - 177) & 511)] + fVec50[((IOTA - 181) & 511)])) + ((0.00906399731f * fVec50[((IOTA - 179) & 511)]) + ((0.00766014587f * fVec50[((IOTA - 178) & 511)]) + ((0.00561540574f * (fVec50[((IOTA - 139) & 511)] + fVec50[((IOTA - 176) & 511)])) + ((0.0045167394f * fVec50[((IOTA - 175) & 511)]) + ((0.0042115543f * fVec50[((IOTA - 169) & 511)]) + ((0.00674459059f * fVec50[((IOTA - 168) & 511)]) + ((0.00857570115f * fVec50[((IOTA - 167) & 511)]) + ((0.00772118289f * fVec50[((IOTA - 166) & 511)]) + ((0.0054933317f * fVec50[((IOTA - 165) & 511)]) + ((0.00628681295f * fVec50[((IOTA - 163) & 511)]) + ((0.00683614612f * (fVec50[((IOTA - 96) & 511)] + fVec50[((IOTA - 162) & 511)])) + ((0.00869777519f * fVec50[((IOTA - 180) & 511)]) + ((0.0083925901f * fVec50[((IOTA - 152) & 511)]) + ((0.0181890316f * fVec50[((IOTA - 151) & 511)]) + ((0.022461623f * fVec50[((IOTA - 150) & 511)]) + ((0.0171819218f * fVec50[((IOTA - 149) & 511)]) + ((0.00701925717f * fVec50[((IOTA - 144) & 511)]) + ((0.0148930326f * fVec50[((IOTA - 143) & 511)]) + ((0.0145878475f * fVec50[((IOTA - 142) & 511)]) + ((0.0112918485f * fVec50[((IOTA - 141) & 511)]) + ((0.00833155308f * fVec50[((IOTA - 140) & 511)]) + ((0.00482192449f * fVec50[((IOTA - 128) & 511)]) + ((0.0182195511f * fVec50[((IOTA - 127) & 511)]) + ((0.0321665108f * fVec50[((IOTA - 126) & 511)]) + ((0.0393688791f * fVec50[((IOTA - 125) & 511)]) + ((0.0333262123f * fVec50[((IOTA - 124) & 511)]) + ((0.014435255f * fVec50[((IOTA - 123) & 511)]) + ((0.0100405896f * fVec50[((IOTA - 118) & 511)]) + ((0.0209356975f * fVec50[((IOTA - 117) & 511)]) + ((0.0231330302f * fVec50[((IOTA - 116) & 511)]) + ((0.0237128828f * fVec50[((IOTA - 115) & 511)]) + ((0.0236823633f * fVec50[((IOTA - 114) & 511)]) + ((0.0239570308f * fVec50[((IOTA - 113) & 511)]) + ((0.0205694754f * fVec50[((IOTA - 112) & 511)]) + ((0.0138248848f * fVec50[((IOTA - 111) & 511)]) + ((0.00393688772f * fVec50[((IOTA - 110) & 511)]) + ((0.00540177617f * fVec50[((IOTA - 100) & 511)]) + ((0.029114658f * fVec50[((IOTA - 99) & 511)]) + ((0.0444654673f * fVec50[((IOTA - 98) & 511)]) + ((0.0408032462f * fVec50[((IOTA - 97) & 511)]) + ((0.0280465111f * fVec50[((IOTA - 91) & 511)]) + ((0.0437025055f * fVec50[((IOTA - 90) & 511)]) + ((0.033845026f * fVec50[((IOTA - 89) & 511)]) + ((0.0143436994f * fVec50[((IOTA - 88) & 511)]) + ((0.00436414685f * fVec50[((IOTA - 87) & 511)]) + ((0.00518814661f * fVec50[((IOTA - 86) & 511)]) + ((0.0177312549f * fVec50[((IOTA - 85) & 511)]) + ((0.00494399853f * fVec50[((IOTA - 84) & 511)]) + ((0.021149328f * fVec50[((IOTA - 81) & 511)]) + ((0.0463270992f * fVec50[((IOTA - 80) & 511)]) + ((0.0524918362f * fVec50[((IOTA - 79) & 511)]) + ((0.0111697745f * fVec50[((IOTA - 78) & 511)]) + ((0.0387279876f * fVec50[((IOTA - 74) & 511)]) + ((0.218329415f * fVec50[((IOTA - 72) & 511)]) + ((0.117923521f * fVec50[((IOTA - 71) & 511)]) + ((0.0071108127f * fVec50[((IOTA - 62) & 511)]) + ((0.0101321451f * fVec50[((IOTA - 61) & 511)]) + ((0.00961333048f * fVec50[((IOTA - 60) & 511)]) + ((0.00662251655f * fVec50[((IOTA - 59) & 511)]) + ((0.00311288796f * fVec50[((IOTA - 58) & 511)]) + (0.164372697f * fVec50[((IOTA - 73) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000610370189f * (((((fVec50[((IOTA - 245) & 511)] + fVec50[((IOTA - 264) & 511)]) + fVec50[((IOTA - 327) & 511)]) + fVec50[((IOTA - 354) & 511)]) - fVec50[((IOTA - 408) & 511)]) - fVec50[((IOTA - 511) & 511)])))) : (((0.000396740623f * ((((fVec49[((IOTA - 231) & 511)] + fVec49[((IOTA - 268) & 511)]) + fVec49[((IOTA - 342) & 511)]) + fVec49[((IOTA - 410) & 511)]) + fVec49[((IOTA - 511) & 511)])) + ((0.00146488845f * ((((fVec49[((IOTA - 225) & 511)] + fVec49[((IOTA - 414) & 511)]) + fVec49[((IOTA - 421) & 511)]) + fVec49[((IOTA - 504) & 511)]) + fVec49[((IOTA - 507) & 511)])) + ((0.001617481f * ((fVec49[((IOTA - 428) & 511)] + fVec49[((IOTA - 505) & 511)]) + fVec49[((IOTA - 506) & 511)])) + ((0.0012817774f * (fVec49[((IOTA - 427) & 511)] + fVec49[((IOTA - 503) & 511)])) + ((0.000976592302f * (((((fVec49[((IOTA - 150) & 511)] + fVec49[((IOTA - 277) & 511)]) + fVec49[((IOTA - 294) & 511)]) + fVec49[((IOTA - 307) & 511)]) + fVec49[((IOTA - 490) & 511)]) + fVec49[((IOTA - 501) & 511)])) + ((0.00143436994f * (fVec49[((IOTA - 206) & 511)] + fVec49[((IOTA - 498) & 511)])) + ((0.00277718436f * (fVec49[((IOTA - 436) & 511)] + fVec49[((IOTA - 494) & 511)])) + ((0.00219733268f * (fVec49[((IOTA - 475) & 511)] + fVec49[((IOTA - 492) & 511)])) + ((0.000640888698f * ((((((((fVec49[((IOTA - 9) & 511)] - fVec49[((IOTA - 203) & 511)]) - fVec49[((IOTA - 229) & 511)]) + fVec49[((IOTA - 272) & 511)]) + fVec49[((IOTA - 320) & 511)]) - fVec49[((IOTA - 366) & 511)]) - fVec49[((IOTA - 367) & 511)]) - fVec49[((IOTA - 382) & 511)]) + fVec49[((IOTA - 489) & 511)])) + ((0.00057985168f * (((((fVec49[((IOTA - 208) & 511)] + fVec49[((IOTA - 266) & 511)]) + fVec49[((IOTA - 286) & 511)]) + fVec49[((IOTA - 305) & 511)]) + fVec49[((IOTA - 321) & 511)]) + fVec49[((IOTA - 488) & 511)])) + ((0.00109866634f * ((((((fVec49[((IOTA - 278) & 511)] + fVec49[((IOTA - 281) & 511)]) + fVec49[((IOTA - 288) & 511)]) + fVec49[((IOTA - 423) & 511)]) + fVec49[((IOTA - 426) & 511)]) + fVec49[((IOTA - 438) & 511)]) + fVec49[((IOTA - 485) & 511)])) + ((0.00122074038f * (((((fVec49[((IOTA - 73) & 511)] + fVec49[((IOTA - 280) & 511)]) + fVec49[((IOTA - 375) & 511)]) + fVec49[((IOTA - 458) & 511)]) + fVec49[((IOTA - 483) & 511)]) + fVec49[((IOTA - 484) & 511)])) + ((0.00131229591f * ((((fVec49[((IOTA - 207) & 511)] - fVec49[((IOTA - 244) & 511)]) + fVec49[((IOTA - 289) & 511)]) + fVec49[((IOTA - 290) & 511)]) + fVec49[((IOTA - 482) & 511)])) + ((0.00198370311f * fVec49[((IOTA - 480) & 511)]) + ((0.00241096225f * fVec49[((IOTA - 479) & 511)]) + ((0.00244148076f * ((((fVec49[((IOTA - 223) & 511)] + fVec49[((IOTA - 224) & 511)]) - fVec49[((IOTA - 256) & 511)]) + fVec49[((IOTA - 418) & 511)]) + fVec49[((IOTA - 476) & 511)])) + ((0.00183111057f * fVec49[((IOTA - 474) & 511)]) + ((0.00112918485f * (((((fVec49[((IOTA - 221) & 511)] - fVec49[((IOTA - 240) & 511)]) + fVec49[((IOTA - 279) & 511)]) + fVec49[((IOTA - 293) & 511)]) - fVec49[((IOTA - 394) & 511)]) + fVec49[((IOTA - 473) & 511)])) + ((3.05185094e-05f * (((((((((((((((((fTemp50 + fVec49[((IOTA - 1) & 511)]) - fVec49[((IOTA - 33) & 511)]) + fVec49[((IOTA - 37) & 511)]) + fVec49[((IOTA - 40) & 511)]) + fVec49[((IOTA - 41) & 511)]) + fVec49[((IOTA - 43) & 511)]) + fVec49[((IOTA - 46) & 511)]) + fVec49[((IOTA - 48) & 511)]) + fVec49[((IOTA - 50) & 511)]) - fVec49[((IOTA - 52) & 511)]) - fVec49[((IOTA - 54) & 511)]) + fVec49[((IOTA - 56) & 511)]) - fVec49[((IOTA - 262) & 511)]) - fVec49[((IOTA - 297) & 511)]) + fVec49[((IOTA - 327) & 511)]) + fVec49[((IOTA - 360) & 511)]) + fVec49[((IOTA - 472) & 511)])) + ((0.00115970336f * ((fVec49[((IOTA - 292) & 511)] - fVec49[((IOTA - 396) & 511)]) - fVec49[((IOTA - 471) & 511)])) + ((0.00186162908f * (fVec49[((IOTA - 222) & 511)] - fVec49[((IOTA - 470) & 511)])) + ((0.00393688772f * fVec49[((IOTA - 466) & 511)]) + ((0.00506607257f * fVec49[((IOTA - 465) & 511)]) + ((0.00518814661f * (fVec49[((IOTA - 384) & 511)] + fVec49[((IOTA - 464) & 511)])) + ((0.00457777642f * fVec49[((IOTA - 463) & 511)]) + ((0.00216681417f * (fVec49[((IOTA - 429) & 511)] + fVec49[((IOTA - 460) & 511)])) + ((0.00167851802f * fVec49[((IOTA - 459) & 511)]) + ((0.000793481246f * ((((fVec49[((IOTA - 105) & 511)] + fVec49[((IOTA - 234) & 511)]) - fVec49[((IOTA - 399) & 511)]) + fVec49[((IOTA - 441) & 511)]) + fVec49[((IOTA - 455) & 511)])) + ((0.00140385143f * (((((((fVec49[((IOTA - 89) & 511)] + fVec49[((IOTA - 345) & 511)]) + fVec49[((IOTA - 347) & 511)]) - fVec49[((IOTA - 377) & 511)]) - fVec49[((IOTA - 397) & 511)]) - fVec49[((IOTA - 398) & 511)]) + fVec49[((IOTA - 408) & 511)]) + fVec49[((IOTA - 453) & 511)])) + ((0.00247199927f * (fVec49[((IOTA - 443) & 511)] + fVec49[((IOTA - 451) & 511)])) + ((0.00381481368f * fVec49[((IOTA - 449) & 511)]) + ((0.0045167394f * fVec49[((IOTA - 447) & 511)]) + ((0.00442518387f * fVec49[((IOTA - 446) & 511)]) + ((0.00405896176f * fVec49[((IOTA - 445) & 511)]) + ((0.00332651753f * fVec49[((IOTA - 444) & 511)]) + ((0.000427259132f * (((((((fVec49[((IOTA - 218) & 511)] + fVec49[((IOTA - 270) & 511)]) - fVec49[((IOTA - 298) & 511)]) + fVec49[((IOTA - 322) & 511)]) + fVec49[((IOTA - 338) & 511)]) + fVec49[((IOTA - 340) & 511)]) + fVec49[((IOTA - 359) & 511)]) + fVec49[((IOTA - 440) & 511)])) + ((0.000518814661f * ((fVec49[((IOTA - 263) & 511)] + fVec49[((IOTA - 358) & 511)]) + fVec49[((IOTA - 439) & 511)])) + ((0.00149540696f * (fVec49[((IOTA - 389) & 511)] - fVec49[((IOTA - 469) & 511)])) + ((0.00344859157f * fVec49[((IOTA - 435) & 511)]) + ((0.0038758507f * (fVec49[((IOTA - 432) & 511)] + fVec49[((IOTA - 434) & 511)])) + ((0.00402844325f * fVec49[((IOTA - 433) & 511)]) + ((0.00347911008f * fVec49[((IOTA - 431) & 511)]) + ((0.00100711081f * (fVec49[((IOTA - 282) & 511)] + fVec49[((IOTA - 425) & 511)])) + ((0.00177007355f * fVec49[((IOTA - 420) & 511)]) + ((0.00207525864f * fVec49[((IOTA - 419) & 511)]) + ((0.00256355479f * (fVec49[((IOTA - 59) & 511)] + fVec49[((IOTA - 416) & 511)])) + ((0.000854518265f * ((fVec49[((IOTA - 233) & 511)] + fVec49[((IOTA - 287) & 511)]) + fVec49[((IOTA - 413) & 511)])) + ((0.000244148076f * ((((((fVec49[((IOTA - 22) & 511)] - fVec49[((IOTA - 210) & 511)]) + fVec49[((IOTA - 226) & 511)]) + fVec49[((IOTA - 313) & 511)]) + fVec49[((IOTA - 317) & 511)]) + fVec49[((IOTA - 326) & 511)]) + fVec49[((IOTA - 411) & 511)])) + ((0.00445570238f * fVec49[((IOTA - 406) & 511)]) + ((0.00628681295f * (fVec49[((IOTA - 93) & 511)] + fVec49[((IOTA - 405) & 511)])) + ((0.00744651631f * fVec49[((IOTA - 404) & 511)]) + ((0.00720236823f * fVec49[((IOTA - 403) & 511)]) + ((0.00552385021f * fVec49[((IOTA - 402) & 511)]) + ((0.00299081393f * fVec49[((IOTA - 401) & 511)]) + ((0.00357066561f * (fVec49[((IOTA - 106) & 511)] + fVec49[((IOTA - 388) & 511)])) + ((0.00531022064f * fVec49[((IOTA - 387) & 511)]) + ((0.006469924f * (fVec49[((IOTA - 385) & 511)] + fVec49[((IOTA - 386) & 511)])) + ((0.0025940733f * fVec49[((IOTA - 383) & 511)]) + ((6.10370189e-05f * ((((fVec49[((IOTA - 249) & 511)] - ((((((((((fVec49[((IOTA - 4) & 511)] + fVec49[((IOTA - 31) & 511)]) - fVec49[((IOTA - 38) & 511)]) - fVec49[((IOTA - 42) & 511)]) - fVec49[((IOTA - 44) & 511)]) - fVec49[((IOTA - 45) & 511)]) - fVec49[((IOTA - 47) & 511)]) + fVec49[((IOTA - 154) & 511)]) + fVec49[((IOTA - 204) & 511)]) + fVec49[((IOTA - 212) & 511)]) + fVec49[((IOTA - 248) & 511)])) - fVec49[((IOTA - 302) & 511)]) + fVec49[((IOTA - 310) & 511)]) + fVec49[((IOTA - 376) & 511)])) + ((0.00283822138f * fVec49[((IOTA - 373) & 511)]) + ((0.00314340647f * fVec49[((IOTA - 372) & 511)]) + ((0.00054933317f * (((((((((((fVec49[((IOTA - 167) & 511)] - fVec49[((IOTA - 216) & 511)]) + fVec49[((IOTA - 219) & 511)]) - fVec49[((IOTA - 246) & 511)]) + fVec49[((IOTA - 271) & 511)]) + fVec49[((IOTA - 284) & 511)]) - fVec49[((IOTA - 300) & 511)]) + fVec49[((IOTA - 319) & 511)]) + fVec49[((IOTA - 339) & 511)]) - fVec49[((IOTA - 362) & 511)]) - fVec49[((IOTA - 363) & 511)]) - fVec49[((IOTA - 364) & 511)])) + ((0.000457777642f * ((((((fVec49[((IOTA - 16) & 511)] - fVec49[((IOTA - 17) & 511)]) + fVec49[((IOTA - 269) & 511)]) + fVec49[((IOTA - 285) & 511)]) + fVec49[((IOTA - 330) & 511)]) + fVec49[((IOTA - 354) & 511)]) + fVec49[((IOTA - 357) & 511)])) + ((0.000274666585f * ((((fVec49[((IOTA - 20) & 511)] - fVec49[((IOTA - 21) & 511)]) - fVec49[((IOTA - 247) & 511)]) + fVec49[((IOTA - 325) & 511)]) + fVec49[((IOTA - 356) & 511)])) + ((0.000823999755f * (fVec49[((IOTA - 274) & 511)] + fVec49[((IOTA - 352) & 511)])) + ((0.000183111057f * ((fVec49[((IOTA - 24) & 511)] - fVec49[((IOTA - 25) & 511)]) + fVec49[((IOTA - 337) & 511)])) + ((0.000762962736f * ((((fVec49[((IOTA - 14) & 511)] + fVec49[((IOTA - 235) & 511)]) + fVec49[((IOTA - 273) & 511)]) + fVec49[((IOTA - 295) & 511)]) + fVec49[((IOTA - 333) & 511)])) + ((9.15555283e-05f * ((((((((((fVec49[((IOTA - 3) & 511)] - fVec49[((IOTA - 29) & 511)]) + fVec49[((IOTA - 32) & 511)]) + fVec49[((IOTA - 34) & 511)]) + fVec49[((IOTA - 36) & 511)]) + fVec49[((IOTA - 51) & 511)]) + fVec49[((IOTA - 53) & 511)]) - fVec49[((IOTA - 211) & 511)]) - fVec49[((IOTA - 230) & 511)]) + fVec49[((IOTA - 303) & 511)]) - fVec49[((IOTA - 311) & 511)])) + ((0.00375377666f * (fVec49[((IOTA - 163) & 511)] - fVec49[((IOTA - 170) & 511)])) + ((0.00463881344f * fVec49[((IOTA - 166) & 511)]) + ((0.00732444227f * fVec49[((IOTA - 165) & 511)]) + ((0.0067751091f * fVec49[((IOTA - 164) & 511)]) + ((0.00558488723f * fVec49[((IOTA - 153) & 511)]) + ((0.00994903408f * fVec49[((IOTA - 152) & 511)]) + ((0.008087405f * fVec49[((IOTA - 151) & 511)]) + ((0.0128482925f * (fVec49[((IOTA - 110) & 511)] - fVec49[((IOTA - 143) & 511)])) + ((0.00173955504f * fVec49[((IOTA - 138) & 511)]) + ((0.00723288674f * fVec49[((IOTA - 137) & 511)]) + ((0.0131839961f * fVec49[((IOTA - 136) & 511)]) + ((0.0143742179f * fVec49[((IOTA - 135) & 511)]) + ((0.00820947904f * fVec49[((IOTA - 134) & 511)]) + ((0.00589007232f * fVec49[((IOTA - 125) & 511)]) + ((0.0174565874f * fVec49[((IOTA - 123) & 511)]) + ((0.0165105145f * fVec49[((IOTA - 122) & 511)]) + ((0.00708029419f * fVec49[((IOTA - 121) & 511)]) + ((0.0244148076f * fVec49[((IOTA - 109) & 511)]) + ((0.0231940672f * fVec49[((IOTA - 108) & 511)]) + ((0.0142826624f * fVec49[((IOTA - 107) & 511)]) + ((0.00924710836f * fVec49[((IOTA - 104) & 511)]) + ((0.0166020691f * fVec49[((IOTA - 103) & 511)]) + ((0.0156254768f * fVec49[((IOTA - 102) & 511)]) + ((0.0123905148f * fVec49[((IOTA - 124) & 511)]) + ((0.0241096225f * fVec49[((IOTA - 92) & 511)]) + ((0.0344859175f * fVec49[((IOTA - 91) & 511)]) + ((0.027741326f * fVec49[((IOTA - 90) & 511)]) + ((0.0236213263f * fVec49[((IOTA - 84) & 511)]) + ((0.0607318357f * fVec49[((IOTA - 83) & 511)]) + ((0.065553762f * fVec49[((IOTA - 82) & 511)]) + ((0.0317697674f * fVec49[((IOTA - 81) & 511)]) + ((0.00411999878f * fVec49[((IOTA - 75) & 511)]) + ((0.00640888698f * fVec49[((IOTA - 74) & 511)]) + ((0.021088291f * fVec49[((IOTA - 72) & 511)]) + ((0.045289468f * fVec49[((IOTA - 71) & 511)]) + ((0.0451063588f * fVec49[((IOTA - 70) & 511)]) + ((0.0136722922f * fVec49[((IOTA - 65) & 511)]) + ((0.20487076f * fVec49[((IOTA - 64) & 511)]) + ((0.297524959f * fVec49[((IOTA - 63) & 511)]) + ((0.242805257f * fVec49[((IOTA - 62) & 511)]) + ((0.119266339f * fVec49[((IOTA - 61) & 511)]) + ((0.0292062145f * fVec49[((IOTA - 60) & 511)]) + ((0.00469985045f * fVec49[((IOTA - 11) & 511)]) + (0.000152592547f * ((((fVec49[((IOTA - 5) & 511)] - fVec49[((IOTA - 6) & 511)]) + fVec49[((IOTA - 26) & 511)]) + fVec49[((IOTA - 55) & 511)]) + fVec49[((IOTA - 57) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000946073793f * ((((fVec49[((IOTA - 184) & 511)] + fVec49[((IOTA - 201) & 511)]) - fVec49[((IOTA - 276) & 511)]) + fVec49[((IOTA - 395) & 511)]) - fVec49[((IOTA - 509) & 511)])) + ((0.00125125889f * ((((fVec49[((IOTA - 139) & 511)] + fVec49[((IOTA - 200) & 511)]) - fVec49[((IOTA - 291) & 511)]) - fVec49[((IOTA - 422) & 511)]) - fVec49[((IOTA - 508) & 511)])) + ((0.00106814783f * ((((fVec49[((IOTA - 13) & 511)] - fVec49[((IOTA - 332) & 511)]) - fVec49[((IOTA - 344) & 511)]) - fVec49[((IOTA - 454) & 511)]) - fVec49[((IOTA - 502) & 511)])) + ((0.00103762932f * (((fVec49[((IOTA - 252) & 511)] - fVec49[((IOTA - 348) & 511)]) - fVec49[((IOTA - 424) & 511)]) - fVec49[((IOTA - 500) & 511)])) + ((0.00119022187f * (fVec49[((IOTA - 10) & 511)] - fVec49[((IOTA - 499) & 511)])) + ((0.00170903653f * ((fVec49[((IOTA - 241) & 511)] + fVec49[((IOTA - 260) & 511)]) - fVec49[((IOTA - 497) & 511)])) + ((0.00210577715f * ((fVec49[((IOTA - 192) & 511)] - fVec49[((IOTA - 415) & 511)]) - fVec49[((IOTA - 496) & 511)])) + ((0.00253303628f * ((fVec49[((IOTA - 197) & 511)] + fVec49[((IOTA - 258) & 511)]) - fVec49[((IOTA - 495) & 511)])) + ((0.00265511032f * ((fVec49[((IOTA - 185) & 511)] - fVec49[((IOTA - 407) & 511)]) - fVec49[((IOTA - 493) & 511)])) + ((0.00158696249f * (((fVec49[((IOTA - 253) & 511)] - fVec49[((IOTA - 346) & 511)]) - fVec49[((IOTA - 481) & 511)]) - fVec49[((IOTA - 491) & 511)])) + ((0.000732444227f * (((((((((fVec49[((IOTA - 214) & 511)] - fVec49[((IOTA - 220) & 511)]) - fVec49[((IOTA - 232) & 511)]) - fVec49[((IOTA - 236) & 511)]) - fVec49[((IOTA - 265) & 511)]) - fVec49[((IOTA - 283) & 511)]) - fVec49[((IOTA - 369) & 511)]) - fVec49[((IOTA - 409) & 511)]) - fVec49[((IOTA - 456) & 511)]) - fVec49[((IOTA - 487) & 511)])) + ((0.000915555283f * ((((fVec49[((IOTA - 183) & 511)] - fVec49[((IOTA - 205) & 511)]) + fVec49[((IOTA - 228) & 511)]) - fVec49[((IOTA - 331) & 511)]) - fVec49[((IOTA - 486) & 511)])) + ((0.00262459181f * ((fVec49[((IOTA - 257) & 511)] - fVec49[((IOTA - 477) & 511)]) - fVec49[((IOTA - 478) & 511)])) + ((0.00204474013f * (fVec49[((IOTA - 94) & 511)] - fVec49[((IOTA - 467) & 511)])) + ((0.00363170262f * (fVec49[((IOTA - 178) & 511)] - fVec49[((IOTA - 462) & 511)])) + ((0.00280770287f * (((fVec49[((IOTA - 196) & 511)] - fVec49[((IOTA - 371) & 511)]) - fVec49[((IOTA - 430) & 511)]) - fVec49[((IOTA - 461) & 511)])) + ((0.000885036774f * (((((((fVec49[((IOTA - 202) & 511)] + fVec49[((IOTA - 215) & 511)]) + fVec49[((IOTA - 245) & 511)]) + fVec49[((IOTA - 261) & 511)]) - fVec49[((IOTA - 275) & 511)]) - fVec49[((IOTA - 306) & 511)]) - fVec49[((IOTA - 308) & 511)]) - fVec49[((IOTA - 457) & 511)])) + ((0.00189214759f * ((((fVec49[((IOTA - 242) & 511)] - fVec49[((IOTA - 370) & 511)]) + fVec49[((IOTA - 392) & 511)]) - fVec49[((IOTA - 437) & 511)]) - fVec49[((IOTA - 452) & 511)])) + ((0.00317392498f * (fVec49[((IOTA - 195) & 511)] - fVec49[((IOTA - 450) & 511)])) + ((0.00427259132f * (fVec49[((IOTA - 111) & 511)] - fVec49[((IOTA - 448) & 511)])) + ((0.00155644398f * (fVec49[((IOTA - 393) & 511)] - fVec49[((IOTA - 442) & 511)])) + ((0.00268562883f * ((fVec49[((IOTA - 191) & 511)] + fVec49[((IOTA - 193) & 511)]) - fVec49[((IOTA - 417) & 511)])) + ((0.000366222113f * (((((((((fVec49[((IOTA - 8) & 511)] - fVec49[((IOTA - 18) & 511)]) - fVec49[((IOTA - 95) & 511)]) - fVec49[((IOTA - 296) & 511)]) + fVec49[((IOTA - 301) & 511)]) - fVec49[((IOTA - 314) & 511)]) - fVec49[((IOTA - 315) & 511)]) - fVec49[((IOTA - 341) & 511)]) + fVec49[((IOTA - 390) & 511)]) - fVec49[((IOTA - 412) & 511)])) + ((0.00152592547f * fVec49[((IOTA - 391) & 511)]) + ((0.00350962859f * ((fVec49[((IOTA - 12) & 511)] + fVec49[((IOTA - 179) & 511)]) + fVec49[((IOTA - 381) & 511)])) + ((0.00497451704f * fVec49[((IOTA - 380) & 511)]) + ((0.00466933195f * (fVec49[((IOTA - 172) & 511)] + fVec49[((IOTA - 379) & 511)])) + ((0.00320444349f * fVec49[((IOTA - 378) & 511)]) + ((0.00213629566f * (fVec49[((IOTA - 198) & 511)] - fVec49[((IOTA - 374) & 511)])) + ((0.000213629566f * (((fVec49[((IOTA - 23) & 511)] - fVec49[((IOTA - 316) & 511)]) - fVec49[((IOTA - 334) & 511)]) + fVec49[((IOTA - 368) & 511)])) + ((0.000610370189f * ((fVec49[((IOTA - 299) & 511)] - fVec49[((IOTA - 350) & 511)]) + fVec49[((IOTA - 365) & 511)])) + ((0.000305185094f * (fVec49[((IOTA - 361) & 511)] - ((((((fVec49[((IOTA - 7) & 511)] - fVec49[((IOTA - 213) & 511)]) + fVec49[((IOTA - 238) & 511)]) - fVec49[((IOTA - 239) & 511)]) + fVec49[((IOTA - 323) & 511)]) + fVec49[((IOTA - 324) & 511)]) + fVec49[((IOTA - 355) & 511)]))) + ((0.000701925717f * (((fVec49[((IOTA - 227) & 511)] - fVec49[((IOTA - 264) & 511)]) - fVec49[((IOTA - 351) & 511)]) - fVec49[((IOTA - 353) & 511)])) + ((0.000122074038f * ((((((((fVec49[((IOTA - 27) & 511)] - fVec49[((IOTA - 28) & 511)]) - fVec49[((IOTA - 30) & 511)]) - fVec49[((IOTA - 49) & 511)]) - fVec49[((IOTA - 58) & 511)]) + fVec49[((IOTA - 126) & 511)]) + fVec49[((IOTA - 328) & 511)]) + fVec49[((IOTA - 335) & 511)]) + fVec49[((IOTA - 336) & 511)])) + ((0.000335703604f * ((fVec49[((IOTA - 19) & 511)] - fVec49[((IOTA - 304) & 511)]) - fVec49[((IOTA - 318) & 511)])) + ((0.000488296151f * (((fVec49[((IOTA - 162) & 511)] + fVec49[((IOTA - 251) & 511)]) - fVec49[((IOTA - 267) & 511)]) - fVec49[((IOTA - 309) & 511)])) + ((0.0022583697f * (fVec49[((IOTA - 255) & 511)] + fVec49[((IOTA - 259) & 511)])) + ((0.0019226661f * fVec49[((IOTA - 254) & 511)]) + ((0.00164799951f * (fVec49[((IOTA - 199) & 511)] + fVec49[((IOTA - 243) & 511)])) + ((0.00305185094f * fVec49[((IOTA - 194) & 511)]) + ((0.00436414685f * fVec49[((IOTA - 190) & 511)]) + ((0.00668355357f * (fVec49[((IOTA - 175) & 511)] + fVec49[((IOTA - 189) & 511)])) + ((0.00845362712f * fVec49[((IOTA - 188) & 511)]) + ((0.00787377544f * fVec49[((IOTA - 187) & 511)]) + ((0.00540177617f * fVec49[((IOTA - 186) & 511)]) + ((0.00180059206f * fVec49[((IOTA - 182) & 511)]) + ((0.00296029542f * fVec49[((IOTA - 181) & 511)]) + ((0.00338755455f * fVec49[((IOTA - 180) & 511)]) + ((0.00418103579f * ((fVec49[((IOTA - 133) & 511)] + fVec49[((IOTA - 169) & 511)]) + fVec49[((IOTA - 177) & 511)])) + ((0.00543229468f * fVec49[((IOTA - 176) & 511)]) + ((0.00729392376f * (fVec49[((IOTA - 160) & 511)] + fVec49[((IOTA - 174) & 511)])) + ((0.00634784997f * fVec49[((IOTA - 173) & 511)]) + ((0.00326548051f * fVec49[((IOTA - 171) & 511)]) + ((0.00292977691f * fVec49[((IOTA - 168) & 511)]) + ((0.00482192449f * fVec49[((IOTA - 161) & 511)]) + ((0.00726340525f * fVec49[((IOTA - 159) & 511)]) + ((0.00595110934f * fVec49[((IOTA - 158) & 511)]) + ((0.00479140598f * fVec49[((IOTA - 157) & 511)]) + ((0.00476088747f * fVec49[((IOTA - 156) & 511)]) + ((0.00369273964f * fVec49[((IOTA - 155) & 511)]) + ((0.00881984923f * fVec49[((IOTA - 149) & 511)]) + ((0.0148319956f * fVec49[((IOTA - 148) & 511)]) + ((0.0156559963f * fVec49[((IOTA - 147) & 511)]) + ((0.0148014771f * fVec49[((IOTA - 146) & 511)]) + ((0.0152287362f * fVec49[((IOTA - 145) & 511)]) + ((0.0153202917f * fVec49[((IOTA - 144) & 511)]) + ((0.00885036774f * fVec49[((IOTA - 142) & 511)]) + ((0.0051576281f * fVec49[((IOTA - 141) & 511)]) + ((0.0028992584f * fVec49[((IOTA - 140) & 511)]) + ((0.017975403f * fVec49[((IOTA - 132) & 511)]) + ((0.0274056215f * fVec49[((IOTA - 131) & 511)]) + ((0.0286263619f * fVec49[((IOTA - 130) & 511)]) + ((0.0225531794f * fVec49[((IOTA - 129) & 511)]) + ((0.0134891812f * fVec49[((IOTA - 128) & 511)]) + ((0.00604266487f * fVec49[((IOTA - 127) & 511)]) + ((0.00997955259f * fVec49[((IOTA - 120) & 511)]) + ((0.0272530299f * fVec49[((IOTA - 119) & 511)]) + ((0.037324138f * fVec49[((IOTA - 118) & 511)]) + ((0.0375988036f * fVec49[((IOTA - 117) & 511)]) + ((0.034150213f * fVec49[((IOTA - 116) & 511)]) + ((0.0303964354f * fVec49[((IOTA - 115) & 511)]) + ((0.0287484359f * fVec49[((IOTA - 114) & 511)]) + ((0.0260322895f * fVec49[((IOTA - 113) & 511)]) + ((0.0183111057f * fVec49[((IOTA - 112) & 511)]) + ((0.0035401471f * fVec49[((IOTA - 101) & 511)]) + ((0.0205084383f * fVec49[((IOTA - 100) & 511)]) + ((0.0292672515f * fVec49[((IOTA - 99) & 511)]) + ((0.025757622f * fVec49[((IOTA - 98) & 511)]) + ((0.0115970336f * fVec49[((IOTA - 97) & 511)]) + ((0.00228888821f * fVec49[((IOTA - 96) & 511)]) + ((0.0419629514f * fVec49[((IOTA - 88) & 511)]) + ((0.0749839768f * fVec49[((IOTA - 87) & 511)]) + ((0.0735190883f * fVec49[((IOTA - 86) & 511)]) + ((0.0311593991f * fVec49[((IOTA - 85) & 511)]) + ((0.0214850307f * fVec49[((IOTA - 80) & 511)]) + ((0.0604266487f * fVec49[((IOTA - 79) & 511)]) + ((0.0732444227f * fVec49[((IOTA - 78) & 511)]) + ((0.0506302081f * fVec49[((IOTA - 77) & 511)]) + ((0.0237739198f * fVec49[((IOTA - 76) & 511)]) + ((0.0374156944f * fVec49[((IOTA - 69) & 511)]) + ((0.142918184f * fVec49[((IOTA - 68) & 511)]) + ((0.164708391f * fVec49[((IOTA - 66) & 511)]) + (0.217871636f * fVec49[((IOTA - 67) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000671407208f * (((((fVec49[((IOTA - 15) & 511)] - fVec49[((IOTA - 237) & 511)]) - fVec49[((IOTA - 343) & 511)]) - fVec49[((IOTA - 349) & 511)]) - fVec49[((IOTA - 400) & 511)]) - fVec49[((IOTA - 510) & 511)])))))))) : (iSlow78 ? (iSlow98 ? (iSlow106 ? (iSlow112 ? (((0.000640888698f * ((((fVec48[((IOTA - 257) & 511)] + fVec48[((IOTA - 258) & 511)]) - fVec48[((IOTA - 263) & 511)]) + fVec48[((IOTA - 405) & 511)]) - fVec48[((IOTA - 491) & 511)])) + ((0.00122074038f * (fVec48[((IOTA - 202) & 511)] - fVec48[((IOTA - 489) & 511)])) + ((0.00210577715f * ((((((fVec48[((IOTA - 219) & 511)] + fVec48[((IOTA - 251) & 511)]) - fVec48[((IOTA - 269) & 511)]) - fVec48[((IOTA - 325) & 511)]) - fVec48[((IOTA - 412) & 511)]) - fVec48[((IOTA - 440) & 511)]) - fVec48[((IOTA - 486) & 511)])) + ((0.00253303628f * (fVec48[((IOTA - 242) & 511)] - fVec48[((IOTA - 485) & 511)])) + ((0.00283822138f * (fVec48[((IOTA - 230) & 511)] - fVec48[((IOTA - 484) & 511)])) + ((0.00286873989f * ((((fVec48[((IOTA - 220) & 511)] + fVec48[((IOTA - 244) & 511)]) - fVec48[((IOTA - 364) & 511)]) - fVec48[((IOTA - 472) & 511)]) - fVec48[((IOTA - 482) & 511)])) + ((0.00274666585f * ((fVec48[((IOTA - 210) & 511)] - fVec48[((IOTA - 477) & 511)]) - fVec48[((IOTA - 478) & 511)])) + ((0.00234992523f * (((fVec48[((IOTA - 110) & 511)] - fVec48[((IOTA - 420) & 511)]) - fVec48[((IOTA - 437) & 511)]) - fVec48[((IOTA - 474) & 511)])) + ((0.00115970336f * (fVec48[((IOTA - 367) & 511)] - fVec48[((IOTA - 468) & 511)])) + ((0.00131229591f * ((fVec48[((IOTA - 238) & 511)] - fVec48[((IOTA - 307) & 511)]) - fVec48[((IOTA - 465) & 511)])) + ((0.00180059206f * ((fVec48[((IOTA - 385) & 511)] - fVec48[((IOTA - 421) & 511)]) - fVec48[((IOTA - 463) & 511)])) + ((0.001617481f * (((fVec48[((IOTA - 163) & 511)] + fVec48[((IOTA - 234) & 511)]) - fVec48[((IOTA - 461) & 511)]) - fVec48[((IOTA - 462) & 511)])) + ((0.0019531846f * (fVec48[((IOTA - 236) & 511)] - fVec48[((IOTA - 460) & 511)])) + ((0.00250251777f * ((fVec48[((IOTA - 248) & 511)] - fVec48[((IOTA - 360) & 511)]) - fVec48[((IOTA - 459) & 511)])) + ((0.00213629566f * (((fVec48[((IOTA - 198) & 511)] - fVec48[((IOTA - 452) & 511)]) - fVec48[((IOTA - 453) & 511)]) - fVec48[((IOTA - 457) & 511)])) + ((0.00106814783f * ((fVec48[((IOTA - 136) & 511)] + fVec48[((IOTA - 380) & 511)]) - fVec48[((IOTA - 455) & 511)])) + ((0.00149540696f * (fVec48[((IOTA - 232) & 511)] - fVec48[((IOTA - 454) & 511)])) + ((0.000671407208f * (fVec48[((IOTA - 253) & 511)] - fVec48[((IOTA - 449) & 511)])) + ((0.00140385143f * (((fVec48[((IOTA - 109) & 511)] + fVec48[((IOTA - 237) & 511)]) + fVec48[((IOTA - 387) & 511)]) - fVec48[((IOTA - 448) & 511)])) + ((0.00399792474f * ((fVec48[((IOTA - 205) & 511)] - fVec48[((IOTA - 373) & 511)]) - fVec48[((IOTA - 446) & 511)])) + ((0.00222785119f * ((fVec48[((IOTA - 240) & 511)] - fVec48[((IOTA - 439) & 511)]) - fVec48[((IOTA - 441) & 511)])) + ((0.00228888821f * ((fVec48[((IOTA - 221) & 511)] + fVec48[((IOTA - 231) & 511)]) - fVec48[((IOTA - 438) & 511)])) + ((0.0028992584f * (((fVec48[((IOTA - 368) & 511)] - fVec48[((IOTA - 377) & 511)]) - fVec48[((IOTA - 396) & 511)]) - fVec48[((IOTA - 435) & 511)])) + ((0.0042115543f * (fVec48[((IOTA - 137) & 511)] - fVec48[((IOTA - 430) & 511)])) + ((0.00173955504f * (fVec48[((IOTA - 211) & 511)] - fVec48[((IOTA - 425) & 511)])) + ((0.00241096225f * (fVec48[((IOTA - 249) & 511)] - fVec48[((IOTA - 413) & 511)])) + ((0.0012817774f * ((fVec48[((IOTA - 222) & 511)] + fVec48[((IOTA - 252) & 511)]) - fVec48[((IOTA - 410) & 511)])) + ((0.000610370189f * (((fVec48[((IOTA - 297) & 511)] - fVec48[((IOTA - 289) & 511)]) - fVec48[((IOTA - 342) & 511)]) - fVec48[((IOTA - 408) & 511)])) + ((0.00177007355f * ((fVec48[((IOTA - 228) & 511)] + fVec48[((IOTA - 239) & 511)]) - fVec48[((IOTA - 402) & 511)])) + ((0.00238044374f * (((fVec48[((IOTA - 241) & 511)] - fVec48[((IOTA - 398) & 511)]) - fVec48[((IOTA - 399) & 511)]) - fVec48[((IOTA - 400) & 511)])) + ((0.0025940733f * (fVec48[((IOTA - 61) & 511)] - fVec48[((IOTA - 397) & 511)])) + ((0.00314340647f * (fVec48[((IOTA - 209) & 511)] - fVec48[((IOTA - 395) & 511)])) + ((0.00350962859f * (fVec48[((IOTA - 207) & 511)] - fVec48[((IOTA - 394) & 511)])) + ((0.00512710959f * (fVec48[((IOTA - 156) & 511)] - fVec48[((IOTA - 392) & 511)])) + ((0.00247199927f * (fVec48[((IOTA - 250) & 511)] - fVec48[((IOTA - 389) & 511)])) + ((0.00207525864f * (fVec48[((IOTA - 235) & 511)] + fVec48[((IOTA - 386) & 511)])) + ((0.00054933317f * (((((((fVec48[((IOTA - 214) & 511)] + fVec48[((IOTA - 256) & 511)]) + fVec48[((IOTA - 259) & 511)]) - fVec48[((IOTA - 264) & 511)]) - fVec48[((IOTA - 271) & 511)]) - fVec48[((IOTA - 288) & 511)]) - fVec48[((IOTA - 366) & 511)]) + fVec48[((IOTA - 381) & 511)])) + ((0.00057985168f * ((((((((fVec48[((IOTA - 218) & 511)] - fVec48[((IOTA - 262) & 511)]) - fVec48[((IOTA - 265) & 511)]) + fVec48[((IOTA - 298) & 511)]) - fVec48[((IOTA - 329) & 511)]) - fVec48[((IOTA - 335) & 511)]) - fVec48[((IOTA - 338) & 511)]) - fVec48[((IOTA - 358) & 511)]) + fVec48[((IOTA - 379) & 511)])) + ((0.00103762932f * (((fVec48[((IOTA - 226) & 511)] + fVec48[((IOTA - 227) & 511)]) - fVec48[((IOTA - 311) & 511)]) - fVec48[((IOTA - 378) & 511)])) + ((0.00244148076f * fVec48[((IOTA - 370) & 511)]) + ((0.00360118411f * ((fVec48[((IOTA - 165) & 511)] + fVec48[((IOTA - 206) & 511)]) + fVec48[((IOTA - 369) & 511)])) + ((0.00186162908f * (fVec48[((IOTA - 164) & 511)] - fVec48[((IOTA - 365) & 511)])) + ((0.00326548051f * (fVec48[((IOTA - 246) & 511)] - fVec48[((IOTA - 361) & 511)])) + ((0.000274666585f * ((fVec48[((IOTA - 282) & 511)] + fVec48[((IOTA - 351) & 511)]) + fVec48[((IOTA - 354) & 511)])) + ((0.000793481246f * (fVec48[((IOTA - 135) & 511)] - fVec48[((IOTA - 343) & 511)])) + ((0.00109866634f * ((((fVec48[((IOTA - 126) & 511)] + fVec48[((IOTA - 224) & 511)]) - fVec48[((IOTA - 267) & 511)]) - fVec48[((IOTA - 304) & 511)]) - fVec48[((IOTA - 317) & 511)])) + ((0.00125125889f * (((fVec48[((IOTA - 225) & 511)] + fVec48[((IOTA - 233) & 511)]) - fVec48[((IOTA - 305) & 511)]) - fVec48[((IOTA - 306) & 511)])) + ((0.00302133244f * ((fVec48[((IOTA - 196) & 511)] + fVec48[((IOTA - 203) & 511)]) + fVec48[((IOTA - 247) & 511)])) + ((0.00305185094f * fVec48[((IOTA - 245) & 511)]) + ((0.00280770287f * fVec48[((IOTA - 243) & 511)]) + ((0.0035401471f * fVec48[((IOTA - 208) & 511)]) + ((0.00405896176f * fVec48[((IOTA - 204) & 511)]) + ((0.00152592547f * (fVec48[((IOTA - 162) & 511)] + fVec48[((IOTA - 199) & 511)])) + ((0.0019226661f * fVec48[((IOTA - 197) & 511)]) + ((0.00448622089f * fVec48[((IOTA - 195) & 511)]) + ((0.00555436872f * fVec48[((IOTA - 194) & 511)]) + ((0.00595110934f * fVec48[((IOTA - 193) & 511)]) + ((0.0058290353f * fVec48[((IOTA - 192) & 511)]) + ((0.00543229468f * fVec48[((IOTA - 191) & 511)]) + ((0.00650044251f * fVec48[((IOTA - 190) & 511)]) + ((0.00793481246f * fVec48[((IOTA - 189) & 511)]) + ((0.00726340525f * fVec48[((IOTA - 188) & 511)]) + ((0.00531022064f * fVec48[((IOTA - 187) & 511)]) + ((0.0061342204f * ((fVec48[((IOTA - 149) & 511)] + fVec48[((IOTA - 182) & 511)]) + fVec48[((IOTA - 186) & 511)])) + ((0.00717184972f * fVec48[((IOTA - 181) & 511)]) + ((0.00817896053f * fVec48[((IOTA - 180) & 511)]) + ((0.00640888698f * fVec48[((IOTA - 179) & 511)]) + ((0.0054933317f * fVec48[((IOTA - 178) & 511)]) + ((0.00848414563f * fVec48[((IOTA - 177) & 511)]) + ((0.0118411817f * fVec48[((IOTA - 176) & 511)]) + ((0.0101626636f * fVec48[((IOTA - 175) & 511)]) + ((0.00756859034f * fVec48[((IOTA - 174) & 511)]) + ((0.00762962736f * fVec48[((IOTA - 173) & 511)]) + ((0.00747703481f * fVec48[((IOTA - 172) & 511)]) + ((0.00744651631f * fVec48[((IOTA - 171) & 511)]) + ((0.00830103457f * fVec48[((IOTA - 170) & 511)]) + ((0.00891140476f * (fVec48[((IOTA - 64) & 511)] + fVec48[((IOTA - 169) & 511)])) + ((0.00735496078f * fVec48[((IOTA - 168) & 511)]) + ((0.00497451704f * fVec48[((IOTA - 167) & 511)]) + ((0.00491348002f * (fVec48[((IOTA - 139) & 511)] + fVec48[((IOTA - 166) & 511)])) + ((0.00787377544f * (fVec48[((IOTA - 155) & 511)] + fVec48[((IOTA - 158) & 511)])) + ((0.00723288674f * fVec48[((IOTA - 157) & 511)]) + ((0.0148319956f * fVec48[((IOTA - 154) & 511)]) + ((0.0198065136f * fVec48[((IOTA - 153) & 511)]) + ((0.0206610318f * fVec48[((IOTA - 152) & 511)]) + ((0.0174871068f * fVec48[((IOTA - 151) & 511)]) + ((0.0117191076f * fVec48[((IOTA - 150) & 511)]) + ((0.00738547929f * fVec48[((IOTA - 148) & 511)]) + ((0.01126133f * fVec48[((IOTA - 147) & 511)]) + ((0.0138554033f * fVec48[((IOTA - 146) & 511)]) + ((0.0124820704f * fVec48[((IOTA - 145) & 511)]) + ((0.00546281319f * (fVec48[((IOTA - 65) & 511)] + fVec48[((IOTA - 138) & 511)])) + ((0.00912503432f * fVec48[((IOTA - 144) & 511)]) + ((0.00759910885f * fVec48[((IOTA - 143) & 511)]) + ((0.00900296029f * fVec48[((IOTA - 142) & 511)]) + ((0.00881984923f * fVec48[((IOTA - 141) & 511)]) + ((0.00659199804f * fVec48[((IOTA - 140) & 511)]) + ((0.00927762687f * fVec48[((IOTA - 184) & 511)]) + ((0.00592059083f * fVec48[((IOTA - 134) & 511)]) + ((0.00790429395f * fVec48[((IOTA - 133) & 511)]) + ((0.00827051606f * fVec48[((IOTA - 132) & 511)]) + ((0.00946073793f * fVec48[((IOTA - 131) & 511)]) + ((0.0136417737f * fVec48[((IOTA - 130) & 511)]) + ((0.016052736f * fVec48[((IOTA - 129) & 511)]) + ((0.017853329f * fVec48[((IOTA - 128) & 511)]) + ((0.0133060701f * fVec48[((IOTA - 127) & 511)]) + ((0.00750755332f * fVec48[((IOTA - 122) & 511)]) + ((0.021210365f * fVec48[((IOTA - 121) & 511)]) + ((0.0250251777f * fVec48[((IOTA - 120) & 511)]) + ((0.0180059206f * fVec48[((IOTA - 119) & 511)]) + ((0.00949125644f * fVec48[((IOTA - 118) & 511)]) + ((0.0108035523f * fVec48[((IOTA - 117) & 511)]) + ((0.0164189581f * fVec48[((IOTA - 116) & 511)]) + ((0.0121768853f * fVec48[((IOTA - 115) & 511)]) + ((0.00656147953f * fVec48[((IOTA - 114) & 511)]) + ((0.0138859218f * fVec48[((IOTA - 105) & 511)]) + ((0.0210272539f * fVec48[((IOTA - 104) & 511)]) + ((0.00503555406f * fVec48[((IOTA - 103) & 511)]) + ((0.0230719931f * fVec48[((IOTA - 101) & 511)]) + ((0.0464491732f * fVec48[((IOTA - 100) & 511)]) + ((0.0243537705f * fVec48[((IOTA - 99) & 511)]) + ((0.0123294778f * fVec48[((IOTA - 94) & 511)]) + ((0.0485549495f * fVec48[((IOTA - 93) & 511)]) + ((0.0440687276f * fVec48[((IOTA - 92) & 511)]) + ((0.0139164403f * fVec48[((IOTA - 88) & 511)]) + ((0.0298471022f * fVec48[((IOTA - 87) & 511)]) + ((0.0196844395f * fVec48[((IOTA - 86) & 511)]) + ((0.0253608823f * fVec48[((IOTA - 85) & 511)]) + ((0.0129703665f * fVec48[((IOTA - 84) & 511)]) + ((0.024567401f * fVec48[((IOTA - 81) & 511)]) + ((0.0568865016f * fVec48[((IOTA - 80) & 511)]) + ((0.0270393994f * fVec48[((IOTA - 79) & 511)]) + ((0.141453296f * fVec48[((IOTA - 75) & 511)]) + ((0.209204376f * fVec48[((IOTA - 74) & 511)]) + ((0.00732444227f * fVec48[((IOTA - 73) & 511)]) + ((0.00680562761f * fVec48[((IOTA - 62) & 511)]) + (0.00955229346f * fVec48[((IOTA - 63) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.000885036774f * (fVec48[((IOTA - 303) & 511)] + fVec48[((IOTA - 508) & 511)])) + ((0.000915555283f * (((fVec48[((IOTA - 409) & 511)] + fVec48[((IOTA - 467) & 511)]) + fVec48[((IOTA - 490) & 511)]) + fVec48[((IOTA - 507) & 511)])) + ((0.000976592302f * ((((fVec48[((IOTA - 330) & 511)] + fVec48[((IOTA - 403) & 511)]) + fVec48[((IOTA - 500) & 511)]) + fVec48[((IOTA - 505) & 511)]) + fVec48[((IOTA - 506) & 511)])) + ((0.000732444227f * ((((fVec48[((IOTA - 216) & 511)] + fVec48[((IOTA - 323) & 511)]) + fVec48[((IOTA - 336) & 511)]) + fVec48[((IOTA - 496) & 511)]) + fVec48[((IOTA - 503) & 511)])) + ((0.000762962736f * (((((fVec48[((IOTA - 217) & 511)] + fVec48[((IOTA - 266) & 511)]) + fVec48[((IOTA - 302) & 511)]) + fVec48[((IOTA - 312) & 511)]) - fVec48[((IOTA - 384) & 511)]) + fVec48[((IOTA - 502) & 511)])) + ((0.00112918485f * (((fVec48[((IOTA - 314) & 511)] + fVec48[((IOTA - 331) & 511)]) + fVec48[((IOTA - 498) & 511)]) + fVec48[((IOTA - 499) & 511)])) + ((0.00100711081f * (fVec48[((IOTA - 466) & 511)] + fVec48[((IOTA - 497) & 511)])) + ((0.000488296151f * ((((fVec48[((IOTA - 333) & 511)] + fVec48[((IOTA - 345) & 511)]) + fVec48[((IOTA - 347) & 511)]) + fVec48[((IOTA - 493) & 511)]) + fVec48[((IOTA - 495) & 511)])) + ((0.000427259132f * (((((fVec48[((IOTA - 201) & 511)] - fVec48[((IOTA - 254) & 511)]) + fVec48[((IOTA - 319) & 511)]) + fVec48[((IOTA - 334) & 511)]) + fVec48[((IOTA - 346) & 511)]) + fVec48[((IOTA - 494) & 511)])) + ((0.000518814661f * (((fVec48[((IOTA - 279) & 511)] - fVec48[((IOTA - 283) & 511)]) + fVec48[((IOTA - 301) & 511)]) + fVec48[((IOTA - 492) & 511)])) + ((0.00143436994f * ((((fVec48[((IOTA - 310) & 511)] + fVec48[((IOTA - 315) & 511)]) + fVec48[((IOTA - 316) & 511)]) + fVec48[((IOTA - 451) & 511)]) + fVec48[((IOTA - 488) & 511)])) + ((0.00170903653f * ((fVec48[((IOTA - 268) & 511)] + fVec48[((IOTA - 309) & 511)]) + fVec48[((IOTA - 487) & 511)])) + ((0.00292977691f * (fVec48[((IOTA - 442) & 511)] + fVec48[((IOTA - 483) & 511)])) + ((0.00277718436f * fVec48[((IOTA - 481) & 511)]) + ((0.00268562883f * (fVec48[((IOTA - 480) & 511)] - ((fVec48[((IOTA - 159) & 511)] + fVec48[((IOTA - 229) & 511)]) - fVec48[((IOTA - 473) & 511)]))) + ((0.00256355479f * (fVec48[((IOTA - 436) & 511)] + fVec48[((IOTA - 476) & 511)])) + ((0.00231940672f * ((fVec48[((IOTA - 160) & 511)] + fVec48[((IOTA - 426) & 511)]) + fVec48[((IOTA - 475) & 511)])) + ((0.00219733268f * (fVec48[((IOTA - 401) & 511)] + fVec48[((IOTA - 470) & 511)])) + ((0.00164799951f * ((fVec48[((IOTA - 161) & 511)] + fVec48[((IOTA - 326) & 511)]) + fVec48[((IOTA - 469) & 511)])) + ((0.00167851802f * ((fVec48[((IOTA - 324) & 511)] + fVec48[((IOTA - 411) & 511)]) + fVec48[((IOTA - 464) & 511)])) + ((0.00137333293f * fVec48[((IOTA - 456) & 511)]) + ((0.000701925717f * ((fVec48[((IOTA - 318) & 511)] + fVec48[((IOTA - 344) & 511)]) + fVec48[((IOTA - 450) & 511)])) + ((0.00271614734f * fVec48[((IOTA - 447) & 511)]) + ((0.00469985045f * fVec48[((IOTA - 445) & 511)]) + ((0.00463881344f * fVec48[((IOTA - 444) & 511)]) + ((0.00390636921f * fVec48[((IOTA - 443) & 511)]) + ((0.00317392498f * fVec48[((IOTA - 434) & 511)]) + ((0.00344859157f * (fVec48[((IOTA - 416) & 511)] + fVec48[((IOTA - 433) & 511)])) + ((0.00363170262f * (fVec48[((IOTA - 362) & 511)] + fVec48[((IOTA - 432) & 511)])) + ((0.00393688772f * fVec48[((IOTA - 431) & 511)]) + ((0.00265511032f * ((fVec48[((IOTA - 458) & 511)] + fVec48[((IOTA - 471) & 511)]) + fVec48[((IOTA - 479) & 511)])) + ((0.00418103579f * fVec48[((IOTA - 429) & 511)]) + ((0.00375377666f * (fVec48[((IOTA - 417) & 511)] + fVec48[((IOTA - 428) & 511)])) + ((0.00146488845f * ((fVec48[((IOTA - 359) & 511)] + fVec48[((IOTA - 423) & 511)]) + fVec48[((IOTA - 424) & 511)])) + ((0.00158696249f * ((fVec48[((IOTA - 270) & 511)] + fVec48[((IOTA - 308) & 511)]) + fVec48[((IOTA - 422) & 511)])) + ((0.00311288796f * fVec48[((IOTA - 419) & 511)]) + ((0.00366222113f * fVec48[((IOTA - 418) & 511)]) + ((0.00299081393f * fVec48[((IOTA - 415) & 511)]) + ((0.00262459181f * (fVec48[((IOTA - 372) & 511)] + fVec48[((IOTA - 414) & 511)])) + ((0.00308236945f * fVec48[((IOTA - 427) & 511)]) + ((0.000244148076f * ((fVec48[((IOTA - 54) & 511)] + fVec48[((IOTA - 341) & 511)]) + fVec48[((IOTA - 407) & 511)])) + ((0.000335703604f * ((((fVec48[((IOTA - 261) & 511)] + fVec48[((IOTA - 293) & 511)]) + fVec48[((IOTA - 294) & 511)]) - fVec48[((IOTA - 299) & 511)]) - fVec48[((IOTA - 406) & 511)])) + ((6.10370189e-05f * ((((((((((((fVec48[((IOTA - 1) & 511)] + fVec48[((IOTA - 3) & 511)]) + fVec48[((IOTA - 4) & 511)]) + fVec48[((IOTA - 14) & 511)]) + fVec48[((IOTA - 17) & 511)]) + fVec48[((IOTA - 18) & 511)]) + fVec48[((IOTA - 20) & 511)]) + fVec48[((IOTA - 21) & 511)]) + fVec48[((IOTA - 23) & 511)]) + fVec48[((IOTA - 59) & 511)]) + fVec48[((IOTA - 322) & 511)]) + fVec48[((IOTA - 357) & 511)]) - fVec48[((IOTA - 404) & 511)])) + ((0.00411999878f * fVec48[((IOTA - 393) & 511)]) + ((0.00573747978f * fVec48[((IOTA - 391) & 511)]) + ((0.00479140598f * fVec48[((IOTA - 390) & 511)]) + ((9.15555283e-05f * (((((fVec48[((IOTA - 25) & 511)] + fVec48[((IOTA - 29) & 511)]) + fVec48[((IOTA - 30) & 511)]) - fVec48[((IOTA - 285) & 511)]) + fVec48[((IOTA - 300) & 511)]) + fVec48[((IOTA - 388) & 511)])) + ((0.000122074038f * (((((((fVec48[((IOTA - 32) & 511)] + fVec48[((IOTA - 48) & 511)]) + fVec48[((IOTA - 49) & 511)]) + fVec48[((IOTA - 50) & 511)]) + fVec48[((IOTA - 51) & 511)]) - fVec48[((IOTA - 260) & 511)]) - fVec48[((IOTA - 356) & 511)]) + fVec48[((IOTA - 383) & 511)])) + ((0.000183111057f * (((((((((((((((((fVec48[((IOTA - 28) & 511)] + fVec48[((IOTA - 37) & 511)]) + fVec48[((IOTA - 38) & 511)]) + fVec48[((IOTA - 39) & 511)]) + fVec48[((IOTA - 40) & 511)]) + fVec48[((IOTA - 41) & 511)]) + fVec48[((IOTA - 42) & 511)]) + fVec48[((IOTA - 43) & 511)]) + fVec48[((IOTA - 44) & 511)]) + fVec48[((IOTA - 45) & 511)]) + fVec48[((IOTA - 46) & 511)]) + fVec48[((IOTA - 53) & 511)]) + fVec48[((IOTA - 58) & 511)]) + fVec48[((IOTA - 286) & 511)]) + fVec48[((IOTA - 291) & 511)]) + fVec48[((IOTA - 320) & 511)]) - fVec48[((IOTA - 355) & 511)]) + fVec48[((IOTA - 382) & 511)])) + ((0.00408948027f * fVec48[((IOTA - 376) & 511)]) + ((0.00445570238f * fVec48[((IOTA - 375) & 511)]) + ((0.00436414685f * (fVec48[((IOTA - 68) & 511)] + fVec48[((IOTA - 374) & 511)])) + ((0.000152592547f * ((((((((((fVec48[((IOTA - 31) & 511)] + fVec48[((IOTA - 33) & 511)]) + fVec48[((IOTA - 34) & 511)]) + fVec48[((IOTA - 35) & 511)]) + fVec48[((IOTA - 36) & 511)]) + fVec48[((IOTA - 47) & 511)]) + fVec48[((IOTA - 52) & 511)]) - fVec48[((IOTA - 213) & 511)]) + fVec48[((IOTA - 281) & 511)]) + fVec48[((IOTA - 339) & 511)]) + fVec48[((IOTA - 371) & 511)])) + ((0.00347911008f * ((fVec48[((IOTA - 82) & 511)] + fVec48[((IOTA - 98) & 511)]) + fVec48[((IOTA - 363) & 511)])) + ((0.000396740623f * ((((fVec48[((IOTA - 57) & 511)] - fVec48[((IOTA - 255) & 511)]) - fVec48[((IOTA - 284) & 511)]) + fVec48[((IOTA - 328) & 511)]) - fVec48[((IOTA - 353) & 511)])) + ((0.000457777642f * ((((fVec48[((IOTA - 56) & 511)] + fVec48[((IOTA - 280) & 511)]) - fVec48[((IOTA - 296) & 511)]) + fVec48[((IOTA - 348) & 511)]) - fVec48[((IOTA - 352) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((fTemp49 + fVec48[((IOTA - 2) & 511)]) + fVec48[((IOTA - 5) & 511)]) + fVec48[((IOTA - 6) & 511)]) + fVec48[((IOTA - 7) & 511)]) + fVec48[((IOTA - 8) & 511)]) + fVec48[((IOTA - 9) & 511)]) + fVec48[((IOTA - 10) & 511)]) + fVec48[((IOTA - 11) & 511)]) + fVec48[((IOTA - 12) & 511)]) + fVec48[((IOTA - 13) & 511)]) + fVec48[((IOTA - 15) & 511)]) + fVec48[((IOTA - 16) & 511)]) + fVec48[((IOTA - 19) & 511)]) + fVec48[((IOTA - 22) & 511)]) + fVec48[((IOTA - 24) & 511)]) + fVec48[((IOTA - 26) & 511)]) + fVec48[((IOTA - 27) & 511)]) - fVec48[((IOTA - 272) & 511)]) + fVec48[((IOTA - 273) & 511)]) - fVec48[((IOTA - 295) & 511)]) + fVec48[((IOTA - 321) & 511)]) - fVec48[((IOTA - 340) & 511)]) - fVec48[((IOTA - 350) & 511)])) + ((0.000213629566f * ((((fVec48[((IOTA - 200) & 511)] - fVec48[((IOTA - 215) & 511)]) + fVec48[((IOTA - 274) & 511)]) + fVec48[((IOTA - 292) & 511)]) + fVec48[((IOTA - 349) & 511)])) + ((0.000366222113f * (((((((fVec48[((IOTA - 55) & 511)] - fVec48[((IOTA - 60) & 511)]) - fVec48[((IOTA - 66) & 511)]) + fVec48[((IOTA - 91) & 511)]) - fVec48[((IOTA - 212) & 511)]) + fVec48[((IOTA - 278) & 511)]) + fVec48[((IOTA - 287) & 511)]) + fVec48[((IOTA - 290) & 511)])) + ((0.000305185094f * ((fVec48[((IOTA - 275) & 511)] + fVec48[((IOTA - 276) & 511)]) + fVec48[((IOTA - 277) & 511)])) + ((0.00875881221f * (fVec48[((IOTA - 123) & 511)] - fVec48[((IOTA - 185) & 511)])) + ((0.00729392376f * (fVec48[((IOTA - 89) & 511)] - fVec48[((IOTA - 183) & 511)])) + ((0.0134586627f * fVec48[((IOTA - 125) & 511)]) + ((0.0173955504f * fVec48[((IOTA - 124) & 511)]) + ((0.00329599902f * fVec48[((IOTA - 113) & 511)]) + ((0.0141300699f * fVec48[((IOTA - 112) & 511)]) + ((0.0155034028f * fVec48[((IOTA - 111) & 511)]) + ((0.0121463668f * fVec48[((IOTA - 108) & 511)]) + ((0.0133671071f * fVec48[((IOTA - 107) & 511)]) + ((0.00488296151f * fVec48[((IOTA - 106) & 511)]) + ((0.00335703604f * fVec48[((IOTA - 102) & 511)]) + ((0.025818659f * fVec48[((IOTA - 97) & 511)]) + ((0.0342417695f * fVec48[((IOTA - 96) & 511)]) + ((0.027680289f * fVec48[((IOTA - 95) & 511)]) + ((0.0256355479f * fVec48[((IOTA - 90) & 511)]) + ((0.00845362712f * fVec48[((IOTA - 83) & 511)]) + ((0.0538041331f * fVec48[((IOTA - 78) & 511)]) + ((0.145390183f * fVec48[((IOTA - 77) & 511)]) + ((0.0673543513f * fVec48[((IOTA - 76) & 511)]) + ((0.281014442f * fVec48[((IOTA - 72) & 511)]) + ((0.326456487f * fVec48[((IOTA - 71) & 511)]) + ((0.16101566f * fVec48[((IOTA - 70) & 511)]) + ((0.00402844325f * fVec48[((IOTA - 67) & 511)]) + (0.0329599902f * fVec48[((IOTA - 69) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000823999755f * (((fVec48[((IOTA - 313) & 511)] + fVec48[((IOTA - 327) & 511)]) + fVec48[((IOTA - 337) & 511)]) + fVec48[((IOTA - 510) & 511)]))) + (0.000854518265f * ((fVec48[((IOTA - 509) & 511)] - (((fVec48[((IOTA - 223) & 511)] - fVec48[((IOTA - 332) & 511)]) - fVec48[((IOTA - 501) & 511)]) - fVec48[((IOTA - 504) & 511)])) + fVec48[((IOTA - 511) & 511)])))) : (((0.000732444227f * (((fVec47[((IOTA - 310) & 511)] - (((fVec47[((IOTA - 240) & 511)] - fVec47[((IOTA - 246) & 511)]) - fVec47[((IOTA - 261) & 511)]) - fVec47[((IOTA - 299) & 511)])) - fVec47[((IOTA - 495) & 511)]) - fVec47[((IOTA - 511) & 511)])) + ((0.000946073793f * (((fVec47[((IOTA - 308) & 511)] + fVec47[((IOTA - 316) & 511)]) + fVec47[((IOTA - 345) & 511)]) - fVec47[((IOTA - 510) & 511)])) + ((0.00109866634f * (((((fVec47[((IOTA - 247) & 511)] + fVec47[((IOTA - 322) & 511)]) + fVec47[((IOTA - 323) & 511)]) + fVec47[((IOTA - 344) & 511)]) - fVec47[((IOTA - 490) & 511)]) - fVec47[((IOTA - 509) & 511)])) + ((0.00134281442f * (((fVec47[((IOTA - 347) & 511)] + fVec47[((IOTA - 441) & 511)]) - fVec47[((IOTA - 506) & 511)]) - fVec47[((IOTA - 507) & 511)])) + ((0.00103762932f * ((((fVec47[((IOTA - 163) & 511)] + fVec47[((IOTA - 221) & 511)]) + fVec47[((IOTA - 418) & 511)]) + fVec47[((IOTA - 440) & 511)]) - fVec47[((IOTA - 504) & 511)])) + ((0.000793481246f * ((((fVec47[((IOTA - 275) & 511)] + fVec47[((IOTA - 279) & 511)]) + fVec47[((IOTA - 305) & 511)]) + fVec47[((IOTA - 374) & 511)]) - fVec47[((IOTA - 503) & 511)])) + ((3.05185094e-05f * ((((((((((((((((((((((((((((((((((((((((fTemp48 + fVec47[((IOTA - 1) & 511)]) + fVec47[((IOTA - 2) & 511)]) + fVec47[((IOTA - 6) & 511)]) + fVec47[((IOTA - 7) & 511)]) + fVec47[((IOTA - 8) & 511)]) + fVec47[((IOTA - 9) & 511)]) + fVec47[((IOTA - 10) & 511)]) + fVec47[((IOTA - 11) & 511)]) + fVec47[((IOTA - 12) & 511)]) + fVec47[((IOTA - 13) & 511)]) + fVec47[((IOTA - 14) & 511)]) + fVec47[((IOTA - 15) & 511)]) + fVec47[((IOTA - 16) & 511)]) + fVec47[((IOTA - 17) & 511)]) + fVec47[((IOTA - 18) & 511)]) + fVec47[((IOTA - 19) & 511)]) + fVec47[((IOTA - 20) & 511)]) + fVec47[((IOTA - 21) & 511)]) + fVec47[((IOTA - 22) & 511)]) + fVec47[((IOTA - 23) & 511)]) + fVec47[((IOTA - 24) & 511)]) + fVec47[((IOTA - 25) & 511)]) - fVec47[((IOTA - 26) & 511)]) + fVec47[((IOTA - 37) & 511)]) + fVec47[((IOTA - 38) & 511)]) + fVec47[((IOTA - 45) & 511)]) + fVec47[((IOTA - 46) & 511)]) + fVec47[((IOTA - 47) & 511)]) + fVec47[((IOTA - 53) & 511)]) + fVec47[((IOTA - 54) & 511)]) + fVec47[((IOTA - 55) & 511)]) + fVec47[((IOTA - 56) & 511)]) + fVec47[((IOTA - 62) & 511)]) - fVec47[((IOTA - 174) & 511)]) - fVec47[((IOTA - 204) & 511)]) - fVec47[((IOTA - 230) & 511)]) - fVec47[((IOTA - 292) & 511)]) + fVec47[((IOTA - 380) & 511)]) - fVec47[((IOTA - 467) & 511)]) + fVec47[((IOTA - 499) & 511)])) + ((9.15555283e-05f * (((((fVec47[((IOTA - 58) & 511)] + fVec47[((IOTA - 286) & 511)]) - fVec47[((IOTA - 376) & 511)]) - fVec47[((IOTA - 462) & 511)]) - fVec47[((IOTA - 475) & 511)]) - fVec47[((IOTA - 497) & 511)])) + ((0.00106814783f * (((fVec47[((IOTA - 248) & 511)] + fVec47[((IOTA - 346) & 511)]) + fVec47[((IOTA - 390) & 511)]) - fVec47[((IOTA - 494) & 511)])) + ((0.00131229591f * ((((fVec47[((IOTA - 70) & 511)] + fVec47[((IOTA - 162) & 511)]) + fVec47[((IOTA - 399) & 511)]) + fVec47[((IOTA - 405) & 511)]) - fVec47[((IOTA - 492) & 511)])) + ((0.00122074038f * (((fVec47[((IOTA - 210) & 511)] + fVec47[((IOTA - 262) & 511)]) + fVec47[((IOTA - 415) & 511)]) - fVec47[((IOTA - 491) & 511)])) + ((0.00100711081f * ((fVec47[((IOTA - 307) & 511)] + fVec47[((IOTA - 434) & 511)]) - fVec47[((IOTA - 489) & 511)])) + ((0.000854518265f * (((fVec47[((IOTA - 309) & 511)] + fVec47[((IOTA - 437) & 511)]) + fVec47[((IOTA - 438) & 511)]) - fVec47[((IOTA - 488) & 511)])) + ((0.000183111057f * ((((((((fVec47[((IOTA - 59) & 511)] + fVec47[((IOTA - 61) & 511)]) - fVec47[((IOTA - 208) & 511)]) + fVec47[((IOTA - 233) & 511)]) - fVec47[((IOTA - 243) & 511)]) + fVec47[((IOTA - 258) & 511)]) + fVec47[((IOTA - 259) & 511)]) - fVec47[((IOTA - 464) & 511)]) + fVec47[((IOTA - 485) & 511)])) + ((0.000488296151f * (((((((fVec47[((IOTA - 118) & 511)] + fVec47[((IOTA - 224) & 511)]) + fVec47[((IOTA - 250) & 511)]) + fVec47[((IOTA - 273) & 511)]) + fVec47[((IOTA - 288) & 511)]) + fVec47[((IOTA - 315) & 511)]) - fVec47[((IOTA - 359) & 511)]) + fVec47[((IOTA - 484) & 511)])) + ((0.000396740623f * ((fVec47[((IOTA - 232) & 511)] - fVec47[((IOTA - 237) & 511)]) + fVec47[((IOTA - 482) & 511)])) + ((0.00057985168f * (((((fVec47[((IOTA - 266) & 511)] + fVec47[((IOTA - 271) & 511)]) + fVec47[((IOTA - 289) & 511)]) + fVec47[((IOTA - 296) & 511)]) + fVec47[((IOTA - 311) & 511)]) - fVec47[((IOTA - 478) & 511)])) + ((0.00186162908f * fVec47[((IOTA - 471) & 511)]) + ((0.00155644398f * ((fVec47[((IOTA - 401) & 511)] + fVec47[((IOTA - 414) & 511)]) + fVec47[((IOTA - 470) & 511)])) + ((0.000976592302f * (((((fVec47[((IOTA - 306) & 511)] + fVec47[((IOTA - 416) & 511)]) + fVec47[((IOTA - 432) & 511)]) + fVec47[((IOTA - 433) & 511)]) + fVec47[((IOTA - 435) & 511)]) + fVec47[((IOTA - 469) & 511)])) + ((0.000213629566f * (((((fVec47[((IOTA - 60) & 511)] - fVec47[((IOTA - 133) & 511)]) - fVec47[((IOTA - 228) & 511)]) + fVec47[((IOTA - 257) & 511)]) - fVec47[((IOTA - 465) & 511)]) - fVec47[((IOTA - 466) & 511)])) + ((0.00112918485f * (fVec47[((IOTA - 431) & 511)] + fVec47[((IOTA - 459) & 511)])) + ((0.00170903653f * (fVec47[((IOTA - 212) & 511)] + fVec47[((IOTA - 458) & 511)])) + ((0.00216681417f * (fVec47[((IOTA - 335) & 511)] + fVec47[((IOTA - 456) & 511)])) + ((0.00183111057f * (fVec47[((IOTA - 407) & 511)] + fVec47[((IOTA - 454) & 511)])) + ((0.00146488845f * ((fVec47[((IOTA - 173) & 511)] + fVec47[((IOTA - 406) & 511)]) + fVec47[((IOTA - 453) & 511)])) + ((0.00189214759f * (fVec47[((IOTA - 442) & 511)] - fVec47[((IOTA - 450) & 511)])) + ((0.00256355479f * (fVec47[((IOTA - 421) & 511)] - fVec47[((IOTA - 449) & 511)])) + ((0.00115970336f * fVec47[((IOTA - 446) & 511)]) + ((0.00244148076f * (fVec47[((IOTA - 394) & 511)] + fVec47[((IOTA - 445) & 511)])) + ((0.00247199927f * fVec47[((IOTA - 443) & 511)]) + ((0.000915555283f * ((((((fVec47[((IOTA - 265) & 511)] + fVec47[((IOTA - 276) & 511)]) + fVec47[((IOTA - 277) & 511)]) + fVec47[((IOTA - 298) & 511)]) + fVec47[((IOTA - 417) & 511)]) + fVec47[((IOTA - 436) & 511)]) + fVec47[((IOTA - 439) & 511)])) + ((0.00180059206f * ((fVec47[((IOTA - 217) & 511)] + fVec47[((IOTA - 328) & 511)]) + fVec47[((IOTA - 429) & 511)])) + ((0.00213629566f * ((fVec47[((IOTA - 370) & 511)] + fVec47[((IOTA - 393) & 511)]) + fVec47[((IOTA - 428) & 511)])) + ((0.00234992523f * ((fVec47[((IOTA - 395) & 511)] + fVec47[((IOTA - 408) & 511)]) + fVec47[((IOTA - 427) & 511)])) + ((0.00250251777f * (fVec47[((IOTA - 387) & 511)] + fVec47[((IOTA - 425) & 511)])) + ((0.00265511032f * ((fVec47[((IOTA - 218) & 511)] + fVec47[((IOTA - 219) & 511)]) + fVec47[((IOTA - 424) & 511)])) + ((0.00286873989f * fVec47[((IOTA - 423) & 511)]) + ((0.00201422162f * ((fVec47[((IOTA - 165) & 511)] - fVec47[((IOTA - 378) & 511)]) + fVec47[((IOTA - 420) & 511)])) + ((0.00238044374f * fVec47[((IOTA - 412) & 511)]) + ((0.00274666585f * ((fVec47[((IOTA - 357) & 511)] + fVec47[((IOTA - 409) & 511)]) + fVec47[((IOTA - 411) & 511)])) + ((0.00292977691f * fVec47[((IOTA - 410) & 511)]) + ((0.00152592547f * (((fVec47[((IOTA - 343) & 511)] - fVec47[((IOTA - 379) & 511)]) + fVec47[((IOTA - 388) & 511)]) + fVec47[((IOTA - 403) & 511)])) + ((0.000335703604f * (((((((fVec47[((IOTA - 223) & 511)] - fVec47[((IOTA - 235) & 511)]) + fVec47[((IOTA - 251) & 511)]) + fVec47[((IOTA - 253) & 511)]) + fVec47[((IOTA - 256) & 511)]) + fVec47[((IOTA - 260) & 511)]) + fVec47[((IOTA - 267) & 511)]) - fVec47[((IOTA - 501) & 511)])) + ((0.00149540696f * (fVec47[((IOTA - 320) & 511)] + fVec47[((IOTA - 400) & 511)])) + ((0.0019226661f * (((((fVec47[((IOTA - 211) & 511)] + fVec47[((IOTA - 220) & 511)]) + fVec47[((IOTA - 336) & 511)]) + fVec47[((IOTA - 339) & 511)]) + fVec47[((IOTA - 350) & 511)]) + fVec47[((IOTA - 396) & 511)])) + ((0.001617481f * (((((fVec47[((IOTA - 172) & 511)] + fVec47[((IOTA - 318) & 511)]) + fVec47[((IOTA - 319) & 511)]) + fVec47[((IOTA - 327) & 511)]) + fVec47[((IOTA - 348) & 511)]) + fVec47[((IOTA - 392) & 511)])) + ((0.00119022187f * fVec47[((IOTA - 389) & 511)]) + ((0.00384533219f * (fVec47[((IOTA - 356) & 511)] + fVec47[((IOTA - 386) & 511)])) + ((0.00540177617f * (fVec47[((IOTA - 367) & 511)] + fVec47[((IOTA - 385) & 511)])) + ((0.00158696249f * fVec47[((IOTA - 402) & 511)]) + ((0.00137333293f * (fVec47[((IOTA - 324) & 511)] - fVec47[((IOTA - 377) & 511)])) + ((0.000762962736f * (fVec47[((IOTA - 249) & 511)] + fVec47[((IOTA - 375) & 511)])) + ((0.000244148076f * (fVec47[((IOTA - 287) & 511)] + fVec47[((IOTA - 372) & 511)])) + ((0.000823999755f * (fVec47[((IOTA - 297) & 511)] + fVec47[((IOTA - 371) & 511)])) + ((0.00631733146f * fVec47[((IOTA - 384) & 511)]) + ((0.00494399853f * fVec47[((IOTA - 368) & 511)]) + ((0.00497451704f * fVec47[((IOTA - 366) & 511)]) + ((0.00378429517f * fVec47[((IOTA - 365) & 511)]) + ((0.00219733268f * (fVec47[((IOTA - 340) & 511)] - fVec47[((IOTA - 360) & 511)])) + ((0.00430310983f * fVec47[((IOTA - 355) & 511)]) + ((0.00360118411f * fVec47[((IOTA - 353) & 511)]) + ((0.0028992584f * fVec47[((IOTA - 352) & 511)]) + ((0.00198370311f * fVec47[((IOTA - 342) & 511)]) + ((0.00167851802f * ((fVec47[((IOTA - 325) & 511)] + fVec47[((IOTA - 326) & 511)]) + fVec47[((IOTA - 338) & 511)])) + ((0.00622577593f * fVec47[((IOTA - 383) & 511)]) + ((0.00210577715f * fVec47[((IOTA - 329) & 511)]) + ((0.000427259132f * (((fVec47[((IOTA - 222) & 511)] + fVec47[((IOTA - 255) & 511)]) + fVec47[((IOTA - 300) & 511)]) + fVec47[((IOTA - 304) & 511)])) + ((0.000457777642f * (((((((fVec47[((IOTA - 213) & 511)] + fVec47[((IOTA - 216) & 511)]) - fVec47[((IOTA - 242) & 511)]) + fVec47[((IOTA - 254) & 511)]) + fVec47[((IOTA - 269) & 511)]) + fVec47[((IOTA - 272) & 511)]) + fVec47[((IOTA - 283) & 511)]) + fVec47[((IOTA - 290) & 511)])) + ((0.000305185094f * (((fVec47[((IOTA - 203) & 511)] + fVec47[((IOTA - 209) & 511)]) - fVec47[((IOTA - 229) & 511)]) + fVec47[((IOTA - 252) & 511)])) + ((0.00436414685f * (fVec47[((IOTA - 117) & 511)] - fVec47[((IOTA - 169) & 511)])) + ((0.00457777642f * fVec47[((IOTA - 144) & 511)]) + ((0.00830103457f * fVec47[((IOTA - 143) & 511)]) + ((0.00888088625f * fVec47[((IOTA - 142) & 511)]) + ((0.00512710959f * fVec47[((IOTA - 141) & 511)]) + ((0.00772118289f * fVec47[((IOTA - 132) & 511)]) + ((0.0116275521f * fVec47[((IOTA - 131) & 511)]) + ((0.0100711081f * fVec47[((IOTA - 130) & 511)]) + ((0.0025940733f * (fVec47[((IOTA - 93) & 511)] + fVec47[((IOTA - 129) & 511)])) + ((0.0170903653f * (fVec47[((IOTA - 103) & 511)] - fVec47[((IOTA - 120) & 511)])) + ((0.00686666463f * fVec47[((IOTA - 116) & 511)]) + ((0.0137028107f * fVec47[((IOTA - 114) & 511)]) + ((0.0193792544f * fVec47[((IOTA - 113) & 511)]) + ((0.0200811792f * fVec47[((IOTA - 112) & 511)]) + ((0.0124210333f * fVec47[((IOTA - 111) & 511)]) + ((0.0395825058f * fVec47[((IOTA - 102) & 511)]) + ((0.0383007303f * fVec47[((IOTA - 101) & 511)]) + ((0.0166631062f * fVec47[((IOTA - 95) & 511)]) + ((0.0176091809f * fVec47[((IOTA - 94) & 511)]) + ((0.00973540451f * fVec47[((IOTA - 85) & 511)]) + ((0.0504165776f * fVec47[((IOTA - 84) & 511)]) + ((0.0775475353f * fVec47[((IOTA - 83) & 511)]) + ((0.055482652f * fVec47[((IOTA - 82) & 511)]) + ((0.0111697745f * fVec47[((IOTA - 100) & 511)]) + ((0.0379345082f * fVec47[((IOTA - 77) & 511)]) + ((0.231788084f * fVec47[((IOTA - 76) & 511)]) + ((0.28733176f * fVec47[((IOTA - 75) & 511)]) + ((0.199682608f * fVec47[((IOTA - 74) & 511)]) + ((0.0815454572f * fVec47[((IOTA - 73) & 511)]) + ((0.00717184972f * fVec47[((IOTA - 71) & 511)]) + (0.0213934761f * fVec47[((IOTA - 72) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00054933317f * (((((fVec47[((IOTA - 238) & 511)] - fVec47[((IOTA - 282) & 511)]) + fVec47[((IOTA - 451) & 511)]) - fVec47[((IOTA - 460) & 511)]) - fVec47[((IOTA - 483) & 511)]) + fVec47[((IOTA - 502) & 511)])) + ((0.000122074038f * ((((((((fVec47[((IOTA - 207) & 511)] + fVec47[((IOTA - 234) & 511)]) - fVec47[((IOTA - 285) & 511)]) - fVec47[((IOTA - 301) & 511)]) - fVec47[((IOTA - 314) & 511)]) - fVec47[((IOTA - 461) & 511)]) + fVec47[((IOTA - 480) & 511)]) - fVec47[((IOTA - 481) & 511)]) + fVec47[((IOTA - 500) & 511)])) + ((6.10370189e-05f * (((((((((((fVec47[((IOTA - 27) & 511)] - fVec47[((IOTA - 48) & 511)]) - fVec47[((IOTA - 49) & 511)]) - fVec47[((IOTA - 50) & 511)]) - fVec47[((IOTA - 51) & 511)]) - fVec47[((IOTA - 52) & 511)]) - fVec47[((IOTA - 57) & 511)]) + fVec47[((IOTA - 171) & 511)]) + fVec47[((IOTA - 293) & 511)]) - fVec47[((IOTA - 303) & 511)]) - fVec47[((IOTA - 313) & 511)]) - fVec47[((IOTA - 498) & 511)])) + ((0.000366222113f * (((((fVec47[((IOTA - 236) & 511)] - fVec47[((IOTA - 295) & 511)]) - fVec47[((IOTA - 373) & 511)]) - fVec47[((IOTA - 468) & 511)]) + fVec47[((IOTA - 479) & 511)]) + fVec47[((IOTA - 496) & 511)])) + ((0.0012817774f * fVec47[((IOTA - 493) & 511)]) + ((0.000640888698f * ((fVec47[((IOTA - 214) & 511)] - fVec47[((IOTA - 225) & 511)]) + fVec47[((IOTA - 487) & 511)])) + ((0.000274666585f * ((((((fVec47[((IOTA - 63) & 511)] - fVec47[((IOTA - 231) & 511)]) - fVec47[((IOTA - 245) & 511)]) - fVec47[((IOTA - 268) & 511)]) - fVec47[((IOTA - 284) & 511)]) - fVec47[((IOTA - 312) & 511)]) + fVec47[((IOTA - 486) & 511)])) + ((0.000671407208f * ((((fVec47[((IOTA - 239) & 511)] + fVec47[((IOTA - 241) & 511)]) - fVec47[((IOTA - 274) & 511)]) + fVec47[((IOTA - 363) & 511)]) + fVec47[((IOTA - 477) & 511)])) + ((0.000518814661f * ((((fVec47[((IOTA - 110) & 511)] + fVec47[((IOTA - 145) & 511)]) - fVec47[((IOTA - 226) & 511)]) - fVec47[((IOTA - 474) & 511)]) + fVec47[((IOTA - 476) & 511)])) + ((0.00173955504f * ((((fVec47[((IOTA - 175) & 511)] - fVec47[((IOTA - 337) & 511)]) - fVec47[((IOTA - 349) & 511)]) - fVec47[((IOTA - 364) & 511)]) - fVec47[((IOTA - 472) & 511)])) + ((0.000152592547f * (((((fVec47[((IOTA - 205) & 511)] + fVec47[((IOTA - 206) & 511)]) - fVec47[((IOTA - 227) & 511)]) - fVec47[((IOTA - 291) & 511)]) - fVec47[((IOTA - 294) & 511)]) + fVec47[((IOTA - 463) & 511)])) + ((0.00207525864f * (fVec47[((IOTA - 448) & 511)] - fVec47[((IOTA - 457) & 511)])) + ((0.00204474013f * (fVec47[((IOTA - 191) & 511)] - fVec47[((IOTA - 455) & 511)])) + ((0.000701925717f * ((fVec47[((IOTA - 215) & 511)] - fVec47[((IOTA - 280) & 511)]) - fVec47[((IOTA - 452) & 511)])) + ((0.000610370189f * (((fVec47[((IOTA - 161) & 511)] - fVec47[((IOTA - 270) & 511)]) - fVec47[((IOTA - 281) & 511)]) + fVec47[((IOTA - 447) & 511)])) + ((0.00283822138f * ((fVec47[((IOTA - 186) & 511)] - fVec47[((IOTA - 422) & 511)]) - fVec47[((IOTA - 444) & 511)])) + ((0.00143436994f * (((fVec47[((IOTA - 64) & 511)] - fVec47[((IOTA - 397) & 511)]) - fVec47[((IOTA - 419) & 511)]) - fVec47[((IOTA - 430) & 511)])) + ((0.00241096225f * (fVec47[((IOTA - 187) & 511)] - fVec47[((IOTA - 426) & 511)])) + ((0.0019531846f * (fVec47[((IOTA - 167) & 511)] - fVec47[((IOTA - 413) & 511)])) + ((0.00140385143f * ((((fVec47[((IOTA - 156) & 511)] - fVec47[((IOTA - 164) & 511)]) - fVec47[((IOTA - 263) & 511)]) - fVec47[((IOTA - 317) & 511)]) - fVec47[((IOTA - 404) & 511)])) + ((0.00463881344f * (fVec47[((IOTA - 198) & 511)] - fVec47[((IOTA - 382) & 511)])) + ((0.00228888821f * ((((fVec47[((IOTA - 189) & 511)] + fVec47[((IOTA - 192) & 511)]) - fVec47[((IOTA - 332) & 511)]) - fVec47[((IOTA - 333) & 511)]) - fVec47[((IOTA - 381) & 511)])) + ((0.00369273964f * (fVec47[((IOTA - 194) & 511)] - fVec47[((IOTA - 369) & 511)])) + ((0.00262459181f * fVec47[((IOTA - 362) & 511)]) + ((0.00311288796f * fVec47[((IOTA - 361) & 511)]) + ((0.00415051728f * (fVec47[((IOTA - 184) & 511)] - fVec47[((IOTA - 354) & 511)])) + ((0.0022583697f * (((fVec47[((IOTA - 190) & 511)] - fVec47[((IOTA - 334) & 511)]) - fVec47[((IOTA - 341) & 511)]) - fVec47[((IOTA - 351) & 511)])) + ((0.00231940672f * ((fVec47[((IOTA - 140) & 511)] - fVec47[((IOTA - 330) & 511)]) - fVec47[((IOTA - 331) & 511)])) + ((0.000885036774f * ((fVec47[((IOTA - 155) & 511)] - fVec47[((IOTA - 166) & 511)]) - fVec47[((IOTA - 278) & 511)])) + ((0.00299081393f * fVec47[((IOTA - 200) & 511)]) + ((0.00418103579f * fVec47[((IOTA - 199) & 511)]) + ((0.00454725791f * fVec47[((IOTA - 197) & 511)]) + ((0.00427259132f * fVec47[((IOTA - 196) & 511)]) + ((0.00408948027f * fVec47[((IOTA - 195) & 511)]) + ((0.00308236945f * fVec47[((IOTA - 193) & 511)]) + ((0.00222785119f * (fVec47[((IOTA - 154) & 511)] + fVec47[((IOTA - 188) & 511)])) + ((0.00338755455f * fVec47[((IOTA - 185) & 511)]) + ((0.00518814661f * fVec47[((IOTA - 183) & 511)]) + ((0.00506607257f * fVec47[((IOTA - 182) & 511)]) + ((0.004852443f * (fVec47[((IOTA - 146) & 511)] + fVec47[((IOTA - 181) & 511)])) + ((0.00531022064f * (fVec47[((IOTA - 69) & 511)] + fVec47[((IOTA - 180) & 511)])) + ((0.00665303506f * fVec47[((IOTA - 179) & 511)]) + ((0.00750755332f * (fVec47[((IOTA - 119) & 511)] + fVec47[((IOTA - 178) & 511)])) + ((0.00650044251f * fVec47[((IOTA - 177) & 511)]) + ((0.00411999878f * fVec47[((IOTA - 176) & 511)]) + ((0.00280770287f * fVec47[((IOTA - 170) & 511)]) + ((0.00433362834f * fVec47[((IOTA - 168) & 511)]) + ((0.00439466536f * fVec47[((IOTA - 160) & 511)]) + ((0.0071108127f * fVec47[((IOTA - 159) & 511)]) + ((0.00625629444f * fVec47[((IOTA - 158) & 511)]) + ((0.0035401471f * fVec47[((IOTA - 157) & 511)]) + ((0.00524918362f * fVec47[((IOTA - 153) & 511)]) + ((0.00866725668f * fVec47[((IOTA - 152) & 511)]) + ((0.0108951079f * fVec47[((IOTA - 151) & 511)]) + ((0.0115970336f * fVec47[((IOTA - 150) & 511)]) + ((0.01126133f * fVec47[((IOTA - 149) & 511)]) + ((0.011322367f * fVec47[((IOTA - 139) & 511)]) + ((0.0184636991f * fVec47[((IOTA - 138) & 511)]) + ((0.0219428092f * fVec47[((IOTA - 137) & 511)]) + ((0.0215155501f * fVec47[((IOTA - 136) & 511)]) + ((0.0172429588f * fVec47[((IOTA - 135) & 511)]) + ((0.00949125644f * fVec47[((IOTA - 134) & 511)]) + ((0.00805688649f * fVec47[((IOTA - 147) & 511)]) + ((0.00784325693f * fVec47[((IOTA - 128) & 511)]) + ((0.0169377737f * fVec47[((IOTA - 127) & 511)]) + ((0.0208746605f * fVec47[((IOTA - 126) & 511)]) + ((0.0221259203f * fVec47[((IOTA - 125) & 511)]) + ((0.0226142164f * fVec47[((IOTA - 124) & 511)]) + ((0.0252388082f * fVec47[((IOTA - 123) & 511)]) + ((0.0269783624f * fVec47[((IOTA - 122) & 511)]) + ((0.0255134739f * fVec47[((IOTA - 121) & 511)]) + ((0.0093691824f * (fVec47[((IOTA - 68) & 511)] - fVec47[((IOTA - 115) & 511)])) + ((0.0101016266f * fVec47[((IOTA - 148) & 511)]) + ((0.0117496261f * fVec47[((IOTA - 109) & 511)]) + ((0.0169682913f * fVec47[((IOTA - 108) & 511)]) + ((0.0209967345f * fVec47[((IOTA - 107) & 511)]) + ((0.0220038462f * fVec47[((IOTA - 106) & 511)]) + ((0.0215460677f * fVec47[((IOTA - 105) & 511)]) + ((0.008087405f * fVec47[((IOTA - 104) & 511)]) + ((0.0226752535f * fVec47[((IOTA - 99) & 511)]) + ((0.0492263548f * fVec47[((IOTA - 98) & 511)]) + ((0.0419629514f * fVec47[((IOTA - 97) & 511)]) + ((0.0164494775f * fVec47[((IOTA - 96) & 511)]) + ((0.0235908087f * fVec47[((IOTA - 92) & 511)]) + ((0.033722952f * fVec47[((IOTA - 91) & 511)]) + ((0.0287484359f * fVec47[((IOTA - 90) & 511)]) + ((0.0211798456f * fVec47[((IOTA - 89) & 511)]) + ((0.0205084383f * fVec47[((IOTA - 88) & 511)]) + ((0.0209356975f * fVec47[((IOTA - 87) & 511)]) + ((0.00976592302f * (fVec47[((IOTA - 67) & 511)] + fVec47[((IOTA - 86) & 511)])) + ((0.0427869521f * fVec47[((IOTA - 81) & 511)]) + ((0.16861476f * fVec47[((IOTA - 80) & 511)]) + ((0.235572368f * fVec47[((IOTA - 79) & 511)]) + ((0.164616838f * fVec47[((IOTA - 78) & 511)]) + ((0.00402844325f * fVec47[((IOTA - 65) & 511)]) + (0.00735496078f * fVec47[((IOTA - 66) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00125125889f * ((((((((fVec47[((IOTA - 201) & 511)] - fVec47[((IOTA - 264) & 511)]) - fVec47[((IOTA - 321) & 511)]) - fVec47[((IOTA - 358) & 511)]) - fVec47[((IOTA - 391) & 511)]) - fVec47[((IOTA - 398) & 511)]) - fVec47[((IOTA - 473) & 511)]) + fVec47[((IOTA - 505) & 511)]) + fVec47[((IOTA - 508) & 511)]))))) : (iSlow107 ? (((0.000244148076f * (((((((fVec46[((IOTA - 167) & 511)] + fVec46[((IOTA - 232) & 511)]) - fVec46[((IOTA - 283) & 511)]) - fVec46[((IOTA - 287) & 511)]) - fVec46[((IOTA - 291) & 511)]) + fVec46[((IOTA - 417) & 511)]) - fVec46[((IOTA - 466) & 511)]) + fVec46[((IOTA - 499) & 511)])) + ((6.10370189e-05f * (((((((((fVec46[((IOTA - 168) & 511)] + fVec46[((IOTA - 202) & 511)]) - fVec46[((IOTA - 219) & 511)]) + fVec46[((IOTA - 245) & 511)]) + fVec46[((IOTA - 364) & 511)]) - fVec46[((IOTA - 418) & 511)]) + fVec46[((IOTA - 476) & 511)]) + fVec46[((IOTA - 477) & 511)]) + fVec46[((IOTA - 483) & 511)]) + fVec46[((IOTA - 491) & 511)])) + ((0.000518814661f * (((((((((fVec46[((IOTA - 237) & 511)] + fVec46[((IOTA - 240) & 511)]) + fVec46[((IOTA - 241) & 511)]) - fVec46[((IOTA - 272) & 511)]) + fVec46[((IOTA - 312) & 511)]) - fVec46[((IOTA - 368) & 511)]) + fVec46[((IOTA - 429) & 511)]) + fVec46[((IOTA - 448) & 511)]) - fVec46[((IOTA - 469) & 511)]) - fVec46[((IOTA - 470) & 511)])) + ((0.000793481246f * ((fVec46[((IOTA - 392) & 511)] - (fVec46[((IOTA - 126) & 511)] + fVec46[((IOTA - 270) & 511)])) + fVec46[((IOTA - 457) & 511)])) + ((0.00057985168f * ((((((fVec46[((IOTA - 159) & 511)] + fVec46[((IOTA - 162) & 511)]) - fVec46[((IOTA - 173) & 511)]) + fVec46[((IOTA - 201) & 511)]) - fVec46[((IOTA - 279) & 511)]) + fVec46[((IOTA - 311) & 511)]) + fVec46[((IOTA - 452) & 511)])) + ((0.000457777642f * (((((((((((fVec46[((IOTA - 163) & 511)] + fVec46[((IOTA - 191) & 511)]) + fVec46[((IOTA - 221) & 511)]) + fVec46[((IOTA - 239) & 511)]) + fVec46[((IOTA - 253) & 511)]) - fVec46[((IOTA - 282) & 511)]) + fVec46[((IOTA - 295) & 511)]) + fVec46[((IOTA - 362) & 511)]) - fVec46[((IOTA - 374) & 511)]) - fVec46[((IOTA - 394) & 511)]) + fVec46[((IOTA - 449) & 511)]) + fVec46[((IOTA - 450) & 511)])) + ((0.000671407208f * ((((((((fVec46[((IOTA - 161) & 511)] + fVec46[((IOTA - 179) & 511)]) - fVec46[((IOTA - 204) & 511)]) - fVec46[((IOTA - 218) & 511)]) + fVec46[((IOTA - 309) & 511)]) - fVec46[((IOTA - 380) & 511)]) - fVec46[((IOTA - 420) & 511)]) + fVec46[((IOTA - 431) & 511)]) + fVec46[((IOTA - 447) & 511)])) + ((0.000610370189f * (((((((fVec46[((IOTA - 233) & 511)] - fVec46[((IOTA - 281) & 511)]) + fVec46[((IOTA - 296) & 511)]) + fVec46[((IOTA - 297) & 511)]) - fVec46[((IOTA - 352) & 511)]) + fVec46[((IOTA - 361) & 511)]) + fVec46[((IOTA - 375) & 511)]) + fVec46[((IOTA - 441) & 511)])) + ((0.000976592302f * (((fVec46[((IOTA - 408) & 511)] + fVec46[((IOTA - 411) & 511)]) + fVec46[((IOTA - 412) & 511)]) - fVec46[((IOTA - 438) & 511)])) + ((0.00134281442f * (fVec46[((IOTA - 180) & 511)] - fVec46[((IOTA - 437) & 511)])) + ((0.00137333293f * ((fVec46[((IOTA - 108) & 511)] - fVec46[((IOTA - 215) & 511)]) - fVec46[((IOTA - 436) & 511)])) + ((0.000366222113f * ((((((((((fVec46[((IOTA - 164) & 511)] + fVec46[((IOTA - 194) & 511)]) + fVec46[((IOTA - 250) & 511)]) - fVec46[((IOTA - 259) & 511)]) - fVec46[((IOTA - 260) & 511)]) - fVec46[((IOTA - 264) & 511)]) + fVec46[((IOTA - 306) & 511)]) + fVec46[((IOTA - 313) & 511)]) + fVec46[((IOTA - 336) & 511)]) - fVec46[((IOTA - 427) & 511)]) + fVec46[((IOTA - 432) & 511)])) + ((0.000732444227f * (((fVec46[((IOTA - 360) & 511)] - fVec46[((IOTA - 369) & 511)]) - fVec46[((IOTA - 426) & 511)]) + fVec46[((IOTA - 430) & 511)])) + ((0.000823999755f * ((((fVec46[((IOTA - 234) & 511)] - fVec46[((IOTA - 267) & 511)]) + fVec46[((IOTA - 323) & 511)]) + fVec46[((IOTA - 359) & 511)]) - fVec46[((IOTA - 421) & 511)])) + ((0.000946073793f * ((((((fVec46[((IOTA - 358) & 511)] + fVec46[((IOTA - 379) & 511)]) + fVec46[((IOTA - 409) & 511)]) + fVec46[((IOTA - 410) & 511)]) + fVec46[((IOTA - 442) & 511)]) + fVec46[((IOTA - 455) & 511)]) + fVec46[((IOTA - 456) & 511)])) + ((0.00103762932f * ((fVec46[((IOTA - 200) & 511)] + fVec46[((IOTA - 355) & 511)]) + fVec46[((IOTA - 407) & 511)])) + ((0.00131229591f * ((fVec46[((IOTA - 134) & 511)] + fVec46[((IOTA - 198) & 511)]) + fVec46[((IOTA - 405) & 511)])) + ((0.0012817774f * (((fVec46[((IOTA - 110) & 511)] - fVec46[((IOTA - 156) & 511)]) + fVec46[((IOTA - 199) & 511)]) + fVec46[((IOTA - 404) & 511)])) + ((0.00228888821f * (fVec46[((IOTA - 143) & 511)] - fVec46[((IOTA - 397) & 511)])) + ((0.00177007355f * ((fVec46[((IOTA - 181) & 511)] + fVec46[((IOTA - 338) & 511)]) - fVec46[((IOTA - 396) & 511)])) + ((0.00143436994f * (fVec46[((IOTA - 148) & 511)] + fVec46[((IOTA - 391) & 511)])) + ((0.00201422162f * (((fVec46[((IOTA - 84) & 511)] + fVec46[((IOTA - 182) & 511)]) + fVec46[((IOTA - 343) & 511)]) + fVec46[((IOTA - 390) & 511)])) + ((0.00216681417f * (fVec46[((IOTA - 324) & 511)] + fVec46[((IOTA - 389) & 511)])) + ((0.00155644398f * fVec46[((IOTA - 388) & 511)]) + ((0.001617481f * ((fVec46[((IOTA - 78) & 511)] + fVec46[((IOTA - 328) & 511)]) - fVec46[((IOTA - 386) & 511)])) + ((0.00210577715f * fVec46[((IOTA - 378) & 511)]) + ((0.00173955504f * ((fVec46[((IOTA - 187) & 511)] - fVec46[((IOTA - 319) & 511)]) + fVec46[((IOTA - 376) & 511)])) + ((0.00109866634f * (fVec46[((IOTA - 357) & 511)] - fVec46[((IOTA - 373) & 511)])) + ((0.00256355479f * fVec46[((IOTA - 341) & 511)]) + ((0.00299081393f * (fVec46[((IOTA - 146) & 511)] + fVec46[((IOTA - 327) & 511)])) + ((0.00360118411f * fVec46[((IOTA - 326) & 511)]) + ((0.00326548051f * ((fVec46[((IOTA - 145) & 511)] - fVec46[((IOTA - 154) & 511)]) + fVec46[((IOTA - 325) & 511)])) + ((0.00054933317f * ((fVec46[((IOTA - 252) & 511)] - fVec46[((IOTA - 265) & 511)]) + fVec46[((IOTA - 307) & 511)])) + ((0.00100711081f * fVec46[((IOTA - 196) & 511)]) + ((0.00146488845f * fVec46[((IOTA - 188) & 511)]) + ((0.00204474013f * fVec46[((IOTA - 183) & 511)]) + ((0.000762962736f * (fVec46[((IOTA - 160) & 511)] - fVec46[((IOTA - 174) & 511)])) + ((0.00277718436f * fVec46[((IOTA - 133) & 511)]) + ((0.00357066561f * fVec46[((IOTA - 132) & 511)]) + ((0.0035401471f * fVec46[((IOTA - 131) & 511)]) + ((0.00317392498f * fVec46[((IOTA - 130) & 511)]) + ((0.00271614734f * fVec46[((IOTA - 129) & 511)]) + ((0.0019226661f * fVec46[((IOTA - 109) & 511)]) + ((0.00378429517f * (fVec46[((IOTA - 88) & 511)] - fVec46[((IOTA - 98) & 511)])) + ((0.00436414685f * (fVec46[((IOTA - 44) & 511)] + fVec46[((IOTA - 96) & 511)])) + ((0.00247199927f * fVec46[((IOTA - 147) & 511)]) + ((0.00778221991f * fVec46[((IOTA - 95) & 511)]) + ((0.0116275521f * fVec46[((IOTA - 94) & 511)]) + ((0.003234962f * fVec46[((IOTA - 144) & 511)]) + ((0.0191961434f * fVec46[((IOTA - 92) & 511)]) + ((0.0199896246f * fVec46[((IOTA - 91) & 511)]) + ((0.0171514023f * fVec46[((IOTA - 90) & 511)]) + ((0.0111697745f * fVec46[((IOTA - 89) & 511)]) + ((0.00668355357f * fVec46[((IOTA - 83) & 511)]) + ((0.00891140476f * fVec46[((IOTA - 82) & 511)]) + ((0.00897244178f * fVec46[((IOTA - 81) & 511)]) + ((0.00747703481f * fVec46[((IOTA - 80) & 511)]) + ((0.00476088747f * fVec46[((IOTA - 79) & 511)]) + ((0.00180059206f * fVec46[((IOTA - 74) & 511)]) + ((0.00567644276f * fVec46[((IOTA - 73) & 511)]) + ((0.00967436749f * fVec46[((IOTA - 72) & 511)]) + ((0.0124210333f * fVec46[((IOTA - 71) & 511)]) + ((0.0138859218f * fVec46[((IOTA - 70) & 511)]) + ((0.0173345134f * fVec46[((IOTA - 69) & 511)]) + ((0.0239875484f * fVec46[((IOTA - 68) & 511)]) + ((0.0302133244f * fVec46[((IOTA - 67) & 511)]) + ((0.029053621f * fVec46[((IOTA - 66) & 511)]) + ((0.0172124393f * (fVec46[((IOTA - 54) & 511)] + fVec46[((IOTA - 65) & 511)])) + ((0.016052736f * fVec46[((IOTA - 58) & 511)]) + ((0.0358592495f * fVec46[((IOTA - 57) & 511)]) + ((0.0441602841f * fVec46[((IOTA - 56) & 511)]) + ((((((((((((((0.019287698f * fVec46[((IOTA - 17) & 511)]) + ((0.0205999948f * fVec46[((IOTA - 16) & 511)]) + ((0.00347911008f * fVec46[((IOTA - 15) & 511)]) + ((0.209875792f * fVec46[((IOTA - 4) & 511)]) + ((0.320352793f * fVec46[((IOTA - 3) & 511)]) + ((0.267189562f * fVec46[((IOTA - 2) & 511)]) + ((0.134891808f * fVec46[((IOTA - 1) & 511)]) + ((fSlow111 * fTemp0) + (0.0028992584f * fVec46[((IOTA - 27) & 511)]))))))))) + (0.0325327329f * fVec46[((IOTA - 28) & 511)])) + (0.0382702127f * fVec46[((IOTA - 29) & 511)])) + (0.0164189581f * fVec46[((IOTA - 30) & 511)])) + (0.00506607257f * fVec46[((IOTA - 36) & 511)])) + (0.0148930326f * fVec46[((IOTA - 37) & 511)])) + (0.0187688842f * fVec46[((IOTA - 38) & 511)])) + (0.0231330302f * fVec46[((IOTA - 39) & 511)])) + (0.0255439933f * fVec46[((IOTA - 40) & 511)])) + (0.0234687347f * fVec46[((IOTA - 41) & 511)])) + (0.0211188085f * fVec46[((IOTA - 42) & 511)])) + (0.01617481f * fVec46[((IOTA - 43) & 511)])) + (0.0365306549f * fVec46[((IOTA - 55) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000183111057f * (((((((((((((fVec46[((IOTA - 111) & 511)] + fVec46[((IOTA - 121) & 511)]) + fVec46[((IOTA - 135) & 511)]) - fVec46[((IOTA - 193) & 511)]) - fVec46[((IOTA - 248) & 511)]) - fVec46[((IOTA - 255) & 511)]) + fVec46[((IOTA - 276) & 511)]) - fVec46[((IOTA - 299) & 511)]) + fVec46[((IOTA - 315) & 511)]) + fVec46[((IOTA - 465) & 511)]) - fVec46[((IOTA - 485) & 511)]) - fVec46[((IOTA - 486) & 511)]) - fVec46[((IOTA - 501) & 511)]) + fVec46[((IOTA - 510) & 511)])) + ((9.15555283e-05f * ((((((((fVec46[((IOTA - 212) & 511)] - fVec46[((IOTA - 226) & 511)]) + fVec46[((IOTA - 231) & 511)]) - fVec46[((IOTA - 246) & 511)]) + fVec46[((IOTA - 329) & 511)]) + fVec46[((IOTA - 480) & 511)]) + fVec46[((IOTA - 481) & 511)]) - fVec46[((IOTA - 488) & 511)]) + fVec46[((IOTA - 509) & 511)])) + ((3.05185094e-05f * (((((((((fVec46[((IOTA - 18) & 511)] - fVec46[((IOTA - 178) & 511)]) + fVec46[((IOTA - 227) & 511)]) - fVec46[((IOTA - 256) & 511)]) + fVec46[((IOTA - 300) & 511)]) + fVec46[((IOTA - 304) & 511)]) - fVec46[((IOTA - 478) & 511)]) + fVec46[((IOTA - 479) & 511)]) + fVec46[((IOTA - 482) & 511)]) - fVec46[((IOTA - 508) & 511)])) + ((0.000122074038f * (((((((((((((((fVec46[((IOTA - 149) & 511)] - fVec46[((IOTA - 158) & 511)]) + fVec46[((IOTA - 169) & 511)]) - fVec46[((IOTA - 247) & 511)]) + fVec46[((IOTA - 284) & 511)]) + fVec46[((IOTA - 285) & 511)]) + fVec46[((IOTA - 365) & 511)]) - fVec46[((IOTA - 402) & 511)]) - fVec46[((IOTA - 428) & 511)]) - fVec46[((IOTA - 440) & 511)]) + fVec46[((IOTA - 461) & 511)]) + fVec46[((IOTA - 474) & 511)]) - fVec46[((IOTA - 487) & 511)]) - fVec46[((IOTA - 492) & 511)]) - fVec46[((IOTA - 503) & 511)]) - fVec46[((IOTA - 507) & 511)])) + ((0.000152592547f * (((((((((((((((((((((fVec46[((IOTA - 211) & 511)] + fVec46[((IOTA - 228) & 511)]) - fVec46[((IOTA - 244) & 511)]) + fVec46[((IOTA - 257) & 511)]) + fVec46[((IOTA - 286) & 511)]) + fVec46[((IOTA - 292) & 511)]) + fVec46[((IOTA - 301) & 511)]) + fVec46[((IOTA - 303) & 511)]) - fVec46[((IOTA - 305) & 511)]) - fVec46[((IOTA - 314) & 511)]) - fVec46[((IOTA - 353) & 511)]) - fVec46[((IOTA - 387) & 511)]) - fVec46[((IOTA - 393) & 511)]) + fVec46[((IOTA - 433) & 511)]) + fVec46[((IOTA - 462) & 511)]) + fVec46[((IOTA - 463) & 511)]) + fVec46[((IOTA - 464) & 511)]) - fVec46[((IOTA - 484) & 511)]) - fVec46[((IOTA - 502) & 511)]) - fVec46[((IOTA - 504) & 511)]) - fVec46[((IOTA - 505) & 511)]) - fVec46[((IOTA - 506) & 511)])) + ((0.000274666585f * (((((((((((fVec46[((IOTA - 107) & 511)] - fVec46[((IOTA - 192) & 511)]) - fVec46[((IOTA - 249) & 511)]) + fVec46[((IOTA - 274) & 511)]) + fVec46[((IOTA - 277) & 511)]) + fVec46[((IOTA - 288) & 511)]) + fVec46[((IOTA - 290) & 511)]) + fVec46[((IOTA - 345) & 511)]) - fVec46[((IOTA - 363) & 511)]) + fVec46[((IOTA - 366) & 511)]) + fVec46[((IOTA - 473) & 511)]) - fVec46[((IOTA - 498) & 511)])) + ((0.000305185094f * (((((fVec46[((IOTA - 258) & 511)] - ((((fVec46[((IOTA - 142) & 511)] - fVec46[((IOTA - 171) & 511)]) + fVec46[((IOTA - 224) & 511)]) - fVec46[((IOTA - 229) & 511)]) - fVec46[((IOTA - 230) & 511)])) + fVec46[((IOTA - 261) & 511)]) + fVec46[((IOTA - 289) & 511)]) - fVec46[((IOTA - 494) & 511)]) - fVec46[((IOTA - 497) & 511)])) + (((0.000427259132f * (((((fVec46[((IOTA - 177) & 511)] - fVec46[((IOTA - 238) & 511)]) - fVec46[((IOTA - 298) & 511)]) + fVec46[((IOTA - 439) & 511)]) + fVec46[((IOTA - 468) & 511)]) + fVec46[((IOTA - 472) & 511)])) + ((0.000488296151f * (((((((((fVec46[((IOTA - 77) & 511)] - fVec46[((IOTA - 97) & 511)]) + fVec46[((IOTA - 157) & 511)]) + fVec46[((IOTA - 210) & 511)]) - fVec46[((IOTA - 242) & 511)]) - fVec46[((IOTA - 251) & 511)]) - fVec46[((IOTA - 416) & 511)]) - fVec46[((IOTA - 451) & 511)]) - fVec46[((IOTA - 458) & 511)]) + fVec46[((IOTA - 471) & 511)])) + ((0.000854518265f * (((((fVec46[((IOTA - 119) & 511)] + fVec46[((IOTA - 175) & 511)]) - fVec46[((IOTA - 235) & 511)]) + fVec46[((IOTA - 401) & 511)]) - fVec46[((IOTA - 414) & 511)]) - fVec46[((IOTA - 454) & 511)])) + ((0.000701925717f * ((fVec46[((IOTA - 434) & 511)] - ((((((((fVec46[((IOTA - 127) & 511)] - fVec46[((IOTA - 176) & 511)]) + fVec46[((IOTA - 190) & 511)]) + fVec46[((IOTA - 195) & 511)]) + fVec46[((IOTA - 236) & 511)]) - fVec46[((IOTA - 266) & 511)]) - fVec46[((IOTA - 335) & 511)]) + fVec46[((IOTA - 354) & 511)]) + fVec46[((IOTA - 415) & 511)])) - fVec46[((IOTA - 453) & 511)])) + ((0.000885036774f * (((((((fVec46[((IOTA - 205) & 511)] + fVec46[((IOTA - 209) & 511)]) + fVec46[((IOTA - 214) & 511)]) + fVec46[((IOTA - 268) & 511)]) + fVec46[((IOTA - 269) & 511)]) - fVec46[((IOTA - 403) & 511)]) + fVec46[((IOTA - 422) & 511)]) - fVec46[((IOTA - 446) & 511)])) + ((0.00106814783f * (((((fVec46[((IOTA - 76) & 511)] - fVec46[((IOTA - 189) & 511)]) + fVec46[((IOTA - 206) & 511)]) - fVec46[((IOTA - 344) & 511)]) + fVec46[((IOTA - 395) & 511)]) - fVec46[((IOTA - 445) & 511)])) + ((0.00115970336f * (((fVec46[((IOTA - 207) & 511)] - fVec46[((IOTA - 356) & 511)]) + fVec46[((IOTA - 435) & 511)]) - fVec46[((IOTA - 444) & 511)])) + ((0.00112918485f * (((fVec46[((IOTA - 208) & 511)] + fVec46[((IOTA - 317) & 511)]) + fVec46[((IOTA - 371) & 511)]) - fVec46[((IOTA - 443) & 511)])) + ((0.000915555283f * ((((fVec46[((IOTA - 370) & 511)] - fVec46[((IOTA - 413) & 511)]) + fVec46[((IOTA - 423) & 511)]) + fVec46[((IOTA - 424) & 511)]) + fVec46[((IOTA - 425) & 511)])) + ((0.000396740623f * (((((((((fVec46[((IOTA - 122) & 511)] + fVec46[((IOTA - 172) & 511)]) + fVec46[((IOTA - 203) & 511)]) + fVec46[((IOTA - 213) & 511)]) - fVec46[((IOTA - 222) & 511)]) + fVec46[((IOTA - 273) & 511)]) + fVec46[((IOTA - 278) & 511)]) + fVec46[((IOTA - 322) & 511)]) + fVec46[((IOTA - 367) & 511)]) + fVec46[((IOTA - 419) & 511)])) + ((0.00119022187f * (((fVec46[((IOTA - 123) & 511)] - fVec46[((IOTA - 197) & 511)]) - fVec46[((IOTA - 337) & 511)]) - fVec46[((IOTA - 406) & 511)])) + ((0.00170903653f * fVec46[((IOTA - 400) & 511)]) + ((0.00231940672f * fVec46[((IOTA - 399) & 511)]) + ((0.00253303628f * fVec46[((IOTA - 398) & 511)]) + ((0.00314340647f * fVec46[((IOTA - 385) & 511)]) + ((0.00402844325f * fVec46[((IOTA - 384) & 511)]) + ((0.00408948027f * fVec46[((IOTA - 383) & 511)]) + ((0.00344859157f * (fVec46[((IOTA - 140) & 511)] + fVec46[((IOTA - 382) & 511)])) + ((0.0022583697f * (fVec46[((IOTA - 155) & 511)] + fVec46[((IOTA - 381) & 511)])) + ((0.00238044374f * (fVec46[((IOTA - 104) & 511)] - fVec46[((IOTA - 377) & 511)])) + ((0.00125125889f * ((fVec46[((IOTA - 136) & 511)] + fVec46[((IOTA - 217) & 511)]) + fVec46[((IOTA - 372) & 511)])) + ((0.00149540696f * fVec46[((IOTA - 351) & 511)]) + ((0.00234992523f * fVec46[((IOTA - 350) & 511)]) + ((0.00296029542f * fVec46[((IOTA - 349) & 511)]) + ((0.00311288796f * (fVec46[((IOTA - 332) & 511)] + fVec46[((IOTA - 348) & 511)])) + ((0.00265511032f * fVec46[((IOTA - 347) & 511)]) + ((0.00164799951f * ((fVec46[((IOTA - 320) & 511)] + fVec46[((IOTA - 330) & 511)]) + fVec46[((IOTA - 346) & 511)])) + ((0.00250251777f * (fVec46[((IOTA - 112) & 511)] - fVec46[((IOTA - 342) & 511)])) + ((0.00241096225f * (fVec46[((IOTA - 105) & 511)] - fVec46[((IOTA - 340) & 511)])) + ((0.00213629566f * (fVec46[((IOTA - 137) & 511)] - fVec46[((IOTA - 339) & 511)])) + ((0.00186162908f * fVec46[((IOTA - 334) & 511)]) + ((0.00274666585f * (fVec46[((IOTA - 331) & 511)] + fVec46[((IOTA - 333) & 511)])) + ((0.00122074038f * fVec46[((IOTA - 321) & 511)]) + ((0.00152592547f * (fVec46[((IOTA - 216) & 511)] + fVec46[((IOTA - 318) & 511)])) + ((0.000640888698f * ((((fVec46[((IOTA - 271) & 511)] + fVec46[((IOTA - 280) & 511)]) - fVec46[((IOTA - 308) & 511)]) - fVec46[((IOTA - 310) & 511)]) + fVec46[((IOTA - 316) & 511)])) + ((0.00183111057f * ((fVec46[((IOTA - 106) & 511)] + fVec46[((IOTA - 150) & 511)]) - fVec46[((IOTA - 186) & 511)])) + ((0.00189214759f * (fVec46[((IOTA - 125) & 511)] - fVec46[((IOTA - 185) & 511)])) + ((0.00198370311f * (fVec46[((IOTA - 141) & 511)] - fVec46[((IOTA - 184) & 511)])) + ((0.00390636921f * fVec46[((IOTA - 153) & 511)]) + ((0.00393688772f * fVec46[((IOTA - 152) & 511)]) + ((0.00320444349f * fVec46[((IOTA - 151) & 511)]) + ((0.00369273964f * fVec46[((IOTA - 139) & 511)]) + ((0.00308236945f * fVec46[((IOTA - 138) & 511)]) + ((0.0019531846f * ((fVec46[((IOTA - 118) & 511)] + fVec46[((IOTA - 124) & 511)]) - fVec46[((IOTA - 128) & 511)])) + ((0.0038758507f * fVec46[((IOTA - 117) & 511)]) + ((0.0061342204f * fVec46[((IOTA - 116) & 511)]) + ((0.00753807183f * fVec46[((IOTA - 115) & 511)]) + ((0.00723288674f * fVec46[((IOTA - 114) & 511)]) + ((0.00518814661f * (fVec46[((IOTA - 86) & 511)] + fVec46[((IOTA - 113) & 511)])) + ((0.00292977691f * (fVec46[((IOTA - 85) & 511)] + fVec46[((IOTA - 103) & 511)])) + ((0.00494399853f * fVec46[((IOTA - 102) & 511)]) + ((0.00756859034f * fVec46[((IOTA - 101) & 511)]) + ((0.0087282937f * fVec46[((IOTA - 100) & 511)]) + ((0.00735496078f * fVec46[((IOTA - 99) & 511)]) + ((0.0157170333f * (fVec46[((IOTA - 13) & 511)] - fVec46[((IOTA - 93) & 511)])) + ((0.00262459181f * fVec46[((IOTA - 87) & 511)]) + ((0.00140385143f * fVec46[((IOTA - 64) & 511)]) + ((0.0197454765f * fVec46[((IOTA - 63) & 511)]) + ((0.0316476934f * fVec46[((IOTA - 62) & 511)]) + ((0.0332041383f * fVec46[((IOTA - 61) & 511)]) + ((0.0239570308f * fVec46[((IOTA - 60) & 511)]) + ((0.00616473891f * fVec46[((IOTA - 59) & 511)]) + ((0.00509659108f * fVec46[((IOTA - 53) & 511)]) + ((0.0224921424f * fVec46[((IOTA - 52) & 511)]) + ((0.0309457686f * fVec46[((IOTA - 51) & 511)]) + ((0.0338755473f * fVec46[((IOTA - 50) & 511)]) + ((0.0357676931f * fVec46[((IOTA - 49) & 511)]) + ((0.0369273983f * fVec46[((IOTA - 48) & 511)]) + ((0.0334788039f * fVec46[((IOTA - 47) & 511)]) + ((0.0246589556f * fVec46[((IOTA - 46) & 511)]) + ((0.011200293f * fVec46[((IOTA - 45) & 511)]) + ((0.0124515519f * fVec46[((IOTA - 35) & 511)]) + ((0.0268257707f * fVec46[((IOTA - 34) & 511)]) + ((0.0349131748f * fVec46[((IOTA - 33) & 511)]) + ((0.0337534733f * fVec46[((IOTA - 32) & 511)]) + ((0.0156559963f * fVec46[((IOTA - 31) & 511)]) + ((0.0574663542f * fVec46[((IOTA - 24) & 511)]) + ((0.0366222113f * fVec46[((IOTA - 23) & 511)]) + ((0.017853329f * fVec46[((IOTA - 22) & 511)]) + ((0.0190130323f * fVec46[((IOTA - 21) & 511)]) + ((0.0238044374f * fVec46[((IOTA - 20) & 511)]) + ((0.0184942167f * fVec46[((IOTA - 19) & 511)]) + ((0.0132450331f * fVec46[((IOTA - 14) & 511)]) + ((0.0177617725f * fVec46[((IOTA - 12) & 511)]) + ((0.0157780703f * fVec46[((IOTA - 11) & 511)]) + ((0.0355845839f * fVec46[((IOTA - 10) & 511)]) + ((0.0974455997f * fVec46[((IOTA - 9) & 511)]) + ((0.198767051f * fVec46[((IOTA - 8) & 511)]) + ((0.259498894f * fVec46[((IOTA - 7) & 511)]) + ((0.201300085f * fVec46[((IOTA - 6) & 511)]) + ((0.0137333293f * fVec46[((IOTA - 5) & 511)]) + ((0.0577715375f * fVec46[((IOTA - 25) & 511)]) + (0.0324106589f * fVec46[((IOTA - 26) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000335703604f * ((((((((((fVec46[((IOTA - 75) & 511)] + fVec46[((IOTA - 120) & 511)]) - fVec46[((IOTA - 165) & 511)]) - fVec46[((IOTA - 166) & 511)]) - fVec46[((IOTA - 220) & 511)]) - fVec46[((IOTA - 223) & 511)]) - fVec46[((IOTA - 243) & 511)]) - fVec46[((IOTA - 254) & 511)]) + fVec46[((IOTA - 467) & 511)]) - fVec46[((IOTA - 495) & 511)]) - fVec46[((IOTA - 496) & 511)])))))))))) + (0.000213629566f * ((((((((((fVec46[((IOTA - 170) & 511)] - fVec46[((IOTA - 225) & 511)]) + fVec46[((IOTA - 262) & 511)]) + fVec46[((IOTA - 263) & 511)]) + fVec46[((IOTA - 275) & 511)]) - fVec46[((IOTA - 294) & 511)]) + fVec46[((IOTA - 302) & 511)]) - fVec46[((IOTA - 459) & 511)]) - fVec46[((IOTA - 493) & 511)]) - fVec46[((IOTA - 500) & 511)]) + fVec46[((IOTA - 511) & 511)])))) : (((0.000335703604f * (((((((((((((((fVec45[((IOTA - 95) & 511)] - fVec45[((IOTA - 98) & 511)]) + fVec45[((IOTA - 210) & 511)]) + fVec45[((IOTA - 370) & 511)]) + fVec45[((IOTA - 380) & 511)]) - fVec45[((IOTA - 385) & 511)]) - fVec45[((IOTA - 399) & 511)]) + fVec45[((IOTA - 412) & 511)]) - fVec45[((IOTA - 423) & 511)]) - fVec45[((IOTA - 424) & 511)]) + fVec45[((IOTA - 434) & 511)]) + fVec45[((IOTA - 456) & 511)]) - fVec45[((IOTA - 470) & 511)]) - fVec45[((IOTA - 474) & 511)]) - fVec45[((IOTA - 506) & 511)]) - fVec45[((IOTA - 510) & 511)])) + (((0.000244148076f * (((((((((fVec45[((IOTA - 123) & 511)] + fVec45[((IOTA - 201) & 511)]) + fVec45[((IOTA - 256) & 511)]) + fVec45[((IOTA - 371) & 511)]) + fVec45[((IOTA - 373) & 511)]) - fVec45[((IOTA - 421) & 511)]) - fVec45[((IOTA - 426) & 511)]) - fVec45[((IOTA - 436) & 511)]) + fVec45[((IOTA - 455) & 511)]) - fVec45[((IOTA - 504) & 511)])) + ((3.05185094e-05f * ((((((((((((fVec45[((IOTA - 58) & 511)] - fVec45[((IOTA - 146) & 511)]) - fVec45[((IOTA - 173) & 511)]) + fVec45[((IOTA - 203) & 511)]) - fVec45[((IOTA - 208) & 511)]) - fVec45[((IOTA - 396) & 511)]) + fVec45[((IOTA - 427) & 511)]) + fVec45[((IOTA - 435) & 511)]) - fVec45[((IOTA - 459) & 511)]) - fVec45[((IOTA - 489) & 511)]) + fVec45[((IOTA - 490) & 511)]) + fVec45[((IOTA - 496) & 511)]) - fVec45[((IOTA - 499) & 511)])) + ((0.000488296151f * (((((((fVec45[((IOTA - 199) & 511)] - fVec45[((IOTA - 232) & 511)]) - fVec45[((IOTA - 319) & 511)]) - fVec45[((IOTA - 438) & 511)]) - fVec45[((IOTA - 439) & 511)]) - fVec45[((IOTA - 445) & 511)]) - fVec45[((IOTA - 467) & 511)]) - fVec45[((IOTA - 484) & 511)])) + ((0.000610370189f * (((((fVec45[((IOTA - 131) & 511)] + fVec45[((IOTA - 194) & 511)]) + fVec45[((IOTA - 369) & 511)]) - fVec45[((IOTA - 397) & 511)]) + fVec45[((IOTA - 417) & 511)]) - fVec45[((IOTA - 483) & 511)])) + ((0.000793481246f * ((((fVec45[((IOTA - 133) & 511)] - fVec45[((IOTA - 139) & 511)]) + fVec45[((IOTA - 179) & 511)]) + fVec45[((IOTA - 329) & 511)]) - fVec45[((IOTA - 479) & 511)])) + ((0.000427259132f * (((((((((((fVec45[((IOTA - 222) & 511)] + fVec45[((IOTA - 238) & 511)]) + fVec45[((IOTA - 317) & 511)]) + fVec45[((IOTA - 321) & 511)]) + fVec45[((IOTA - 359) & 511)]) - fVec45[((IOTA - 437) & 511)]) - fVec45[((IOTA - 440) & 511)]) - fVec45[((IOTA - 446) & 511)]) - fVec45[((IOTA - 449) & 511)]) - fVec45[((IOTA - 450) & 511)]) - fVec45[((IOTA - 462) & 511)]) - fVec45[((IOTA - 476) & 511)])) + ((0.000457777642f * ((((((((((((fVec45[((IOTA - 142) & 511)] + fVec45[((IOTA - 178) & 511)]) - fVec45[((IOTA - 218) & 511)]) + fVec45[((IOTA - 221) & 511)]) + fVec45[((IOTA - 223) & 511)]) + fVec45[((IOTA - 249) & 511)]) + fVec45[((IOTA - 358) & 511)]) + fVec45[((IOTA - 360) & 511)]) + fVec45[((IOTA - 414) & 511)]) + fVec45[((IOTA - 418) & 511)]) + fVec45[((IOTA - 428) & 511)]) - fVec45[((IOTA - 442) & 511)]) - fVec45[((IOTA - 468) & 511)])) + ((0.00054933317f * (((((((fVec45[((IOTA - 228) & 511)] + fVec45[((IOTA - 401) & 511)]) + fVec45[((IOTA - 406) & 511)]) + fVec45[((IOTA - 415) & 511)]) - fVec45[((IOTA - 443) & 511)]) - fVec45[((IOTA - 444) & 511)]) - fVec45[((IOTA - 464) & 511)]) - fVec45[((IOTA - 465) & 511)])) + ((0.00100711081f * (((((fVec45[((IOTA - 91) & 511)] + fVec45[((IOTA - 227) & 511)]) + fVec45[((IOTA - 259) & 511)]) + fVec45[((IOTA - 316) & 511)]) + fVec45[((IOTA - 330) & 511)]) + fVec45[((IOTA - 432) & 511)])) + ((0.00119022187f * (fVec45[((IOTA - 286) & 511)] + fVec45[((IOTA - 431) & 511)])) + ((0.00134281442f * ((((((((fVec45[((IOTA - 66) & 511)] - fVec45[((IOTA - 163) & 511)]) - fVec45[((IOTA - 168) & 511)]) + fVec45[((IOTA - 181) & 511)]) + fVec45[((IOTA - 294) & 511)]) + fVec45[((IOTA - 303) & 511)]) + fVec45[((IOTA - 304) & 511)]) + fVec45[((IOTA - 325) & 511)]) + fVec45[((IOTA - 404) & 511)])) + ((0.0012817774f * ((fVec45[((IOTA - 270) & 511)] + fVec45[((IOTA - 307) & 511)]) + fVec45[((IOTA - 403) & 511)])) + ((0.000946073793f * ((((fVec45[((IOTA - 132) & 511)] - fVec45[((IOTA - 135) & 511)]) - fVec45[((IOTA - 158) & 511)]) + fVec45[((IOTA - 292) & 511)]) + fVec45[((IOTA - 402) & 511)])) + ((0.00149540696f * ((((fVec45[((IOTA - 145) & 511)] + fVec45[((IOTA - 352) & 511)]) - fVec45[((IOTA - 383) & 511)]) + fVec45[((IOTA - 392) & 511)]) + fVec45[((IOTA - 394) & 511)])) + ((0.00164799951f * ((((((fVec45[((IOTA - 272) & 511)] + fVec45[((IOTA - 275) & 511)]) + fVec45[((IOTA - 278) & 511)]) + fVec45[((IOTA - 298) & 511)]) + fVec45[((IOTA - 309) & 511)]) + fVec45[((IOTA - 379) & 511)]) + fVec45[((IOTA - 393) & 511)])) + ((0.00283822138f * fVec45[((IOTA - 389) & 511)]) + ((0.0028992584f * fVec45[((IOTA - 388) & 511)]) + ((0.00112918485f * (((((fVec45[((IOTA - 241) & 511)] + fVec45[((IOTA - 245) & 511)]) + fVec45[((IOTA - 338) & 511)]) + fVec45[((IOTA - 353) & 511)]) + fVec45[((IOTA - 367) & 511)]) - fVec45[((IOTA - 384) & 511)])) + ((0.000762962736f * (fVec45[((IOTA - 262) & 511)] - fVec45[((IOTA - 381) & 511)])) + ((0.00280770287f * fVec45[((IOTA - 377) & 511)]) + ((0.00222785119f * fVec45[((IOTA - 376) & 511)]) + ((0.00131229591f * (((fVec45[((IOTA - 264) & 511)] + fVec45[((IOTA - 266) & 511)]) + fVec45[((IOTA - 305) & 511)]) + fVec45[((IOTA - 375) & 511)])) + ((0.001617481f * ((fVec45[((IOTA - 182) & 511)] + fVec45[((IOTA - 281) & 511)]) + fVec45[((IOTA - 391) & 511)])) + ((0.000915555283f * ((((fVec45[((IOTA - 90) & 511)] + fVec45[((IOTA - 333) & 511)]) + fVec45[((IOTA - 334) & 511)]) + fVec45[((IOTA - 336) & 511)]) + fVec45[((IOTA - 368) & 511)])) + ((0.000976592302f * (((((((((fVec45[((IOTA - 119) & 511)] - fVec45[((IOTA - 136) & 511)]) - fVec45[((IOTA - 215) & 511)]) + fVec45[((IOTA - 225) & 511)]) + fVec45[((IOTA - 240) & 511)]) + fVec45[((IOTA - 288) & 511)]) + fVec45[((IOTA - 289) & 511)]) + fVec45[((IOTA - 332) & 511)]) + fVec45[((IOTA - 335) & 511)]) + fVec45[((IOTA - 364) & 511)])) + ((0.000671407208f * (((((fVec45[((IOTA - 192) & 511)] + fVec45[((IOTA - 193) & 511)]) + fVec45[((IOTA - 195) & 511)]) - fVec45[((IOTA - 214) & 511)]) + fVec45[((IOTA - 248) & 511)]) + fVec45[((IOTA - 355) & 511)])) + ((0.000823999755f * (((fVec45[((IOTA - 149) & 511)] - fVec45[((IOTA - 217) & 511)]) + fVec45[((IOTA - 291) & 511)]) + fVec45[((IOTA - 354) & 511)])) + ((0.00207525864f * (fVec45[((IOTA - 342) & 511)] + fVec45[((IOTA - 350) & 511)])) + ((0.0022583697f * fVec45[((IOTA - 348) & 511)]) + ((0.00204474013f * (fVec45[((IOTA - 341) & 511)] + fVec45[((IOTA - 343) & 511)])) + ((0.00189214759f * (((fVec45[((IOTA - 96) & 511)] + fVec45[((IOTA - 184) & 511)]) + fVec45[((IOTA - 185) & 511)]) + fVec45[((IOTA - 340) & 511)])) + ((0.00155644398f * ((fVec45[((IOTA - 284) & 511)] + fVec45[((IOTA - 301) & 511)]) + fVec45[((IOTA - 339) & 511)])) + ((0.00183111057f * (((fVec45[((IOTA - 188) & 511)] + fVec45[((IOTA - 273) & 511)]) + fVec45[((IOTA - 310) & 511)]) + fVec45[((IOTA - 324) & 511)])) + ((0.00125125889f * (((((fVec45[((IOTA - 242) & 511)] + fVec45[((IOTA - 243) & 511)]) + fVec45[((IOTA - 267) & 511)]) + fVec45[((IOTA - 269) & 511)]) + fVec45[((IOTA - 306) & 511)]) + fVec45[((IOTA - 322) & 511)])) + ((0.00140385143f * (((((fVec45[((IOTA - 271) & 511)] + fVec45[((IOTA - 285) & 511)]) + fVec45[((IOTA - 295) & 511)]) + fVec45[((IOTA - 302) & 511)]) + fVec45[((IOTA - 308) & 511)]) + fVec45[((IOTA - 315) & 511)])) + ((0.00170903653f * ((fVec45[((IOTA - 97) & 511)] - fVec45[((IOTA - 162) & 511)]) + fVec45[((IOTA - 314) & 511)])) + ((0.00173955504f * ((((fVec45[((IOTA - 80) & 511)] - fVec45[((IOTA - 94) & 511)]) - fVec45[((IOTA - 165) & 511)]) + fVec45[((IOTA - 279) & 511)]) + fVec45[((IOTA - 300) & 511)])) + ((0.00158696249f * (fVec45[((IOTA - 282) & 511)] + fVec45[((IOTA - 283) & 511)])) + ((0.00167851802f * fVec45[((IOTA - 280) & 511)]) + ((0.00143436994f * fVec45[((IOTA - 276) & 511)]) + ((0.00198370311f * fVec45[((IOTA - 187) & 511)]) + ((0.00109866634f * (fVec45[((IOTA - 118) & 511)] + fVec45[((IOTA - 180) & 511)])) + ((0.00286873989f * fVec45[((IOTA - 144) & 511)]) + ((0.00247199927f * fVec45[((IOTA - 143) & 511)]) + ((0.00244148076f * fVec45[((IOTA - 83) & 511)]) + ((0.00585955381f * fVec45[((IOTA - 82) & 511)]) + ((0.004852443f * fVec45[((IOTA - 81) & 511)]) + ((0.00747703481f * fVec45[((IOTA - 71) & 511)]) + ((0.00854518265f * fVec45[((IOTA - 70) & 511)]) + ((0.00729392376f * fVec45[((IOTA - 69) & 511)]) + ((0.00567644276f * fVec45[((IOTA - 68) & 511)]) + ((0.00396740623f * fVec45[((IOTA - 67) & 511)]) + ((0.02600177f * (fVec45[((IOTA - 43) & 511)] - fVec45[((IOTA - 61) & 511)])) + ((0.0214545131f * fVec45[((IOTA - 57) & 511)]) + ((0.0304879919f * fVec45[((IOTA - 56) & 511)]) + ((0.0207220688f * fVec45[((IOTA - 55) & 511)]) + ((0.0101931822f * fVec45[((IOTA - 45) & 511)]) + ((((((((((((((0.0836817548f * fVec45[((IOTA - 10) & 511)]) + ((0.0478530228f * fVec45[((IOTA - 5) & 511)]) + ((0.278603464f * fVec45[((IOTA - 4) & 511)]) + ((0.31510362f * fVec45[((IOTA - 3) & 511)]) + ((0.190801725f * fVec45[((IOTA - 2) & 511)]) + ((0.0701925755f * fVec45[((IOTA - 1) & 511)]) + ((fSlow109 * fTemp0) + ((0.0449537635f * fVec45[((IOTA - 11) & 511)]) + (0.00454725791f * fVec45[((IOTA - 16) & 511)]))))))))) + (0.0246284381f * fVec45[((IOTA - 27) & 511)])) + (0.0569475405f * fVec45[((IOTA - 28) & 511)])) + (0.0564592443f * fVec45[((IOTA - 29) & 511)])) + (0.0231940672f * fVec45[((IOTA - 30) & 511)])) + (0.0074159978f * fVec45[((IOTA - 36) & 511)])) + (0.0172124393f * fVec45[((IOTA - 37) & 511)])) + (0.0229499191f * fVec45[((IOTA - 38) & 511)])) + (0.0238654744f * fVec45[((IOTA - 39) & 511)])) + (0.0224005859f * fVec45[((IOTA - 40) & 511)])) + (0.0209051799f * fVec45[((IOTA - 41) & 511)])) + (0.0228888821f * fVec45[((IOTA - 42) & 511)])) + (0.0226752535f * fVec45[((IOTA - 44) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * (((((((((((((fVec45[((IOTA - 200) & 511)] + fVec45[((IOTA - 220) & 511)]) - fVec45[((IOTA - 230) & 511)]) - fVec45[((IOTA - 233) & 511)]) + fVec45[((IOTA - 250) & 511)]) + fVec45[((IOTA - 251) & 511)]) - fVec45[((IOTA - 447) & 511)]) - fVec45[((IOTA - 448) & 511)]) - fVec45[((IOTA - 451) & 511)]) - fVec45[((IOTA - 475) & 511)]) - fVec45[((IOTA - 485) & 511)]) - fVec45[((IOTA - 507) & 511)]) - fVec45[((IOTA - 508) & 511)]) - fVec45[((IOTA - 509) & 511)])))) - (((0.000274666585f * ((((((((fVec45[((IOTA - 175) & 511)] + fVec45[((IOTA - 234) & 511)]) + fVec45[((IOTA - 320) & 511)]) + fVec45[((IOTA - 452) & 511)]) - fVec45[((IOTA - 457) & 511)]) + fVec45[((IOTA - 471) & 511)]) + fVec45[((IOTA - 472) & 511)]) + fVec45[((IOTA - 486) & 511)]) + fVec45[((IOTA - 505) & 511)])) + ((0.000183111057f * ((((((fVec45[((IOTA - 171) & 511)] + fVec45[((IOTA - 176) & 511)]) - fVec45[((IOTA - 254) & 511)]) + fVec45[((IOTA - 318) & 511)]) - fVec45[((IOTA - 372) & 511)]) + fVec45[((IOTA - 460) & 511)]) + fVec45[((IOTA - 503) & 511)])) + ((0.000122074038f * ((((((((((((((fVec45[((IOTA - 89) & 511)] - fVec45[((IOTA - 125) & 511)]) - fVec45[((IOTA - 138) & 511)]) + fVec45[((IOTA - 172) & 511)]) + fVec45[((IOTA - 174) & 511)]) - fVec45[((IOTA - 177) & 511)]) - fVec45[((IOTA - 209) & 511)]) + fVec45[((IOTA - 235) & 511)]) - fVec45[((IOTA - 400) & 511)]) + fVec45[((IOTA - 408) & 511)]) + fVec45[((IOTA - 453) & 511)]) - fVec45[((IOTA - 492) & 511)]) - fVec45[((IOTA - 493) & 511)]) + fVec45[((IOTA - 501) & 511)]) + fVec45[((IOTA - 502) & 511)])) + ((9.15555283e-05f * ((((fVec45[((IOTA - 409) & 511)] - ((((fVec45[((IOTA - 129) & 511)] - fVec45[((IOTA - 205) & 511)]) - fVec45[((IOTA - 206) & 511)]) + fVec45[((IOTA - 255) & 511)]) + fVec45[((IOTA - 407) & 511)])) - fVec45[((IOTA - 491) & 511)]) - fVec45[((IOTA - 494) & 511)]) + fVec45[((IOTA - 500) & 511)])) + ((6.10370189e-05f * ((((((((fVec45[((IOTA - 134) & 511)] + fVec45[((IOTA - 204) & 511)]) + fVec45[((IOTA - 207) & 511)]) - fVec45[((IOTA - 236) & 511)]) - fVec45[((IOTA - 410) & 511)]) + fVec45[((IOTA - 420) & 511)]) - fVec45[((IOTA - 454) & 511)]) + fVec45[((IOTA - 488) & 511)]) - fVec45[((IOTA - 495) & 511)])) + ((0.000152592547f * (((fVec45[((IOTA - 147) & 511)] - fVec45[((IOTA - 202) & 511)]) - fVec45[((IOTA - 458) & 511)]) + fVec45[((IOTA - 487) & 511)])) + ((0.000732444227f * ((fVec45[((IOTA - 169) & 511)] - fVec45[((IOTA - 362) & 511)]) + fVec45[((IOTA - 482) & 511)])) + ((0.000854518265f * ((((((((fVec45[((IOTA - 79) & 511)] + fVec45[((IOTA - 122) & 511)]) - fVec45[((IOTA - 190) & 511)]) - fVec45[((IOTA - 196) & 511)]) - fVec45[((IOTA - 260) & 511)]) - fVec45[((IOTA - 363) & 511)]) - fVec45[((IOTA - 395) & 511)]) + fVec45[((IOTA - 480) & 511)]) + fVec45[((IOTA - 481) & 511)])) + ((0.000640888698f * ((((fVec45[((IOTA - 157) & 511)] - fVec45[((IOTA - 191) & 511)]) - fVec45[((IOTA - 224) & 511)]) - fVec45[((IOTA - 416) & 511)]) + fVec45[((IOTA - 478) & 511)])) + ((0.000518814661f * ((((((fVec45[((IOTA - 231) & 511)] - fVec45[((IOTA - 257) & 511)]) - fVec45[((IOTA - 328) & 511)]) - fVec45[((IOTA - 357) & 511)]) + fVec45[((IOTA - 463) & 511)]) + fVec45[((IOTA - 466) & 511)]) + fVec45[((IOTA - 477) & 511)])) + ((0.000396740623f * ((((((fVec45[((IOTA - 128) & 511)] - fVec45[((IOTA - 211) & 511)]) - fVec45[((IOTA - 252) & 511)]) - fVec45[((IOTA - 327) & 511)]) - fVec45[((IOTA - 413) & 511)]) + fVec45[((IOTA - 441) & 511)]) + fVec45[((IOTA - 469) & 511)])) + ((0.000701925717f * ((((((((((fVec45[((IOTA - 54) & 511)] - fVec45[((IOTA - 124) & 511)]) + fVec45[((IOTA - 126) & 511)]) - fVec45[((IOTA - 148) & 511)]) + fVec45[((IOTA - 156) & 511)]) - fVec45[((IOTA - 198) & 511)]) - fVec45[((IOTA - 239) & 511)]) - fVec45[((IOTA - 261) & 511)]) - fVec45[((IOTA - 326) & 511)]) + fVec45[((IOTA - 398) & 511)]) - fVec45[((IOTA - 433) & 511)])) + ((0.00115970336f * ((((fVec45[((IOTA - 155) & 511)] - fVec45[((IOTA - 226) & 511)]) - fVec45[((IOTA - 293) & 511)]) - fVec45[((IOTA - 366) & 511)]) - fVec45[((IOTA - 430) & 511)])) + ((0.000885036774f * (((((((fVec45[((IOTA - 127) & 511)] - fVec45[((IOTA - 197) & 511)]) - fVec45[((IOTA - 247) & 511)]) - fVec45[((IOTA - 258) & 511)]) - fVec45[((IOTA - 290) & 511)]) - fVec45[((IOTA - 337) & 511)]) - fVec45[((IOTA - 386) & 511)]) - fVec45[((IOTA - 429) & 511)])) + ((0.000213629566f * (((((fVec45[((IOTA - 137) & 511)] - fVec45[((IOTA - 212) & 511)]) + fVec45[((IOTA - 213) & 511)]) - fVec45[((IOTA - 237) & 511)]) - fVec45[((IOTA - 411) & 511)]) - fVec45[((IOTA - 419) & 511)])) + ((0.00106814783f * (((fVec45[((IOTA - 117) & 511)] - fVec45[((IOTA - 331) & 511)]) - fVec45[((IOTA - 365) & 511)]) - fVec45[((IOTA - 405) & 511)])) + ((0.00216681417f * (fVec45[((IOTA - 110) & 511)] - fVec45[((IOTA - 390) & 511)])) + ((0.00213629566f * (fVec45[((IOTA - 15) & 511)] - fVec45[((IOTA - 387) & 511)])) + ((0.00137333293f * ((((fVec45[((IOTA - 164) & 511)] - fVec45[((IOTA - 189) & 511)]) - fVec45[((IOTA - 265) & 511)]) - fVec45[((IOTA - 296) & 511)]) + fVec45[((IOTA - 382) & 511)])) + ((0.0025940733f * (fVec45[((IOTA - 153) & 511)] - fVec45[((IOTA - 378) & 511)])) + ((0.00057985168f * (((fVec45[((IOTA - 120) & 511)] - fVec45[((IOTA - 356) & 511)]) - fVec45[((IOTA - 361) & 511)]) - fVec45[((IOTA - 374) & 511)])) + ((0.00186162908f * ((((fVec45[((IOTA - 167) & 511)] - fVec45[((IOTA - 183) & 511)]) - fVec45[((IOTA - 274) & 511)]) - fVec45[((IOTA - 313) & 511)]) - fVec45[((IOTA - 351) & 511)])) + ((0.00219733268f * ((fVec45[((IOTA - 93) & 511)] - fVec45[((IOTA - 347) & 511)]) - fVec45[((IOTA - 349) & 511)])) + ((0.00201422162f * ((fVec45[((IOTA - 161) & 511)] + fVec45[((IOTA - 166) & 511)]) - fVec45[((IOTA - 346) & 511)])) + ((0.0019226661f * ((fVec45[((IOTA - 154) & 511)] - fVec45[((IOTA - 311) & 511)]) - fVec45[((IOTA - 345) & 511)])) + ((0.0019531846f * ((((fVec45[((IOTA - 140) & 511)] + fVec45[((IOTA - 160) & 511)]) - fVec45[((IOTA - 186) & 511)]) - fVec45[((IOTA - 312) & 511)]) - fVec45[((IOTA - 344) & 511)])) + ((0.00180059206f * (fVec45[((IOTA - 151) & 511)] - fVec45[((IOTA - 323) & 511)])) + ((0.00177007355f * (fVec45[((IOTA - 108) & 511)] - fVec45[((IOTA - 299) & 511)])) + ((0.00146488845f * (((fVec45[((IOTA - 121) & 511)] + fVec45[((IOTA - 159) & 511)]) - fVec45[((IOTA - 277) & 511)]) - fVec45[((IOTA - 297) & 511)])) + ((0.00103762932f * (((fVec45[((IOTA - 216) & 511)] - fVec45[((IOTA - 246) & 511)]) - fVec45[((IOTA - 263) & 511)]) - fVec45[((IOTA - 287) & 511)])) + ((0.00122074038f * (((fVec45[((IOTA - 17) & 511)] + fVec45[((IOTA - 109) & 511)]) - fVec45[((IOTA - 244) & 511)]) - fVec45[((IOTA - 268) & 511)])) + ((0.00265511032f * fVec45[((IOTA - 152) & 511)]) + ((0.00152592547f * (fVec45[((IOTA - 65) & 511)] + fVec45[((IOTA - 141) & 511)])) + ((0.0038758507f * fVec45[((IOTA - 116) & 511)]) + ((0.0051576281f * (fVec45[((IOTA - 114) & 511)] + fVec45[((IOTA - 115) & 511)])) + ((0.00469985045f * fVec45[((IOTA - 113) & 511)]) + ((0.00405896176f * fVec45[((IOTA - 112) & 511)]) + ((0.00332651753f * fVec45[((IOTA - 111) & 511)]) + ((0.00402844325f * fVec45[((IOTA - 107) & 511)]) + ((0.00595110934f * fVec45[((IOTA - 106) & 511)]) + ((0.00607318338f * fVec45[((IOTA - 105) & 511)]) + ((0.00558488723f * fVec45[((IOTA - 104) & 511)]) + ((0.00564592425f * fVec45[((IOTA - 103) & 511)]) + ((0.00659199804f * fVec45[((IOTA - 102) & 511)]) + ((0.00769066438f * fVec45[((IOTA - 101) & 511)]) + ((0.00726340525f * fVec45[((IOTA - 100) & 511)]) + ((0.00411999878f * fVec45[((IOTA - 99) & 511)]) + ((0.00271614734f * fVec45[((IOTA - 88) & 511)]) + ((0.00680562761f * fVec45[((IOTA - 87) & 511)]) + ((0.0102542192f * fVec45[((IOTA - 86) & 511)]) + ((0.00946073793f * fVec45[((IOTA - 85) & 511)]) + ((0.00430310983f * fVec45[((IOTA - 84) & 511)]) + ((0.00296029542f * fVec45[((IOTA - 78) & 511)]) + ((0.00671407208f * fVec45[((IOTA - 77) & 511)]) + ((0.0108035523f * fVec45[((IOTA - 76) & 511)]) + ((0.0122989593f * fVec45[((IOTA - 75) & 511)]) + ((0.00915555283f * fVec45[((IOTA - 74) & 511)]) + ((0.00277718436f * fVec45[((IOTA - 73) & 511)]) + ((0.00366222113f * (fVec45[((IOTA - 35) & 511)] - fVec45[((IOTA - 72) & 511)])) + ((0.00476088747f * fVec45[((IOTA - 64) & 511)]) + ((0.00988799706f * fVec45[((IOTA - 63) & 511)]) + ((0.0178228095f * fVec45[((IOTA - 62) & 511)]) + ((0.0282906592f * fVec45[((IOTA - 60) & 511)]) + ((0.0196234025f * fVec45[((IOTA - 59) & 511)]) + ((0.0211188085f * fVec45[((IOTA - 53) & 511)]) + ((0.0318613239f * fVec45[((IOTA - 52) & 511)]) + ((0.0339671001f * fVec45[((IOTA - 51) & 511)]) + ((0.035523545f * fVec45[((IOTA - 50) & 511)]) + ((0.0396435447f * fVec45[((IOTA - 49) & 511)]) + ((0.040498063f * fVec45[((IOTA - 48) & 511)]) + ((0.0301522873f * fVec45[((IOTA - 47) & 511)]) + ((0.00994903408f * fVec45[((IOTA - 46) & 511)]) + ((0.0208441429f * (fVec45[((IOTA - 26) & 511)] + fVec45[((IOTA - 34) & 511)])) + ((0.0416272469f * fVec45[((IOTA - 33) & 511)]) + ((0.04876858f * fVec45[((IOTA - 32) & 511)]) + ((0.0229194015f * fVec45[((IOTA - 31) & 511)]) + ((0.0472426526f * fVec45[((IOTA - 25) & 511)]) + ((0.040742211f * fVec45[((IOTA - 24) & 511)]) + ((0.0205999948f * fVec45[((IOTA - 23) & 511)]) + ((0.00234992523f * fVec45[((IOTA - 9) & 511)]) + ((0.18018128f * fVec45[((IOTA - 8) & 511)]) + ((0.303079307f * fVec45[((IOTA - 7) & 511)]) + ((0.216162607f * fVec45[((IOTA - 6) & 511)]) + ((0.00717184972f * fVec45[((IOTA - 18) & 511)]) + ((0.012817774f * fVec45[((IOTA - 21) & 511)]) + ((0.0118717002f * fVec45[((IOTA - 22) & 511)]) + ((0.0204474013f * fVec45[((IOTA - 14) & 511)]) + ((0.00955229346f * fVec45[((IOTA - 20) & 511)]) + (((0.0236213263f * fVec45[((IOTA - 12) & 511)]) + (0.0412915424f * fVec45[((IOTA - 13) & 511)])) + (0.00753807183f * fVec45[((IOTA - 19) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000305185094f * (((((((((fVec45[((IOTA - 92) & 511)] - fVec45[((IOTA - 130) & 511)]) + fVec45[((IOTA - 150) & 511)]) + fVec45[((IOTA - 170) & 511)]) - fVec45[((IOTA - 253) & 511)]) + fVec45[((IOTA - 422) & 511)]) + fVec45[((IOTA - 425) & 511)]) + fVec45[((IOTA - 461) & 511)]) + fVec45[((IOTA - 473) & 511)]) + fVec45[((IOTA - 511) & 511)])))))) : (iSlow99 ? (iSlow103 ? ((((0.000457777642f * (((fVec44[((IOTA - 309) & 511)] + fVec44[((IOTA - 311) & 511)]) + fVec44[((IOTA - 428) & 511)]) + fVec44[((IOTA - 509) & 511)])) + ((6.10370189e-05f * ((((fVec44[((IOTA - 43) & 511)] - fVec44[((IOTA - 296) & 511)]) + fVec44[((IOTA - 341) & 511)]) - fVec44[((IOTA - 471) & 511)]) + fVec44[((IOTA - 505) & 511)])) + ((0.000244148076f * (((((((((fVec44[((IOTA - 233) & 511)] + fVec44[((IOTA - 290) & 511)]) + fVec44[((IOTA - 297) & 511)]) + fVec44[((IOTA - 348) & 511)]) + fVec44[((IOTA - 349) & 511)]) + fVec44[((IOTA - 350) & 511)]) + fVec44[((IOTA - 354) & 511)]) + fVec44[((IOTA - 355) & 511)]) + fVec44[((IOTA - 446) & 511)]) - fVec44[((IOTA - 497) & 511)])) + ((0.00057985168f * ((fVec44[((IOTA - 344) & 511)] + fVec44[((IOTA - 345) & 511)]) + fVec44[((IOTA - 495) & 511)])) + ((0.00103762932f * ((((fVec44[((IOTA - 23) & 511)] - fVec44[((IOTA - 206) & 511)]) + fVec44[((IOTA - 416) & 511)]) - fVec44[((IOTA - 457) & 511)]) + fVec44[((IOTA - 494) & 511)])) + ((0.00216681417f * (fVec44[((IOTA - 216) & 511)] + fVec44[((IOTA - 491) & 511)])) + ((0.00219733268f * fVec44[((IOTA - 490) & 511)]) + ((0.00198370311f * (fVec44[((IOTA - 477) & 511)] + fVec44[((IOTA - 489) & 511)])) + ((0.00152592547f * (fVec44[((IOTA - 315) & 511)] + fVec44[((IOTA - 488) & 511)])) + ((0.00100711081f * (((((fVec44[((IOTA - 5) & 511)] + fVec44[((IOTA - 36) & 511)]) - fVec44[((IOTA - 245) & 511)]) + fVec44[((IOTA - 331) & 511)]) + fVec44[((IOTA - 475) & 511)]) + fVec44[((IOTA - 487) & 511)])) + ((0.00054933317f * ((fVec44[((IOTA - 44) & 511)] + fVec44[((IOTA - 310) & 511)]) + fVec44[((IOTA - 485) & 511)])) + ((0.000732444227f * ((((((((fVec44[((IOTA - 257) & 511)] + fVec44[((IOTA - 279) & 511)]) - fVec44[((IOTA - 359) & 511)]) - fVec44[((IOTA - 360) & 511)]) - fVec44[((IOTA - 393) & 511)]) - fVec44[((IOTA - 402) & 511)]) + fVec44[((IOTA - 443) & 511)]) + fVec44[((IOTA - 469) & 511)]) + fVec44[((IOTA - 484) & 511)])) + ((0.00112918485f * ((((fVec44[((IOTA - 18) & 511)] + fVec44[((IOTA - 209) & 511)]) + fVec44[((IOTA - 371) & 511)]) - fVec44[((IOTA - 403) & 511)]) + fVec44[((IOTA - 483) & 511)])) + ((0.00183111057f * (fVec44[((IOTA - 322) & 511)] + fVec44[((IOTA - 481) & 511)])) + ((0.00158696249f * ((((((((fVec44[((IOTA - 9) & 511)] - fVec44[((IOTA - 68) & 511)]) + fVec44[((IOTA - 164) & 511)]) + fVec44[((IOTA - 269) & 511)]) + fVec44[((IOTA - 320) & 511)]) - fVec44[((IOTA - 378) & 511)]) + fVec44[((IOTA - 407) & 511)]) - fVec44[((IOTA - 459) & 511)]) + fVec44[((IOTA - 476) & 511)])) + ((0.000335703604f * (((((fVec44[((IOTA - 335) & 511)] + fVec44[((IOTA - 347) & 511)]) - fVec44[((IOTA - 404) & 511)]) + fVec44[((IOTA - 414) & 511)]) + fVec44[((IOTA - 470) & 511)]) + fVec44[((IOTA - 474) & 511)])) + ((0.000976592302f * ((fVec44[((IOTA - 281) & 511)] + fVec44[((IOTA - 430) & 511)]) + fVec44[((IOTA - 468) & 511)])) + ((0.00119022187f * ((((fVec44[((IOTA - 417) & 511)] + fVec44[((IOTA - 418) & 511)]) + fVec44[((IOTA - 449) & 511)]) + fVec44[((IOTA - 463) & 511)]) + fVec44[((IOTA - 467) & 511)])) + ((0.00146488845f * (((fVec44[((IOTA - 47) & 511)] + fVec44[((IOTA - 176) & 511)]) + fVec44[((IOTA - 271) & 511)]) + fVec44[((IOTA - 466) & 511)])) + ((0.00173955504f * (fVec44[((IOTA - 432) & 511)] + fVec44[((IOTA - 464) & 511)])) + ((0.000213629566f * (((fVec44[((IOTA - 291) & 511)] + fVec44[((IOTA - 342) & 511)]) + fVec44[((IOTA - 384) & 511)]) + fVec44[((IOTA - 462) & 511)])) + ((0.00137333293f * (((((((fVec44[((IOTA - 20) & 511)] + fVec44[((IOTA - 21) & 511)]) + fVec44[((IOTA - 51) & 511)]) - fVec44[((IOTA - 260) & 511)]) + fVec44[((IOTA - 268) & 511)]) + fVec44[((IOTA - 370) & 511)]) - fVec44[((IOTA - 392) & 511)]) - fVec44[((IOTA - 460) & 511)])) + ((0.0025940733f * ((fVec44[((IOTA - 102) & 511)] - fVec44[((IOTA - 234) & 511)]) + fVec44[((IOTA - 454) & 511)])) + ((0.00271614734f * ((fVec44[((IOTA - 7) & 511)] - fVec44[((IOTA - 375) & 511)]) + fVec44[((IOTA - 451) & 511)])) + ((0.000488296151f * ((((((((fVec44[((IOTA - 318) & 511)] + fVec44[((IOTA - 334) & 511)]) + fVec44[((IOTA - 346) & 511)]) - fVec44[((IOTA - 358) & 511)]) - fVec44[((IOTA - 410) & 511)]) - fVec44[((IOTA - 412) & 511)]) + fVec44[((IOTA - 420) & 511)]) + fVec44[((IOTA - 421) & 511)]) + fVec44[((IOTA - 447) & 511)])) + ((0.00234992523f * (((fVec44[((IOTA - 49) & 511)] - fVec44[((IOTA - 71) & 511)]) - fVec44[((IOTA - 205) & 511)]) + fVec44[((IOTA - 440) & 511)])) + ((0.0028992584f * (((fVec44[((IOTA - 380) & 511)] + fVec44[((IOTA - 382) & 511)]) - fVec44[((IOTA - 389) & 511)]) + fVec44[((IOTA - 439) & 511)])) + ((0.00329599902f * ((((fVec44[((IOTA - 33) & 511)] + fVec44[((IOTA - 126) & 511)]) + fVec44[((IOTA - 177) & 511)]) - fVec44[((IOTA - 187) & 511)]) + fVec44[((IOTA - 438) & 511)])) + ((0.00213629566f * ((((((fVec44[((IOTA - 6) & 511)] + fVec44[((IOTA - 208) & 511)]) - fVec44[((IOTA - 212) & 511)]) + fVec44[((IOTA - 275) & 511)]) - fVec44[((IOTA - 387) & 511)]) + fVec44[((IOTA - 478) & 511)]) + fVec44[((IOTA - 479) & 511)])) + ((0.00170903653f * fVec44[((IOTA - 425) & 511)]) + ((0.0019226661f * fVec44[((IOTA - 424) & 511)]) + ((0.000701925717f * ((((fVec44[((IOTA - 267) & 511)] - fVec44[((IOTA - 294) & 511)]) + fVec44[((IOTA - 317) & 511)]) + fVec44[((IOTA - 325) & 511)]) - fVec44[((IOTA - 411) & 511)])) + ((0.00164799951f * ((fVec44[((IOTA - 272) & 511)] + fVec44[((IOTA - 283) & 511)]) + fVec44[((IOTA - 406) & 511)])) + ((0.000885036774f * ((((fVec44[((IOTA - 278) & 511)] + fVec44[((IOTA - 319) & 511)]) + fVec44[((IOTA - 326) & 511)]) + fVec44[((IOTA - 379) & 511)]) + fVec44[((IOTA - 405) & 511)])) + ((0.000854518265f * ((fVec44[((IOTA - 328) & 511)] + fVec44[((IOTA - 329) & 511)]) + fVec44[((IOTA - 401) & 511)])) + ((0.00393688772f * fVec44[((IOTA - 399) & 511)]) + ((0.00402844325f * (fVec44[((IOTA - 163) & 511)] + fVec44[((IOTA - 398) & 511)])) + ((0.003234962f * (fVec44[((IOTA - 180) & 511)] + fVec44[((IOTA - 397) & 511)])) + ((0.00265511032f * (((fVec44[((IOTA - 62) & 511)] - fVec44[((IOTA - 65) & 511)]) - fVec44[((IOTA - 254) & 511)]) - fVec44[((IOTA - 390) & 511)])) + ((0.00335703604f * fVec44[((IOTA - 436) & 511)]) + ((0.00378429517f * (fVec44[((IOTA - 232) & 511)] - fVec44[((IOTA - 376) & 511)])) + ((0.00357066561f * fVec44[((IOTA - 381) & 511)]) + ((0.00106814783f * ((fVec44[((IOTA - 46) & 511)] - fVec44[((IOTA - 69) & 511)]) + fVec44[((IOTA - 367) & 511)])) + ((0.000305185094f * ((fVec44[((IOTA - 336) & 511)] + fVec44[((IOTA - 339) & 511)]) + fVec44[((IOTA - 366) & 511)])) + ((0.000427259132f * ((((((((((fVec44[((IOTA - 24) & 511)] - fVec44[((IOTA - 228) & 511)]) - fVec44[((IOTA - 237) & 511)]) + fVec44[((IOTA - 258) & 511)]) - fVec44[((IOTA - 263) & 511)]) - fVec44[((IOTA - 264) & 511)]) - fVec44[((IOTA - 295) & 511)]) - fVec44[((IOTA - 300) & 511)]) + fVec44[((IOTA - 312) & 511)]) + fVec44[((IOTA - 338) & 511)]) + fVec44[((IOTA - 343) & 511)])) + ((0.0019531846f * (((fVec44[((IOTA - 48) & 511)] - fVec44[((IOTA - 53) & 511)]) + fVec44[((IOTA - 284) & 511)]) + fVec44[((IOTA - 321) & 511)])) + ((0.00125125889f * (((fVec44[((IOTA - 111) & 511)] + fVec44[((IOTA - 277) & 511)]) - fVec44[((IOTA - 305) & 511)]) + fVec44[((IOTA - 316) & 511)])) + ((0.000823999755f * ((fVec44[((IOTA - 45) & 511)] - fVec44[((IOTA - 243) & 511)]) + fVec44[((IOTA - 287) & 511)])) + ((0.00204474013f * (((fVec44[((IOTA - 222) & 511)] - fVec44[((IOTA - 236) & 511)]) + fVec44[((IOTA - 273) & 511)]) + fVec44[((IOTA - 285) & 511)])) + ((0.00222785119f * ((fVec44[((IOTA - 32) & 511)] + fVec44[((IOTA - 50) & 511)]) + fVec44[((IOTA - 274) & 511)])) + ((0.00503555406f * (fVec44[((IOTA - 230) & 511)] - fVec44[((IOTA - 247) & 511)])) + ((0.00604266487f * fVec44[((IOTA - 231) & 511)]) + ((0.00238044374f * fVec44[((IOTA - 224) & 511)]) + ((0.00280770287f * fVec44[((IOTA - 221) & 511)]) + ((0.00326548051f * ((fVec44[((IOTA - 59) & 511)] - fVec44[((IOTA - 94) & 511)]) + fVec44[((IOTA - 220) & 511)])) + ((0.00274666585f * fVec44[((IOTA - 218) & 511)]) + ((0.00207525864f * fVec44[((IOTA - 215) & 511)]) + ((0.0058290353f * (fVec44[((IOTA - 148) & 511)] - fVec44[((IOTA - 201) & 511)])) + ((0.00497451704f * fVec44[((IOTA - 179) & 511)]) + ((0.00473036896f * fVec44[((IOTA - 178) & 511)]) + ((0.00723288674f * fVec44[((IOTA - 174) & 511)]) + ((0.00885036774f * fVec44[((IOTA - 173) & 511)]) + ((0.00500503555f * fVec44[((IOTA - 172) & 511)]) + ((0.00433362834f * fVec44[((IOTA - 166) & 511)]) + ((0.00384533219f * fVec44[((IOTA - 165) & 511)]) + ((0.0106814783f * (fVec44[((IOTA - 149) & 511)] + fVec44[((IOTA - 162) & 511)])) + ((0.0152897732f * fVec44[((IOTA - 161) & 511)]) + ((0.00659199804f * fVec44[((IOTA - 160) & 511)]) + ((0.00985747855f * fVec44[((IOTA - 154) & 511)]) + ((0.0115970336f * fVec44[((IOTA - 153) & 511)]) + ((0.0107425153f * fVec44[((IOTA - 152) & 511)]) + ((0.0115359966f * fVec44[((IOTA - 151) & 511)]) + ((0.0120853297f * fVec44[((IOTA - 150) & 511)]) + ((0.0067751091f * (fVec44[((IOTA - 101) & 511)] + fVec44[((IOTA - 139) & 511)])) + ((0.0105288858f * fVec44[((IOTA - 138) & 511)]) + ((0.00561540574f * fVec44[((IOTA - 137) & 511)]) + ((0.00750755332f * fVec44[((IOTA - 125) & 511)]) + ((0.0101321451f * fVec44[((IOTA - 124) & 511)]) + ((0.0054933317f * fVec44[((IOTA - 123) & 511)]) + ((0.0083925901f * fVec44[((IOTA - 122) & 511)]) + ((0.0123294778f * fVec44[((IOTA - 121) & 511)]) + ((0.0252082888f * fVec44[((IOTA - 120) & 511)]) + ((0.0287179183f * fVec44[((IOTA - 119) & 511)]) + ((0.0255134739f * fVec44[((IOTA - 118) & 511)]) + ((0.00869777519f * fVec44[((IOTA - 117) & 511)]) + ((0.0241706595f * fVec44[((IOTA - 110) & 511)]) + ((0.0411084332f * fVec44[((IOTA - 109) & 511)]) + ((0.0338755473f * fVec44[((IOTA - 108) & 511)]) + ((0.00442518387f * (fVec44[((IOTA - 60) & 511)] + fVec44[((IOTA - 107) & 511)])) + ((0.0374156944f * fVec44[((IOTA - 93) & 511)]) + ((0.0454725809f * fVec44[((IOTA - 92) & 511)]) + ((0.0264290292f * fVec44[((IOTA - 91) & 511)]) + ((0.128421888f * fVec44[((IOTA - 84) & 511)]) + ((0.272408217f * fVec44[((IOTA - 83) & 511)]) + ((0.301248193f * fVec44[((IOTA - 82) & 511)]) + ((0.0819422007f * fVec44[((IOTA - 80) & 511)]) + ((0.0201422162f * fVec44[((IOTA - 79) & 511)]) + ((0.00415051728f * (fVec44[((IOTA - 61) & 511)] + fVec44[((IOTA - 78) & 511)])) + ((0.204168826f * fVec44[((IOTA - 81) & 511)]) + ((0.00344859157f * fVec44[((IOTA - 34) & 511)]) + (0.00253303628f * (fVec44[((IOTA - 8) & 511)] + fVec44[((IOTA - 35) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000152592547f * ((((((((((((fVec44[((IOTA - 10) & 511)] - fVec44[((IOTA - 52) & 511)]) - fVec44[((IOTA - 292) & 511)]) + fVec44[((IOTA - 340) & 511)]) + fVec44[((IOTA - 356) & 511)]) - fVec44[((IOTA - 357) & 511)]) - fVec44[((IOTA - 394) & 511)]) - fVec44[((IOTA - 413) & 511)]) + fVec44[((IOTA - 445) & 511)]) - fVec44[((IOTA - 456) & 511)]) + fVec44[((IOTA - 496) & 511)]) + fVec44[((IOTA - 510) & 511)]) - fVec44[((IOTA - 511) & 511)]))) - (((0.000366222113f * ((fVec44[((IOTA - 365) & 511)] - fVec44[((IOTA - 444) & 511)]) - fVec44[((IOTA - 506) & 511)])) + ((0.000274666585f * ((((((fVec44[((IOTA - 4) & 511)] + fVec44[((IOTA - 238) & 511)]) - fVec44[((IOTA - 351) & 511)]) - fVec44[((IOTA - 352) & 511)]) - fVec44[((IOTA - 353) & 511)]) + fVec44[((IOTA - 472) & 511)]) + fVec44[((IOTA - 504) & 511)])) + ((0.000946073793f * ((((fVec44[((IOTA - 303) & 511)] - fVec44[((IOTA - 327) & 511)]) - fVec44[((IOTA - 332) & 511)]) - fVec44[((IOTA - 422) & 511)]) + fVec44[((IOTA - 502) & 511)])) + ((0.00109866634f * (((((fVec44[((IOTA - 15) & 511)] - fVec44[((IOTA - 58) & 511)]) + fVec44[((IOTA - 167) & 511)]) + fVec44[((IOTA - 306) & 511)]) + fVec44[((IOTA - 500) & 511)]) + fVec44[((IOTA - 501) & 511)])) + ((0.000915555283f * (((fVec44[((IOTA - 147) & 511)] - fVec44[((IOTA - 330) & 511)]) - fVec44[((IOTA - 408) & 511)]) + fVec44[((IOTA - 499) & 511)])) + ((0.000640888698f * ((((fVec44[((IOTA - 259) & 511)] + fVec44[((IOTA - 361) & 511)]) - fVec44[((IOTA - 415) & 511)]) - fVec44[((IOTA - 486) & 511)]) + fVec44[((IOTA - 498) & 511)])) + ((0.00149540696f * (((((fVec44[((IOTA - 64) & 511)] - fVec44[((IOTA - 286) & 511)]) - fVec44[((IOTA - 368) & 511)]) - fVec44[((IOTA - 383) & 511)]) + fVec44[((IOTA - 458) & 511)]) - fVec44[((IOTA - 493) & 511)])) + ((0.00189214759f * ((fVec44[((IOTA - 2) & 511)] - fVec44[((IOTA - 396) & 511)]) - fVec44[((IOTA - 492) & 511)])) + ((0.00155644398f * ((((fVec44[((IOTA - 239) & 511)] + fVec44[((IOTA - 250) & 511)]) - fVec44[((IOTA - 369) & 511)]) - fVec44[((IOTA - 423) & 511)]) - fVec44[((IOTA - 482) & 511)])) + ((0.00201422162f * (((fVec44[((IOTA - 14) & 511)] - fVec44[((IOTA - 229) & 511)]) + fVec44[((IOTA - 391) & 511)]) - fVec44[((IOTA - 480) & 511)])) + ((0.000122074038f * (((fVec44[((IOTA - 266) & 511)] - fVec44[((IOTA - 289) & 511)]) - fVec44[((IOTA - 373) & 511)]) + fVec44[((IOTA - 473) & 511)])) + ((0.00177007355f * ((fVec44[((IOTA - 155) & 511)] - fVec44[((IOTA - 441) & 511)]) - fVec44[((IOTA - 465) & 511)])) + ((0.00122074038f * ((((((fVec44[((IOTA - 30) & 511)] - fVec44[((IOTA - 207) & 511)]) - fVec44[((IOTA - 214) & 511)]) - fVec44[((IOTA - 282) & 511)]) - fVec44[((IOTA - 323) & 511)]) - fVec44[((IOTA - 442) & 511)]) - fVec44[((IOTA - 455) & 511)])) + ((0.00341807306f * ((((fVec44[((IOTA - 189) & 511)] + fVec44[((IOTA - 246) & 511)]) + fVec44[((IOTA - 377) & 511)]) - fVec44[((IOTA - 437) & 511)]) - fVec44[((IOTA - 453) & 511)])) + ((0.00338755455f * (fVec44[((IOTA - 54) & 511)] - fVec44[((IOTA - 452) & 511)])) + ((0.00186162908f * (fVec44[((IOTA - 1) & 511)] - fVec44[((IOTA - 450) & 511)])) + ((0.000793481246f * ((((((fVec44[((IOTA - 262) & 511)] - fVec44[((IOTA - 280) & 511)]) - fVec44[((IOTA - 313) & 511)]) - fVec44[((IOTA - 333) & 511)]) - fVec44[((IOTA - 372) & 511)]) - fVec44[((IOTA - 419) & 511)]) - fVec44[((IOTA - 448) & 511)])) + ((0.00302133244f * (fVec44[((IOTA - 235) & 511)] - fVec44[((IOTA - 435) & 511)])) + ((0.00256355479f * (fVec44[((IOTA - 27) & 511)] - fVec44[((IOTA - 434) & 511)])) + ((0.00210577715f * (((fVec44[((IOTA - 38) & 511)] - fVec44[((IOTA - 225) & 511)]) + fVec44[((IOTA - 252) & 511)]) - fVec44[((IOTA - 433) & 511)])) + ((0.00134281442f * ((fVec44[((IOTA - 3) & 511)] + fVec44[((IOTA - 261) & 511)]) - fVec44[((IOTA - 431) & 511)])) + ((0.00115970336f * (((fVec44[((IOTA - 70) & 511)] + fVec44[((IOTA - 304) & 511)]) + fVec44[((IOTA - 374) & 511)]) - fVec44[((IOTA - 426) & 511)])) + ((9.15555283e-05f * ((fVec44[((IOTA - 16) & 511)] + fVec44[((IOTA - 299) & 511)]) - fVec44[((IOTA - 409) & 511)])) + ((0.00268562883f * ((fVec44[((IOTA - 39) & 511)] + fVec44[((IOTA - 211) & 511)]) - fVec44[((IOTA - 400) & 511)])) + ((0.000762962736f * (((((fVec44[((IOTA - 37) & 511)] + fVec44[((IOTA - 42) & 511)]) + fVec44[((IOTA - 302) & 511)]) - fVec44[((IOTA - 324) & 511)]) - fVec44[((IOTA - 395) & 511)]) + fVec44[((IOTA - 461) & 511)])) + ((0.00277718436f * fVec44[((IOTA - 388) & 511)]) + ((0.00143436994f * (((fTemp45 + fVec44[((IOTA - 255) & 511)]) - fVec44[((IOTA - 270) & 511)]) + fVec44[((IOTA - 386) & 511)])) + ((0.000671407208f * ((((fVec44[((IOTA - 227) & 511)] - (fVec44[((IOTA - 17) & 511)] + fVec44[((IOTA - 226) & 511)])) + fVec44[((IOTA - 363) & 511)]) + fVec44[((IOTA - 364) & 511)]) + fVec44[((IOTA - 385) & 511)])) + ((0.000396740623f * (fVec44[((IOTA - 265) & 511)] - fVec44[((IOTA - 337) & 511)])) + ((0.0012817774f * (fVec44[((IOTA - 11) & 511)] - fVec44[((IOTA - 314) & 511)])) + ((3.05185094e-05f * fVec44[((IOTA - 308) & 511)]) + ((0.000183111057f * (((fVec44[((IOTA - 213) & 511)] - fVec44[((IOTA - 244) & 511)]) - fVec44[((IOTA - 288) & 511)]) - fVec44[((IOTA - 298) & 511)])) + ((0.000518814661f * (((fVec44[((IOTA - 25) & 511)] - fVec44[((IOTA - 31) & 511)]) - fVec44[((IOTA - 63) & 511)]) + fVec44[((IOTA - 293) & 511)])) + ((0.00167851802f * (fVec44[((IOTA - 41) & 511)] - fVec44[((IOTA - 276) & 511)])) + ((0.00296029542f * fVec44[((IOTA - 253) & 511)]) + ((0.00131229591f * ((fVec44[((IOTA - 210) & 511)] - (((fVec44[((IOTA - 19) & 511)] + fVec44[((IOTA - 22) & 511)]) - fVec44[((IOTA - 57) & 511)]) - fVec44[((IOTA - 181) & 511)])) + fVec44[((IOTA - 251) & 511)])) + ((0.00320444349f * fVec44[((IOTA - 249) & 511)]) + ((0.00482192449f * fVec44[((IOTA - 248) & 511)]) + ((0.00305185094f * fVec44[((IOTA - 242) & 511)]) + ((0.00424207281f * (fVec44[((IOTA - 188) & 511)] + fVec44[((IOTA - 241) & 511)])) + ((0.0035401471f * fVec44[((IOTA - 240) & 511)]) + ((0.0022583697f * ((fVec44[((IOTA - 12) & 511)] + fVec44[((IOTA - 140) & 511)]) - fVec44[((IOTA - 223) & 511)])) + ((0.00332651753f * (fVec44[((IOTA - 116) & 511)] - fVec44[((IOTA - 219) & 511)])) + ((0.00250251777f * (((fVec44[((IOTA - 13) & 511)] + fVec44[((IOTA - 40) & 511)]) - fVec44[((IOTA - 175) & 511)]) - fVec44[((IOTA - 217) & 511)])) + ((0.00262459181f * (fVec44[((IOTA - 203) & 511)] + fVec44[((IOTA - 204) & 511)])) + ((0.00427259132f * fVec44[((IOTA - 202) & 511)]) + ((0.0071108127f * fVec44[((IOTA - 200) & 511)]) + ((0.00643940549f * fVec44[((IOTA - 199) & 511)]) + ((0.00558488723f * fVec44[((IOTA - 198) & 511)]) + ((0.00476088747f * fVec44[((IOTA - 197) & 511)]) + ((0.00555436872f * fVec44[((IOTA - 196) & 511)]) + ((0.00631733146f * fVec44[((IOTA - 195) & 511)]) + ((0.00698873866f * fVec44[((IOTA - 194) & 511)]) + ((0.00592059083f * fVec44[((IOTA - 193) & 511)]) + ((0.00231940672f * (fVec44[((IOTA - 67) & 511)] + fVec44[((IOTA - 190) & 511)])) + ((0.00411999878f * fVec44[((IOTA - 186) & 511)]) + ((0.00708029419f * fVec44[((IOTA - 185) & 511)]) + ((0.0101016266f * fVec44[((IOTA - 184) & 511)]) + ((0.00943021942f * fVec44[((IOTA - 183) & 511)]) + ((0.0061342204f * fVec44[((IOTA - 182) & 511)]) + ((0.00463881344f * fVec44[((IOTA - 171) & 511)]) + ((0.0119327372f * fVec44[((IOTA - 170) & 511)]) + ((0.0136112552f * (fVec44[((IOTA - 112) & 511)] + fVec44[((IOTA - 169) & 511)])) + ((0.00399792474f * fVec44[((IOTA - 192) & 511)]) + ((0.00228888821f * fVec44[((IOTA - 191) & 511)]) + ((0.0167241432f * fVec44[((IOTA - 159) & 511)]) + ((0.0396130271f * fVec44[((IOTA - 158) & 511)]) + ((0.0427259132f * fVec44[((IOTA - 157) & 511)]) + ((0.0241401419f * fVec44[((IOTA - 156) & 511)]) + ((0.00854518265f * fVec44[((IOTA - 146) & 511)]) + ((0.0166631062f * fVec44[((IOTA - 145) & 511)]) + ((0.0237739198f * fVec44[((IOTA - 144) & 511)]) + ((0.0272835474f * fVec44[((IOTA - 143) & 511)]) + ((0.0236518458f * fVec44[((IOTA - 142) & 511)]) + ((0.0144657735f * fVec44[((IOTA - 141) & 511)]) + ((0.00390636921f * (fVec44[((IOTA - 55) & 511)] + fVec44[((IOTA - 136) & 511)])) + ((0.00909451582f * fVec44[((IOTA - 168) & 511)]) + ((0.0353099145f * fVec44[((IOTA - 132) & 511)]) + ((0.0379345082f * fVec44[((IOTA - 131) & 511)]) + ((0.0361949541f * fVec44[((IOTA - 130) & 511)]) + ((0.034028139f * fVec44[((IOTA - 129) & 511)]) + ((0.022644734f * fVec44[((IOTA - 128) & 511)]) + ((0.0104068117f * fVec44[((IOTA - 127) & 511)]) + ((0.0271004364f * fVec44[((IOTA - 134) & 511)]) + ((0.0173955504f * fVec44[((IOTA - 135) & 511)]) + ((0.0188299213f * fVec44[((IOTA - 115) & 511)]) + ((0.0238654744f * (fVec44[((IOTA - 103) & 511)] + fVec44[((IOTA - 114) & 511)])) + ((0.022461623f * fVec44[((IOTA - 113) & 511)]) + ((0.0280770287f * fVec44[((IOTA - 106) & 511)]) + ((0.0502334684f * fVec44[((IOTA - 105) & 511)]) + ((0.0477309488f * fVec44[((IOTA - 104) & 511)]) + ((0.0141605884f * fVec44[((IOTA - 100) & 511)]) + ((0.0365001373f * fVec44[((IOTA - 99) & 511)]) + ((0.0571306497f * fVec44[((IOTA - 98) & 511)]) + ((0.0668355376f * fVec44[((IOTA - 97) & 511)]) + ((0.0653096139f * fVec44[((IOTA - 96) & 511)]) + ((0.0376293212f * fVec44[((IOTA - 95) & 511)]) + ((0.0343028046f * fVec44[((IOTA - 133) & 511)]) + ((0.0119632557f * fVec44[((IOTA - 90) & 511)]) + ((0.0459608771f * fVec44[((IOTA - 89) & 511)]) + ((0.0983611569f * fVec44[((IOTA - 88) & 511)]) + ((0.141453296f * fVec44[((IOTA - 87) & 511)]) + ((0.135258034f * fVec44[((IOTA - 86) & 511)]) + ((0.043244727f * fVec44[((IOTA - 85) & 511)]) + ((0.00610370189f * fVec44[((IOTA - 76) & 511)]) + ((0.00961333048f * fVec44[((IOTA - 75) & 511)]) + ((0.00991851557f * fVec44[((IOTA - 74) & 511)]) + ((0.00805688649f * fVec44[((IOTA - 73) & 511)]) + ((0.00491348002f * fVec44[((IOTA - 72) & 511)]) + ((0.00283822138f * fVec44[((IOTA - 66) & 511)]) + ((0.00317392498f * fVec44[((IOTA - 56) & 511)]) + ((0.00247199927f * fVec44[((IOTA - 29) & 511)]) + ((0.001617481f * fVec44[((IOTA - 26) & 511)]) + (0.00292977691f * fVec44[((IOTA - 28) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000610370189f * ((((((((fVec44[((IOTA - 77) & 511)] + fVec44[((IOTA - 301) & 511)]) + fVec44[((IOTA - 307) & 511)]) + fVec44[((IOTA - 362) & 511)]) - fVec44[((IOTA - 427) & 511)]) - fVec44[((IOTA - 429) & 511)]) + fVec44[((IOTA - 503) & 511)]) - fVec44[((IOTA - 507) & 511)]) - fVec44[((IOTA - 508) & 511)])))) : ((((0.000701925717f * ((((fVec43[((IOTA - 414) & 511)] + fVec43[((IOTA - 425) & 511)]) + fVec43[((IOTA - 438) & 511)]) - fVec43[((IOTA - 465) & 511)]) + fVec43[((IOTA - 509) & 511)])) + ((0.000488296151f * ((((fVec43[((IOTA - 200) & 511)] - fVec43[((IOTA - 410) & 511)]) + fVec43[((IOTA - 441) & 511)]) + fVec43[((IOTA - 449) & 511)]) + fVec43[((IOTA - 508) & 511)])) + ((0.000213629566f * (((((fVec43[((IOTA - 57) & 511)] + fVec43[((IOTA - 166) & 511)]) - fVec43[((IOTA - 212) & 511)]) - fVec43[((IOTA - 213) & 511)]) - fVec43[((IOTA - 468) & 511)]) + fVec43[((IOTA - 507) & 511)])) + ((6.10370189e-05f * ((((((((((((((((((((((((((((fVec43[((IOTA - 18) & 511)] + fVec43[((IOTA - 19) & 511)]) + fVec43[((IOTA - 20) & 511)]) + fVec43[((IOTA - 21) & 511)]) + fVec43[((IOTA - 23) & 511)]) + fVec43[((IOTA - 26) & 511)]) + fVec43[((IOTA - 28) & 511)]) + fVec43[((IOTA - 31) & 511)]) + fVec43[((IOTA - 32) & 511)]) + fVec43[((IOTA - 33) & 511)]) + fVec43[((IOTA - 34) & 511)]) + fVec43[((IOTA - 35) & 511)]) + fVec43[((IOTA - 37) & 511)]) + fVec43[((IOTA - 39) & 511)]) + fVec43[((IOTA - 40) & 511)]) + fVec43[((IOTA - 41) & 511)]) + fVec43[((IOTA - 42) & 511)]) + fVec43[((IOTA - 43) & 511)]) + fVec43[((IOTA - 44) & 511)]) + fVec43[((IOTA - 50) & 511)]) + fVec43[((IOTA - 51) & 511)]) + fVec43[((IOTA - 53) & 511)]) + fVec43[((IOTA - 58) & 511)]) + fVec43[((IOTA - 360) & 511)]) + fVec43[((IOTA - 399) & 511)]) - fVec43[((IOTA - 403) & 511)]) + fVec43[((IOTA - 454) & 511)]) + fVec43[((IOTA - 463) & 511)]) - fVec43[((IOTA - 506) & 511)])) + ((0.000366222113f * ((((fVec43[((IOTA - 401) & 511)] + fVec43[((IOTA - 402) & 511)]) - fVec43[((IOTA - 453) & 511)]) - fVec43[((IOTA - 464) & 511)]) - fVec43[((IOTA - 504) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((fTemp44 + fVec43[((IOTA - 1) & 511)]) + fVec43[((IOTA - 2) & 511)]) + fVec43[((IOTA - 3) & 511)]) + fVec43[((IOTA - 4) & 511)]) + fVec43[((IOTA - 5) & 511)]) + fVec43[((IOTA - 6) & 511)]) + fVec43[((IOTA - 7) & 511)]) + fVec43[((IOTA - 8) & 511)]) + fVec43[((IOTA - 9) & 511)]) + fVec43[((IOTA - 10) & 511)]) + fVec43[((IOTA - 11) & 511)]) + fVec43[((IOTA - 12) & 511)]) + fVec43[((IOTA - 13) & 511)]) + fVec43[((IOTA - 14) & 511)]) + fVec43[((IOTA - 15) & 511)]) + fVec43[((IOTA - 16) & 511)]) + fVec43[((IOTA - 17) & 511)]) + fVec43[((IOTA - 22) & 511)]) + fVec43[((IOTA - 24) & 511)]) + fVec43[((IOTA - 25) & 511)]) + fVec43[((IOTA - 29) & 511)]) + fVec43[((IOTA - 30) & 511)]) + fVec43[((IOTA - 36) & 511)]) + fVec43[((IOTA - 38) & 511)]) + fVec43[((IOTA - 52) & 511)]) - fVec43[((IOTA - 411) & 511)]) - fVec43[((IOTA - 502) & 511)])) + ((0.000244148076f * ((((fVec43[((IOTA - 55) & 511)] - fVec43[((IOTA - 59) & 511)]) - fVec43[((IOTA - 165) & 511)]) + fVec43[((IOTA - 378) & 511)]) + fVec43[((IOTA - 501) & 511)])) + ((0.000396740623f * ((((fVec43[((IOTA - 162) & 511)] - fVec43[((IOTA - 317) & 511)]) - fVec43[((IOTA - 328) & 511)]) + fVec43[((IOTA - 412) & 511)]) - fVec43[((IOTA - 494) & 511)])) + ((0.000427259132f * (fVec43[((IOTA - 439) & 511)] - fVec43[((IOTA - 493) & 511)])) + ((0.000122074038f * (((fVec43[((IOTA - 54) & 511)] + fVec43[((IOTA - 148) & 511)]) - fVec43[((IOTA - 424) & 511)]) - fVec43[((IOTA - 491) & 511)])) + ((0.00134281442f * (((((((fVec43[((IOTA - 133) & 511)] - fVec43[((IOTA - 304) & 511)]) - fVec43[((IOTA - 332) & 511)]) + fVec43[((IOTA - 436) & 511)]) + fVec43[((IOTA - 481) & 511)]) + fVec43[((IOTA - 482) & 511)]) + fVec43[((IOTA - 483) & 511)]) + fVec43[((IOTA - 484) & 511)])) + ((0.00100711081f * fVec43[((IOTA - 461) & 511)]) + ((0.00183111057f * (((fVec43[((IOTA - 199) & 511)] - fVec43[((IOTA - 313) & 511)]) - fVec43[((IOTA - 352) & 511)]) + fVec43[((IOTA - 459) & 511)])) + ((0.00198370311f * fVec43[((IOTA - 458) & 511)]) + ((0.00317392498f * fVec43[((IOTA - 447) & 511)]) + ((0.00347911008f * fVec43[((IOTA - 445) & 511)]) + ((0.000305185094f * (((fVec43[((IOTA - 56) & 511)] + fVec43[((IOTA - 400) & 511)]) - fVec43[((IOTA - 404) & 511)]) + fVec43[((IOTA - 440) & 511)])) + ((0.00253303628f * (fVec43[((IOTA - 395) & 511)] + fVec43[((IOTA - 429) & 511)])) + ((9.15555283e-05f * (((((fVec43[((IOTA - 45) & 511)] + fVec43[((IOTA - 46) & 511)]) + fVec43[((IOTA - 47) & 511)]) + fVec43[((IOTA - 48) & 511)]) + fVec43[((IOTA - 49) & 511)]) + fVec43[((IOTA - 420) & 511)])) + ((0.000762962736f * ((fVec43[((IOTA - 198) & 511)] - fVec43[((IOTA - 325) & 511)]) - fVec43[((IOTA - 406) & 511)])) + ((0.000671407208f * fVec43[((IOTA - 365) & 511)]) + ((0.00527970213f * fVec43[((IOTA - 161) & 511)]) + ((0.00720236823f * fVec43[((IOTA - 160) & 511)]) + ((0.00402844325f * fVec43[((IOTA - 159) & 511)]) + ((0.00405896176f * fVec43[((IOTA - 139) & 511)]) + ((0.00662251655f * fVec43[((IOTA - 138) & 511)]) + ((0.0093691824f * fVec43[((IOTA - 137) & 511)]) + ((0.0104678487f * fVec43[((IOTA - 136) & 511)]) + ((0.0109256264f * fVec43[((IOTA - 135) & 511)]) + ((0.00668355357f * fVec43[((IOTA - 134) & 511)]) + ((0.00781273842f * fVec43[((IOTA - 125) & 511)]) + ((0.0211188085f * fVec43[((IOTA - 124) & 511)]) + ((0.0216071047f * fVec43[((IOTA - 123) & 511)]) + ((0.00564592425f * fVec43[((IOTA - 112) & 511)]) + ((0.0198065136f * fVec43[((IOTA - 111) & 511)]) + ((0.0224921424f * fVec43[((IOTA - 110) & 511)]) + ((0.0228888821f * fVec43[((IOTA - 109) & 511)]) + ((0.0279244371f * fVec43[((IOTA - 108) & 511)]) + ((0.0267342143f * fVec43[((IOTA - 107) & 511)]) + ((0.0208441429f * fVec43[((IOTA - 106) & 511)]) + ((0.00967436749f * fVec43[((IOTA - 122) & 511)]) + ((0.0201116987f * fVec43[((IOTA - 98) & 511)]) + ((0.0325327329f * fVec43[((IOTA - 97) & 511)]) + ((0.024567401f * fVec43[((IOTA - 96) & 511)]) + ((0.0042115543f * fVec43[((IOTA - 95) & 511)]) + ((0.0218817722f * fVec43[((IOTA - 83) & 511)]) + ((0.0331125818f * fVec43[((IOTA - 82) & 511)]) + ((0.0370494723f * fVec43[((IOTA - 81) & 511)]) + ((0.0369884335f * fVec43[((IOTA - 80) & 511)]) + ((0.0148930326f * fVec43[((IOTA - 79) & 511)]) + ((0.0684224963f * fVec43[((IOTA - 73) & 511)]) + ((0.267830431f * fVec43[((IOTA - 72) & 511)]) + ((0.338633388f * fVec43[((IOTA - 71) & 511)]) + ((0.227759629f * fVec43[((IOTA - 70) & 511)]) + ((0.0834376067f * fVec43[((IOTA - 69) & 511)]) + ((0.00476088747f * fVec43[((IOTA - 67) & 511)]) + (0.0180669576f * fVec43[((IOTA - 68) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000793481246f * ((fVec43[((IOTA - 390) & 511)] + fVec43[((IOTA - 510) & 511)]) + fVec43[((IOTA - 511) & 511)]))) - ((((0.000732444227f * (((((((fVec43[((IOTA - 310) & 511)] + fVec43[((IOTA - 359) & 511)]) - fVec43[((IOTA - 415) & 511)]) + fVec43[((IOTA - 423) & 511)]) + fVec43[((IOTA - 452) & 511)]) + fVec43[((IOTA - 467) & 511)]) - fVec43[((IOTA - 498) & 511)]) - fVec43[((IOTA - 499) & 511)])) + ((0.000518814661f * ((((fVec43[((IOTA - 140) & 511)] - fVec43[((IOTA - 373) & 511)]) + fVec43[((IOTA - 421) & 511)]) - fVec43[((IOTA - 462) & 511)]) - fVec43[((IOTA - 497) & 511)])) + ((0.000152592547f * (fVec43[((IOTA - 495) & 511)] - fVec43[((IOTA - 496) & 511)])) + ((0.000335703604f * (((fVec43[((IOTA - 84) & 511)] - fVec43[((IOTA - 147) & 511)]) - fVec43[((IOTA - 398) & 511)]) + fVec43[((IOTA - 492) & 511)])) + ((0.000183111057f * (fVec43[((IOTA - 211) & 511)] - fVec43[((IOTA - 490) & 511)])) + ((0.00057985168f * ((((fVec43[((IOTA - 104) & 511)] + fVec43[((IOTA - 329) & 511)]) - fVec43[((IOTA - 413) & 511)]) + fVec43[((IOTA - 450) & 511)]) - fVec43[((IOTA - 489) & 511)])) + ((0.000915555283f * (fVec43[((IOTA - 451) & 511)] - fVec43[((IOTA - 488) & 511)])) + ((0.00115970336f * (((fVec43[((IOTA - 372) & 511)] - fVec43[((IOTA - 477) & 511)]) - fVec43[((IOTA - 478) & 511)]) - fVec43[((IOTA - 487) & 511)])) + ((0.00131229591f * ((((fVec43[((IOTA - 254) & 511)] + fVec43[((IOTA - 303) & 511)]) + fVec43[((IOTA - 358) & 511)]) - fVec43[((IOTA - 480) & 511)]) - fVec43[((IOTA - 486) & 511)])) + ((0.00137333293f * ((((fVec43[((IOTA - 209) & 511)] + fVec43[((IOTA - 344) & 511)]) - fVec43[((IOTA - 374) & 511)]) - fVec43[((IOTA - 433) & 511)]) - fVec43[((IOTA - 485) & 511)])) + ((0.00125125889f * (((fVec43[((IOTA - 255) & 511)] + fVec43[((IOTA - 320) & 511)]) + fVec43[((IOTA - 349) & 511)]) - fVec43[((IOTA - 479) & 511)])) + ((0.0012817774f * (((fVec43[((IOTA - 315) & 511)] + fVec43[((IOTA - 348) & 511)]) - fVec43[((IOTA - 456) & 511)]) - fVec43[((IOTA - 476) & 511)])) + ((0.00158696249f * ((fVec43[((IOTA - 146) & 511)] - fVec43[((IOTA - 470) & 511)]) - fVec43[((IOTA - 475) & 511)])) + ((0.00210577715f * ((((fVec43[((IOTA - 261) & 511)] + fVec43[((IOTA - 278) & 511)]) - fVec43[((IOTA - 375) & 511)]) - fVec43[((IOTA - 427) & 511)]) - fVec43[((IOTA - 474) & 511)])) + ((0.00262459181f * (fVec43[((IOTA - 155) & 511)] - fVec43[((IOTA - 473) & 511)])) + ((0.00280770287f * (((fVec43[((IOTA - 243) & 511)] + fVec43[((IOTA - 244) & 511)]) + fVec43[((IOTA - 286) & 511)]) - fVec43[((IOTA - 472) & 511)])) + ((0.00244148076f * (fVec43[((IOTA - 270) & 511)] - fVec43[((IOTA - 471) & 511)])) + ((0.000610370189f * ((fVec43[((IOTA - 405) & 511)] - fVec43[((IOTA - 455) & 511)]) - fVec43[((IOTA - 469) & 511)])) + ((0.000854518265f * (((fVec43[((IOTA - 210) & 511)] - fVec43[((IOTA - 397) & 511)]) + fVec43[((IOTA - 422) & 511)]) + fVec43[((IOTA - 466) & 511)])) + ((0.00143436994f * ((((fVec43[((IOTA - 321) & 511)] + fVec43[((IOTA - 335) & 511)]) + fVec43[((IOTA - 350) & 511)]) - fVec43[((IOTA - 435) & 511)]) - fVec43[((IOTA - 460) & 511)])) + ((0.00180059206f * ((fVec43[((IOTA - 164) & 511)] - fVec43[((IOTA - 377) & 511)]) - fVec43[((IOTA - 457) & 511)])) + ((0.0019226661f * ((fVec43[((IOTA - 176) & 511)] + fVec43[((IOTA - 301) & 511)]) - fVec43[((IOTA - 448) & 511)])) + ((0.00375377666f * (fVec43[((IOTA - 386) & 511)] - fVec43[((IOTA - 446) & 511)])) + ((0.00256355479f * ((((fVec43[((IOTA - 175) & 511)] + fVec43[((IOTA - 276) & 511)]) + fVec43[((IOTA - 291) & 511)]) + fVec43[((IOTA - 298) & 511)]) - fVec43[((IOTA - 444) & 511)])) + ((0.001617481f * ((fVec43[((IOTA - 333) & 511)] + fVec43[((IOTA - 346) & 511)]) - fVec43[((IOTA - 443) & 511)])) + ((0.000885036774f * (((((fVec43[((IOTA - 337) & 511)] + fVec43[((IOTA - 342) & 511)]) - fVec43[((IOTA - 361) & 511)]) + fVec43[((IOTA - 409) & 511)]) - fVec43[((IOTA - 417) & 511)]) - fVec43[((IOTA - 442) & 511)])) + ((0.00103762932f * ((((fVec43[((IOTA - 324) & 511)] + fVec43[((IOTA - 336) & 511)]) + fVec43[((IOTA - 343) & 511)]) + fVec43[((IOTA - 366) & 511)]) - fVec43[((IOTA - 437) & 511)])) + ((0.00152592547f * ((fVec43[((IOTA - 256) & 511)] + fVec43[((IOTA - 312) & 511)]) - fVec43[((IOTA - 432) & 511)])) + ((0.00186162908f * ((((fVec43[((IOTA - 163) & 511)] + fVec43[((IOTA - 216) & 511)]) + fVec43[((IOTA - 307) & 511)]) - fVec43[((IOTA - 364) & 511)]) - fVec43[((IOTA - 431) & 511)])) + ((0.00228888821f * (((fVec43[((IOTA - 260) & 511)] + fVec43[((IOTA - 269) & 511)]) + fVec43[((IOTA - 296) & 511)]) - fVec43[((IOTA - 430) & 511)])) + ((0.00250251777f * ((((((fVec43[((IOTA - 158) & 511)] + fVec43[((IOTA - 287) & 511)]) + fVec43[((IOTA - 289) & 511)]) + fVec43[((IOTA - 299) & 511)]) + fVec43[((IOTA - 382) & 511)]) - fVec43[((IOTA - 391) & 511)]) - fVec43[((IOTA - 428) & 511)])) + ((0.00149540696f * (((fVec43[((IOTA - 252) & 511)] + fVec43[((IOTA - 302) & 511)]) + fVec43[((IOTA - 322) & 511)]) - fVec43[((IOTA - 426) & 511)])) + ((0.000640888698f * ((fVec43[((IOTA - 316) & 511)] + fVec43[((IOTA - 326) & 511)]) - fVec43[((IOTA - 419) & 511)])) + ((0.000946073793f * ((fVec43[((IOTA - 215) & 511)] + fVec43[((IOTA - 338) & 511)]) - fVec43[((IOTA - 418) & 511)])) + ((0.000823999755f * (fVec43[((IOTA - 319) & 511)] - fVec43[((IOTA - 416) & 511)])) + ((0.00177007355f * (fVec43[((IOTA - 267) & 511)] - fVec43[((IOTA - 396) & 511)])) + ((0.00305185094f * (fVec43[((IOTA - 229) & 511)] - fVec43[((IOTA - 394) & 511)])) + ((0.00326548051f * (fVec43[((IOTA - 281) & 511)] - fVec43[((IOTA - 393) & 511)])) + ((0.00314340647f * (((fVec43[((IOTA - 242) & 511)] + fVec43[((IOTA - 285) & 511)]) + fVec43[((IOTA - 367) & 511)]) - fVec43[((IOTA - 392) & 511)])) + ((0.00109866634f * (fVec43[((IOTA - 339) & 511)] + fVec43[((IOTA - 389) & 511)])) + ((0.00140385143f * (((fVec43[((IOTA - 60) & 511)] + fVec43[((IOTA - 264) & 511)]) + fVec43[((IOTA - 265) & 511)]) - fVec43[((IOTA - 434) & 511)])) + ((0.00271614734f * fVec43[((IOTA - 388) & 511)]) + ((0.00344859157f * fVec43[((IOTA - 387) & 511)]) + ((0.00335703604f * fVec43[((IOTA - 385) & 511)]) + ((0.00274666585f * fVec43[((IOTA - 384) & 511)]) + ((0.00234992523f * fVec43[((IOTA - 383) & 511)]) + ((0.00286873989f * ((fVec43[((IOTA - 196) & 511)] + fVec43[((IOTA - 231) & 511)]) + fVec43[((IOTA - 381) & 511)])) + ((0.00268562883f * (fVec43[((IOTA - 230) & 511)] + fVec43[((IOTA - 380) & 511)])) + ((0.00155644398f * ((fVec43[((IOTA - 266) & 511)] + fVec43[((IOTA - 305) & 511)]) + fVec43[((IOTA - 379) & 511)])) + ((0.00247199927f * (fVec43[((IOTA - 271) & 511)] - fVec43[((IOTA - 376) & 511)])) + ((0.00360118411f * ((fVec43[((IOTA - 240) & 511)] + fVec43[((IOTA - 283) & 511)]) + fVec43[((IOTA - 371) & 511)])) + ((0.0058290353f * (fVec43[((IOTA - 154) & 511)] + fVec43[((IOTA - 370) & 511)])) + ((0.00631733146f * fVec43[((IOTA - 369) & 511)]) + ((0.00518814661f * (fVec43[((IOTA - 188) & 511)] + fVec43[((IOTA - 368) & 511)])) + ((0.00213629566f * (fVec43[((IOTA - 355) & 511)] - fVec43[((IOTA - 363) & 511)])) + ((0.00173955504f * ((fVec43[((IOTA - 201) & 511)] + fVec43[((IOTA - 306) & 511)]) - fVec43[((IOTA - 362) & 511)])) + ((0.00167851802f * ((((fVec43[((IOTA - 177) & 511)] + fVec43[((IOTA - 208) & 511)]) + fVec43[((IOTA - 308) & 511)]) + fVec43[((IOTA - 314) & 511)]) + fVec43[((IOTA - 357) & 511)])) + ((0.0019531846f * fVec43[((IOTA - 356) & 511)]) + ((0.00216681417f * (fVec43[((IOTA - 257) & 511)] + fVec43[((IOTA - 354) & 511)])) + ((0.00204474013f * fVec43[((IOTA - 353) & 511)]) + ((0.00164799951f * ((fVec43[((IOTA - 263) & 511)] + fVec43[((IOTA - 345) & 511)]) + fVec43[((IOTA - 351) & 511)])) + ((0.00146488845f * (fVec43[((IOTA - 253) & 511)] + fVec43[((IOTA - 347) & 511)])) + ((0.00119022187f * fVec43[((IOTA - 340) & 511)]) + ((0.00170903653f * fVec43[((IOTA - 334) & 511)]) + ((0.00122074038f * (((fVec43[((IOTA - 249) & 511)] + fVec43[((IOTA - 251) & 511)]) + fVec43[((IOTA - 323) & 511)]) + fVec43[((IOTA - 331) & 511)])) + ((0.000976592302f * (fVec43[((IOTA - 250) & 511)] + fVec43[((IOTA - 330) & 511)])) + ((0.000457777642f * fVec43[((IOTA - 327) & 511)]) + ((0.00112918485f * ((fVec43[((IOTA - 66) & 511)] + fVec43[((IOTA - 197) & 511)]) + fVec43[((IOTA - 311) & 511)])) + ((0.00231940672f * (fVec43[((IOTA - 205) & 511)] + fVec43[((IOTA - 300) & 511)])) + ((0.00241096225f * (fVec43[((IOTA - 288) & 511)] + fVec43[((IOTA - 297) & 511)])) + ((0.00222785119f * (fVec43[((IOTA - 293) & 511)] + fVec43[((IOTA - 295) & 511)])) + ((0.00219733268f * (fVec43[((IOTA - 277) & 511)] + fVec43[((IOTA - 294) & 511)])) + ((0.00238044374f * ((fVec43[((IOTA - 178) & 511)] + fVec43[((IOTA - 279) & 511)]) + fVec43[((IOTA - 292) & 511)])) + ((0.0025940733f * ((((fVec43[((IOTA - 78) & 511)] + fVec43[((IOTA - 258) & 511)]) + fVec43[((IOTA - 259) & 511)]) + fVec43[((IOTA - 272) & 511)]) + fVec43[((IOTA - 290) & 511)])) + ((0.00338755455f * (fVec43[((IOTA - 241) & 511)] + fVec43[((IOTA - 284) & 511)])) + ((0.00366222113f * (((fVec43[((IOTA - 190) & 511)] + fVec43[((IOTA - 218) & 511)]) + fVec43[((IOTA - 235) & 511)]) + fVec43[((IOTA - 282) & 511)])) + ((0.00283822138f * (fVec43[((IOTA - 217) & 511)] + fVec43[((IOTA - 280) & 511)])) + ((0.00296029542f * ((fVec43[((IOTA - 245) & 511)] + fVec43[((IOTA - 247) & 511)]) + fVec43[((IOTA - 275) & 511)])) + ((0.00308236945f * (fVec43[((IOTA - 237) & 511)] + fVec43[((IOTA - 274) & 511)])) + ((0.0028992584f * fVec43[((IOTA - 273) & 511)]) + ((0.00201422162f * (((fVec43[((IOTA - 167) & 511)] + fVec43[((IOTA - 206) & 511)]) + fVec43[((IOTA - 207) & 511)]) + fVec43[((IOTA - 268) & 511)])) + ((0.00189214759f * fVec43[((IOTA - 262) & 511)]) + ((0.00106814783f * (((fVec43[((IOTA - 309) & 511)] + fVec43[((IOTA - 341) & 511)]) + fVec43[((IOTA - 407) & 511)]) + fVec43[((IOTA - 408) & 511)])) + ((0.00207525864f * fVec43[((IOTA - 248) & 511)]) + ((0.003234962f * (fVec43[((IOTA - 238) & 511)] + fVec43[((IOTA - 246) & 511)])) + ((0.00350962859f * fVec43[((IOTA - 239) & 511)]) + ((0.00329599902f * fVec43[((IOTA - 236) & 511)]) + ((0.00381481368f * (fVec43[((IOTA - 189) & 511)] + fVec43[((IOTA - 234) & 511)])) + ((0.00369273964f * fVec43[((IOTA - 233) & 511)]) + ((0.00341807306f * (fVec43[((IOTA - 202) & 511)] + fVec43[((IOTA - 232) & 511)])) + ((0.00399792474f * (fVec43[((IOTA - 223) & 511)] + fVec43[((IOTA - 228) & 511)])) + ((0.00424207281f * (fVec43[((IOTA - 174) & 511)] + fVec43[((IOTA - 227) & 511)])) + ((0.00390636921f * fVec43[((IOTA - 226) & 511)]) + ((0.00332651753f * (fVec43[((IOTA - 224) & 511)] + fVec43[((IOTA - 225) & 511)])) + ((0.00491348002f * fVec43[((IOTA - 222) & 511)]) + ((0.00540177617f * fVec43[((IOTA - 221) & 511)]) + ((0.00524918362f * (fVec43[((IOTA - 145) & 511)] + fVec43[((IOTA - 220) & 511)])) + ((0.00460829493f * fVec43[((IOTA - 219) & 511)]) + ((0.00302133244f * fVec43[((IOTA - 204) & 511)]) + ((0.00372325815f * fVec43[((IOTA - 203) & 511)]) + ((0.00384533219f * (fVec43[((IOTA - 149) & 511)] + fVec43[((IOTA - 195) & 511)])) + ((0.00457777642f * fVec43[((IOTA - 194) & 511)]) + ((0.00479140598f * fVec43[((IOTA - 193) & 511)]) + ((0.00503555406f * fVec43[((IOTA - 192) & 511)]) + ((0.00442518387f * (fVec43[((IOTA - 61) & 511)] + fVec43[((IOTA - 191) & 511)])) + ((0.00634784997f * (fVec43[((IOTA - 172) & 511)] + fVec43[((IOTA - 187) & 511)])) + ((0.00680562761f * fVec43[((IOTA - 186) & 511)]) + ((0.0077517014f * fVec43[((IOTA - 185) & 511)]) + ((0.00976592302f * fVec43[((IOTA - 184) & 511)]) + ((0.0114749596f * fVec43[((IOTA - 183) & 511)]) + ((0.0116275521f * fVec43[((IOTA - 182) & 511)]) + ((0.00991851557f * fVec43[((IOTA - 181) & 511)]) + ((0.00704977568f * fVec43[((IOTA - 180) & 511)]) + ((0.00411999878f * fVec43[((IOTA - 179) & 511)]) + ((0.00543229468f * fVec43[((IOTA - 173) & 511)]) + ((0.00790429395f * fVec43[((IOTA - 171) & 511)]) + ((0.00921658985f * fVec43[((IOTA - 170) & 511)]) + ((0.00906399731f * fVec43[((IOTA - 169) & 511)]) + ((0.0061342204f * fVec43[((IOTA - 168) & 511)]) + ((0.00473036896f * fVec43[((IOTA - 157) & 511)]) + ((0.00320444349f * fVec43[((IOTA - 156) & 511)]) + ((0.0118106632f * fVec43[((IOTA - 153) & 511)]) + ((0.0174565874f * fVec43[((IOTA - 152) & 511)]) + ((0.0172124393f * fVec43[((IOTA - 151) & 511)]) + ((0.0117801446f * fVec43[((IOTA - 150) & 511)]) + ((0.00979644153f * fVec43[((IOTA - 144) & 511)]) + ((0.0108951079f * fVec43[((IOTA - 143) & 511)]) + ((0.00878933072f * fVec43[((IOTA - 142) & 511)]) + ((0.00469985045f * fVec43[((IOTA - 141) & 511)]) + ((0.00653096102f * fVec43[((IOTA - 132) & 511)]) + ((0.0172734763f * fVec43[((IOTA - 131) & 511)]) + ((0.0281685852f * fVec43[((IOTA - 130) & 511)]) + ((0.0351573229f * (fVec43[((IOTA - 86) & 511)] + fVec43[((IOTA - 129) & 511)])) + ((0.0369579159f * fVec43[((IOTA - 128) & 511)]) + ((0.0300302133f * fVec43[((IOTA - 127) & 511)]) + ((0.0133976256f * fVec43[((IOTA - 126) & 511)]) + ((0.00640888698f * fVec43[((IOTA - 121) & 511)]) + ((0.0209967345f * fVec43[((IOTA - 120) & 511)]) + ((0.0256660674f * fVec43[((IOTA - 119) & 511)]) + ((0.0264290292f * fVec43[((IOTA - 118) & 511)]) + ((0.0266121402f * fVec43[((IOTA - 117) & 511)]) + ((0.0285653248f * fVec43[((IOTA - 116) & 511)]) + ((0.0248725861f * fVec43[((IOTA - 115) & 511)]) + ((0.0180059206f * fVec43[((IOTA - 114) & 511)]) + ((0.00863673817f * fVec43[((IOTA - 113) & 511)]) + ((0.0155034028f * (fVec43[((IOTA - 85) & 511)] - fVec43[((IOTA - 105) & 511)])) + ((0.014618366f * fVec43[((IOTA - 103) & 511)]) + ((0.0223090313f * fVec43[((IOTA - 102) & 511)]) + ((0.0256050304f * fVec43[((IOTA - 101) & 511)]) + ((0.0278939176f * fVec43[((IOTA - 100) & 511)]) + ((0.00796533097f * fVec43[((IOTA - 99) & 511)]) + ((0.0177617725f * fVec43[((IOTA - 94) & 511)]) + ((0.0299691763f * fVec43[((IOTA - 93) & 511)]) + ((0.0310983621f * fVec43[((IOTA - 92) & 511)]) + ((0.0147099216f * fVec43[((IOTA - 91) & 511)]) + ((0.009704886f * fVec43[((IOTA - 90) & 511)]) + ((0.0134586627f * fVec43[((IOTA - 89) & 511)]) + ((0.0333872512f * fVec43[((IOTA - 88) & 511)]) + ((0.0316476934f * fVec43[((IOTA - 87) & 511)]) + ((0.0528885759f * fVec43[((IOTA - 77) & 511)]) + ((0.110721156f * fVec43[((IOTA - 76) & 511)]) + ((0.154942468f * fVec43[((IOTA - 75) & 511)]) + ((0.104678489f * fVec43[((IOTA - 74) & 511)]) + ((0.00778221991f * fVec43[((IOTA - 65) & 511)]) + ((0.0112308115f * fVec43[((IOTA - 64) & 511)]) + ((0.00842310861f * fVec43[((IOTA - 62) & 511)]) + (0.0111392559f * fVec43[((IOTA - 63) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00054933317f * ((fVec43[((IOTA - 214) & 511)] + fVec43[((IOTA - 318) & 511)]) - fVec43[((IOTA - 500) & 511)]))) + (0.000274666585f * (fVec43[((IOTA - 503) & 511)] + fVec43[((IOTA - 505) & 511)]))))) : (iSlow100 ? (((0.000671407208f * (((fVec42[((IOTA - 241) & 511)] + fVec42[((IOTA - 366) & 511)]) + fVec42[((IOTA - 393) & 511)]) - fVec42[((IOTA - 511) & 511)])) + ((0.000610370189f * ((((((fVec42[((IOTA - 305) & 511)] + fVec42[((IOTA - 319) & 511)]) - fVec42[((IOTA - 344) & 511)]) + fVec42[((IOTA - 411) & 511)]) - fVec42[((IOTA - 435) & 511)]) - fVec42[((IOTA - 465) & 511)]) - fVec42[((IOTA - 510) & 511)])) + ((0.00057985168f * (((((fVec42[((IOTA - 133) & 511)] + fVec42[((IOTA - 224) & 511)]) + fVec42[((IOTA - 352) & 511)]) - fVec42[((IOTA - 466) & 511)]) - fVec42[((IOTA - 493) & 511)]) - fVec42[((IOTA - 509) & 511)])) + ((0.000396740623f * ((((((fVec42[((IOTA - 262) & 511)] + fVec42[((IOTA - 341) & 511)]) + fVec42[((IOTA - 371) & 511)]) + fVec42[((IOTA - 399) & 511)]) + fVec42[((IOTA - 419) & 511)]) - fVec42[((IOTA - 423) & 511)]) - fVec42[((IOTA - 507) & 511)])) + ((0.000274666585f * (((((((fVec42[((IOTA - 200) & 511)] + fVec42[((IOTA - 230) & 511)]) + fVec42[((IOTA - 277) & 511)]) - fVec42[((IOTA - 430) & 511)]) - fVec42[((IOTA - 438) & 511)]) + fVec42[((IOTA - 458) & 511)]) - fVec42[((IOTA - 463) & 511)]) - fVec42[((IOTA - 505) & 511)])) + ((0.000122074038f * (((((fVec42[((IOTA - 135) & 511)] + fVec42[((IOTA - 192) & 511)]) + fVec42[((IOTA - 264) & 511)]) + fVec42[((IOTA - 369) & 511)]) - fVec42[((IOTA - 473) & 511)]) - fVec42[((IOTA - 503) & 511)])) + ((9.15555283e-05f * ((((((((fVec42[((IOTA - 395) & 511)] - fVec42[((IOTA - 396) & 511)]) - fVec42[((IOTA - 452) & 511)]) + fVec42[((IOTA - 455) & 511)]) + fVec42[((IOTA - 476) & 511)]) - fVec42[((IOTA - 478) & 511)]) - fVec42[((IOTA - 480) & 511)]) - fVec42[((IOTA - 487) & 511)]) - fVec42[((IOTA - 502) & 511)])) + ((0.000762962736f * (fVec42[((IOTA - 136) & 511)] - fVec42[((IOTA - 498) & 511)])) + ((0.000885036774f * (((((((fVec42[((IOTA - 187) & 511)] + fVec42[((IOTA - 206) & 511)]) + fVec42[((IOTA - 225) & 511)]) + fVec42[((IOTA - 236) & 511)]) + fVec42[((IOTA - 261) & 511)]) + fVec42[((IOTA - 306) & 511)]) + fVec42[((IOTA - 382) & 511)]) - fVec42[((IOTA - 497) & 511)])) + ((0.000915555283f * (fVec42[((IOTA - 337) & 511)] - fVec42[((IOTA - 496) & 511)])) + ((0.000854518265f * ((fVec42[((IOTA - 384) & 511)] + fVec42[((IOTA - 386) & 511)]) - fVec42[((IOTA - 495) & 511)])) + ((0.000213629566f * (((((((((((((((fVec42[((IOTA - 186) & 511)] - fVec42[((IOTA - 195) & 511)]) + fVec42[((IOTA - 265) & 511)]) + fVec42[((IOTA - 266) & 511)]) + fVec42[((IOTA - 324) & 511)]) + fVec42[((IOTA - 347) & 511)]) - fVec42[((IOTA - 397) & 511)]) + fVec42[((IOTA - 416) & 511)]) + fVec42[((IOTA - 417) & 511)]) - fVec42[((IOTA - 426) & 511)]) - fVec42[((IOTA - 440) & 511)]) + fVec42[((IOTA - 443) & 511)]) + fVec42[((IOTA - 449) & 511)]) + fVec42[((IOTA - 457) & 511)]) - fVec42[((IOTA - 469) & 511)]) - fVec42[((IOTA - 488) & 511)])) + ((0.000152592547f * ((((((((((fVec42[((IOTA - 152) & 511)] + fVec42[((IOTA - 169) & 511)]) - fVec42[((IOTA - 194) & 511)]) + fVec42[((IOTA - 228) & 511)]) + fVec42[((IOTA - 238) & 511)]) + fVec42[((IOTA - 421) & 511)]) - fVec42[((IOTA - 422) & 511)]) - fVec42[((IOTA - 441) & 511)]) + fVec42[((IOTA - 456) & 511)]) - fVec42[((IOTA - 472) & 511)]) - fVec42[((IOTA - 479) & 511)])) + ((0.000305185094f * ((((((((((fVec42[((IOTA - 35) & 511)] + fVec42[((IOTA - 222) & 511)]) + fVec42[((IOTA - 223) & 511)]) + fVec42[((IOTA - 267) & 511)]) + fVec42[((IOTA - 286) & 511)]) + fVec42[((IOTA - 320) & 511)]) + fVec42[((IOTA - 325) & 511)]) + fVec42[((IOTA - 415) & 511)]) + fVec42[((IOTA - 459) & 511)]) + fVec42[((IOTA - 460) & 511)]) - fVec42[((IOTA - 468) & 511)])) + ((0.000366222113f * (((((((fVec42[((IOTA - 134) & 511)] + fVec42[((IOTA - 350) & 511)]) + fVec42[((IOTA - 367) & 511)]) + fVec42[((IOTA - 394) & 511)]) + fVec42[((IOTA - 420) & 511)]) - fVec42[((IOTA - 425) & 511)]) - fVec42[((IOTA - 437) & 511)]) + fVec42[((IOTA - 448) & 511)])) + ((0.00054933317f * ((((fVec42[((IOTA - 237) & 511)] + fVec42[((IOTA - 304) & 511)]) + fVec42[((IOTA - 412) & 511)]) + fVec42[((IOTA - 413) & 511)]) + fVec42[((IOTA - 447) & 511)])) + ((0.000823999755f * fVec42[((IOTA - 410) & 511)]) + ((0.00115970336f * (((((((fVec42[((IOTA - 220) & 511)] + fVec42[((IOTA - 235) & 511)]) + fVec42[((IOTA - 280) & 511)]) + fVec42[((IOTA - 331) & 511)]) + fVec42[((IOTA - 361) & 511)]) + fVec42[((IOTA - 364) & 511)]) + fVec42[((IOTA - 400) & 511)]) + fVec42[((IOTA - 409) & 511)])) + ((0.00152592547f * fVec42[((IOTA - 408) & 511)]) + ((0.00183111057f * ((fVec42[((IOTA - 203) & 511)] + fVec42[((IOTA - 219) & 511)]) + fVec42[((IOTA - 407) & 511)])) + ((0.00204474013f * (fVec42[((IOTA - 214) & 511)] + fVec42[((IOTA - 406) & 511)])) + ((0.00216681417f * fVec42[((IOTA - 405) & 511)]) + ((0.00231940672f * (((fVec42[((IOTA - 83) & 511)] + fVec42[((IOTA - 215) & 511)]) + fVec42[((IOTA - 315) & 511)]) + fVec42[((IOTA - 404) & 511)])) + ((0.00241096225f * (fVec42[((IOTA - 375) & 511)] + fVec42[((IOTA - 403) & 511)])) + ((0.00234992523f * fVec42[((IOTA - 402) & 511)]) + ((0.00186162908f * (((((fVec42[((IOTA - 147) & 511)] - fVec42[((IOTA - 174) & 511)]) - fVec42[((IOTA - 177) & 511)]) + fVec42[((IOTA - 283) & 511)]) + fVec42[((IOTA - 358) & 511)]) + fVec42[((IOTA - 401) & 511)])) + ((0.000946073793f * ((((fVec42[((IOTA - 226) & 511)] + fVec42[((IOTA - 231) & 511)]) + fVec42[((IOTA - 327) & 511)]) + fVec42[((IOTA - 372) & 511)]) + fVec42[((IOTA - 392) & 511)])) + ((0.00125125889f * ((((((fVec42[((IOTA - 113) & 511)] - fVec42[((IOTA - 131) & 511)]) + fVec42[((IOTA - 188) & 511)]) + fVec42[((IOTA - 190) & 511)]) + fVec42[((IOTA - 336) & 511)]) + fVec42[((IOTA - 387) & 511)]) + fVec42[((IOTA - 391) & 511)])) + ((0.00155644398f * fVec42[((IOTA - 389) & 511)]) + ((0.00149540696f * (fVec42[((IOTA - 281) & 511)] + fVec42[((IOTA - 388) & 511)])) + ((0.00106814783f * ((fVec42[((IOTA - 205) & 511)] + fVec42[((IOTA - 285) & 511)]) + fVec42[((IOTA - 383) & 511)])) + ((0.00109866634f * ((fVec42[((IOTA - 318) & 511)] + fVec42[((IOTA - 362) & 511)]) - fVec42[((IOTA - 380) & 511)])) + ((0.00167851802f * (fVec42[((IOTA - 284) & 511)] - fVec42[((IOTA - 379) & 511)])) + ((0.00238044374f * ((fVec42[((IOTA - 298) & 511)] + fVec42[((IOTA - 314) & 511)]) + fVec42[((IOTA - 374) & 511)])) + ((0.00213629566f * (fVec42[((IOTA - 297) & 511)] + fVec42[((IOTA - 356) & 511)])) + ((0.00103762932f * (fVec42[((IOTA - 274) & 511)] + fVec42[((IOTA - 353) & 511)])) + ((0.00100711081f * (((fVec42[((IOTA - 56) & 511)] + fVec42[((IOTA - 270) & 511)]) + fVec42[((IOTA - 289) & 511)]) + fVec42[((IOTA - 332) & 511)])) + ((0.00164799951f * (fVec42[((IOTA - 233) & 511)] + fVec42[((IOTA - 317) & 511)])) + ((0.00244148076f * (fVec42[((IOTA - 259) & 511)] + fVec42[((IOTA - 313) & 511)])) + ((0.00262459181f * ((fVec42[((IOTA - 149) & 511)] + fVec42[((IOTA - 295) & 511)]) + fVec42[((IOTA - 312) & 511)])) + ((0.0028992584f * ((fVec42[((IOTA - 243) & 511)] + fVec42[((IOTA - 291) & 511)]) + fVec42[((IOTA - 311) & 511)])) + ((0.00302133244f * ((fVec42[((IOTA - 254) & 511)] + fVec42[((IOTA - 294) & 511)]) + fVec42[((IOTA - 310) & 511)])) + ((0.00274666585f * (fVec42[((IOTA - 150) & 511)] + fVec42[((IOTA - 309) & 511)])) + ((0.00210577715f * (fVec42[((IOTA - 290) & 511)] + fVec42[((IOTA - 308) & 511)])) + ((0.00158696249f * ((fVec42[((IOTA - 260) & 511)] + fVec42[((IOTA - 329) & 511)]) + fVec42[((IOTA - 354) & 511)])) + ((0.0022583697f * fVec42[((IOTA - 301) & 511)]) + ((0.00280770287f * fVec42[((IOTA - 300) & 511)]) + ((0.00277718436f * fVec42[((IOTA - 299) & 511)]) + ((0.00326548051f * (fVec42[((IOTA - 255) & 511)] + fVec42[((IOTA - 293) & 511)])) + ((0.003234962f * fVec42[((IOTA - 292) & 511)]) + ((0.00180059206f * (fVec42[((IOTA - 242) & 511)] + fVec42[((IOTA - 282) & 511)])) + ((0.00317392498f * (fVec42[((IOTA - 114) & 511)] + fVec42[((IOTA - 258) & 511)])) + ((0.00357066561f * fVec42[((IOTA - 257) & 511)]) + ((0.00350962859f * fVec42[((IOTA - 256) & 511)]) + ((0.00338755455f * (fVec42[((IOTA - 248) & 511)] + fVec42[((IOTA - 252) & 511)])) + ((0.00363170262f * (fVec42[((IOTA - 246) & 511)] + fVec42[((IOTA - 251) & 511)])) + ((0.00360118411f * (fVec42[((IOTA - 142) & 511)] + fVec42[((IOTA - 250) & 511)])) + ((0.00344859157f * fVec42[((IOTA - 249) & 511)]) + ((0.00341807306f * fVec42[((IOTA - 247) & 511)]) + ((0.00372325815f * (fVec42[((IOTA - 101) & 511)] + fVec42[((IOTA - 245) & 511)])) + ((0.00222785119f * fVec42[((IOTA - 296) & 511)]) + ((0.00228888821f * fVec42[((IOTA - 218) & 511)]) + ((0.0025940733f * fVec42[((IOTA - 217) & 511)]) + ((0.00256355479f * fVec42[((IOTA - 216) & 511)]) + ((0.00201422162f * fVec42[((IOTA - 213) & 511)]) + ((0.00219733268f * fVec42[((IOTA - 212) & 511)]) + ((0.00253303628f * (fVec42[((IOTA - 209) & 511)] + fVec42[((IOTA - 211) & 511)])) + ((0.00268562883f * fVec42[((IOTA - 210) & 511)]) + ((0.00189214759f * ((fVec42[((IOTA - 202) & 511)] - (fVec42[((IOTA - 172) & 511)] + fVec42[((IOTA - 176) & 511)])) + fVec42[((IOTA - 208) & 511)])) + ((0.00134281442f * (fVec42[((IOTA - 68) & 511)] + fVec42[((IOTA - 207) & 511)])) + ((0.0019531846f * (fVec42[((IOTA - 22) & 511)] - fVec42[((IOTA - 175) & 511)])) + ((0.00488296151f * (fVec42[((IOTA - 145) & 511)] - fVec42[((IOTA - 163) & 511)])) + ((0.00567644276f * fVec42[((IOTA - 144) & 511)]) + ((0.00482192449f * fVec42[((IOTA - 143) & 511)]) + ((0.00335703604f * fVec42[((IOTA - 141) & 511)]) + ((0.00506607257f * fVec42[((IOTA - 140) & 511)]) + ((0.00640888698f * fVec42[((IOTA - 139) & 511)]) + ((0.00570696127f * (fVec42[((IOTA - 69) & 511)] + fVec42[((IOTA - 138) & 511)])) + ((0.00320444349f * fVec42[((IOTA - 137) & 511)]) + ((0.00390636921f * (fVec42[((IOTA - 103) & 511)] - fVec42[((IOTA - 122) & 511)])) + ((0.00491348002f * fVec42[((IOTA - 102) & 511)]) + ((0.00173955504f * fVec42[((IOTA - 100) & 511)]) + ((0.00473036896f * fVec42[((IOTA - 99) & 511)]) + ((0.01126133f * fVec42[((IOTA - 98) & 511)]) + ((0.0172429588f * (fVec42[((IOTA - 21) & 511)] - fVec42[((IOTA - 93) & 511)])) + ((0.0109256264f * fVec42[((IOTA - 96) & 511)]) + ((0.0140079958f * fVec42[((IOTA - 97) & 511)]) + ((0.00305185094f * fVec42[((IOTA - 146) & 511)]) + ((0.00299081393f * fVec42[((IOTA - 84) & 511)]) + ((0.00399792474f * fVec42[((IOTA - 76) & 511)]) + ((0.00766014587f * fVec42[((IOTA - 75) & 511)]) + ((0.00717184972f * fVec42[((IOTA - 74) & 511)]) + ((0.00625629444f * fVec42[((IOTA - 73) & 511)]) + ((0.00732444227f * fVec42[((IOTA - 71) & 511)]) + ((0.00833155308f * fVec42[((IOTA - 70) & 511)]) + ((0.0144047365f * (fVec42[((IOTA - 46) & 511)] + fVec42[((IOTA - 59) & 511)])) + ((0.0242622159f * fVec42[((IOTA - 58) & 511)]) + ((0.0205389578f * fVec42[((IOTA - 57) & 511)]) + ((0.0221869573f * fVec42[((IOTA - 45) & 511)]) + ((0.0263985116f * fVec42[((IOTA - 44) & 511)]) + ((0.0190740693f * fVec42[((IOTA - 43) & 511)]) + ((0.0118411817f * fVec42[((IOTA - 42) & 511)]) + ((0.011200293f * fVec42[((IOTA - 41) & 511)]) + ((0.00585955381f * fVec42[((IOTA - 40) & 511)]) + (((0.0189519953f * (fTemp43 - fVec42[((IOTA - 17) & 511)])) + ((0.0087282937f * fVec42[((IOTA - 11) & 511)]) + ((0.0628986508f * fVec42[((IOTA - 10) & 511)]) + ((0.0812707916f * fVec42[((IOTA - 5) & 511)]) + ((0.298348963f * fVec42[((IOTA - 4) & 511)]) + ((0.371990114f * fVec42[((IOTA - 3) & 511)]) + ((0.261055321f * fVec42[((IOTA - 2) & 511)]) + ((0.101290934f * fVec42[((IOTA - 1) & 511)]) + ((0.0155339213f * fVec42[((IOTA - 28) & 511)]) + ((0.0411694683f * fVec42[((IOTA - 29) & 511)]) + (0.0298776217f * fVec42[((IOTA - 30) & 511)]))))))))))) + (0.00439466536f * fVec42[((IOTA - 39) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000335703604f * ((fVec42[((IOTA - 500) & 511)] - ((((fVec42[((IOTA - 168) & 511)] + fVec42[((IOTA - 276) & 511)]) + fVec42[((IOTA - 351) & 511)]) + fVec42[((IOTA - 418) & 511)]) - fVec42[((IOTA - 489) & 511)])) + fVec42[((IOTA - 506) & 511)])) + ((0.000183111057f * (((((((((((((((fVec42[((IOTA - 85) & 511)] + fVec42[((IOTA - 193) & 511)]) + fVec42[((IOTA - 239) & 511)]) - fVec42[((IOTA - 263) & 511)]) + fVec42[((IOTA - 287) & 511)]) - fVec42[((IOTA - 321) & 511)]) - fVec42[((IOTA - 322) & 511)]) - fVec42[((IOTA - 323) & 511)]) + fVec42[((IOTA - 346) & 511)]) - fVec42[((IOTA - 368) & 511)]) - fVec42[((IOTA - 370) & 511)]) - fVec42[((IOTA - 461) & 511)]) + fVec42[((IOTA - 470) & 511)]) + fVec42[((IOTA - 471) & 511)]) + fVec42[((IOTA - 501) & 511)]) + fVec42[((IOTA - 504) & 511)])) + ((0.000518814661f * (((fVec42[((IOTA - 185) & 511)] - fVec42[((IOTA - 326) & 511)]) + fVec42[((IOTA - 345) & 511)]) + fVec42[((IOTA - 499) & 511)])) + ((0.000701925717f * ((((((fVec42[((IOTA - 129) & 511)] - fVec42[((IOTA - 191) & 511)]) - fVec42[((IOTA - 269) & 511)]) - fVec42[((IOTA - 340) & 511)]) - fVec42[((IOTA - 385) & 511)]) + fVec42[((IOTA - 434) & 511)]) + fVec42[((IOTA - 494) & 511)])) + ((0.000457777642f * ((((((((fVec42[((IOTA - 115) & 511)] + fVec42[((IOTA - 132) & 511)]) + fVec42[((IOTA - 167) & 511)]) + fVec42[((IOTA - 196) & 511)]) - fVec42[((IOTA - 268) & 511)]) - fVec42[((IOTA - 278) & 511)]) - fVec42[((IOTA - 444) & 511)]) + fVec42[((IOTA - 467) & 511)]) + fVec42[((IOTA - 491) & 511)])) + ((0.000427259132f * (fVec42[((IOTA - 343) & 511)] + fVec42[((IOTA - 490) & 511)])) + ((3.05185094e-05f * (((((((fVec42[((IOTA - 229) & 511)] + fVec42[((IOTA - 342) & 511)]) + fVec42[((IOTA - 427) & 511)]) - fVec42[((IOTA - 450) & 511)]) - fVec42[((IOTA - 454) & 511)]) + fVec42[((IOTA - 474) & 511)]) - fVec42[((IOTA - 484) & 511)]) + fVec42[((IOTA - 486) & 511)])) + ((6.10370189e-05f * (((((((((fVec42[((IOTA - 240) & 511)] - fVec42[((IOTA - 288) & 511)]) - fVec42[((IOTA - 377) & 511)]) + fVec42[((IOTA - 398) & 511)]) + fVec42[((IOTA - 429) & 511)]) + fVec42[((IOTA - 451) & 511)]) + fVec42[((IOTA - 453) & 511)]) - fVec42[((IOTA - 475) & 511)]) - fVec42[((IOTA - 482) & 511)]) - fVec42[((IOTA - 483) & 511)])) + ((0.000640888698f * ((((((fVec42[((IOTA - 170) & 511)] - fVec42[((IOTA - 221) & 511)]) - fVec42[((IOTA - 227) & 511)]) - fVec42[((IOTA - 275) & 511)]) + fVec42[((IOTA - 432) & 511)]) - fVec42[((IOTA - 445) & 511)]) - fVec42[((IOTA - 446) & 511)])) + ((0.000244148076f * fVec42[((IOTA - 439) & 511)]) + ((0.000732444227f * (((((fVec42[((IOTA - 153) & 511)] + fVec42[((IOTA - 154) & 511)]) + fVec42[((IOTA - 199) & 511)]) - fVec42[((IOTA - 338) & 511)]) - fVec42[((IOTA - 339) & 511)]) + fVec42[((IOTA - 433) & 511)])) + ((0.00146488845f * ((((((((((fVec42[((IOTA - 34) & 511)] - fVec42[((IOTA - 151) & 511)]) + fVec42[((IOTA - 171) & 511)]) - fVec42[((IOTA - 232) & 511)]) - fVec42[((IOTA - 234) & 511)]) - fVec42[((IOTA - 302) & 511)]) - fVec42[((IOTA - 330) & 511)]) - fVec42[((IOTA - 334) & 511)]) - fVec42[((IOTA - 335) & 511)]) - fVec42[((IOTA - 376) & 511)]) - fVec42[((IOTA - 390) & 511)])) + ((0.0012817774f * ((fVec42[((IOTA - 180) & 511)] - fVec42[((IOTA - 273) & 511)]) + fVec42[((IOTA - 378) & 511)])) + ((0.00170903653f * (fVec42[((IOTA - 77) & 511)] - fVec42[((IOTA - 373) & 511)])) + ((0.000976592302f * ((fVec42[((IOTA - 155) & 511)] + fVec42[((IOTA - 197) & 511)]) - fVec42[((IOTA - 365) & 511)])) + ((0.00119022187f * (((fVec42[((IOTA - 179) & 511)] + fVec42[((IOTA - 198) & 511)]) - fVec42[((IOTA - 333) & 511)]) - fVec42[((IOTA - 363) & 511)])) + ((0.00131229591f * (((fVec42[((IOTA - 95) & 511)] - fVec42[((IOTA - 201) & 511)]) - fVec42[((IOTA - 272) & 511)]) - fVec42[((IOTA - 360) & 511)])) + ((0.001617481f * (fVec42[((IOTA - 127) & 511)] - fVec42[((IOTA - 359) & 511)])) + ((0.00207525864f * (((((fVec42[((IOTA - 60) & 511)] - fVec42[((IOTA - 148) & 511)]) + fVec42[((IOTA - 166) & 511)]) + fVec42[((IOTA - 182) & 511)]) - fVec42[((IOTA - 316) & 511)]) - fVec42[((IOTA - 357) & 511)])) + ((0.00198370311f * ((fVec42[((IOTA - 173) & 511)] + fVec42[((IOTA - 183) & 511)]) - fVec42[((IOTA - 355) & 511)])) + ((0.00137333293f * ((fVec42[((IOTA - 184) & 511)] - fVec42[((IOTA - 307) & 511)]) - fVec42[((IOTA - 328) & 511)])) + ((0.000793481246f * ((fVec42[((IOTA - 82) & 511)] - fVec42[((IOTA - 279) & 511)]) - fVec42[((IOTA - 303) & 511)])) + ((0.00122074038f * (fVec42[((IOTA - 130) & 511)] - fVec42[((IOTA - 271) & 511)])) + ((0.00314340647f * (fVec42[((IOTA - 31) & 511)] - fVec42[((IOTA - 253) & 511)])) + ((0.0035401471f * (fVec42[((IOTA - 165) & 511)] - fVec42[((IOTA - 244) & 511)])) + ((0.00143436994f * ((fVec42[((IOTA - 178) & 511)] - fVec42[((IOTA - 189) & 511)]) - fVec42[((IOTA - 204) & 511)])) + ((0.00177007355f * fVec42[((IOTA - 181) & 511)]) + ((0.0045167394f * (fVec42[((IOTA - 86) & 511)] + fVec42[((IOTA - 164) & 511)])) + ((0.00497451704f * fVec42[((IOTA - 162) & 511)]) + ((0.00531022064f * (fVec42[((IOTA - 158) & 511)] + fVec42[((IOTA - 161) & 511)])) + ((0.00576799829f * (fVec42[((IOTA - 125) & 511)] + fVec42[((IOTA - 160) & 511)])) + ((0.00598162785f * fVec42[((IOTA - 159) & 511)]) + ((0.00369273964f * fVec42[((IOTA - 157) & 511)]) + ((0.0019226661f * fVec42[((IOTA - 156) & 511)]) + ((0.00405896176f * fVec42[((IOTA - 126) & 511)]) + ((0.00656147953f * fVec42[((IOTA - 124) & 511)]) + ((0.00540177617f * fVec42[((IOTA - 123) & 511)]) + ((0.00381481368f * (fVec42[((IOTA - 90) & 511)] + fVec42[((IOTA - 121) & 511)])) + ((0.00634784997f * fVec42[((IOTA - 120) & 511)]) + ((0.0107425153f * fVec42[((IOTA - 119) & 511)]) + ((0.0123599963f * fVec42[((IOTA - 118) & 511)]) + ((0.0114749596f * (fVec42[((IOTA - 79) & 511)] + fVec42[((IOTA - 117) & 511)])) + ((0.00466933195f * fVec42[((IOTA - 116) & 511)]) + ((0.00296029542f * fVec42[((IOTA - 112) & 511)]) + ((0.00631733146f * fVec42[((IOTA - 111) & 511)]) + ((0.00860621966f * fVec42[((IOTA - 110) & 511)]) + ((0.0104678487f * fVec42[((IOTA - 109) & 511)]) + ((0.0137333293f * fVec42[((IOTA - 108) & 511)]) + ((0.0155949583f * (fVec42[((IOTA - 106) & 511)] + fVec42[((IOTA - 107) & 511)])) + ((0.00988799706f * fVec42[((IOTA - 105) & 511)]) + ((0.00292977691f * fVec42[((IOTA - 104) & 511)]) + ((0.0137943663f * fVec42[((IOTA - 92) & 511)]) + ((0.00653096102f * fVec42[((IOTA - 91) & 511)]) + ((0.00564592425f * (fVec42[((IOTA - 23) & 511)] + fVec42[((IOTA - 89) & 511)])) + ((0.00827051606f * fVec42[((IOTA - 88) & 511)]) + ((0.0083925901f * fVec42[((IOTA - 87) & 511)]) + ((0.00592059083f * fVec42[((IOTA - 81) & 511)]) + ((0.0101626636f * fVec42[((IOTA - 80) & 511)]) + ((0.00857570115f * fVec42[((IOTA - 78) & 511)]) + ((0.00637836847f * (fVec42[((IOTA - 67) & 511)] - fVec42[((IOTA - 72) & 511)])) + ((0.0125736259f * fVec42[((IOTA - 94) & 511)]) + ((0.0131534776f * fVec42[((IOTA - 66) & 511)]) + ((0.0197149571f * fVec42[((IOTA - 65) & 511)]) + ((0.0208441429f * fVec42[((IOTA - 64) & 511)]) + ((0.0223395489f * fVec42[((IOTA - 63) & 511)]) + ((0.0215765871f * fVec42[((IOTA - 62) & 511)]) + ((0.0148319956f * fVec42[((IOTA - 61) & 511)]) + ((0.0235908087f * fVec42[((IOTA - 55) & 511)]) + ((0.0422070995f * fVec42[((IOTA - 54) & 511)]) + ((0.0474868007f * fVec42[((IOTA - 53) & 511)]) + ((0.0443128757f * fVec42[((IOTA - 52) & 511)]) + ((0.0416577645f * fVec42[((IOTA - 51) & 511)]) + ((0.0350047313f * fVec42[((IOTA - 50) & 511)]) + ((0.0332041383f * fVec42[((IOTA - 49) & 511)]) + ((0.019409772f * fVec42[((IOTA - 48) & 511)]) + ((0.00543229468f * fVec42[((IOTA - 47) & 511)]) + ((0.0123905148f * fVec42[((IOTA - 38) & 511)]) + ((0.0133671071f * fVec42[((IOTA - 37) & 511)]) + ((0.0105594043f * fVec42[((IOTA - 36) & 511)]) + ((0.0132450331f * fVec42[((IOTA - 33) & 511)]) + ((0.0152592547f * fVec42[((IOTA - 32) & 511)]) + ((0.012817774f * fVec42[((IOTA - 27) & 511)]) + ((0.0611285754f * fVec42[((IOTA - 26) & 511)]) + ((0.060029909f * fVec42[((IOTA - 25) & 511)]) + (((((((((((((0.140476704f * fVec42[((IOTA - 6) & 511)]) + (0.190771207f * fVec42[((IOTA - 7) & 511)])) + (0.111636706f * fVec42[((IOTA - 8) & 511)])) + (0.00683614612f * fVec42[((IOTA - 9) & 511)])) + (0.0375682861f * fVec42[((IOTA - 12) & 511)])) + (0.0858180523f * fVec42[((IOTA - 13) & 511)])) + (0.0664693117f * fVec42[((IOTA - 14) & 511)])) + (0.050141912f * fVec42[((IOTA - 15) & 511)])) + (0.0177312549f * fVec42[((IOTA - 16) & 511)])) + (0.0282906592f * fVec42[((IOTA - 18) & 511)])) + (0.0216376241f * fVec42[((IOTA - 19) & 511)])) + (0.0202642903f * fVec42[((IOTA - 20) & 511)])) + (0.0585039817f * fVec42[((IOTA - 24) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000488296151f * (((((((((fVec42[((IOTA - 128) & 511)] - fVec42[((IOTA - 348) & 511)]) - fVec42[((IOTA - 349) & 511)]) - fVec42[((IOTA - 414) & 511)]) + fVec42[((IOTA - 424) & 511)]) + fVec42[((IOTA - 431) & 511)]) + fVec42[((IOTA - 436) & 511)]) + fVec42[((IOTA - 464) & 511)]) + fVec42[((IOTA - 492) & 511)]) + fVec42[((IOTA - 508) & 511)])))) : (((0.00164799951f * (((fVec41[((IOTA - 343) & 511)] + fVec41[((IOTA - 383) & 511)]) + fVec41[((IOTA - 401) & 511)]) - fVec41[((IOTA - 511) & 511)])) + ((0.00170903653f * (fVec41[((IOTA - 111) & 511)] - fVec41[((IOTA - 510) & 511)])) + ((0.00122074038f * (((((fVec41[((IOTA - 302) & 511)] + fVec41[((IOTA - 347) & 511)]) + fVec41[((IOTA - 377) & 511)]) + fVec41[((IOTA - 489) & 511)]) - fVec41[((IOTA - 496) & 511)]) - fVec41[((IOTA - 508) & 511)])) + ((0.000732444227f * ((((((((fVec41[((IOTA - 250) & 511)] + fVec41[((IOTA - 405) & 511)]) + fVec41[((IOTA - 409) & 511)]) + fVec41[((IOTA - 416) & 511)]) + fVec41[((IOTA - 438) & 511)]) + fVec41[((IOTA - 451) & 511)]) + fVec41[((IOTA - 455) & 511)]) - fVec41[((IOTA - 505) & 511)]) - fVec41[((IOTA - 506) & 511)])) + ((0.000183111057f * (((((((((((fVec41[((IOTA - 205) & 511)] + fVec41[((IOTA - 251) & 511)]) - fVec41[((IOTA - 269) & 511)]) - fVec41[((IOTA - 273) & 511)]) - fVec41[((IOTA - 282) & 511)]) - fVec41[((IOTA - 291) & 511)]) + fVec41[((IOTA - 294) & 511)]) - fVec41[((IOTA - 427) & 511)]) + fVec41[((IOTA - 433) & 511)]) - fVec41[((IOTA - 457) & 511)]) + fVec41[((IOTA - 479) & 511)]) + fVec41[((IOTA - 502) & 511)])) + ((0.000457777642f * (((((fVec41[((IOTA - 270) & 511)] - fVec41[((IOTA - 276) & 511)]) - fVec41[((IOTA - 279) & 511)]) + fVec41[((IOTA - 295) & 511)]) - fVec41[((IOTA - 498) & 511)]) + fVec41[((IOTA - 501) & 511)])) + ((0.000335703604f * (((fVec41[((IOTA - 287) & 511)] + fVec41[((IOTA - 421) & 511)]) + fVec41[((IOTA - 456) & 511)]) + fVec41[((IOTA - 500) & 511)])) + ((6.10370189e-05f * (((((((((((((((fVec41[((IOTA - 62) & 511)] - fVec41[((IOTA - 69) & 511)]) + fVec41[((IOTA - 89) & 511)]) + fVec41[((IOTA - 90) & 511)]) + fVec41[((IOTA - 91) & 511)]) + fVec41[((IOTA - 92) & 511)]) - fVec41[((IOTA - 95) & 511)]) + fVec41[((IOTA - 98) & 511)]) - fVec41[((IOTA - 103) & 511)]) - fVec41[((IOTA - 122) & 511)]) - fVec41[((IOTA - 292) & 511)]) + fVec41[((IOTA - 293) & 511)]) + fVec41[((IOTA - 418) & 511)]) - fVec41[((IOTA - 419) & 511)]) + fVec41[((IOTA - 476) & 511)]) - fVec41[((IOTA - 499) & 511)])) + ((0.00262459181f * (fVec41[((IOTA - 158) & 511)] - fVec41[((IOTA - 494) & 511)])) + ((0.00213629566f * ((fVec41[((IOTA - 242) & 511)] + fVec41[((IOTA - 358) & 511)]) - fVec41[((IOTA - 492) & 511)])) + ((0.00109866634f * (((((fVec41[((IOTA - 179) & 511)] - fVec41[((IOTA - 235) & 511)]) - fVec41[((IOTA - 264) & 511)]) + fVec41[((IOTA - 365) & 511)]) - fVec41[((IOTA - 461) & 511)]) + fVec41[((IOTA - 488) & 511)])) + ((0.000671407208f * (((((fVec41[((IOTA - 406) & 511)] + fVec41[((IOTA - 407) & 511)]) + fVec41[((IOTA - 450) & 511)]) - fVec41[((IOTA - 458) & 511)]) - fVec41[((IOTA - 463) & 511)]) - fVec41[((IOTA - 484) & 511)])) + ((0.00057985168f * (fVec41[((IOTA - 422) & 511)] - fVec41[((IOTA - 483) & 511)])) + ((0.000244148076f * (fVec41[((IOTA - 436) & 511)] - fVec41[((IOTA - 481) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((((fVec41[((IOTA - 9) & 511)] + fVec41[((IOTA - 10) & 511)]) + fVec41[((IOTA - 20) & 511)]) + fVec41[((IOTA - 21) & 511)]) + fVec41[((IOTA - 22) & 511)]) - fVec41[((IOTA - 25) & 511)]) + fVec41[((IOTA - 28) & 511)]) + fVec41[((IOTA - 29) & 511)]) + fVec41[((IOTA - 47) & 511)]) + fVec41[((IOTA - 48) & 511)]) + fVec41[((IOTA - 49) & 511)]) + fVec41[((IOTA - 53) & 511)]) + fVec41[((IOTA - 54) & 511)]) + fVec41[((IOTA - 55) & 511)]) - fVec41[((IOTA - 57) & 511)]) - fVec41[((IOTA - 58) & 511)]) + fVec41[((IOTA - 60) & 511)]) + fVec41[((IOTA - 61) & 511)]) + fVec41[((IOTA - 63) & 511)]) + fVec41[((IOTA - 64) & 511)]) - fVec41[((IOTA - 68) & 511)]) - fVec41[((IOTA - 70) & 511)]) - fVec41[((IOTA - 71) & 511)]) + fVec41[((IOTA - 73) & 511)]) + fVec41[((IOTA - 74) & 511)]) - fVec41[((IOTA - 77) & 511)]) - fVec41[((IOTA - 78) & 511)]) + fVec41[((IOTA - 82) & 511)]) + fVec41[((IOTA - 88) & 511)]) - fVec41[((IOTA - 94) & 511)]) - fVec41[((IOTA - 96) & 511)]) - fVec41[((IOTA - 97) & 511)]) + fVec41[((IOTA - 254) & 511)]) + fVec41[((IOTA - 420) & 511)]) + fVec41[((IOTA - 435) & 511)]) - fVec41[((IOTA - 480) & 511)])) + ((0.000366222113f * (fVec41[((IOTA - 417) & 511)] - fVec41[((IOTA - 471) & 511)])) + ((0.000122074038f * ((fVec41[((IOTA - 99) & 511)] + fVec41[((IOTA - 102) & 511)]) - fVec41[((IOTA - 470) & 511)])) + ((0.00115970336f * (((((fVec41[((IOTA - 225) & 511)] - fVec41[((IOTA - 233) & 511)]) + fVec41[((IOTA - 328) & 511)]) + fVec41[((IOTA - 364) & 511)]) + fVec41[((IOTA - 415) & 511)]) - fVec41[((IOTA - 460) & 511)])) + ((0.000854518265f * (((((fVec41[((IOTA - 241) & 511)] + fVec41[((IOTA - 319) & 511)]) + fVec41[((IOTA - 430) & 511)]) + fVec41[((IOTA - 431) & 511)]) - fVec41[((IOTA - 445) & 511)]) + fVec41[((IOTA - 454) & 511)])) + ((0.000762962736f * (fVec41[((IOTA - 439) & 511)] + fVec41[((IOTA - 452) & 511)])) + ((0.00189214759f * ((fVec41[((IOTA - 339) & 511)] + fVec41[((IOTA - 359) & 511)]) + fVec41[((IOTA - 413) & 511)])) + ((0.001617481f * ((fVec41[((IOTA - 326) & 511)] + fVec41[((IOTA - 400) & 511)]) + fVec41[((IOTA - 411) & 511)])) + ((0.00112918485f * (((((fVec41[((IOTA - 367) & 511)] + fVec41[((IOTA - 372) & 511)]) + fVec41[((IOTA - 390) & 511)]) + fVec41[((IOTA - 391) & 511)]) + fVec41[((IOTA - 403) & 511)]) + fVec41[((IOTA - 410) & 511)])) + ((0.00143436994f * (((fVec41[((IOTA - 310) & 511)] + fVec41[((IOTA - 321) & 511)]) + fVec41[((IOTA - 337) & 511)]) + fVec41[((IOTA - 402) & 511)])) + ((0.00146488845f * ((fVec41[((IOTA - 330) & 511)] + fVec41[((IOTA - 344) & 511)]) + fVec41[((IOTA - 399) & 511)])) + ((0.00134281442f * ((fVec41[((IOTA - 388) & 511)] - ((((fVec41[((IOTA - 236) & 511)] - fVec41[((IOTA - 309) & 511)]) - fVec41[((IOTA - 368) & 511)]) - fVec41[((IOTA - 378) & 511)]) - fVec41[((IOTA - 379) & 511)])) + fVec41[((IOTA - 398) & 511)])) + ((0.00137333293f * ((fVec41[((IOTA - 336) & 511)] + fVec41[((IOTA - 361) & 511)]) + fVec41[((IOTA - 397) & 511)])) + ((0.00152592547f * (fVec41[((IOTA - 387) & 511)] + fVec41[((IOTA - 396) & 511)])) + ((0.00140385143f * ((((fVec41[((IOTA - 307) & 511)] + fVec41[((IOTA - 308) & 511)]) + fVec41[((IOTA - 348) & 511)]) + fVec41[((IOTA - 382) & 511)]) + fVec41[((IOTA - 393) & 511)])) + ((0.00167851802f * (((fVec41[((IOTA - 194) & 511)] + fVec41[((IOTA - 249) & 511)]) + fVec41[((IOTA - 338) & 511)]) + fVec41[((IOTA - 386) & 511)])) + ((0.00177007355f * ((fVec41[((IOTA - 188) & 511)] + fVec41[((IOTA - 384) & 511)]) + fVec41[((IOTA - 385) & 511)])) + ((0.00106814783f * ((fVec41[((IOTA - 296) & 511)] + fVec41[((IOTA - 366) & 511)]) + fVec41[((IOTA - 376) & 511)])) + ((0.000946073793f * (fVec41[((IOTA - 320) & 511)] + fVec41[((IOTA - 375) & 511)])) + ((0.00149540696f * ((fVec41[((IOTA - 256) & 511)] + fVec41[((IOTA - 369) & 511)]) + fVec41[((IOTA - 370) & 511)])) + ((0.00158696249f * ((fVec41[((IOTA - 360) & 511)] + fVec41[((IOTA - 395) & 511)]) + fVec41[((IOTA - 414) & 511)])) + ((0.00119022187f * ((((fVec41[((IOTA - 263) & 511)] + fVec41[((IOTA - 306) & 511)]) + fVec41[((IOTA - 329) & 511)]) + fVec41[((IOTA - 346) & 511)]) + fVec41[((IOTA - 363) & 511)])) + ((0.00228888821f * fVec41[((IOTA - 357) & 511)]) + ((0.00234992523f * ((fVec41[((IOTA - 246) & 511)] + fVec41[((IOTA - 353) & 511)]) + fVec41[((IOTA - 356) & 511)])) + ((0.00241096225f * fVec41[((IOTA - 355) & 511)]) + ((0.00238044374f * fVec41[((IOTA - 354) & 511)]) + ((0.0022583697f * ((fVec41[((IOTA - 258) & 511)] + fVec41[((IOTA - 324) & 511)]) + fVec41[((IOTA - 352) & 511)])) + ((0.00219733268f * fVec41[((IOTA - 351) & 511)]) + ((0.00201422162f * (((fVec41[((IOTA - 322) & 511)] + fVec41[((IOTA - 325) & 511)]) + fVec41[((IOTA - 332) & 511)]) + fVec41[((IOTA - 350) & 511)])) + ((0.00173955504f * (fVec41[((IOTA - 311) & 511)] + fVec41[((IOTA - 349) & 511)])) + ((0.00180059206f * fVec41[((IOTA - 342) & 511)]) + ((0.0019531846f * ((fVec41[((IOTA - 186) & 511)] + fVec41[((IOTA - 297) & 511)]) + fVec41[((IOTA - 341) & 511)])) + ((0.00198370311f * fVec41[((IOTA - 340) & 511)]) + ((0.00204474013f * (fVec41[((IOTA - 187) & 511)] + fVec41[((IOTA - 333) & 511)])) + ((0.0012817774f * (fVec41[((IOTA - 318) & 511)] + fVec41[((IOTA - 327) & 511)])) + ((0.00277718436f * fVec41[((IOTA - 316) & 511)]) + ((0.00302133244f * ((fVec41[((IOTA - 247) & 511)] + fVec41[((IOTA - 259) & 511)]) + fVec41[((IOTA - 315) & 511)])) + ((0.00222785119f * (fVec41[((IOTA - 245) & 511)] + fVec41[((IOTA - 312) & 511)])) + ((0.00256355479f * fVec41[((IOTA - 298) & 511)]) + ((0.00332651753f * fVec41[((IOTA - 262) & 511)]) + ((0.00430310983f * fVec41[((IOTA - 261) & 511)]) + ((0.00384533219f * fVec41[((IOTA - 260) & 511)]) + ((0.00186162908f * (fVec41[((IOTA - 185) & 511)] + fVec41[((IOTA - 257) & 511)])) + ((0.00253303628f * fVec41[((IOTA - 248) & 511)]) + ((0.00216681417f * fVec41[((IOTA - 244) & 511)]) + ((0.000213629566f * (((((((fVec41[((IOTA - 100) & 511)] + fVec41[((IOTA - 101) & 511)]) + fVec41[((IOTA - 272) & 511)]) + fVec41[((IOTA - 424) & 511)]) + fVec41[((IOTA - 466) & 511)]) + fVec41[((IOTA - 469) & 511)]) + fVec41[((IOTA - 477) & 511)]) - fVec41[((IOTA - 486) & 511)])) + ((0.00616473891f * fVec41[((IOTA - 208) & 511)]) + ((0.0105594043f * fVec41[((IOTA - 207) & 511)]) + ((0.00738547929f * fVec41[((IOTA - 206) & 511)]) + ((0.00463881344f * fVec41[((IOTA - 202) & 511)]) + ((0.00366222113f * fVec41[((IOTA - 201) & 511)]) + ((0.00350962859f * fVec41[((IOTA - 195) & 511)]) + ((0.0104373302f * (fVec41[((IOTA - 183) & 511)] - fVec41[((IOTA - 190) & 511)])) + ((0.00631733146f * fVec41[((IOTA - 184) & 511)]) + ((0.0135807367f * fVec41[((IOTA - 182) & 511)]) + ((0.0120853297f * fVec41[((IOTA - 181) & 511)]) + ((0.00265511032f * fVec41[((IOTA - 300) & 511)]) + ((0.0114749596f * fVec41[((IOTA - 171) & 511)]) + ((0.0291451775f * fVec41[((IOTA - 170) & 511)]) + ((0.0290231034f * fVec41[((IOTA - 169) & 511)]) + ((0.0154118473f * fVec41[((IOTA - 168) & 511)]) + ((0.00704977568f * fVec41[((IOTA - 157) & 511)]) + ((0.00830103457f * fVec41[((IOTA - 156) & 511)]) + ((0.0169072542f * fVec41[((IOTA - 155) & 511)]) + ((0.0205389578f * fVec41[((IOTA - 154) & 511)]) + ((0.0201727357f * fVec41[((IOTA - 153) & 511)]) + ((0.00900296029f * fVec41[((IOTA - 152) & 511)]) + ((0.0343333222f * fVec41[((IOTA - 143) & 511)]) + ((0.0528885759f * fVec41[((IOTA - 142) & 511)]) + ((0.0433057658f * fVec41[((IOTA - 141) & 511)]) + ((0.0042115543f * fVec41[((IOTA - 140) & 511)]) + ((0.0221564379f * fVec41[((IOTA - 135) & 511)]) + ((0.0301828068f * fVec41[((IOTA - 134) & 511)]) + ((0.021332439f * fVec41[((IOTA - 124) & 511)]) + ((0.0529496148f * fVec41[((IOTA - 123) & 511)]) + ((0.0131839961f * fVec41[((IOTA - 118) & 511)]) + ((0.227149263f * fVec41[((IOTA - 117) & 511)]) + ((0.306161702f * fVec41[((IOTA - 116) & 511)]) + ((0.211066008f * fVec41[((IOTA - 115) & 511)]) + ((0.0769981965f * fVec41[((IOTA - 114) & 511)]) + ((0.00656147953f * fVec41[((IOTA - 112) & 511)]) + (0.0149845881f * fVec41[((IOTA - 113) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000915555283f * (((((fVec41[((IOTA - 222) & 511)] + fVec41[((IOTA - 234) & 511)]) - fVec41[((IOTA - 305) & 511)]) - fVec41[((IOTA - 374) & 511)]) + fVec41[((IOTA - 462) & 511)]) + fVec41[((IOTA - 507) & 511)])) + ((0.000305185094f * ((fVec41[((IOTA - 286) & 511)] + fVec41[((IOTA - 426) & 511)]) + fVec41[((IOTA - 503) & 511)])) + ((0.000793481246f * fVec41[((IOTA - 497) & 511)]) + ((0.0019226661f * ((fVec41[((IOTA - 267) & 511)] - fVec41[((IOTA - 412) & 511)]) + fVec41[((IOTA - 495) & 511)])) + ((0.00283822138f * ((fVec41[((IOTA - 221) & 511)] - fVec41[((IOTA - 299) & 511)]) + fVec41[((IOTA - 493) & 511)])) + ((0.000823999755f * (((fVec41[((IOTA - 283) & 511)] + fVec41[((IOTA - 446) & 511)]) - fVec41[((IOTA - 453) & 511)]) + fVec41[((IOTA - 491) & 511)])) + ((0.000518814661f * ((((fVec41[((IOTA - 136) & 511)] - fVec41[((IOTA - 255) & 511)]) - fVec41[((IOTA - 271) & 511)]) - fVec41[((IOTA - 437) & 511)]) - fVec41[((IOTA - 490) & 511)])) + ((0.000488296151f * ((fVec41[((IOTA - 447) & 511)] + fVec41[((IOTA - 472) & 511)]) - fVec41[((IOTA - 487) & 511)])) + ((0.000640888698f * (((((fVec41[((IOTA - 223) & 511)] - fVec41[((IOTA - 303) & 511)]) - fVec41[((IOTA - 408) & 511)]) - fVec41[((IOTA - 440) & 511)]) + fVec41[((IOTA - 444) & 511)]) + fVec41[((IOTA - 504) & 511)])) + ((0.000610370189f * ((fVec41[((IOTA - 278) & 511)] - fVec41[((IOTA - 304) & 511)]) + fVec41[((IOTA - 485) & 511)])) + ((0.000427259132f * ((fVec41[((IOTA - 275) & 511)] - fVec41[((IOTA - 449) & 511)]) + fVec41[((IOTA - 482) & 511)])) + ((0.000274666585f * ((((((fVec41[((IOTA - 104) & 511)] - fVec41[((IOTA - 226) & 511)]) - fVec41[((IOTA - 252) & 511)]) - fVec41[((IOTA - 289) & 511)]) + fVec41[((IOTA - 443) & 511)]) + fVec41[((IOTA - 474) & 511)]) - fVec41[((IOTA - 478) & 511)])) + ((9.15555283e-05f * (((((fVec41[((IOTA - 203) & 511)] - fVec41[((IOTA - 281) & 511)]) + fVec41[((IOTA - 290) & 511)]) - fVec41[((IOTA - 442) & 511)]) + fVec41[((IOTA - 465) & 511)]) + fVec41[((IOTA - 475) & 511)])) + ((0.000396740623f * (((((fVec41[((IOTA - 274) & 511)] - fVec41[((IOTA - 441) & 511)]) + fVec41[((IOTA - 464) & 511)]) - fVec41[((IOTA - 467) & 511)]) - fVec41[((IOTA - 468) & 511)]) + fVec41[((IOTA - 473) & 511)])) + ((0.00100711081f * fVec41[((IOTA - 459) & 511)]) + ((0.00054933317f * ((((fVec41[((IOTA - 277) & 511)] - fVec41[((IOTA - 288) & 511)]) - fVec41[((IOTA - 423) & 511)]) - fVec41[((IOTA - 429) & 511)]) - fVec41[((IOTA - 432) & 511)])) + ((0.000152592547f * ((fVec41[((IOTA - 280) & 511)] + fVec41[((IOTA - 425) & 511)]) - fVec41[((IOTA - 428) & 511)])) + ((0.000885036774f * (fVec41[((IOTA - 285) & 511)] - fVec41[((IOTA - 404) & 511)])) + ((0.00125125889f * (((((fVec41[((IOTA - 284) & 511)] - fVec41[((IOTA - 362) & 511)]) - fVec41[((IOTA - 380) & 511)]) - fVec41[((IOTA - 381) & 511)]) - fVec41[((IOTA - 389) & 511)]) - fVec41[((IOTA - 392) & 511)])) + ((0.000976592302f * (fVec41[((IOTA - 268) & 511)] - fVec41[((IOTA - 373) & 511)])) + ((0.00131229591f * ((fVec41[((IOTA - 105) & 511)] - fVec41[((IOTA - 345) & 511)]) - fVec41[((IOTA - 371) & 511)])) + ((0.00183111057f * ((fVec41[((IOTA - 196) & 511)] - fVec41[((IOTA - 331) & 511)]) - fVec41[((IOTA - 334) & 511)])) + ((0.00231940672f * (fVec41[((IOTA - 265) & 511)] - fVec41[((IOTA - 323) & 511)])) + ((0.00210577715f * ((fVec41[((IOTA - 204) & 511)] - fVec41[((IOTA - 301) & 511)]) - fVec41[((IOTA - 317) & 511)])) + ((0.00296029542f * (fVec41[((IOTA - 238) & 511)] - fVec41[((IOTA - 314) & 511)])) + ((0.00268562883f * (fVec41[((IOTA - 232) & 511)] - fVec41[((IOTA - 313) & 511)])) + ((0.00250251777f * fVec41[((IOTA - 266) & 511)]) + ((0.0025940733f * (fVec41[((IOTA - 237) & 511)] - fVec41[((IOTA - 243) & 511)])) + ((0.00308236945f * fVec41[((IOTA - 239) & 511)]) + ((0.00500503555f * fVec41[((IOTA - 231) & 511)]) + ((0.00753807183f * fVec41[((IOTA - 230) & 511)]) + ((0.00881984923f * fVec41[((IOTA - 229) & 511)]) + ((0.00717184972f * fVec41[((IOTA - 228) & 511)]) + ((0.00329599902f * fVec41[((IOTA - 227) & 511)]) + ((0.000701925717f * (fVec41[((IOTA - 209) & 511)] - fVec41[((IOTA - 224) & 511)])) + ((0.00457777642f * fVec41[((IOTA - 220) & 511)]) + ((0.00619525742f * fVec41[((IOTA - 219) & 511)]) + ((0.006469924f * fVec41[((IOTA - 218) & 511)]) + ((0.00640888698f * fVec41[((IOTA - 217) & 511)]) + ((0.00567644276f * fVec41[((IOTA - 216) & 511)]) + ((0.00534073915f * (fVec41[((IOTA - 210) & 511)] + fVec41[((IOTA - 215) & 511)])) + ((0.00482192449f * fVec41[((IOTA - 214) & 511)]) + ((0.0038758507f * fVec41[((IOTA - 213) & 511)]) + ((0.004852443f * fVec41[((IOTA - 212) & 511)]) + ((0.00509659108f * fVec41[((IOTA - 211) & 511)]) + ((0.00320444349f * fVec41[((IOTA - 200) & 511)]) + ((0.0121768853f * fVec41[((IOTA - 199) & 511)]) + ((0.0154728843f * fVec41[((IOTA - 198) & 511)]) + ((0.01126133f * fVec41[((IOTA - 197) & 511)]) + ((0.00543229468f * fVec41[((IOTA - 193) & 511)]) + ((0.0130314035f * fVec41[((IOTA - 192) & 511)]) + ((0.0155339213f * fVec41[((IOTA - 191) & 511)]) + ((0.00375377666f * fVec41[((IOTA - 189) & 511)]) + ((0.00909451582f * (fVec41[((IOTA - 128) & 511)] - fVec41[((IOTA - 180) & 511)])) + ((0.00921658985f * fVec41[((IOTA - 178) & 511)]) + ((0.0164189581f * fVec41[((IOTA - 177) & 511)]) + ((0.0224311054f * (fVec41[((IOTA - 145) & 511)] + fVec41[((IOTA - 176) & 511)])) + ((0.0268257707f * fVec41[((IOTA - 175) & 511)]) + ((0.0259712525f * fVec41[((IOTA - 174) & 511)]) + ((0.0200506616f * fVec41[((IOTA - 173) & 511)]) + ((0.00735496078f * fVec41[((IOTA - 172) & 511)]) + ((0.00915555283f * fVec41[((IOTA - 167) & 511)]) + ((0.0294808801f * (fVec41[((IOTA - 132) & 511)] + fVec41[((IOTA - 166) & 511)])) + ((0.0397961363f * fVec41[((IOTA - 165) & 511)]) + ((0.0350962877f * fVec41[((IOTA - 164) & 511)]) + ((0.030793177f * fVec41[((IOTA - 163) & 511)]) + ((0.0241096225f * fVec41[((IOTA - 162) & 511)]) + ((0.0155034028f * fVec41[((IOTA - 161) & 511)]) + ((0.0122989593f * fVec41[((IOTA - 160) & 511)]) + ((0.00439466536f * fVec41[((IOTA - 159) & 511)]) + ((0.0163579211f * fVec41[((IOTA - 151) & 511)]) + ((0.0268868078f * fVec41[((IOTA - 150) & 511)]) + ((0.0213934761f * fVec41[((IOTA - 149) & 511)]) + ((0.00650044251f * fVec41[((IOTA - 148) & 511)]) + ((0.00595110934f * fVec41[((IOTA - 147) & 511)]) + ((0.0150456252f * fVec41[((IOTA - 146) & 511)]) + ((0.00836207159f * fVec41[((IOTA - 144) & 511)]) + ((0.069124423f * fVec41[((IOTA - 138) & 511)]) + ((0.0464491732f * fVec41[((IOTA - 139) & 511)]) + ((0.0560930222f * fVec41[((IOTA - 137) & 511)]) + ((0.0166936256f * fVec41[((IOTA - 133) & 511)]) + ((0.048341319f * fVec41[((IOTA - 131) & 511)]) + ((0.0208441429f * fVec41[((IOTA - 130) & 511)]) + ((0.0122684408f * fVec41[((IOTA - 129) & 511)]) + ((0.0141911069f * fVec41[((IOTA - 127) & 511)]) + ((0.0286568813f * fVec41[((IOTA - 126) & 511)]) + ((0.003234962f * fVec41[((IOTA - 125) & 511)]) + ((0.105594046f * fVec41[((IOTA - 121) & 511)]) + ((0.219550163f * fVec41[((IOTA - 120) & 511)]) + ((0.188360244f * fVec41[((IOTA - 119) & 511)]) + ((0.00503555406f * fVec41[((IOTA - 110) & 511)]) + ((0.00939970091f * fVec41[((IOTA - 109) & 511)]) + ((0.0100711081f * fVec41[((IOTA - 108) & 511)]) + ((0.00418103579f * fVec41[((IOTA - 106) & 511)]) + (0.00762962736f * fVec41[((IOTA - 107) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00155644398f * (((fVec41[((IOTA - 240) & 511)] - fVec41[((IOTA - 335) & 511)]) - fVec41[((IOTA - 394) & 511)]) + fVec41[((IOTA - 509) & 511)]))))))) : (iSlow79 ? (iSlow91 ? (iSlow95 ? (((0.000122074038f * (((((((((((fVec40[((IOTA - 2) & 511)] + fVec40[((IOTA - 6) & 511)]) + fVec40[((IOTA - 15) & 511)]) + fVec40[((IOTA - 17) & 511)]) + fVec40[((IOTA - 29) & 511)]) + fVec40[((IOTA - 41) & 511)]) + fVec40[((IOTA - 44) & 511)]) + fVec40[((IOTA - 56) & 511)]) + fVec40[((IOTA - 60) & 511)]) + fVec40[((IOTA - 331) & 511)]) - fVec40[((IOTA - 342) & 511)]) - fVec40[((IOTA - 511) & 511)])) + ((0.000183111057f * (((((fVec40[((IOTA - 3) & 511)] + fVec40[((IOTA - 4) & 511)]) + fVec40[((IOTA - 58) & 511)]) + fVec40[((IOTA - 59) & 511)]) - fVec40[((IOTA - 314) & 511)]) - fVec40[((IOTA - 510) & 511)])) + ((0.000213629566f * (((((fVec40[((IOTA - 247) & 511)] - fVec40[((IOTA - 254) & 511)]) - fVec40[((IOTA - 313) & 511)]) + fVec40[((IOTA - 319) & 511)]) + fVec40[((IOTA - 323) & 511)]) - fVec40[((IOTA - 509) & 511)])) + ((0.000152592547f * (((((((fVec40[((IOTA - 5) & 511)] + fVec40[((IOTA - 16) & 511)]) + fVec40[((IOTA - 42) & 511)]) + fVec40[((IOTA - 43) & 511)]) + fVec40[((IOTA - 57) & 511)]) + fVec40[((IOTA - 362) & 511)]) - fVec40[((IOTA - 380) & 511)]) - fVec40[((IOTA - 508) & 511)])) + ((3.05185094e-05f * (((((((((((fVec40[((IOTA - 8) & 511)] - fVec40[((IOTA - 9) & 511)]) - fVec40[((IOTA - 20) & 511)]) - fVec40[((IOTA - 21) & 511)]) - fVec40[((IOTA - 22) & 511)]) + fVec40[((IOTA - 24) & 511)]) - fVec40[((IOTA - 32) & 511)]) - fVec40[((IOTA - 35) & 511)]) + fVec40[((IOTA - 45) & 511)]) + fVec40[((IOTA - 50) & 511)]) + fVec40[((IOTA - 61) & 511)]) + fVec40[((IOTA - 507) & 511)])) + ((0.00100711081f * (((((fVec40[((IOTA - 259) & 511)] + fVec40[((IOTA - 345) & 511)]) + fVec40[((IOTA - 376) & 511)]) - fVec40[((IOTA - 381) & 511)]) + fVec40[((IOTA - 490) & 511)]) + fVec40[((IOTA - 504) & 511)])) + ((0.00149540696f * fVec40[((IOTA - 502) & 511)]) + ((0.00152592547f * (fVec40[((IOTA - 501) & 511)] - (((((((fVec40[((IOTA - 145) & 511)] + fVec40[((IOTA - 252) & 511)]) - fVec40[((IOTA - 258) & 511)]) + fVec40[((IOTA - 276) & 511)]) - fVec40[((IOTA - 378) & 511)]) - fVec40[((IOTA - 401) & 511)]) - fVec40[((IOTA - 466) & 511)]) - fVec40[((IOTA - 470) & 511)]))) + ((0.000305185094f * fVec40[((IOTA - 495) & 511)]) + ((0.000762962736f * (fVec40[((IOTA - 453) & 511)] + fVec40[((IOTA - 492) & 511)])) + ((0.000854518265f * (fVec40[((IOTA - 353) & 511)] + fVec40[((IOTA - 491) & 511)])) + ((0.00204474013f * fVec40[((IOTA - 486) & 511)]) + ((0.00198370311f * fVec40[((IOTA - 485) & 511)]) + ((0.00183111057f * ((fVec40[((IOTA - 399) & 511)] + fVec40[((IOTA - 455) & 511)]) + fVec40[((IOTA - 483) & 511)])) + ((0.00244148076f * fVec40[((IOTA - 480) & 511)]) + ((0.00329599902f * fVec40[((IOTA - 478) & 511)]) + ((0.00363170262f * fVec40[((IOTA - 477) & 511)]) + ((0.0038758507f * (fVec40[((IOTA - 359) & 511)] + fVec40[((IOTA - 474) & 511)])) + ((0.00338755455f * fVec40[((IOTA - 473) & 511)]) + ((0.00109866634f * ((fVec40[((IOTA - 321) & 511)] - fVec40[((IOTA - 382) & 511)]) + fVec40[((IOTA - 468) & 511)])) + ((0.00344859157f * fVec40[((IOTA - 463) & 511)]) + ((0.00463881344f * (fVec40[((IOTA - 422) & 511)] + fVec40[((IOTA - 461) & 511)])) + ((0.00497451704f * fVec40[((IOTA - 460) & 511)]) + ((0.00433362834f * fVec40[((IOTA - 458) & 511)]) + ((0.00125125889f * ((fVec40[((IOTA - 256) & 511)] + fVec40[((IOTA - 451) & 511)]) + fVec40[((IOTA - 454) & 511)])) + ((0.00250251777f * ((((fVec40[((IOTA - 82) & 511)] + fVec40[((IOTA - 219) & 511)]) + fVec40[((IOTA - 391) & 511)]) + fVec40[((IOTA - 397) & 511)]) + fVec40[((IOTA - 450) & 511)])) + ((0.00543229468f * (fVec40[((IOTA - 448) & 511)] - (fVec40[((IOTA - 203) & 511)] - fVec40[((IOTA - 439) & 511)]))) + ((0.0061342204f * fVec40[((IOTA - 447) & 511)]) + ((0.00604266487f * (fVec40[((IOTA - 431) & 511)] + fVec40[((IOTA - 446) & 511)])) + ((0.00546281319f * (fVec40[((IOTA - 426) & 511)] + fVec40[((IOTA - 445) & 511)])) + ((0.004852443f * fVec40[((IOTA - 444) & 511)]) + ((0.00460829493f * fVec40[((IOTA - 443) & 511)]) + ((0.00405896176f * fVec40[((IOTA - 462) & 511)]) + ((0.00540177617f * fVec40[((IOTA - 440) & 511)]) + ((0.00610370189f * fVec40[((IOTA - 432) & 511)]) + ((0.00561540574f * fVec40[((IOTA - 430) & 511)]) + ((0.00512710959f * fVec40[((IOTA - 429) & 511)]) + ((0.00506607257f * fVec40[((IOTA - 427) & 511)]) + ((0.00576799829f * ((fVec40[((IOTA - 369) & 511)] + fVec40[((IOTA - 386) & 511)]) + fVec40[((IOTA - 425) & 511)])) + ((0.00509659108f * fVec40[((IOTA - 437) & 511)]) + ((0.00378429517f * ((fVec40[((IOTA - 408) & 511)] + fVec40[((IOTA - 415) & 511)]) + fVec40[((IOTA - 421) & 511)])) + ((0.00305185094f * ((fVec40[((IOTA - 167) & 511)] - fVec40[((IOTA - 279) & 511)]) + fVec40[((IOTA - 420) & 511)])) + ((0.00253303628f * fVec40[((IOTA - 418) & 511)]) + ((0.00283822138f * fVec40[((IOTA - 417) & 511)]) + ((0.00335703604f * fVec40[((IOTA - 416) & 511)]) + ((0.00381481368f * (fVec40[((IOTA - 409) & 511)] + fVec40[((IOTA - 410) & 511)])) + ((0.00357066561f * (fVec40[((IOTA - 357) & 511)] + fVec40[((IOTA - 407) & 511)])) + ((0.00326548051f * (fVec40[((IOTA - 360) & 511)] + fVec40[((IOTA - 406) & 511)])) + ((0.00277718436f * fVec40[((IOTA - 405) & 511)]) + ((0.00494399853f * fVec40[((IOTA - 436) & 511)]) + ((0.001617481f * fVec40[((IOTA - 400) & 511)]) + ((0.00219733268f * fVec40[((IOTA - 398) & 511)]) + ((0.00228888821f * ((fVec40[((IOTA - 144) & 511)] + fVec40[((IOTA - 367) & 511)]) + fVec40[((IOTA - 392) & 511)])) + ((0.00341807306f * fVec40[((IOTA - 390) & 511)]) + ((0.00473036896f * fVec40[((IOTA - 389) & 511)]) + ((0.00592059083f * fVec40[((IOTA - 388) & 511)]) + ((0.00143436994f * (fVec40[((IOTA - 354) & 511)] + fVec40[((IOTA - 377) & 511)])) + ((0.003234962f * (fVec40[((IOTA - 71) & 511)] + fVec40[((IOTA - 372) & 511)])) + ((0.00454725791f * fVec40[((IOTA - 371) & 511)]) + ((0.00558488723f * fVec40[((IOTA - 370) & 511)]) + ((0.00216681417f * fVec40[((IOTA - 355) & 511)]) + ((0.000915555283f * (fVec40[((IOTA - 320) & 511)] + fVec40[((IOTA - 344) & 511)])) + ((0.000244148076f * (fVec40[((IOTA - 329) & 511)] - fVec40[((IOTA - 339) & 511)])) + ((0.00158696249f * (fVec40[((IOTA - 257) & 511)] - fVec40[((IOTA - 266) & 511)])) + ((0.000457777642f * fVec40[((IOTA - 246) & 511)]) + ((9.15555283e-05f * ((((((((fVec40[((IOTA - 7) & 511)] + fVec40[((IOTA - 28) & 511)]) + fVec40[((IOTA - 30) & 511)]) - fVec40[((IOTA - 34) & 511)]) - fVec40[((IOTA - 47) & 511)]) + fVec40[((IOTA - 54) & 511)]) + fVec40[((IOTA - 55) & 511)]) - fVec40[((IOTA - 62) & 511)]) + fVec40[((IOTA - 245) & 511)])) + ((0.0025940733f * fVec40[((IOTA - 221) & 511)]) + ((0.00299081393f * fVec40[((IOTA - 220) & 511)]) + ((0.00134281442f * fVec40[((IOTA - 218) & 511)]) + ((0.00704977568f * (fVec40[((IOTA - 110) & 511)] - fVec40[((IOTA - 185) & 511)])) + ((6.10370189e-05f * ((((((((((((((((((((fVec40[((IOTA - 1) & 511)] - fVec40[((IOTA - 10) & 511)]) - fVec40[((IOTA - 11) & 511)]) - fVec40[((IOTA - 12) & 511)]) + fVec40[((IOTA - 14) & 511)]) + fVec40[((IOTA - 18) & 511)]) + fVec40[((IOTA - 26) & 511)]) + fVec40[((IOTA - 27) & 511)]) + fVec40[((IOTA - 31) & 511)]) - fVec40[((IOTA - 33) & 511)]) + fVec40[((IOTA - 37) & 511)]) + fVec40[((IOTA - 38) & 511)]) + fVec40[((IOTA - 39) & 511)]) + fVec40[((IOTA - 40) & 511)]) - fVec40[((IOTA - 46) & 511)]) - fVec40[((IOTA - 48) & 511)]) + fVec40[((IOTA - 51) & 511)]) + fVec40[((IOTA - 52) & 511)]) + fVec40[((IOTA - 53) & 511)]) - fVec40[((IOTA - 260) & 511)]) + fVec40[((IOTA - 351) & 511)])) + ((0.000701925717f * fVec40[((IOTA - 168) & 511)]) + ((0.00656147953f * fVec40[((IOTA - 166) & 511)]) + ((0.00894192327f * fVec40[((IOTA - 165) & 511)]) + ((0.00787377544f * fVec40[((IOTA - 164) & 511)]) + ((0.00723288674f * fVec40[((IOTA - 143) & 511)]) + ((0.011322367f * fVec40[((IOTA - 142) & 511)]) + ((0.01126133f * fVec40[((IOTA - 141) & 511)]) + ((0.0067751091f * fVec40[((IOTA - 140) & 511)]) + ((0.00961333048f * fVec40[((IOTA - 130) & 511)]) + ((0.0174565874f * fVec40[((IOTA - 129) & 511)]) + ((0.0121463668f * fVec40[((IOTA - 128) & 511)]) + ((0.00698873866f * fVec40[((IOTA - 117) & 511)]) + ((0.0166020691f * fVec40[((IOTA - 116) & 511)]) + ((0.0219428092f * fVec40[((IOTA - 115) & 511)]) + ((0.0234992523f * fVec40[((IOTA - 114) & 511)]) + ((0.0253303628f * fVec40[((IOTA - 113) & 511)]) + ((0.0278634001f * fVec40[((IOTA - 112) & 511)]) + ((0.0236823633f * fVec40[((IOTA - 111) & 511)]) + ((0.0190740693f * fVec40[((IOTA - 102) & 511)]) + ((0.03607288f * fVec40[((IOTA - 101) & 511)]) + ((0.0312204361f * fVec40[((IOTA - 100) & 511)]) + ((0.00790429395f * fVec40[((IOTA - 99) & 511)]) + ((0.0287789553f * fVec40[((IOTA - 88) & 511)]) + ((0.0417493209f * fVec40[((IOTA - 87) & 511)]) + ((0.0299386587f * fVec40[((IOTA - 86) & 511)]) + ((0.0748313889f * fVec40[((IOTA - 77) & 511)]) + ((0.255867183f * fVec40[((IOTA - 76) & 511)]) + ((0.332316041f * fVec40[((IOTA - 75) & 511)]) + ((0.253730893f * fVec40[((IOTA - 74) & 511)]) + ((0.0254219193f * fVec40[((IOTA - 72) & 511)]) + (0.111758783f * fVec40[((IOTA - 73) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000671407208f * (((fVec40[((IOTA - 337) & 511)] - fVec40[((IOTA - 452) & 511)]) - fVec40[((IOTA - 493) & 511)]) - fVec40[((IOTA - 505) & 511)])) + ((0.00131229591f * ((((((fVec40[((IOTA - 94) & 511)] - fVec40[((IOTA - 222) & 511)]) + fVec40[((IOTA - 243) & 511)]) + fVec40[((IOTA - 261) & 511)]) - fVec40[((IOTA - 489) & 511)]) - fVec40[((IOTA - 500) & 511)]) - fVec40[((IOTA - 503) & 511)])) + ((0.000976592302f * ((fVec40[((IOTA - 253) & 511)] - fVec40[((IOTA - 379) & 511)]) - fVec40[((IOTA - 499) & 511)])) + ((0.000640888698f * ((((fVec40[((IOTA - 231) & 511)] + fVec40[((IOTA - 244) & 511)]) - fVec40[((IOTA - 255) & 511)]) + fVec40[((IOTA - 326) & 511)]) - fVec40[((IOTA - 498) & 511)])) + ((0.000366222113f * (fVec40[((IOTA - 327) & 511)] - fVec40[((IOTA - 497) & 511)])) + ((0.000274666585f * (((((fVec40[((IOTA - 217) & 511)] + fVec40[((IOTA - 233) & 511)]) + fVec40[((IOTA - 324) & 511)]) + fVec40[((IOTA - 332) & 511)]) + fVec40[((IOTA - 350) & 511)]) - fVec40[((IOTA - 496) & 511)])) + ((0.000488296151f * ((((((fVec40[((IOTA - 248) & 511)] + fVec40[((IOTA - 273) & 511)]) + fVec40[((IOTA - 315) & 511)]) + fVec40[((IOTA - 318) & 511)]) + fVec40[((IOTA - 349) & 511)]) + fVec40[((IOTA - 366) & 511)]) - fVec40[((IOTA - 494) & 511)])) + ((0.00164799951f * (fVec40[((IOTA - 237) & 511)] - fVec40[((IOTA - 488) & 511)])) + ((0.0019531846f * (fVec40[((IOTA - 238) & 511)] - fVec40[((IOTA - 487) & 511)])) + ((0.00186162908f * (fVec40[((IOTA - 224) & 511)] - fVec40[((IOTA - 484) & 511)])) + ((0.0019226661f * (((fVec40[((IOTA - 216) & 511)] + fVec40[((IOTA - 239) & 511)]) - fVec40[((IOTA - 384) & 511)]) - fVec40[((IOTA - 482) & 511)])) + ((0.00210577715f * (fVec40[((IOTA - 269) & 511)] - fVec40[((IOTA - 481) & 511)])) + ((0.0028992584f * ((fVec40[((IOTA - 278) & 511)] - fVec40[((IOTA - 356) & 511)]) - fVec40[((IOTA - 479) & 511)])) + ((0.00384533219f * ((fVec40[((IOTA - 298) & 511)] - fVec40[((IOTA - 411) & 511)]) - fVec40[((IOTA - 476) & 511)])) + ((0.00396740623f * (fVec40[((IOTA - 289) & 511)] - fVec40[((IOTA - 475) & 511)])) + ((0.00268562883f * ((fVec40[((IOTA - 205) & 511)] - fVec40[((IOTA - 396) & 511)]) - fVec40[((IOTA - 472) & 511)])) + ((0.00201422162f * ((((fVec40[((IOTA - 139) & 511)] + fVec40[((IOTA - 308) & 511)]) - fVec40[((IOTA - 361) & 511)]) - fVec40[((IOTA - 373) & 511)]) - fVec40[((IOTA - 471) & 511)])) + ((0.00122074038f * ((fVec40[((IOTA - 249) & 511)] - fVec40[((IOTA - 374) & 511)]) - fVec40[((IOTA - 469) & 511)])) + ((0.00119022187f * (fVec40[((IOTA - 335) & 511)] - fVec40[((IOTA - 467) & 511)])) + ((0.00213629566f * (((fVec40[((IOTA - 265) & 511)] + fVec40[((IOTA - 282) & 511)]) + fVec40[((IOTA - 283) & 511)]) - fVec40[((IOTA - 465) & 511)])) + ((0.00280770287f * ((fVec40[((IOTA - 156) & 511)] + fVec40[((IOTA - 280) & 511)]) - fVec40[((IOTA - 464) & 511)])) + ((0.00491348002f * ((fVec40[((IOTA - 93) & 511)] + fVec40[((IOTA - 170) & 511)]) - fVec40[((IOTA - 459) & 511)])) + ((0.00347911008f * (fVec40[((IOTA - 288) & 511)] - fVec40[((IOTA - 457) & 511)])) + ((0.00256355479f * ((fVec40[((IOTA - 365) & 511)] - fVec40[((IOTA - 419) & 511)]) - fVec40[((IOTA - 456) & 511)])) + ((0.00408948027f * (fVec40[((IOTA - 182) & 511)] - fVec40[((IOTA - 449) & 511)])) + ((0.00479140598f * ((fVec40[((IOTA - 208) & 511)] + fVec40[((IOTA - 214) & 511)]) - fVec40[((IOTA - 442) & 511)])) + ((0.0051576281f * (fVec40[((IOTA - 65) & 511)] - fVec40[((IOTA - 441) & 511)])) + ((0.00527970213f * (fVec40[((IOTA - 212) & 511)] - fVec40[((IOTA - 438) & 511)])) + ((0.00500503555f * (fVec40[((IOTA - 118) & 511)] - fVec40[((IOTA - 435) & 511)])) + ((0.00531022064f * ((fVec40[((IOTA - 213) & 511)] - fVec40[((IOTA - 423) & 511)]) - fVec40[((IOTA - 434) & 511)])) + ((0.0057985168f * (fVec40[((IOTA - 194) & 511)] - fVec40[((IOTA - 433) & 511)])) + ((0.00488296151f * (fVec40[((IOTA - 181) & 511)] - fVec40[((IOTA - 428) & 511)])) + ((0.00399792474f * (((fVec40[((IOTA - 300) & 511)] + fVec40[((IOTA - 306) & 511)]) - fVec40[((IOTA - 413) & 511)]) - fVec40[((IOTA - 414) & 511)])) + ((0.00393688772f * ((fVec40[((IOTA - 301) & 511)] + fVec40[((IOTA - 302) & 511)]) - fVec40[((IOTA - 412) & 511)])) + ((0.00231940672f * (fVec40[((IOTA - 226) & 511)] - fVec40[((IOTA - 404) & 511)])) + ((0.00189214759f * (fVec40[((IOTA - 64) & 511)] - fVec40[((IOTA - 403) & 511)])) + ((0.00167851802f * (((fVec40[((IOTA - 227) & 511)] + fVec40[((IOTA - 250) & 511)]) + fVec40[((IOTA - 268) & 511)]) - fVec40[((IOTA - 402) & 511)])) + ((0.00271614734f * (fVec40[((IOTA - 263) & 511)] - fVec40[((IOTA - 395) & 511)])) + ((0.00265511032f * ((fVec40[((IOTA - 206) & 511)] + fVec40[((IOTA - 285) & 511)]) - fVec40[((IOTA - 394) & 511)])) + ((0.00241096225f * (fVec40[((IOTA - 281) & 511)] - fVec40[((IOTA - 393) & 511)])) + ((0.00634784997f * (fVec40[((IOTA - 192) & 511)] - fVec40[((IOTA - 387) & 511)])) + ((0.00415051728f * (fVec40[((IOTA - 295) & 511)] - fVec40[((IOTA - 385) & 511)])) + ((0.000885036774f * ((fVec40[((IOTA - 229) & 511)] + fVec40[((IOTA - 317) & 511)]) - fVec40[((IOTA - 375) & 511)])) + ((0.00466933195f * ((fVec40[((IOTA - 291) & 511)] + fVec40[((IOTA - 292) & 511)]) - fVec40[((IOTA - 368) & 511)])) + ((0.00302133244f * fVec40[((IOTA - 364) & 511)]) + ((0.00180059206f * ((((fVec40[((IOTA - 70) & 511)] - fVec40[((IOTA - 163) & 511)]) + fVec40[((IOTA - 240) & 511)]) + fVec40[((IOTA - 271) & 511)]) + fVec40[((IOTA - 363) & 511)])) + ((0.00390636921f * ((((fVec40[((IOTA - 146) & 511)] + fVec40[((IOTA - 204) & 511)]) + fVec40[((IOTA - 297) & 511)]) + fVec40[((IOTA - 299) & 511)]) - fVec40[((IOTA - 358) & 511)])) + ((0.000427259132f * (((((fVec40[((IOTA - 223) & 511)] + fVec40[((IOTA - 232) & 511)]) + fVec40[((IOTA - 341) & 511)]) - fVec40[((IOTA - 343) & 511)]) + fVec40[((IOTA - 348) & 511)]) - fVec40[((IOTA - 352) & 511)])) + ((0.000610370189f * ((fVec40[((IOTA - 235) & 511)] + fVec40[((IOTA - 325) & 511)]) - fVec40[((IOTA - 346) & 511)])) + ((0.00103762932f * fVec40[((IOTA - 336) & 511)]) + ((0.00112918485f * ((fVec40[((IOTA - 228) & 511)] + fVec40[((IOTA - 236) & 511)]) + fVec40[((IOTA - 334) & 511)])) + ((0.000732444227f * (fVec40[((IOTA - 310) & 511)] + fVec40[((IOTA - 333) & 511)])) + ((0.00573747978f * (fVec40[((IOTA - 193) & 511)] - fVec40[((IOTA - 424) & 511)])) + ((0.000793481246f * (fVec40[((IOTA - 230) & 511)] - fVec40[((IOTA - 322) & 511)])) + ((0.000823999755f * (fVec40[((IOTA - 275) & 511)] + fVec40[((IOTA - 316) & 511)])) + ((0.000396740623f * ((fVec40[((IOTA - 63) & 511)] + fVec40[((IOTA - 274) & 511)]) + fVec40[((IOTA - 312) & 511)])) + ((0.00057985168f * fVec40[((IOTA - 311) & 511)]) + ((0.00115970336f * fVec40[((IOTA - 309) & 511)]) + ((0.00311288796f * (fVec40[((IOTA - 287) & 511)] + fVec40[((IOTA - 307) & 511)])) + ((0.00430310983f * ((fVec40[((IOTA - 183) & 511)] + fVec40[((IOTA - 294) & 511)]) + fVec40[((IOTA - 305) & 511)])) + ((0.00424207281f * (fVec40[((IOTA - 154) & 511)] + fVec40[((IOTA - 304) & 511)])) + ((0.00402844325f * (fVec40[((IOTA - 296) & 511)] + fVec40[((IOTA - 303) & 511)])) + ((0.00448622089f * (fVec40[((IOTA - 127) & 511)] + fVec40[((IOTA - 293) & 511)])) + ((0.00439466536f * fVec40[((IOTA - 290) & 511)]) + ((0.00286873989f * fVec40[((IOTA - 286) & 511)]) + ((0.00238044374f * fVec40[((IOTA - 284) & 511)]) + ((0.00234992523f * fVec40[((IOTA - 277) & 511)]) + ((0.00106814783f * fVec40[((IOTA - 272) & 511)]) + ((0.00222785119f * fVec40[((IOTA - 270) & 511)]) + ((0.00140385143f * (fVec40[((IOTA - 155) & 511)] + fVec40[((IOTA - 267) & 511)])) + ((0.00262459181f * fVec40[((IOTA - 264) & 511)]) + ((0.0022583697f * fVec40[((IOTA - 262) & 511)]) + ((0.00177007355f * (fVec40[((IOTA - 241) & 511)] + fVec40[((IOTA - 251) & 511)])) + ((0.00170903653f * fVec40[((IOTA - 242) & 511)]) + ((0.00247199927f * fVec40[((IOTA - 225) & 511)]) + ((0.0035401471f * fVec40[((IOTA - 215) & 511)]) + ((0.00524918362f * (fVec40[((IOTA - 209) & 511)] + fVec40[((IOTA - 211) & 511)])) + ((0.00537125766f * fVec40[((IOTA - 210) & 511)]) + ((0.00369273964f * fVec40[((IOTA - 207) & 511)]) + ((0.006469924f * fVec40[((IOTA - 202) & 511)]) + ((0.00674459059f * fVec40[((IOTA - 201) & 511)]) + ((0.00701925717f * fVec40[((IOTA - 200) & 511)]) + ((0.00817896053f * fVec40[((IOTA - 199) & 511)]) + ((0.00906399731f * fVec40[((IOTA - 198) & 511)]) + ((0.00918607134f * fVec40[((IOTA - 197) & 511)]) + ((0.00836207159f * fVec40[((IOTA - 196) & 511)]) + ((0.00689718314f * (fVec40[((IOTA - 191) & 511)] + fVec40[((IOTA - 195) & 511)])) + ((0.00720236823f * fVec40[((IOTA - 190) & 511)]) + ((0.00759910885f * fVec40[((IOTA - 189) & 511)]) + ((0.00762962736f * fVec40[((IOTA - 188) & 511)]) + ((0.00778221991f * fVec40[((IOTA - 187) & 511)]) + ((0.00766014587f * fVec40[((IOTA - 186) & 511)]) + ((0.00552385021f * fVec40[((IOTA - 184) & 511)]) + ((0.00695822015f * fVec40[((IOTA - 180) & 511)]) + ((0.00897244178f * fVec40[((IOTA - 179) & 511)]) + ((0.00952177495f * fVec40[((IOTA - 178) & 511)]) + ((0.00869777519f * fVec40[((IOTA - 177) & 511)]) + ((0.00793481246f * fVec40[((IOTA - 176) & 511)]) + ((0.00866725668f * fVec40[((IOTA - 175) & 511)]) + ((0.0115054781f * fVec40[((IOTA - 174) & 511)]) + ((0.0143436994f * fVec40[((IOTA - 173) & 511)]) + ((0.0140385143f * fVec40[((IOTA - 172) & 511)]) + ((0.00997955259f * fVec40[((IOTA - 171) & 511)]) + ((0.00155644398f * fVec40[((IOTA - 169) & 511)]) + ((0.00668355357f * fVec40[((IOTA - 162) & 511)]) + ((0.0137943663f * fVec40[((IOTA - 161) & 511)]) + ((0.0180059206f * fVec40[((IOTA - 160) & 511)]) + ((0.0190130323f * fVec40[((IOTA - 159) & 511)]) + ((0.0154118473f * fVec40[((IOTA - 158) & 511)]) + ((0.0087282937f * fVec40[((IOTA - 157) & 511)]) + ((0.00827051606f * fVec40[((IOTA - 153) & 511)]) + ((0.0109561449f * fVec40[((IOTA - 152) & 511)]) + ((0.0126956999f * fVec40[((IOTA - 151) & 511)]) + ((0.013000885f * fVec40[((IOTA - 150) & 511)]) + ((0.0115665151f * fVec40[((IOTA - 149) & 511)]) + ((0.00912503432f * fVec40[((IOTA - 148) & 511)]) + ((0.00653096102f * fVec40[((IOTA - 147) & 511)]) + ((0.0124820704f * fVec40[((IOTA - 138) & 511)]) + ((0.0218207352f * fVec40[((IOTA - 137) & 511)]) + ((0.0267952513f * fVec40[((IOTA - 136) & 511)]) + ((0.0296334736f * fVec40[((IOTA - 135) & 511)]) + ((0.030915251f * fVec40[((IOTA - 134) & 511)]) + ((0.0281991027f * fVec40[((IOTA - 133) & 511)]) + ((0.019287698f * fVec40[((IOTA - 132) & 511)]) + ((0.00534073915f * fVec40[((IOTA - 131) & 511)]) + ((0.0223395489f * fVec40[((IOTA - 126) & 511)]) + ((0.0335703604f * fVec40[((IOTA - 125) & 511)]) + ((0.0365001373f * fVec40[((IOTA - 124) & 511)]) + ((0.0349742137f * fVec40[((IOTA - 123) & 511)]) + ((0.0321665108f * fVec40[((IOTA - 122) & 511)]) + ((0.0313119926f * fVec40[((IOTA - 121) & 511)]) + ((0.0273445845f * fVec40[((IOTA - 120) & 511)]) + ((0.0185247362f * fVec40[((IOTA - 119) & 511)]) + ((0.0104068117f * fVec40[((IOTA - 109) & 511)]) + ((0.0206610318f * fVec40[((IOTA - 108) & 511)]) + ((0.0240180679f * fVec40[((IOTA - 107) & 511)]) + ((0.0202642903f * fVec40[((IOTA - 106) & 511)]) + ((0.0189519953f * fVec40[((IOTA - 105) & 511)]) + ((0.0169988107f * fVec40[((IOTA - 104) & 511)]) + ((0.00680562761f * fVec40[((IOTA - 103) & 511)]) + ((0.0270393994f * fVec40[((IOTA - 98) & 511)]) + ((0.0518204309f * fVec40[((IOTA - 97) & 511)]) + ((0.049012728f * fVec40[((IOTA - 96) & 511)]) + ((0.0227973275f * fVec40[((IOTA - 95) & 511)]) + ((0.0307626575f * fVec40[((IOTA - 92) & 511)]) + ((0.0563676879f * fVec40[((IOTA - 91) & 511)]) + ((0.0489822067f * fVec40[((IOTA - 90) & 511)]) + ((0.0148014771f * fVec40[((IOTA - 89) & 511)]) + ((0.00729392376f * fVec40[((IOTA - 85) & 511)]) + ((0.0259102155f * fVec40[((IOTA - 84) & 511)]) + ((0.0150456252f * fVec40[((IOTA - 83) & 511)]) + ((0.0202948097f * fVec40[((IOTA - 81) & 511)]) + ((0.0816980526f * fVec40[((IOTA - 80) & 511)]) + ((0.123020113f * fVec40[((IOTA - 79) & 511)]) + ((0.0831324235f * fVec40[((IOTA - 78) & 511)]) + ((0.00805688649f * fVec40[((IOTA - 69) & 511)]) + ((0.0117496261f * fVec40[((IOTA - 68) & 511)]) + ((0.0090334788f * fVec40[((IOTA - 66) & 511)]) + (0.0118717002f * fVec40[((IOTA - 67) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000335703604f * ((((fVec40[((IOTA - 234) & 511)] - fVec40[((IOTA - 330) & 511)]) + fVec40[((IOTA - 338) & 511)]) + fVec40[((IOTA - 340) & 511)]) - fVec40[((IOTA - 506) & 511)])))) : (((0.000762962736f * (((fVec39[((IOTA - 22) & 511)] - fVec39[((IOTA - 414) & 511)]) + fVec39[((IOTA - 454) & 511)]) - fVec39[((IOTA - 507) & 511)])) + ((0.00057985168f * ((fVec39[((IOTA - 398) & 511)] - ((((((fVec39[((IOTA - 1) & 511)] - fVec39[((IOTA - 20) & 511)]) + fVec39[((IOTA - 28) & 511)]) - fVec39[((IOTA - 48) & 511)]) + fVec39[((IOTA - 50) & 511)]) - fVec39[((IOTA - 61) & 511)]) + fVec39[((IOTA - 357) & 511)])) - fVec39[((IOTA - 506) & 511)])) + ((0.000335703604f * ((((fVec39[((IOTA - 12) & 511)] + fVec39[((IOTA - 96) & 511)]) - fVec39[((IOTA - 492) & 511)]) - fVec39[((IOTA - 495) & 511)]) - fVec39[((IOTA - 504) & 511)])) + ((0.00103762932f * (((fVec39[((IOTA - 249) & 511)] - fVec39[((IOTA - 358) & 511)]) + fVec39[((IOTA - 368) & 511)]) - fVec39[((IOTA - 500) & 511)])) + ((0.000274666585f * ((((fVec39[((IOTA - 9) & 511)] + fVec39[((IOTA - 36) & 511)]) - fVec39[((IOTA - 39) & 511)]) + fVec39[((IOTA - 466) & 511)]) - fVec39[((IOTA - 494) & 511)])) + ((0.000488296151f * (((fVec39[((IOTA - 11) & 511)] - fVec39[((IOTA - 54) & 511)]) + fVec39[((IOTA - 396) & 511)]) - fVec39[((IOTA - 490) & 511)])) + ((0.00122074038f * ((((fVec39[((IOTA - 324) & 511)] + fVec39[((IOTA - 337) & 511)]) + fVec39[((IOTA - 405) & 511)]) - fVec39[((IOTA - 438) & 511)]) - fVec39[((IOTA - 486) & 511)])) + ((0.00131229591f * ((((((fVec39[((IOTA - 250) & 511)] + fVec39[((IOTA - 340) & 511)]) + fVec39[((IOTA - 403) & 511)]) + fVec39[((IOTA - 404) & 511)]) - fVec39[((IOTA - 436) & 511)]) - fVec39[((IOTA - 437) & 511)]) - fVec39[((IOTA - 485) & 511)])) + ((0.00140385143f * ((fVec39[((IOTA - 374) & 511)] - fVec39[((IOTA - 470) & 511)]) - fVec39[((IOTA - 483) & 511)])) + ((0.00146488845f * (((fVec39[((IOTA - 354) & 511)] - fVec39[((IOTA - 411) & 511)]) - fVec39[((IOTA - 412) & 511)]) - fVec39[((IOTA - 482) & 511)])) + ((0.001617481f * ((fVec39[((IOTA - 308) & 511)] - fVec39[((IOTA - 448) & 511)]) - fVec39[((IOTA - 481) & 511)])) + ((0.0019226661f * ((fVec39[((IOTA - 342) & 511)] - fVec39[((IOTA - 428) & 511)]) - fVec39[((IOTA - 479) & 511)])) + ((0.00234992523f * ((((fVec39[((IOTA - 146) & 511)] + fVec39[((IOTA - 203) & 511)]) + fVec39[((IOTA - 376) & 511)]) - fVec39[((IOTA - 473) & 511)]) - fVec39[((IOTA - 477) & 511)])) + ((0.00247199927f * ((((fVec39[((IOTA - 263) & 511)] + fVec39[((IOTA - 346) & 511)]) + fVec39[((IOTA - 352) & 511)]) + fVec39[((IOTA - 377) & 511)]) - fVec39[((IOTA - 476) & 511)])) + ((0.00170903653f * (((fVec39[((IOTA - 248) & 511)] + fVec39[((IOTA - 264) & 511)]) - fVec39[((IOTA - 430) & 511)]) - fVec39[((IOTA - 471) & 511)])) + ((0.000152592547f * ((((fVec39[((IOTA - 33) & 511)] - fVec39[((IOTA - 44) & 511)]) + fVec39[((IOTA - 56) & 511)]) + fVec39[((IOTA - 361) & 511)]) + fVec39[((IOTA - 465) & 511)])) + ((0.00149540696f * (((((fVec39[((IOTA - 307) & 511)] + fVec39[((IOTA - 326) & 511)]) + fVec39[((IOTA - 328) & 511)]) - fVec39[((IOTA - 422) & 511)]) + fVec39[((IOTA - 453) & 511)]) - fVec39[((IOTA - 462) & 511)])) + ((0.0019531846f * ((fVec39[((IOTA - 251) & 511)] + fVec39[((IOTA - 343) & 511)]) - fVec39[((IOTA - 461) & 511)])) + ((0.00204474013f * ((((fVec39[((IOTA - 196) & 511)] + fVec39[((IOTA - 331) & 511)]) + fVec39[((IOTA - 344) & 511)]) + fVec39[((IOTA - 353) & 511)]) - fVec39[((IOTA - 457) & 511)])) + ((0.000122074038f * ((((fVec39[((IOTA - 31) & 511)] - (fVec39[((IOTA - 5) & 511)] - fVec39[((IOTA - 8) & 511)])) + fVec39[((IOTA - 57) & 511)]) + fVec39[((IOTA - 60) & 511)]) - fVec39[((IOTA - 455) & 511)])) + ((0.00186162908f * ((fVec39[((IOTA - 309) & 511)] + fVec39[((IOTA - 315) & 511)]) + fVec39[((IOTA - 452) & 511)])) + ((0.000915555283f * ((fVec39[((IOTA - 47) & 511)] - fVec39[((IOTA - 441) & 511)]) + fVec39[((IOTA - 450) & 511)])) + ((0.00253303628f * ((fVec39[((IOTA - 273) & 511)] + fVec39[((IOTA - 318) & 511)]) - fVec39[((IOTA - 447) & 511)])) + ((0.00280770287f * ((fVec39[((IOTA - 274) & 511)] + fVec39[((IOTA - 351) & 511)]) - fVec39[((IOTA - 446) & 511)])) + ((0.00198370311f * ((fVec39[((IOTA - 310) & 511)] + fVec39[((IOTA - 385) & 511)]) - fVec39[((IOTA - 444) & 511)])) + ((0.00143436994f * ((((fVec39[((IOTA - 202) & 511)] + fVec39[((IOTA - 362) & 511)]) - fVec39[((IOTA - 391) & 511)]) - fVec39[((IOTA - 433) & 511)]) - fVec39[((IOTA - 443) & 511)])) + ((0.00112918485f * (((fVec39[((IOTA - 91) & 511)] - fVec39[((IOTA - 372) & 511)]) + fVec39[((IOTA - 400) & 511)]) - fVec39[((IOTA - 439) & 511)])) + ((0.00137333293f * ((fVec39[((IOTA - 322) & 511)] + fVec39[((IOTA - 402) & 511)]) - fVec39[((IOTA - 434) & 511)])) + ((0.00164799951f * (fVec39[((IOTA - 312) & 511)] - fVec39[((IOTA - 431) & 511)])) + ((0.00219733268f * (((fVec39[((IOTA - 215) & 511)] + fVec39[((IOTA - 332) & 511)]) + fVec39[((IOTA - 345) & 511)]) - fVec39[((IOTA - 427) & 511)])) + ((0.00173955504f * (fVec39[((IOTA - 451) & 511)] - fVec39[((IOTA - 480) & 511)])) + ((0.0025940733f * ((fVec39[((IOTA - 317) & 511)] - (fVec39[((IOTA - 114) & 511)] - fVec39[((IOTA - 290) & 511)])) - fVec39[((IOTA - 424) & 511)])) + ((0.00216681417f * ((((fVec39[((IOTA - 299) & 511)] + fVec39[((IOTA - 333) & 511)]) + fVec39[((IOTA - 334) & 511)]) - fVec39[((IOTA - 371) & 511)]) - fVec39[((IOTA - 423) & 511)])) + ((0.000732444227f * (fVec39[((IOTA - 150) & 511)] - fVec39[((IOTA - 421) & 511)])) + ((9.15555283e-05f * (((fVec39[((IOTA - 19) & 511)] - fVec39[((IOTA - 24) & 511)]) - fVec39[((IOTA - 199) & 511)]) - fVec39[((IOTA - 415) & 511)])) + ((0.0012817774f * (fVec39[((IOTA - 265) & 511)] - fVec39[((IOTA - 410) & 511)])) + ((0.000183111057f * ((((fVec39[((IOTA - 32) & 511)] + fVec39[((IOTA - 34) & 511)]) + fVec39[((IOTA - 214) & 511)]) - fVec39[((IOTA - 393) & 511)]) - fVec39[((IOTA - 408) & 511)])) + ((0.00238044374f * (fVec39[((IOTA - 62) & 511)] - fVec39[((IOTA - 389) & 511)])) + ((0.00228888821f * (fVec39[((IOTA - 304) & 511)] - fVec39[((IOTA - 388) & 511)])) + ((0.0035401471f * (fVec39[((IOTA - 232) & 511)] + fVec39[((IOTA - 384) & 511)])) + ((0.00430310983f * (((fVec39[((IOTA - 173) & 511)] + fVec39[((IOTA - 241) & 511)]) + fVec39[((IOTA - 382) & 511)]) + fVec39[((IOTA - 383) & 511)])) + ((0.00390636921f * ((fVec39[((IOTA - 205) & 511)] + fVec39[((IOTA - 269) & 511)]) + fVec39[((IOTA - 381) & 511)])) + ((0.00320444349f * (fVec39[((IOTA - 271) & 511)] + fVec39[((IOTA - 380) & 511)])) + ((0.00210577715f * fVec39[((IOTA - 375) & 511)]) + ((0.00222785119f * ((fVec39[((IOTA - 316) & 511)] + fVec39[((IOTA - 319) & 511)]) - fVec39[((IOTA - 370) & 511)])) + ((0.00119022187f * (((fVec39[((IOTA - 105) & 511)] - fVec39[((IOTA - 158) & 511)]) + fVec39[((IOTA - 323) & 511)]) - fVec39[((IOTA - 369) & 511)])) + ((0.00372325815f * (fVec39[((IOTA - 276) & 511)] + fVec39[((IOTA - 367) & 511)])) + ((0.00592059083f * (fVec39[((IOTA - 163) & 511)] + fVec39[((IOTA - 366) & 511)])) + ((0.006469924f * (fVec39[((IOTA - 222) & 511)] + fVec39[((IOTA - 365) & 511)])) + ((0.00527970213f * ((fVec39[((IOTA - 224) & 511)] + fVec39[((IOTA - 228) & 511)]) + fVec39[((IOTA - 364) & 511)])) + ((0.00329599902f * fVec39[((IOTA - 363) & 511)]) + ((0.00277718436f * fVec39[((IOTA - 379) & 511)]) + ((0.00299081393f * ((fVec39[((IOTA - 204) & 511)] + fVec39[((IOTA - 348) & 511)]) + fVec39[((IOTA - 350) & 511)])) + ((0.00305185094f * fVec39[((IOTA - 349) & 511)]) + ((0.00274666585f * (fVec39[((IOTA - 272) & 511)] + fVec39[((IOTA - 347) & 511)])) + ((0.00167851802f * ((fVec39[((IOTA - 306) & 511)] + fVec39[((IOTA - 336) & 511)]) + fVec39[((IOTA - 341) & 511)])) + ((0.00158696249f * ((fVec39[((IOTA - 266) & 511)] + fVec39[((IOTA - 321) & 511)]) + fVec39[((IOTA - 329) & 511)])) + ((0.00152592547f * ((fVec39[((IOTA - 313) & 511)] + fVec39[((IOTA - 314) & 511)]) + fVec39[((IOTA - 327) & 511)])) + ((0.00189214759f * (fVec39[((IOTA - 301) & 511)] + fVec39[((IOTA - 311) & 511)])) + ((0.0022583697f * fVec39[((IOTA - 303) & 511)]) + ((0.00244148076f * ((fVec39[((IOTA - 267) & 511)] + fVec39[((IOTA - 289) & 511)]) + fVec39[((IOTA - 298) & 511)])) + ((0.00308236945f * (((fVec39[((IOTA - 233) & 511)] + fVec39[((IOTA - 253) & 511)]) + fVec39[((IOTA - 259) & 511)]) + fVec39[((IOTA - 297) & 511)])) + ((0.00396740623f * fVec39[((IOTA - 296) & 511)]) + ((0.00460829493f * (fVec39[((IOTA - 167) & 511)] + fVec39[((IOTA - 295) & 511)])) + ((0.00476088747f * (fVec39[((IOTA - 174) & 511)] + fVec39[((IOTA - 294) & 511)])) + ((0.00445570238f * fVec39[((IOTA - 293) & 511)]) + ((0.00381481368f * fVec39[((IOTA - 292) & 511)]) + ((0.00311288796f * (fVec39[((IOTA - 237) & 511)] + fVec39[((IOTA - 291) & 511)])) + ((0.00271614734f * (fVec39[((IOTA - 252) & 511)] + fVec39[((IOTA - 288) & 511)])) + ((0.00317392498f * fVec39[((IOTA - 287) & 511)]) + ((0.00366222113f * fVec39[((IOTA - 286) & 511)]) + ((0.00378429517f * (((((fVec39[((IOTA - 133) & 511)] - fVec39[((IOTA - 137) & 511)]) + fVec39[((IOTA - 216) & 511)]) + fVec39[((IOTA - 270) & 511)]) + fVec39[((IOTA - 281) & 511)]) + fVec39[((IOTA - 285) & 511)])) + ((0.00360118411f * (fVec39[((IOTA - 178) & 511)] + fVec39[((IOTA - 282) & 511)])) + ((0.00393688772f * (fVec39[((IOTA - 246) & 511)] + fVec39[((IOTA - 280) & 511)])) + ((0.00411999878f * fVec39[((IOTA - 279) & 511)]) + ((0.0042115543f * (fVec39[((IOTA - 231) & 511)] + fVec39[((IOTA - 278) & 511)])) + ((0.00405896176f * fVec39[((IOTA - 277) & 511)]) + ((0.00326548051f * fVec39[((IOTA - 275) & 511)]) + ((0.00347911008f * fVec39[((IOTA - 268) & 511)]) + ((0.00292977691f * fVec39[((IOTA - 260) & 511)]) + ((0.003234962f * fVec39[((IOTA - 258) & 511)]) + ((0.00344859157f * (fVec39[((IOTA - 254) & 511)] + fVec39[((IOTA - 256) & 511)])) + ((0.00296029542f * fVec39[((IOTA - 262) & 511)]) + ((0.0045167394f * (fVec39[((IOTA - 172) & 511)] + fVec39[((IOTA - 245) & 511)])) + ((0.00442518387f * fVec39[((IOTA - 244) & 511)]) + ((0.00415051728f * (fVec39[((IOTA - 242) & 511)] + fVec39[((IOTA - 243) & 511)])) + ((0.00418103579f * (fVec39[((IOTA - 171) & 511)] + fVec39[((IOTA - 240) & 511)])) + ((0.00302133244f * fVec39[((IOTA - 238) & 511)]) + ((0.00509659108f * fVec39[((IOTA - 230) & 511)]) + ((0.00543229468f * fVec39[((IOTA - 229) & 511)]) + ((0.00463881344f * fVec39[((IOTA - 227) & 511)]) + ((0.00436414685f * fVec39[((IOTA - 226) & 511)]) + ((0.00454725791f * (fVec39[((IOTA - 217) & 511)] + fVec39[((IOTA - 225) & 511)])) + ((0.00598162785f * fVec39[((IOTA - 223) & 511)]) + ((0.00643940549f * fVec39[((IOTA - 221) & 511)]) + ((0.00610370189f * fVec39[((IOTA - 220) & 511)]) + ((0.00552385021f * ((fVec39[((IOTA - 166) & 511)] + fVec39[((IOTA - 176) & 511)]) + fVec39[((IOTA - 219) & 511)])) + ((0.00506607257f * fVec39[((IOTA - 218) & 511)]) + ((0.00286873989f * fVec39[((IOTA - 261) & 511)]) + ((0.00375377666f * fVec39[((IOTA - 209) & 511)]) + ((0.00531022064f * fVec39[((IOTA - 208) & 511)]) + ((0.00555436872f * fVec39[((IOTA - 207) & 511)]) + ((0.00491348002f * (fVec39[((IOTA - 170) & 511)] + fVec39[((IOTA - 195) & 511)])) + ((0.0067751091f * fVec39[((IOTA - 194) & 511)]) + ((0.00772118289f * (fVec39[((IOTA - 165) & 511)] + fVec39[((IOTA - 193) & 511)])) + ((0.00784325693f * (fVec39[((IOTA - 191) & 511)] + fVec39[((IOTA - 192) & 511)])) + ((0.00766014587f * fVec39[((IOTA - 190) & 511)]) + ((0.00744651631f * fVec39[((IOTA - 189) & 511)]) + ((0.00625629444f * fVec39[((IOTA - 188) & 511)]) + ((0.00433362834f * fVec39[((IOTA - 187) & 511)]) + ((0.00338755455f * fVec39[((IOTA - 186) & 511)]) + ((0.00537125766f * fVec39[((IOTA - 185) & 511)]) + ((0.00793481246f * fVec39[((IOTA - 184) & 511)]) + ((0.0111392559f * fVec39[((IOTA - 183) & 511)]) + ((0.0129093295f * fVec39[((IOTA - 182) & 511)]) + ((0.0119937742f * (fVec39[((IOTA - 85) & 511)] + fVec39[((IOTA - 181) & 511)])) + ((0.00576799829f * (fVec39[((IOTA - 63) & 511)] + fVec39[((IOTA - 179) & 511)])) + ((0.0058290353f * fVec39[((IOTA - 169) & 511)]) + ((0.00524918362f * fVec39[((IOTA - 168) & 511)]) + ((0.00900296029f * fVec39[((IOTA - 164) & 511)]) + ((0.0110171819f * fVec39[((IOTA - 157) & 511)]) + ((0.0214545131f * fVec39[((IOTA - 156) & 511)]) + ((0.0272530299f * fVec39[((IOTA - 155) & 511)]) + ((0.0268562883f * fVec39[((IOTA - 154) & 511)]) + ((0.0184331797f * fVec39[((IOTA - 153) & 511)]) + ((0.00732444227f * fVec39[((IOTA - 152) & 511)]) + ((0.00958281197f * fVec39[((IOTA - 180) & 511)]) + ((0.00512710959f * fVec39[((IOTA - 149) & 511)]) + ((0.00851466414f * fVec39[((IOTA - 148) & 511)]) + ((0.00604266487f * fVec39[((IOTA - 147) & 511)]) + ((0.000244148076f * (fVec39[((IOTA - 37) & 511)] - fVec39[((IOTA - 145) & 511)])) + ((0.00314340647f * fVec39[((IOTA - 234) & 511)]) + ((0.0294198431f * fVec39[((IOTA - 131) & 511)]) + ((0.0394909531f * fVec39[((IOTA - 130) & 511)]) + ((0.042115543f * fVec39[((IOTA - 129) & 511)]) + ((0.0327158421f * fVec39[((IOTA - 128) & 511)]) + ((0.0120853297f * fVec39[((IOTA - 127) & 511)]) + ((0.0106204413f * fVec39[((IOTA - 122) & 511)]) + ((0.022583697f * fVec39[((IOTA - 121) & 511)]) + ((0.0249946602f * fVec39[((IOTA - 120) & 511)]) + ((0.0248420667f * fVec39[((IOTA - 119) & 511)]) + ((0.025818659f * fVec39[((IOTA - 118) & 511)]) + ((0.02438429f * fVec39[((IOTA - 117) & 511)]) + ((0.0180059206f * fVec39[((IOTA - 116) & 511)]) + ((0.0093691824f * fVec39[((IOTA - 115) & 511)]) + ((0.0181890316f * fVec39[((IOTA - 104) & 511)]) + ((0.0244148076f * fVec39[((IOTA - 103) & 511)]) + ((0.0298471022f * fVec39[((IOTA - 102) & 511)]) + ((0.0222785119f * fVec39[((IOTA - 101) & 511)]) + ((0.0195013285f * fVec39[((IOTA - 95) & 511)]) + ((0.036896877f * fVec39[((IOTA - 94) & 511)]) + ((0.0285042878f * fVec39[((IOTA - 93) & 511)]) + ((0.0150151066f * fVec39[((IOTA - 92) & 511)]) + ((0.0158391073f * fVec39[((IOTA - 90) & 511)]) + ((0.0257881414f * fVec39[((IOTA - 89) & 511)]) + ((0.0299081393f * fVec39[((IOTA - 88) & 511)]) + ((0.0307626575f * fVec39[((IOTA - 87) & 511)]) + ((0.0169988107f * fVec39[((IOTA - 86) & 511)]) + ((0.00717184972f * fVec39[((IOTA - 79) & 511)]) + ((0.104861602f * fVec39[((IOTA - 78) & 511)]) + ((0.158696249f * fVec39[((IOTA - 77) & 511)]) + ((0.131076992f * fVec39[((IOTA - 76) & 511)]) + ((0.00503555406f * fVec39[((IOTA - 67) & 511)]) + ((0.00973540451f * fVec39[((IOTA - 66) & 511)]) + ((0.00921658985f * fVec39[((IOTA - 64) & 511)]) + (0.0109561449f * fVec39[((IOTA - 65) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000793481246f * ((((((fVec39[((IOTA - 15) & 511)] + fVec39[((IOTA - 26) & 511)]) + fVec39[((IOTA - 27) & 511)]) - fVec39[((IOTA - 355) & 511)]) - fVec39[((IOTA - 399) & 511)]) + fVec39[((IOTA - 409) & 511)]) + fVec39[((IOTA - 510) & 511)])) + ((0.000885036774f * ((fVec39[((IOTA - 53) & 511)] + fVec39[((IOTA - 508) & 511)]) + fVec39[((IOTA - 509) & 511)])) + ((0.000427259132f * (((((fTemp40 - fVec39[((IOTA - 10) & 511)]) - fVec39[((IOTA - 23) & 511)]) - fVec39[((IOTA - 45) & 511)]) + fVec39[((IOTA - 503) & 511)]) + fVec39[((IOTA - 505) & 511)])) + ((0.000610370189f * fVec39[((IOTA - 502) & 511)]) + ((0.000854518265f * (((((fVec39[((IOTA - 17) & 511)] - fVec39[((IOTA - 21) & 511)]) - fVec39[((IOTA - 46) & 511)]) - fVec39[((IOTA - 210) & 511)]) + fVec39[((IOTA - 488) & 511)]) + fVec39[((IOTA - 501) & 511)])) + ((0.00109866634f * (fVec39[((IOTA - 52) & 511)] + fVec39[((IOTA - 499) & 511)])) + ((0.00100711081f * (((fVec39[((IOTA - 144) & 511)] - fVec39[((IOTA - 406) & 511)]) + fVec39[((IOTA - 469) & 511)]) + fVec39[((IOTA - 498) & 511)])) + ((0.000823999755f * fVec39[((IOTA - 497) & 511)]) + ((0.00054933317f * (((fVec39[((IOTA - 200) & 511)] - fVec39[((IOTA - 416) & 511)]) - fVec39[((IOTA - 419) & 511)]) + fVec39[((IOTA - 496) & 511)])) + ((0.000305185094f * ((((fVec39[((IOTA - 29) & 511)] - fVec39[((IOTA - 197) & 511)]) - fVec39[((IOTA - 201) & 511)]) + fVec39[((IOTA - 449) & 511)]) + fVec39[((IOTA - 493) & 511)])) + ((0.000366222113f * (((fVec39[((IOTA - 3) & 511)] - fVec39[((IOTA - 395) & 511)]) + fVec39[((IOTA - 464) & 511)]) + fVec39[((IOTA - 491) & 511)])) + ((0.000640888698f * fVec39[((IOTA - 489) & 511)]) + ((0.00106814783f * ((fVec39[((IOTA - 359) & 511)] + fVec39[((IOTA - 442) & 511)]) + fVec39[((IOTA - 487) & 511)])) + ((0.00134281442f * (((((fVec39[((IOTA - 142) & 511)] + fVec39[((IOTA - 143) & 511)]) - fVec39[((IOTA - 325) & 511)]) - fVec39[((IOTA - 401) & 511)]) + fVec39[((IOTA - 435) & 511)]) + fVec39[((IOTA - 484) & 511)])) + ((0.00213629566f * fVec39[((IOTA - 478) & 511)]) + ((0.00250251777f * ((((((fVec39[((IOTA - 134) & 511)] - fVec39[((IOTA - 378) & 511)]) + fVec39[((IOTA - 426) & 511)]) + fVec39[((IOTA - 445) & 511)]) + fVec39[((IOTA - 458) & 511)]) + fVec39[((IOTA - 474) & 511)]) + fVec39[((IOTA - 475) & 511)])) + ((0.00207525864f * fVec39[((IOTA - 472) & 511)]) + ((0.000518814661f * ((fVec39[((IOTA - 2) & 511)] + fVec39[((IOTA - 25) & 511)]) + fVec39[((IOTA - 468) & 511)])) + ((0.000976592302f * ((((fVec39[((IOTA - 16) & 511)] + fVec39[((IOTA - 42) & 511)]) + fVec39[((IOTA - 51) & 511)]) - fVec39[((IOTA - 339) & 511)]) + fVec39[((IOTA - 463) & 511)])) + ((0.00231940672f * fVec39[((IOTA - 460) & 511)]) + ((0.00256355479f * fVec39[((IOTA - 459) & 511)]) + ((0.00115970336f * fVec39[((IOTA - 456) & 511)]) + ((0.000946073793f * ((((fVec39[((IOTA - 41) & 511)] - fVec39[((IOTA - 338) & 511)]) - fVec39[((IOTA - 417) & 511)]) - fVec39[((IOTA - 418) & 511)]) + fVec39[((IOTA - 440) & 511)])) + ((0.00155644398f * (fVec39[((IOTA - 387) & 511)] + fVec39[((IOTA - 432) & 511)])) + ((0.00177007355f * fVec39[((IOTA - 429) & 511)]) + ((3.05185094e-05f * ((((((fVec39[((IOTA - 30) & 511)] - fVec39[((IOTA - 13) & 511)]) - fVec39[((IOTA - 49) & 511)]) - fVec39[((IOTA - 58) & 511)]) - fVec39[((IOTA - 59) & 511)]) + fVec39[((IOTA - 151) & 511)]) + fVec39[((IOTA - 420) & 511)])) + ((0.00268562883f * fVec39[((IOTA - 425) & 511)]) + ((0.00125125889f * fVec39[((IOTA - 413) & 511)]) + ((0.000457777642f * ((fVec39[((IOTA - 18) & 511)] - fVec39[((IOTA - 397) & 511)]) - fVec39[((IOTA - 407) & 511)])) + ((0.000213629566f * (((fVec39[((IOTA - 4) & 511)] - fVec39[((IOTA - 35) & 511)]) - fVec39[((IOTA - 373) & 511)]) - fVec39[((IOTA - 394) & 511)])) + ((0.00201422162f * (((((fVec39[((IOTA - 213) & 511)] - fVec39[((IOTA - 300) & 511)]) - fVec39[((IOTA - 302) & 511)]) - fVec39[((IOTA - 305) & 511)]) - fVec39[((IOTA - 335) & 511)]) + fVec39[((IOTA - 390) & 511)])) + ((6.10370189e-05f * ((((fVec39[((IOTA - 6) & 511)] - fVec39[((IOTA - 38) & 511)]) + fVec39[((IOTA - 55) & 511)]) - fVec39[((IOTA - 198) & 511)]) - fVec39[((IOTA - 356) & 511)])) + ((0.00183111057f * ((fVec39[((IOTA - 211) & 511)] - fVec39[((IOTA - 320) & 511)]) - fVec39[((IOTA - 330) & 511)])) + ((0.00369273964f * ((fVec39[((IOTA - 140) & 511)] - fVec39[((IOTA - 177) & 511)]) - fVec39[((IOTA - 284) & 511)])) + ((0.00357066561f * (((fVec39[((IOTA - 139) & 511)] - fVec39[((IOTA - 239) & 511)]) - fVec39[((IOTA - 255) & 511)]) - fVec39[((IOTA - 283) & 511)])) + ((0.00332651753f * (fVec39[((IOTA - 162) & 511)] - fVec39[((IOTA - 257) & 511)])) + ((0.0028992584f * (((fVec39[((IOTA - 138) & 511)] + fVec39[((IOTA - 141) & 511)]) + fVec39[((IOTA - 212) & 511)]) - fVec39[((IOTA - 247) & 511)])) + ((0.00335703604f * ((fVec39[((IOTA - 100) & 511)] - fVec39[((IOTA - 235) & 511)]) - fVec39[((IOTA - 236) & 511)])) + ((0.00500503555f * (fVec39[((IOTA - 135) & 511)] - fVec39[((IOTA - 206) & 511)])) + ((0.00558488723f * (fVec39[((IOTA - 136) & 511)] - fVec39[((IOTA - 175) & 511)])) + ((0.0143742179f * fVec39[((IOTA - 161) & 511)]) + ((0.0191351064f * fVec39[((IOTA - 160) & 511)]) + ((0.0136417737f * fVec39[((IOTA - 159) & 511)]) + ((0.0157170333f * (fVec39[((IOTA - 75) & 511)] - fVec39[((IOTA - 132) & 511)])) + ((0.0100711081f * fVec39[((IOTA - 126) & 511)]) + ((0.0217291787f * fVec39[((IOTA - 125) & 511)]) + ((0.0189519953f * fVec39[((IOTA - 124) & 511)]) + ((0.00619525742f * fVec39[((IOTA - 123) & 511)]) + ((0.0151982177f * fVec39[((IOTA - 113) & 511)]) + ((0.0220038462f * fVec39[((IOTA - 112) & 511)]) + ((0.0205694754f * fVec39[((IOTA - 111) & 511)]) + ((0.022644734f * fVec39[((IOTA - 110) & 511)]) + ((0.0262764376f * fVec39[((IOTA - 109) & 511)]) + ((0.0236518458f * fVec39[((IOTA - 108) & 511)]) + ((0.0242622159f * fVec39[((IOTA - 107) & 511)]) + ((0.0157475509f * fVec39[((IOTA - 106) & 511)]) + ((0.0311593991f * fVec39[((IOTA - 99) & 511)]) + ((0.0318002887f * fVec39[((IOTA - 98) & 511)]) + ((0.0214850307f * fVec39[((IOTA - 97) & 511)]) + ((0.00747703481f * fVec39[((IOTA - 84) & 511)]) + ((0.00631733146f * fVec39[((IOTA - 83) & 511)]) + ((0.0404370241f * fVec39[((IOTA - 82) & 511)]) + ((0.0688802749f * fVec39[((IOTA - 81) & 511)]) + ((0.0661336109f * fVec39[((IOTA - 80) & 511)]) + ((0.208258316f * fVec39[((IOTA - 74) & 511)]) + ((0.324503303f * fVec39[((IOTA - 73) & 511)]) + ((0.268654436f * fVec39[((IOTA - 72) & 511)]) + ((0.123142183f * fVec39[((IOTA - 71) & 511)]) + ((0.0308236945f * fVec39[((IOTA - 70) & 511)]) + ((0.00704977568f * fVec39[((IOTA - 69) & 511)]) + ((0.00180059206f * fVec39[((IOTA - 68) & 511)]) + ((0.000396740623f * fVec39[((IOTA - 14) & 511)]) + (0.000671407208f * fVec39[((IOTA - 40) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000701925717f * (((fVec39[((IOTA - 43) & 511)] + fVec39[((IOTA - 360) & 511)]) + fVec39[((IOTA - 392) & 511)]) + fVec39[((IOTA - 511) & 511)]))))) : (iSlow92 ? (((0.000213629566f * (((fVec38[((IOTA - 325) & 511)] - ((((fVec38[((IOTA - 18) & 511)] - fVec38[((IOTA - 30) & 511)]) + fVec38[((IOTA - 218) & 511)]) - fVec38[((IOTA - 226) & 511)]) + fVec38[((IOTA - 324) & 511)])) - fVec38[((IOTA - 499) & 511)]) - fVec38[((IOTA - 510) & 511)])) + ((0.000396740623f * (((((((((((fVec38[((IOTA - 37) & 511)] + fVec38[((IOTA - 288) & 511)]) - fVec38[((IOTA - 299) & 511)]) + fVec38[((IOTA - 309) & 511)]) - fVec38[((IOTA - 323) & 511)]) + fVec38[((IOTA - 346) & 511)]) - fVec38[((IOTA - 354) & 511)]) + fVec38[((IOTA - 426) & 511)]) - fVec38[((IOTA - 441) & 511)]) + fVec38[((IOTA - 488) & 511)]) - fVec38[((IOTA - 490) & 511)]) - fVec38[((IOTA - 508) & 511)])) + ((0.00057985168f * (((((((fVec38[((IOTA - 5) & 511)] - fVec38[((IOTA - 23) & 511)]) - fVec38[((IOTA - 31) & 511)]) + fVec38[((IOTA - 258) & 511)]) - fVec38[((IOTA - 298) & 511)]) - fVec38[((IOTA - 356) & 511)]) + fVec38[((IOTA - 464) & 511)]) - fVec38[((IOTA - 507) & 511)])) + ((0.000885036774f * ((((((((fVec38[((IOTA - 25) & 511)] + fVec38[((IOTA - 241) & 511)]) + fVec38[((IOTA - 361) & 511)]) + fVec38[((IOTA - 419) & 511)]) - fVec38[((IOTA - 424) & 511)]) - fVec38[((IOTA - 468) & 511)]) - fVec38[((IOTA - 492) & 511)]) - fVec38[((IOTA - 495) & 511)]) - fVec38[((IOTA - 505) & 511)])) + ((0.000915555283f * ((fVec38[((IOTA - 54) & 511)] - fVec38[((IOTA - 66) & 511)]) - fVec38[((IOTA - 504) & 511)])) + ((0.000854518265f * ((((((fVec38[((IOTA - 29) & 511)] + fVec38[((IOTA - 242) & 511)]) - fVec38[((IOTA - 276) & 511)]) + fVec38[((IOTA - 338) & 511)]) + fVec38[((IOTA - 345) & 511)]) - fVec38[((IOTA - 451) & 511)]) - fVec38[((IOTA - 503) & 511)])) + ((0.000457777642f * ((((((fVec38[((IOTA - 215) & 511)] + fVec38[((IOTA - 247) & 511)]) + fVec38[((IOTA - 301) & 511)]) + fVec38[((IOTA - 400) & 511)]) - fVec38[((IOTA - 470) & 511)]) - fVec38[((IOTA - 497) & 511)]) - fVec38[((IOTA - 501) & 511)])) + ((0.000701925717f * (((fVec38[((IOTA - 216) & 511)] + fVec38[((IOTA - 331) & 511)]) - fVec38[((IOTA - 491) & 511)]) - fVec38[((IOTA - 496) & 511)])) + ((0.000946073793f * ((((((fVec38[((IOTA - 13) & 511)] - fVec38[((IOTA - 163) & 511)]) + fVec38[((IOTA - 279) & 511)]) + fVec38[((IOTA - 289) & 511)]) + fVec38[((IOTA - 302) & 511)]) + fVec38[((IOTA - 308) & 511)]) - fVec38[((IOTA - 494) & 511)])) + ((0.000976592302f * ((((fVec38[((IOTA - 2) & 511)] - fVec38[((IOTA - 237) & 511)]) + fVec38[((IOTA - 257) & 511)]) - fVec38[((IOTA - 271) & 511)]) - fVec38[((IOTA - 493) & 511)])) + ((0.000732444227f * ((((fVec38[((IOTA - 42) & 511)] + fVec38[((IOTA - 267) & 511)]) + fVec38[((IOTA - 283) & 511)]) - fVec38[((IOTA - 455) & 511)]) + fVec38[((IOTA - 487) & 511)])) + ((0.00131229591f * (((((((((fVec38[((IOTA - 232) & 511)] + fVec38[((IOTA - 252) & 511)]) - fVec38[((IOTA - 273) & 511)]) - fVec38[((IOTA - 274) & 511)]) + fVec38[((IOTA - 327) & 511)]) + fVec38[((IOTA - 343) & 511)]) - fVec38[((IOTA - 454) & 511)]) + fVec38[((IOTA - 462) & 511)]) + fVec38[((IOTA - 480) & 511)]) + fVec38[((IOTA - 484) & 511)])) + ((0.00143436994f * (((fVec38[((IOTA - 254) & 511)] + fVec38[((IOTA - 329) & 511)]) + fVec38[((IOTA - 476) & 511)]) + fVec38[((IOTA - 482) & 511)])) + ((0.00125125889f * (((((((fVec38[((IOTA - 26) & 511)] + fVec38[((IOTA - 159) & 511)]) - fVec38[((IOTA - 221) & 511)]) + fVec38[((IOTA - 253) & 511)]) + fVec38[((IOTA - 307) & 511)]) + fVec38[((IOTA - 340) & 511)]) + fVec38[((IOTA - 342) & 511)]) + fVec38[((IOTA - 479) & 511)])) + ((0.0012817774f * ((((((fVec38[((IOTA - 303) & 511)] + fVec38[((IOTA - 305) & 511)]) - fVec38[((IOTA - 407) & 511)]) + fVec38[((IOTA - 418) & 511)]) + fVec38[((IOTA - 427) & 511)]) + fVec38[((IOTA - 461) & 511)]) + fVec38[((IOTA - 477) & 511)])) + ((0.00103762932f * (((fVec38[((IOTA - 172) & 511)] + fVec38[((IOTA - 291) & 511)]) - fVec38[((IOTA - 423) & 511)]) + fVec38[((IOTA - 473) & 511)])) + ((3.05185094e-05f * ((((((((((fVec38[((IOTA - 55) & 511)] - fVec38[((IOTA - 211) & 511)]) - fVec38[((IOTA - 225) & 511)]) + fVec38[((IOTA - 238) & 511)]) + fVec38[((IOTA - 245) & 511)]) - fVec38[((IOTA - 300) & 511)]) + fVec38[((IOTA - 347) & 511)]) - fVec38[((IOTA - 349) & 511)]) - fVec38[((IOTA - 409) & 511)]) + fVec38[((IOTA - 465) & 511)]) - fVec38[((IOTA - 471) & 511)])) + ((0.000183111057f * (((((((((fTemp39 + fVec38[((IOTA - 24) & 511)]) - fVec38[((IOTA - 224) & 511)]) + fVec38[((IOTA - 244) & 511)]) + fVec38[((IOTA - 278) & 511)]) + fVec38[((IOTA - 333) & 511)]) + fVec38[((IOTA - 336) & 511)]) + fVec38[((IOTA - 351) & 511)]) + fVec38[((IOTA - 438) & 511)]) - fVec38[((IOTA - 456) & 511)])) + ((0.00167851802f * (((((((fVec38[((IOTA - 15) & 511)] - fVec38[((IOTA - 33) & 511)]) + fVec38[((IOTA - 41) & 511)]) + fVec38[((IOTA - 53) & 511)]) + fVec38[((IOTA - 170) & 511)]) + fVec38[((IOTA - 251) & 511)]) + fVec38[((IOTA - 417) & 511)]) - fVec38[((IOTA - 453) & 511)])) + ((0.00317392498f * fVec38[((IOTA - 447) & 511)]) + ((0.00180059206f * (fVec38[((IOTA - 281) & 511)] + fVec38[((IOTA - 445) & 511)])) + ((0.000335703604f * ((((fVec38[((IOTA - 213) & 511)] - fVec38[((IOTA - 296) & 511)]) + fVec38[((IOTA - 360) & 511)]) - fVec38[((IOTA - 390) & 511)]) - fVec38[((IOTA - 440) & 511)])) + ((0.000122074038f * (((((((((fVec38[((IOTA - 12) & 511)] + fVec38[((IOTA - 246) & 511)]) - fVec38[((IOTA - 295) & 511)]) - fVec38[((IOTA - 322) & 511)]) + fVec38[((IOTA - 334) & 511)]) + fVec38[((IOTA - 350) & 511)]) - fVec38[((IOTA - 353) & 511)]) - fVec38[((IOTA - 359) & 511)]) + fVec38[((IOTA - 374) & 511)]) - fVec38[((IOTA - 439) & 511)])) + ((0.00231940672f * fVec38[((IOTA - 433) & 511)]) + ((0.00277718436f * fVec38[((IOTA - 432) & 511)]) + ((0.00314340647f * fVec38[((IOTA - 431) & 511)]) + ((0.00320444349f * (fVec38[((IOTA - 207) & 511)] + fVec38[((IOTA - 430) & 511)])) + ((0.00283822138f * (fVec38[((IOTA - 193) & 511)] + fVec38[((IOTA - 429) & 511)])) + ((0.000366222113f * (((((fVec38[((IOTA - 192) & 511)] - fVec38[((IOTA - 223) & 511)]) + fVec38[((IOTA - 227) & 511)]) - fVec38[((IOTA - 358) & 511)]) + fVec38[((IOTA - 420) & 511)]) - fVec38[((IOTA - 425) & 511)])) + ((0.00198370311f * ((((fVec38[((IOTA - 169) & 511)] - fVec38[((IOTA - 173) & 511)]) + fVec38[((IOTA - 318) & 511)]) - fVec38[((IOTA - 383) & 511)]) + fVec38[((IOTA - 416) & 511)])) + ((0.0022583697f * fVec38[((IOTA - 415) & 511)]) + ((0.00207525864f * ((fVec38[((IOTA - 51) & 511)] + fVec38[((IOTA - 250) & 511)]) + fVec38[((IOTA - 413) & 511)])) + ((0.00054933317f * ((fVec38[((IOTA - 49) & 511)] - fVec38[((IOTA - 355) & 511)]) + fVec38[((IOTA - 410) & 511)])) + ((0.00189214759f * (fVec38[((IOTA - 391) & 511)] - fVec38[((IOTA - 405) & 511)])) + ((0.00173955504f * fVec38[((IOTA - 399) & 511)]) + ((0.00476088747f * (fVec38[((IOTA - 377) & 511)] + fVec38[((IOTA - 397) & 511)])) + ((0.00610370189f * fVec38[((IOTA - 396) & 511)]) + ((0.00692770164f * ((fVec38[((IOTA - 197) & 511)] + fVec38[((IOTA - 394) & 511)]) + fVec38[((IOTA - 395) & 511)])) + ((0.00598162785f * fVec38[((IOTA - 393) & 511)]) + ((0.0042115543f * fVec38[((IOTA - 392) & 511)]) + ((0.00201422162f * (fVec38[((IOTA - 39) & 511)] - fVec38[((IOTA - 389) & 511)])) + ((0.00311288796f * (fVec38[((IOTA - 122) & 511)] - fVec38[((IOTA - 388) & 511)])) + ((0.00363170262f * (fVec38[((IOTA - 161) & 511)] - fVec38[((IOTA - 386) & 511)])) + ((0.00335703604f * ((fVec38[((IOTA - 206) & 511)] - fVec38[((IOTA - 235) & 511)]) - fVec38[((IOTA - 385) & 511)])) + ((0.00280770287f * ((fVec38[((IOTA - 142) & 511)] + fVec38[((IOTA - 160) & 511)]) - fVec38[((IOTA - 384) & 511)])) + ((0.0035401471f * fVec38[((IOTA - 379) & 511)]) + ((0.0045167394f * fVec38[((IOTA - 378) & 511)]) + ((0.00274666585f * (fVec38[((IOTA - 231) & 511)] - fVec38[((IOTA - 373) & 511)])) + ((0.00158696249f * ((fVec38[((IOTA - 263) & 511)] + fVec38[((IOTA - 264) & 511)]) + fVec38[((IOTA - 367) & 511)])) + ((0.00305185094f * fVec38[((IOTA - 365) & 511)]) + ((0.00234992523f * (fVec38[((IOTA - 316) & 511)] + fVec38[((IOTA - 363) & 511)])) + ((0.000152592547f * (fVec38[((IOTA - 214) & 511)] - fVec38[((IOTA - 348) & 511)])) + ((0.00112918485f * ((((((fVec38[((IOTA - 3) & 511)] + fVec38[((IOTA - 162) & 511)]) + fVec38[((IOTA - 209) & 511)]) - fVec38[((IOTA - 233) & 511)]) - fVec38[((IOTA - 275) & 511)]) + fVec38[((IOTA - 320) & 511)]) + fVec38[((IOTA - 339) & 511)])) + ((0.000488296151f * ((fVec38[((IOTA - 239) & 511)] + fVec38[((IOTA - 243) & 511)]) + fVec38[((IOTA - 337) & 511)])) + ((0.000305185094f * ((fVec38[((IOTA - 212) & 511)] + fVec38[((IOTA - 268) & 511)]) + fVec38[((IOTA - 332) & 511)])) + ((0.00241096225f * fVec38[((IOTA - 315) & 511)]) + ((0.00210577715f * fVec38[((IOTA - 314) & 511)]) + ((0.00146488845f * (((fVec38[((IOTA - 27) & 511)] + fVec38[((IOTA - 171) & 511)]) - fVec38[((IOTA - 180) & 511)]) + fVec38[((IOTA - 313) & 511)])) + ((0.00134281442f * (fVec38[((IOTA - 28) & 511)] + fVec38[((IOTA - 306) & 511)])) + ((0.00137333293f * (((fVec38[((IOTA - 16) & 511)] - fVec38[((IOTA - 35) & 511)]) + fVec38[((IOTA - 38) & 511)]) + fVec38[((IOTA - 304) & 511)])) + ((0.000640888698f * ((((((fVec38[((IOTA - 1) & 511)] + fVec38[((IOTA - 17) & 511)]) + fVec38[((IOTA - 95) & 511)]) + fVec38[((IOTA - 240) & 511)]) - fVec38[((IOTA - 270) & 511)]) - fVec38[((IOTA - 285) & 511)]) + fVec38[((IOTA - 381) & 511)])) + ((0.00265511032f * fVec38[((IOTA - 230) & 511)]) + ((0.00213629566f * ((fVec38[((IOTA - 40) & 511)] + fVec38[((IOTA - 52) & 511)]) + fVec38[((IOTA - 205) & 511)])) + ((0.00238044374f * (fVec38[((IOTA - 144) & 511)] - fVec38[((IOTA - 201) & 511)])) + ((0.00222785119f * fVec38[((IOTA - 199) & 511)]) + ((0.00494399853f * fVec38[((IOTA - 198) & 511)]) + ((0.00784325693f * fVec38[((IOTA - 196) & 511)]) + ((0.00769066438f * fVec38[((IOTA - 195) & 511)]) + ((0.0061342204f * fVec38[((IOTA - 194) & 511)]) + ((0.00375377666f * (fVec38[((IOTA - 104) & 511)] - fVec38[((IOTA - 181) & 511)])) + ((0.00854518265f * (fVec38[((IOTA - 99) & 511)] - fVec38[((IOTA - 175) & 511)])) + ((0.00521866512f * fVec38[((IOTA - 157) & 511)]) + ((0.0111697745f * fVec38[((IOTA - 156) & 511)]) + ((0.013061922f * fVec38[((IOTA - 155) & 511)]) + ((0.00701925717f * (fVec38[((IOTA - 135) & 511)] + fVec38[((IOTA - 154) & 511)])) + ((0.0028992584f * fVec38[((IOTA - 143) & 511)]) + ((0.00393688772f * fVec38[((IOTA - 141) & 511)]) + ((0.00512710959f * fVec38[((IOTA - 140) & 511)]) + ((0.00637836847f * fVec38[((IOTA - 139) & 511)]) + ((0.0057985168f * fVec38[((IOTA - 138) & 511)]) + ((0.00543229468f * fVec38[((IOTA - 137) & 511)]) + ((0.00497451704f * fVec38[((IOTA - 136) & 511)]) + ((0.00994903408f * fVec38[((IOTA - 134) & 511)]) + ((0.0111087374f * fVec38[((IOTA - 133) & 511)]) + ((0.0110171819f * fVec38[((IOTA - 124) & 511)]) + ((0.0125125889f * fVec38[((IOTA - 123) & 511)]) + ((0.00350962859f * fVec38[((IOTA - 111) & 511)]) + ((0.00918607134f * fVec38[((IOTA - 110) & 511)]) + ((0.0103457747f * fVec38[((IOTA - 109) & 511)]) + ((0.0182805881f * fVec38[((IOTA - 108) & 511)]) + ((0.0240180679f * fVec38[((IOTA - 107) & 511)]) + ((0.0240791049f * fVec38[((IOTA - 106) & 511)]) + ((0.0177312549f * fVec38[((IOTA - 105) & 511)]) + ((0.040742211f * fVec38[((IOTA - 98) & 511)]) + ((0.0468153954f * fVec38[((IOTA - 97) & 511)]) + ((0.032654807f * fVec38[((IOTA - 96) & 511)]) + ((0.00811792351f * fVec38[((IOTA - 132) & 511)]) + ((0.0238349568f * fVec38[((IOTA - 81) & 511)]) + ((0.0514236875f * fVec38[((IOTA - 80) & 511)]) + ((0.0306100659f * fVec38[((IOTA - 79) & 511)]) + ((0.147770628f * fVec38[((IOTA - 73) & 511)]) + ((0.275795758f * fVec38[((IOTA - 72) & 511)]) + ((0.278267771f * fVec38[((IOTA - 71) & 511)]) + ((0.173741877f * fVec38[((IOTA - 70) & 511)]) + ((0.0645771697f * fVec38[((IOTA - 69) & 511)]) + ((0.0147404401f * fVec38[((IOTA - 68) & 511)]) + ((0.00152592547f * ((fVec38[((IOTA - 14) & 511)] - fVec38[((IOTA - 44) & 511)]) - fVec38[((IOTA - 57) & 511)])) + (0.00430310983f * fVec38[((IOTA - 67) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000762962736f * ((fVec38[((IOTA - 286) & 511)] + fVec38[((IOTA - 469) & 511)]) + fVec38[((IOTA - 506) & 511)])) + ((0.000671407208f * (((fVec38[((IOTA - 7) & 511)] + fVec38[((IOTA - 11) & 511)]) + fVec38[((IOTA - 408) & 511)]) + fVec38[((IOTA - 502) & 511)])) + ((0.000274666585f * (((((fVec38[((IOTA - 200) & 511)] - fVec38[((IOTA - 210) & 511)]) + fVec38[((IOTA - 287) & 511)]) + fVec38[((IOTA - 442) & 511)]) + fVec38[((IOTA - 498) & 511)]) + fVec38[((IOTA - 500) & 511)])) + ((0.00100711081f * (((fVec38[((IOTA - 19) & 511)] - fVec38[((IOTA - 4) & 511)]) + fVec38[((IOTA - 179) & 511)]) - fVec38[((IOTA - 486) & 511)])) + ((0.00119022187f * ((fVec38[((IOTA - 8) & 511)] - fVec38[((IOTA - 261) & 511)]) - fVec38[((IOTA - 485) & 511)])) + ((0.00140385143f * ((((((fVec38[((IOTA - 9) & 511)] - fVec38[((IOTA - 256) & 511)]) - fVec38[((IOTA - 265) & 511)]) + fVec38[((IOTA - 402) & 511)]) - fVec38[((IOTA - 474) & 511)]) - fVec38[((IOTA - 481) & 511)]) - fVec38[((IOTA - 483) & 511)])) + ((0.00122074038f * (((((fVec38[((IOTA - 10) & 511)] + fVec38[((IOTA - 22) & 511)]) + fVec38[((IOTA - 32) & 511)]) - fVec38[((IOTA - 290) & 511)]) - fVec38[((IOTA - 341) & 511)]) - fVec38[((IOTA - 478) & 511)])) + ((0.00149540696f * ((((((fVec38[((IOTA - 20) & 511)] - fVec38[((IOTA - 50) & 511)]) - fVec38[((IOTA - 262) & 511)]) - fVec38[((IOTA - 282) & 511)]) - fVec38[((IOTA - 328) & 511)]) - fVec38[((IOTA - 435) & 511)]) - fVec38[((IOTA - 475) & 511)])) + ((0.000518814661f * (((fVec38[((IOTA - 297) & 511)] + fVec38[((IOTA - 357) & 511)]) - fVec38[((IOTA - 458) & 511)]) - fVec38[((IOTA - 472) & 511)])) + ((0.000427259132f * (((((fVec38[((IOTA - 43) & 511)] - fVec38[((IOTA - 259) & 511)]) + fVec38[((IOTA - 277) & 511)]) - fVec38[((IOTA - 321) & 511)]) - fVec38[((IOTA - 450) & 511)]) + fVec38[((IOTA - 466) & 511)])) + ((0.00106814783f * (((fVec38[((IOTA - 191) & 511)] - fVec38[((IOTA - 436) & 511)]) - fVec38[((IOTA - 460) & 511)]) - fVec38[((IOTA - 463) & 511)])) + ((0.00155644398f * ((((fVec38[((IOTA - 21) & 511)] + fVec38[((IOTA - 131) & 511)]) - fVec38[((IOTA - 255) & 511)]) - fVec38[((IOTA - 280) & 511)]) + fVec38[((IOTA - 452) & 511)])) + ((0.00183111057f * ((fVec38[((IOTA - 190) & 511)] + fVec38[((IOTA - 403) & 511)]) - fVec38[((IOTA - 449) & 511)])) + ((0.00286873989f * ((fVec38[((IOTA - 202) & 511)] - fVec38[((IOTA - 364) & 511)]) - fVec38[((IOTA - 448) & 511)])) + ((0.00268562883f * ((fVec38[((IOTA - 186) & 511)] - fVec38[((IOTA - 366) & 511)]) - fVec38[((IOTA - 446) & 511)])) + ((0.000823999755f * (((fVec38[((IOTA - 56) & 511)] - fVec38[((IOTA - 326) & 511)]) + fVec38[((IOTA - 382) & 511)]) - fVec38[((IOTA - 444) & 511)])) + ((9.15555283e-05f * ((((fVec38[((IOTA - 145) & 511)] + fVec38[((IOTA - 269) & 511)]) - fVec38[((IOTA - 335) & 511)]) - fVec38[((IOTA - 352) & 511)]) - fVec38[((IOTA - 443) & 511)])) + ((0.000610370189f * ((((((fVec38[((IOTA - 36) & 511)] + fVec38[((IOTA - 48) & 511)]) - fVec38[((IOTA - 217) & 511)]) - fVec38[((IOTA - 292) & 511)]) - fVec38[((IOTA - 312) & 511)]) + fVec38[((IOTA - 401) & 511)]) - fVec38[((IOTA - 437) & 511)])) + ((0.00186162908f * ((fVec38[((IOTA - 188) & 511)] - fVec38[((IOTA - 249) & 511)]) - fVec38[((IOTA - 434) & 511)])) + ((0.00216681417f * ((fVec38[((IOTA - 45) & 511)] - fVec38[((IOTA - 380) & 511)]) - fVec38[((IOTA - 428) & 511)])) + ((0.00228888821f * (fVec38[((IOTA - 189) & 511)] - fVec38[((IOTA - 414) & 511)])) + ((0.001617481f * ((fVec38[((IOTA - 220) & 511)] - fVec38[((IOTA - 229) & 511)]) - fVec38[((IOTA - 412) & 511)])) + ((0.00109866634f * (((fVec38[((IOTA - 219) & 511)] - fVec38[((IOTA - 266) & 511)]) - fVec38[((IOTA - 330) & 511)]) - fVec38[((IOTA - 411) & 511)])) + ((0.00170903653f * ((fVec38[((IOTA - 34) & 511)] + fVec38[((IOTA - 203) & 511)]) + fVec38[((IOTA - 406) & 511)])) + ((0.0019226661f * ((fVec38[((IOTA - 58) & 511)] - fVec38[((IOTA - 168) & 511)]) + fVec38[((IOTA - 404) & 511)])) + ((0.003234962f * (fVec38[((IOTA - 164) & 511)] - fVec38[((IOTA - 398) & 511)])) + ((0.00360118411f * fVec38[((IOTA - 387) & 511)]) + ((0.000793481246f * (((((fVec38[((IOTA - 222) & 511)] - fVec38[((IOTA - 228) & 511)]) - fVec38[((IOTA - 260) & 511)]) + fVec38[((IOTA - 422) & 511)]) - fVec38[((IOTA - 459) & 511)]) + fVec38[((IOTA - 467) & 511)])) + ((0.00408948027f * (fVec38[((IOTA - 185) & 511)] - fVec38[((IOTA - 376) & 511)])) + ((0.00250251777f * (fVec38[((IOTA - 187) & 511)] - fVec38[((IOTA - 375) & 511)])) + ((0.00509659108f * fVec38[((IOTA - 372) & 511)]) + ((0.00589007232f * fVec38[((IOTA - 371) & 511)]) + ((0.00479140598f * fVec38[((IOTA - 370) & 511)]) + ((0.0025940733f * (fVec38[((IOTA - 166) & 511)] + fVec38[((IOTA - 369) & 511)])) + ((0.00164799951f * ((fVec38[((IOTA - 47) & 511)] - fVec38[((IOTA - 319) & 511)]) - fVec38[((IOTA - 362) & 511)])) + ((0.00115970336f * ((((fVec38[((IOTA - 125) & 511)] - fVec38[((IOTA - 158) & 511)]) - fVec38[((IOTA - 248) & 511)]) + fVec38[((IOTA - 272) & 511)]) - fVec38[((IOTA - 344) & 511)])) + ((0.00219733268f * ((fVec38[((IOTA - 46) & 511)] - fVec38[((IOTA - 208) & 511)]) - fVec38[((IOTA - 317) & 511)])) + ((6.10370189e-05f * (fVec38[((IOTA - 284) & 511)] - fVec38[((IOTA - 311) & 511)])) + ((0.00247199927f * fVec38[((IOTA - 236) & 511)]) + ((0.00296029542f * fVec38[((IOTA - 234) & 511)]) + ((0.00573747978f * fVec38[((IOTA - 184) & 511)]) + ((0.00640888698f * (fVec38[((IOTA - 177) & 511)] + fVec38[((IOTA - 183) & 511)])) + ((0.00540177617f * fVec38[((IOTA - 182) & 511)]) + ((0.00357066561f * fVec38[((IOTA - 178) & 511)]) + ((0.00891140476f * fVec38[((IOTA - 176) & 511)]) + ((0.00607318338f * fVec38[((IOTA - 174) & 511)]) + ((0.00381481368f * fVec38[((IOTA - 165) & 511)]) + ((0.00662251655f * fVec38[((IOTA - 153) & 511)]) + ((0.0201727357f * fVec38[((IOTA - 152) & 511)]) + ((0.025940733f * fVec38[((IOTA - 151) & 511)]) + ((0.0227973275f * fVec38[((IOTA - 150) & 511)]) + ((0.016296884f * fVec38[((IOTA - 149) & 511)]) + ((0.0123599963f * fVec38[((IOTA - 148) & 511)]) + ((0.0100100711f * fVec38[((IOTA - 147) & 511)]) + ((0.00552385021f * fVec38[((IOTA - 146) & 511)]) + ((0.0159001444f * fVec38[((IOTA - 130) & 511)]) + ((0.0301522873f * fVec38[((IOTA - 129) & 511)]) + ((0.0371410251f * fVec38[((IOTA - 128) & 511)]) + ((0.0332346559f * fVec38[((IOTA - 127) & 511)]) + ((0.019226661f * fVec38[((IOTA - 126) & 511)]) + ((0.00885036774f * fVec38[((IOTA - 121) & 511)]) + ((0.0204474013f * fVec38[((IOTA - 120) & 511)]) + ((0.0245979186f * fVec38[((IOTA - 119) & 511)]) + ((0.0270393994f * fVec38[((IOTA - 118) & 511)]) + ((0.0273751039f * fVec38[((IOTA - 117) & 511)]) + ((0.0293893255f * fVec38[((IOTA - 116) & 511)]) + ((0.0292062145f * fVec38[((IOTA - 115) & 511)]) + ((0.0229804385f * fVec38[((IOTA - 114) & 511)]) + ((0.0130314035f * fVec38[((IOTA - 113) & 511)]) + ((0.00302133244f * fVec38[((IOTA - 112) & 511)]) + ((0.0143742179f * fVec38[((IOTA - 103) & 511)]) + ((0.0300607327f * fVec38[((IOTA - 102) & 511)]) + ((0.0316476934f * fVec38[((IOTA - 101) & 511)]) + ((0.0185247362f * fVec38[((IOTA - 100) & 511)]) + ((0.0313730277f * fVec38[((IOTA - 94) & 511)]) + ((0.0504165776f * fVec38[((IOTA - 93) & 511)]) + ((0.0522171706f * fVec38[((IOTA - 92) & 511)]) + ((0.0394299142f * fVec38[((IOTA - 91) & 511)]) + ((0.0403454714f * fVec38[((IOTA - 90) & 511)]) + ((0.0310678426f * fVec38[((IOTA - 89) & 511)]) + ((0.0380260646f * fVec38[((IOTA - 88) & 511)]) + ((0.0176396985f * fVec38[((IOTA - 87) & 511)]) + ((0.0195928831f * fVec38[((IOTA - 86) & 511)]) + ((0.0142521439f * fVec38[((IOTA - 85) & 511)]) + ((0.0275276955f * fVec38[((IOTA - 84) & 511)]) + ((0.025818659f * fVec38[((IOTA - 83) & 511)]) + ((0.00341807306f * fVec38[((IOTA - 82) & 511)]) + ((0.0273445845f * fVec38[((IOTA - 78) & 511)]) + ((0.12305063f * fVec38[((IOTA - 77) & 511)]) + ((0.18576616f * fVec38[((IOTA - 76) & 511)]) + ((0.173162028f * fVec38[((IOTA - 75) & 511)]) + ((0.0428785048f * fVec38[((IOTA - 74) & 511)]) + ((0.00628681295f * fVec38[((IOTA - 65) & 511)]) + ((0.0087282937f * fVec38[((IOTA - 64) & 511)]) + ((0.00830103457f * fVec38[((IOTA - 63) & 511)]) + ((0.00616473891f * fVec38[((IOTA - 62) & 511)]) + ((0.00390636921f * fVec38[((IOTA - 61) & 511)]) + ((0.00204474013f * fVec38[((IOTA - 59) & 511)]) + (0.00244148076f * fVec38[((IOTA - 60) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000244148076f * (((((((fVec38[((IOTA - 167) & 511)] - fVec38[((IOTA - 204) & 511)]) - fVec38[((IOTA - 293) & 511)]) + fVec38[((IOTA - 368) & 511)]) + fVec38[((IOTA - 421) & 511)]) - fVec38[((IOTA - 457) & 511)]) + fVec38[((IOTA - 509) & 511)]) + fVec38[((IOTA - 511) & 511)])))) : (((0.000732444227f * ((fVec37[((IOTA - 361) & 511)] - fVec37[((IOTA - 387) & 511)]) - fVec37[((IOTA - 509) & 511)])) + ((0.000183111057f * (((fVec37[((IOTA - 209) & 511)] - fVec37[((IOTA - 214) & 511)]) + fVec37[((IOTA - 412) & 511)]) - fVec37[((IOTA - 500) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((((((((fVec37[((IOTA - 4) & 511)] + fVec37[((IOTA - 5) & 511)]) + fVec37[((IOTA - 6) & 511)]) + fVec37[((IOTA - 9) & 511)]) + fVec37[((IOTA - 10) & 511)]) + fVec37[((IOTA - 11) & 511)]) + fVec37[((IOTA - 12) & 511)]) + fVec37[((IOTA - 13) & 511)]) + fVec37[((IOTA - 14) & 511)]) + fVec37[((IOTA - 15) & 511)]) + fVec37[((IOTA - 16) & 511)]) + fVec37[((IOTA - 17) & 511)]) + fVec37[((IOTA - 18) & 511)]) + fVec37[((IOTA - 19) & 511)]) + fVec37[((IOTA - 22) & 511)]) + fVec37[((IOTA - 23) & 511)]) + fVec37[((IOTA - 24) & 511)]) - fVec37[((IOTA - 26) & 511)]) + fVec37[((IOTA - 34) & 511)]) + fVec37[((IOTA - 35) & 511)]) + fVec37[((IOTA - 36) & 511)]) + fVec37[((IOTA - 40) & 511)]) + fVec37[((IOTA - 41) & 511)]) + fVec37[((IOTA - 42) & 511)]) + fVec37[((IOTA - 43) & 511)]) + fVec37[((IOTA - 44) & 511)]) + fVec37[((IOTA - 45) & 511)]) + fVec37[((IOTA - 46) & 511)]) + fVec37[((IOTA - 47) & 511)]) + fVec37[((IOTA - 51) & 511)]) + fVec37[((IOTA - 52) & 511)]) + fVec37[((IOTA - 53) & 511)]) + fVec37[((IOTA - 54) & 511)]) + fVec37[((IOTA - 155) & 511)]) - fVec37[((IOTA - 201) & 511)]) - fVec37[((IOTA - 217) & 511)]) - fVec37[((IOTA - 260) & 511)]) + fVec37[((IOTA - 462) & 511)]) + fVec37[((IOTA - 476) & 511)]) - fVec37[((IOTA - 499) & 511)])) + ((0.000152592547f * ((((fVec37[((IOTA - 205) & 511)] - fVec37[((IOTA - 333) & 511)]) - fVec37[((IOTA - 388) & 511)]) - fVec37[((IOTA - 488) & 511)]) - fVec37[((IOTA - 497) & 511)])) + ((0.000823999755f * ((fVec37[((IOTA - 208) & 511)] - fVec37[((IOTA - 221) & 511)]) - fVec37[((IOTA - 495) & 511)])) + ((0.00112918485f * ((((((fVec37[((IOTA - 154) & 511)] - fVec37[((IOTA - 210) & 511)]) - fVec37[((IOTA - 307) & 511)]) - fVec37[((IOTA - 338) & 511)]) - fVec37[((IOTA - 419) & 511)]) - fVec37[((IOTA - 452) & 511)]) - fVec37[((IOTA - 494) & 511)])) + ((0.000366222113f * (fVec37[((IOTA - 478) & 511)] + fVec37[((IOTA - 487) & 511)])) + ((0.0012817774f * (fVec37[((IOTA - 484) & 511)] - (fVec37[((IOTA - 342) & 511)] - fVec37[((IOTA - 392) & 511)]))) + ((0.000762962736f * ((((fVec37[((IOTA - 161) & 511)] + fVec37[((IOTA - 398) & 511)]) + fVec37[((IOTA - 456) & 511)]) + fVec37[((IOTA - 468) & 511)]) + fVec37[((IOTA - 481) & 511)])) + ((0.00057985168f * ((fVec37[((IOTA - 116) & 511)] - fVec37[((IOTA - 334) & 511)]) + fVec37[((IOTA - 479) & 511)])) + ((0.000244148076f * ((fVec37[((IOTA - 58) & 511)] + fVec37[((IOTA - 439) & 511)]) + fVec37[((IOTA - 475) & 511)])) + ((0.000701925717f * ((((fVec37[((IOTA - 207) & 511)] - fVec37[((IOTA - 320) & 511)]) + fVec37[((IOTA - 390) & 511)]) + fVec37[((IOTA - 414) & 511)]) - fVec37[((IOTA - 463) & 511)])) + ((0.000274666585f * ((fVec37[((IOTA - 202) & 511)] - fVec37[((IOTA - 418) & 511)]) + fVec37[((IOTA - 455) & 511)])) + ((6.10370189e-05f * (((((((((((((fVec37[((IOTA - 20) & 511)] + fVec37[((IOTA - 21) & 511)]) + fVec37[((IOTA - 48) & 511)]) + fVec37[((IOTA - 49) & 511)]) + fVec37[((IOTA - 50) & 511)]) + fVec37[((IOTA - 55) & 511)]) + fVec37[((IOTA - 60) & 511)]) + fVec37[((IOTA - 203) & 511)]) - fVec37[((IOTA - 204) & 511)]) - fVec37[((IOTA - 258) & 511)]) + fVec37[((IOTA - 259) & 511)]) - fVec37[((IOTA - 326) & 511)]) - fVec37[((IOTA - 332) & 511)]) - fVec37[((IOTA - 454) & 511)])) + ((0.00140385143f * fVec37[((IOTA - 436) & 511)]) + ((0.000122074038f * (((fVec37[((IOTA - 56) & 511)] + fVec37[((IOTA - 216) & 511)]) - fVec37[((IOTA - 220) & 511)]) - fVec37[((IOTA - 422) & 511)])) + ((0.00100711081f * ((fVec37[((IOTA - 358) & 511)] + fVec37[((IOTA - 391) & 511)]) - fVec37[((IOTA - 421) & 511)])) + ((0.003234962f * (((fVec37[((IOTA - 167) & 511)] - fVec37[((IOTA - 198) & 511)]) - fVec37[((IOTA - 234) & 511)]) - fVec37[((IOTA - 404) & 511)])) + ((0.000213629566f * (((fVec37[((IOTA - 57) & 511)] + fVec37[((IOTA - 59) & 511)]) - fVec37[((IOTA - 324) & 511)]) - fVec37[((IOTA - 399) & 511)])) + ((0.00177007355f * (((fVec37[((IOTA - 143) & 511)] - fVec37[((IOTA - 222) & 511)]) + fVec37[((IOTA - 359) & 511)]) + fVec37[((IOTA - 394) & 511)])) + ((0.00442518387f * (fVec37[((IOTA - 69) & 511)] - fVec37[((IOTA - 383) & 511)])) + ((0.00567644276f * (fVec37[((IOTA - 137) & 511)] - fVec37[((IOTA - 364) & 511)])) + ((0.00054933317f * (((fVec37[((IOTA - 168) & 511)] - fVec37[((IOTA - 174) & 511)]) + fVec37[((IOTA - 206) & 511)]) - fVec37[((IOTA - 312) & 511)])) + ((0.00625629444f * ((fVec37[((IOTA - 115) & 511)] - fVec37[((IOTA - 178) & 511)]) - fVec37[((IOTA - 184) & 511)])) + ((0.00518814661f * fVec37[((IOTA - 166) & 511)]) + ((0.00573747978f * fVec37[((IOTA - 165) & 511)]) + ((0.00622577593f * fVec37[((IOTA - 164) & 511)]) + ((0.00714133121f * fVec37[((IOTA - 163) & 511)]) + ((0.00527970213f * fVec37[((IOTA - 162) & 511)]) + ((0.00854518265f * (fVec37[((IOTA - 141) & 511)] - fVec37[((IOTA - 152) & 511)])) + ((0.004852443f * fVec37[((IOTA - 142) & 511)]) + ((0.011322367f * fVec37[((IOTA - 140) & 511)]) + ((0.0133365886f * fVec37[((IOTA - 139) & 511)]) + ((0.011200293f * fVec37[((IOTA - 138) & 511)]) + ((0.0136722922f * fVec37[((IOTA - 128) & 511)]) + ((0.0202032533f * fVec37[((IOTA - 127) & 511)]) + ((0.0130314035f * fVec37[((IOTA - 126) & 511)]) + ((0.0119937742f * fVec37[((IOTA - 114) & 511)]) + ((0.017975403f * fVec37[((IOTA - 113) & 511)]) + ((0.0238654744f * fVec37[((IOTA - 112) & 511)]) + ((0.0234992523f * fVec37[((IOTA - 111) & 511)]) + ((0.0219428092f * fVec37[((IOTA - 110) & 511)]) + ((0.0221869573f * fVec37[((IOTA - 109) & 511)]) + ((0.0177007355f * fVec37[((IOTA - 108) & 511)]) + ((0.00747703481f * fVec37[((IOTA - 107) & 511)]) + ((0.0120853297f * fVec37[((IOTA - 101) & 511)]) + ((0.0313425101f * fVec37[((IOTA - 100) & 511)]) + ((0.0361949541f * fVec37[((IOTA - 99) & 511)]) + ((0.0205084383f * fVec37[((IOTA - 98) & 511)]) + ((0.0296334736f * fVec37[((IOTA - 82) & 511)]) + ((0.0646076873f * fVec37[((IOTA - 81) & 511)]) + ((0.0405896194f * fVec37[((IOTA - 80) & 511)]) + ((0.127842039f * fVec37[((IOTA - 75) & 511)]) + ((0.28833887f * fVec37[((IOTA - 74) & 511)]) + ((0.30957976f * fVec37[((IOTA - 73) & 511)]) + ((0.195684686f * fVec37[((IOTA - 72) & 511)]) + ((0.0230109561f * fVec37[((IOTA - 70) & 511)]) + (0.078066349f * fVec37[((IOTA - 71) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000610370189f * ((((((fVec37[((IOTA - 261) & 511)] + fVec37[((IOTA - 272) & 511)]) + fVec37[((IOTA - 314) & 511)]) + fVec37[((IOTA - 377) & 511)]) - fVec37[((IOTA - 417) & 511)]) - fVec37[((IOTA - 447) & 511)]) + fVec37[((IOTA - 510) & 511)])) + ((0.000885036774f * (((fVec37[((IOTA - 329) & 511)] + fVec37[((IOTA - 356) & 511)]) + fVec37[((IOTA - 465) & 511)]) + fVec37[((IOTA - 508) & 511)])) + ((0.00103762932f * (((fVec37[((IOTA - 318) & 511)] + fVec37[((IOTA - 378) & 511)]) - fVec37[((IOTA - 415) & 511)]) + fVec37[((IOTA - 507) & 511)])) + ((0.00115970336f * (((fVec37[((IOTA - 212) & 511)] + fVec37[((IOTA - 337) & 511)]) - fVec37[((IOTA - 483) & 511)]) + fVec37[((IOTA - 506) & 511)])) + ((0.00125125889f * (((fVec37[((IOTA - 265) & 511)] - fVec37[((IOTA - 446) & 511)]) + fVec37[((IOTA - 504) & 511)]) + fVec37[((IOTA - 505) & 511)])) + ((0.00109866634f * (((fVec37[((IOTA - 271) & 511)] + fVec37[((IOTA - 274) & 511)]) + fVec37[((IOTA - 362) & 511)]) + fVec37[((IOTA - 503) & 511)])) + ((0.000793481246f * ((fVec37[((IOTA - 311) & 511)] - fVec37[((IOTA - 474) & 511)]) + fVec37[((IOTA - 502) & 511)])) + ((0.000488296151f * ((fVec37[((IOTA - 257) & 511)] + fVec37[((IOTA - 327) & 511)]) + fVec37[((IOTA - 501) & 511)])) + ((0.000457777642f * fVec37[((IOTA - 496) & 511)]) + ((0.00137333293f * ((fVec37[((IOTA - 340) & 511)] + fVec37[((IOTA - 420) & 511)]) + fVec37[((IOTA - 493) & 511)])) + ((0.00143436994f * (((((fVec37[((IOTA - 62) & 511)] + fVec37[((IOTA - 341) & 511)]) - fVec37[((IOTA - 457) & 511)]) - fVec37[((IOTA - 469) & 511)]) - fVec37[((IOTA - 473) & 511)]) + fVec37[((IOTA - 492) & 511)])) + ((0.00131229591f * (fVec37[((IOTA - 254) & 511)] + fVec37[((IOTA - 491) & 511)])) + ((0.00106814783f * (((((((fVec37[((IOTA - 256) & 511)] + fVec37[((IOTA - 309) & 511)]) + fVec37[((IOTA - 310) & 511)]) + fVec37[((IOTA - 315) & 511)]) + fVec37[((IOTA - 335) & 511)]) + fVec37[((IOTA - 343) & 511)]) - fVec37[((IOTA - 416) & 511)]) + fVec37[((IOTA - 490) & 511)])) + ((0.000671407208f * (((((((fVec37[((IOTA - 200) & 511)] + fVec37[((IOTA - 319) & 511)]) + fVec37[((IOTA - 323) & 511)]) + fVec37[((IOTA - 330) & 511)]) + fVec37[((IOTA - 375) & 511)]) + fVec37[((IOTA - 376) & 511)]) - fVec37[((IOTA - 480) & 511)]) + fVec37[((IOTA - 489) & 511)])) + ((0.000854518265f * (((fVec37[((IOTA - 328) & 511)] - fVec37[((IOTA - 423) & 511)]) - fVec37[((IOTA - 441) & 511)]) - fVec37[((IOTA - 486) & 511)])) + ((0.00119022187f * (((fVec37[((IOTA - 255) & 511)] + fVec37[((IOTA - 339) & 511)]) + fVec37[((IOTA - 347) & 511)]) - fVec37[((IOTA - 485) & 511)])) + ((0.000946073793f * (fVec37[((IOTA - 344) & 511)] - fVec37[((IOTA - 482) & 511)])) + ((9.15555283e-05f * (((fVec37[((IOTA - 219) & 511)] - fVec37[((IOTA - 325) & 511)]) - fVec37[((IOTA - 467) & 511)]) - fVec37[((IOTA - 477) & 511)])) + ((0.0019226661f * (((((fVec37[((IOTA - 290) & 511)] + fVec37[((IOTA - 305) & 511)]) + fVec37[((IOTA - 379) & 511)]) - fVec37[((IOTA - 434) & 511)]) - fVec37[((IOTA - 470) & 511)]) - fVec37[((IOTA - 472) & 511)])) + ((0.00210577715f * (((fVec37[((IOTA - 241) & 511)] + fVec37[((IOTA - 253) & 511)]) + fVec37[((IOTA - 289) & 511)]) - fVec37[((IOTA - 471) & 511)])) + ((0.000518814661f * (((fVec37[((IOTA - 313) & 511)] - fVec37[((IOTA - 438) & 511)]) + fVec37[((IOTA - 453) & 511)]) + fVec37[((IOTA - 466) & 511)])) + ((0.000976592302f * (((((fVec37[((IOTA - 308) & 511)] + fVec37[((IOTA - 322) & 511)]) + fVec37[((IOTA - 346) & 511)]) - fVec37[((IOTA - 437) & 511)]) - fVec37[((IOTA - 461) & 511)]) + fVec37[((IOTA - 464) & 511)])) + ((0.00180059206f * ((fVec37[((IOTA - 270) & 511)] - fVec37[((IOTA - 396) & 511)]) - fVec37[((IOTA - 460) & 511)])) + ((0.00216681417f * (((fVec37[((IOTA - 278) & 511)] + fVec37[((IOTA - 294) & 511)]) - fVec37[((IOTA - 426) & 511)]) - fVec37[((IOTA - 459) & 511)])) + ((0.00198370311f * ((((fVec37[((IOTA - 153) & 511)] + fVec37[((IOTA - 295) & 511)]) + fVec37[((IOTA - 298) & 511)]) - fVec37[((IOTA - 425) & 511)]) - fVec37[((IOTA - 458) & 511)])) + ((0.00173955504f * ((fVec37[((IOTA - 275) & 511)] - fVec37[((IOTA - 435) & 511)]) + fVec37[((IOTA - 451) & 511)])) + ((0.00186162908f * (fVec37[((IOTA - 296) & 511)] + fVec37[((IOTA - 450) & 511)])) + ((0.00134281442f * ((fVec37[((IOTA - 266) & 511)] - fVec37[((IOTA - 442) & 511)]) + fVec37[((IOTA - 449) & 511)])) + ((0.000335703604f * ((((fVec37[((IOTA - 213) & 511)] + fVec37[((IOTA - 331) & 511)]) + fVec37[((IOTA - 374) & 511)]) - fVec37[((IOTA - 389) & 511)]) + fVec37[((IOTA - 448) & 511)])) + ((0.00155644398f * (((fVec37[((IOTA - 264) & 511)] + fVec37[((IOTA - 306) & 511)]) - fVec37[((IOTA - 443) & 511)]) - fVec37[((IOTA - 445) & 511)])) + ((0.00164799951f * (fVec37[((IOTA - 409) & 511)] - fVec37[((IOTA - 444) & 511)])) + ((0.00201422162f * ((fVec37[((IOTA - 279) & 511)] + fVec37[((IOTA - 401) & 511)]) - fVec37[((IOTA - 433) & 511)])) + ((0.00204474013f * (fVec37[((IOTA - 280) & 511)] - fVec37[((IOTA - 432) & 511)])) + ((0.00219733268f * (fVec37[((IOTA - 349) & 511)] - fVec37[((IOTA - 431) & 511)])) + ((0.00244148076f * ((fVec37[((IOTA - 68) & 511)] + fVec37[((IOTA - 243) & 511)]) - fVec37[((IOTA - 429) & 511)])) + ((0.00241096225f * (((fVec37[((IOTA - 240) & 511)] + fVec37[((IOTA - 304) & 511)]) + fVec37[((IOTA - 368) & 511)]) - fVec37[((IOTA - 428) & 511)])) + ((0.00228888821f * (((fVec37[((IOTA - 247) & 511)] + fVec37[((IOTA - 293) & 511)]) - fVec37[((IOTA - 370) & 511)]) - fVec37[((IOTA - 427) & 511)])) + ((0.001617481f * (((fVec37[((IOTA - 199) & 511)] + fVec37[((IOTA - 348) & 511)]) + fVec37[((IOTA - 355) & 511)]) - fVec37[((IOTA - 424) & 511)])) + ((0.000640888698f * ((fVec37[((IOTA - 273) & 511)] - fVec37[((IOTA - 373) & 511)]) + fVec37[((IOTA - 410) & 511)])) + ((0.00280770287f * fVec37[((IOTA - 408) & 511)]) + ((0.00357066561f * (fVec37[((IOTA - 225) & 511)] + fVec37[((IOTA - 407) & 511)])) + ((0.00384533219f * fVec37[((IOTA - 406) & 511)]) + ((0.00366222113f * fVec37[((IOTA - 405) & 511)]) + ((0.00234992523f * ((((fVec37[((IOTA - 227) & 511)] + fVec37[((IOTA - 248) & 511)]) + fVec37[((IOTA - 288) & 511)]) + fVec37[((IOTA - 299) & 511)]) - fVec37[((IOTA - 430) & 511)])) + ((0.00283822138f * ((fVec37[((IOTA - 238) & 511)] + fVec37[((IOTA - 301) & 511)]) + fVec37[((IOTA - 403) & 511)])) + ((0.00250251777f * (fVec37[((IOTA - 181) & 511)] + fVec37[((IOTA - 402) & 511)])) + ((0.00122074038f * (fVec37[((IOTA - 336) & 511)] + fVec37[((IOTA - 400) & 511)])) + ((0.00149540696f * ((fVec37[((IOTA - 262) & 511)] + fVec37[((IOTA - 317) & 511)]) - fVec37[((IOTA - 397) & 511)])) + ((0.00183111057f * ((((fVec37[((IOTA - 136) & 511)] + fVec37[((IOTA - 263) & 511)]) + fVec37[((IOTA - 297) & 511)]) - fVec37[((IOTA - 372) & 511)]) - fVec37[((IOTA - 395) & 511)])) + ((0.00158696249f * ((fVec37[((IOTA - 85) & 511)] + fVec37[((IOTA - 144) & 511)]) - fVec37[((IOTA - 393) & 511)])) + ((0.00152592547f * (fVec37[((IOTA - 173) & 511)] + fVec37[((IOTA - 386) & 511)])) + ((0.00271614734f * ((((fVec37[((IOTA - 229) & 511)] + fVec37[((IOTA - 284) & 511)]) + fVec37[((IOTA - 287) & 511)]) - fVec37[((IOTA - 371) & 511)]) + fVec37[((IOTA - 385) & 511)])) + ((0.00378429517f * fVec37[((IOTA - 384) & 511)]) + ((0.00424207281f * fVec37[((IOTA - 382) & 511)]) + ((0.00375377666f * fVec37[((IOTA - 381) & 511)]) + ((0.00286873989f * ((fVec37[((IOTA - 237) & 511)] + fVec37[((IOTA - 286) & 511)]) + fVec37[((IOTA - 380) & 511)])) + ((0.00506607257f * fVec37[((IOTA - 367) & 511)]) + ((0.0067751091f * fVec37[((IOTA - 366) & 511)]) + ((0.00695822015f * fVec37[((IOTA - 365) & 511)]) + ((0.00347911008f * (fVec37[((IOTA - 145) & 511)] + fVec37[((IOTA - 363) & 511)])) + ((0.00170903653f * ((fVec37[((IOTA - 211) & 511)] + fVec37[((IOTA - 267) & 511)]) - fVec37[((IOTA - 360) & 511)])) + ((0.00231940672f * (fVec37[((IOTA - 228) & 511)] + fVec37[((IOTA - 354) & 511)])) + ((0.0028992584f * (((fVec37[((IOTA - 180) & 511)] + fVec37[((IOTA - 226) & 511)]) + fVec37[((IOTA - 302) & 511)]) + fVec37[((IOTA - 353) & 511)])) + ((0.00314340647f * (fVec37[((IOTA - 236) & 511)] + fVec37[((IOTA - 351) & 511)])) + ((0.00274666585f * ((((fVec37[((IOTA - 246) & 511)] + fVec37[((IOTA - 283) & 511)]) + fVec37[((IOTA - 285) & 511)]) + fVec37[((IOTA - 303) & 511)]) + fVec37[((IOTA - 350) & 511)])) + ((0.000915555283f * (fVec37[((IOTA - 321) & 511)] + fVec37[((IOTA - 345) & 511)])) + ((0.00320444349f * ((fVec37[((IOTA - 86) & 511)] + fVec37[((IOTA - 125) & 511)]) + fVec37[((IOTA - 352) & 511)])) + ((0.00146488845f * fVec37[((IOTA - 316) & 511)]) + ((0.00268562883f * fVec37[((IOTA - 300) & 511)]) + ((0.00213629566f * (fVec37[((IOTA - 268) & 511)] + fVec37[((IOTA - 292) & 511)])) + ((0.0019531846f * fVec37[((IOTA - 291) & 511)]) + ((0.0025940733f * (fVec37[((IOTA - 223) & 511)] + fVec37[((IOTA - 282) & 511)])) + ((0.0022583697f * ((fVec37[((IOTA - 269) & 511)] + fVec37[((IOTA - 276) & 511)]) + fVec37[((IOTA - 281) & 511)])) + ((0.00238044374f * fVec37[((IOTA - 277) & 511)]) + ((0.00308236945f * fVec37[((IOTA - 252) & 511)]) + ((0.00363170262f * fVec37[((IOTA - 251) & 511)]) + ((0.00350962859f * fVec37[((IOTA - 250) & 511)]) + ((0.00305185094f * (fVec37[((IOTA - 245) & 511)] + fVec37[((IOTA - 249) & 511)])) + ((0.00277718436f * (fVec37[((IOTA - 239) & 511)] + fVec37[((IOTA - 244) & 511)])) + ((0.00222785119f * fVec37[((IOTA - 242) & 511)]) + ((0.00329599902f * (fVec37[((IOTA - 224) & 511)] + fVec37[((IOTA - 235) & 511)])) + ((0.00341807306f * fVec37[((IOTA - 233) & 511)]) + ((0.00369273964f * (fVec37[((IOTA - 231) & 511)] + fVec37[((IOTA - 232) & 511)])) + ((0.00317392498f * (fVec37[((IOTA - 169) & 511)] + fVec37[((IOTA - 230) & 511)])) + ((0.00396740623f * fVec37[((IOTA - 197) & 511)]) + ((0.00439466536f * (fVec37[((IOTA - 172) & 511)] + fVec37[((IOTA - 196) & 511)])) + ((0.00546281319f * (fVec37[((IOTA - 148) & 511)] + fVec37[((IOTA - 195) & 511)])) + ((0.00628681295f * fVec37[((IOTA - 194) & 511)]) + ((0.00576799829f * fVec37[((IOTA - 193) & 511)]) + ((0.00445570238f * fVec37[((IOTA - 192) & 511)]) + ((0.00372325815f * fVec37[((IOTA - 191) & 511)]) + ((0.00433362834f * fVec37[((IOTA - 190) & 511)]) + ((0.00564592425f * fVec37[((IOTA - 189) & 511)]) + ((0.00720236823f * fVec37[((IOTA - 188) & 511)]) + ((0.0074159978f * fVec37[((IOTA - 187) & 511)]) + ((0.00738547929f * (fVec37[((IOTA - 97) & 511)] + fVec37[((IOTA - 186) & 511)])) + ((0.00543229468f * fVec37[((IOTA - 183) & 511)]) + ((0.00408948027f * fVec37[((IOTA - 182) & 511)]) + ((0.00463881344f * fVec37[((IOTA - 179) & 511)]) + ((0.00662251655f * fVec37[((IOTA - 177) & 511)]) + ((0.00512710959f * fVec37[((IOTA - 176) & 511)]) + ((0.00299081393f * fVec37[((IOTA - 175) & 511)]) + ((0.00759910885f * fVec37[((IOTA - 171) & 511)]) + ((0.006469924f * fVec37[((IOTA - 170) & 511)]) + ((0.00643940549f * fVec37[((IOTA - 160) & 511)]) + ((0.0115054781f * fVec37[((IOTA - 159) & 511)]) + ((0.0138859218f * fVec37[((IOTA - 158) & 511)]) + ((0.009704886f * fVec37[((IOTA - 157) & 511)]) + ((0.00430310983f * fVec37[((IOTA - 156) & 511)]) + ((0.00668355357f * fVec37[((IOTA - 185) & 511)]) + ((0.0133976256f * fVec37[((IOTA - 151) & 511)]) + ((0.0128482925f * fVec37[((IOTA - 150) & 511)]) + ((0.00836207159f * fVec37[((IOTA - 149) & 511)]) + ((0.00469985045f * fVec37[((IOTA - 147) & 511)]) + ((0.00491348002f * fVec37[((IOTA - 146) & 511)]) + ((0.00881984923f * fVec37[((IOTA - 135) & 511)]) + ((0.016235847f * fVec37[((IOTA - 134) & 511)]) + ((0.0245368816f * fVec37[((IOTA - 133) & 511)]) + ((0.0302438438f * fVec37[((IOTA - 132) & 511)]) + ((0.030793177f * fVec37[((IOTA - 131) & 511)]) + ((0.0209662169f * fVec37[((IOTA - 130) & 511)]) + ((0.00411999878f * fVec37[((IOTA - 129) & 511)]) + ((0.0189519953f * fVec37[((IOTA - 124) & 511)]) + ((0.0285958443f * fVec37[((IOTA - 123) & 511)]) + ((0.0295113996f * fVec37[((IOTA - 122) & 511)]) + ((0.0273140669f * fVec37[((IOTA - 121) & 511)]) + ((0.0254219193f * fVec37[((IOTA - 120) & 511)]) + ((0.0260628071f * fVec37[((IOTA - 119) & 511)]) + ((0.0216681417f * fVec37[((IOTA - 118) & 511)]) + ((0.0125431074f * fVec37[((IOTA - 117) & 511)]) + ((0.00900296029f * fVec37[((IOTA - 106) & 511)]) + ((0.0157170333f * fVec37[((IOTA - 105) & 511)]) + ((0.0240791049f * fVec37[((IOTA - 104) & 511)]) + ((0.0247810297f * fVec37[((IOTA - 103) & 511)]) + ((0.0142521439f * fVec37[((IOTA - 102) & 511)]) + ((0.0335703604f * fVec37[((IOTA - 96) & 511)]) + ((0.0387890264f * fVec37[((IOTA - 95) & 511)]) + ((0.0297250282f * fVec37[((IOTA - 94) & 511)]) + ((0.0115665151f * fVec37[((IOTA - 93) & 511)]) + ((0.00595110934f * fVec37[((IOTA - 92) & 511)]) + ((0.0102237007f * fVec37[((IOTA - 91) & 511)]) + ((0.025940733f * fVec37[((IOTA - 90) & 511)]) + ((0.0305490289f * fVec37[((IOTA - 89) & 511)]) + ((0.0293588061f * fVec37[((IOTA - 88) & 511)]) + ((0.0108951079f * fVec37[((IOTA - 87) & 511)]) + ((0.0120242927f * fVec37[((IOTA - 84) & 511)]) + ((0.00952177495f * fVec37[((IOTA - 83) & 511)]) + ((0.0672933161f * fVec37[((IOTA - 79) & 511)]) + ((0.155522332f * fVec37[((IOTA - 78) & 511)]) + ((0.16559343f * fVec37[((IOTA - 77) & 511)]) + ((0.0631733164f * fVec37[((IOTA - 76) & 511)]) + ((0.0087282937f * fVec37[((IOTA - 67) & 511)]) + ((0.0114749596f * fVec37[((IOTA - 66) & 511)]) + ((0.00393688772f * fVec37[((IOTA - 63) & 511)]) + ((0.00778221991f * fVec37[((IOTA - 64) & 511)]) + ((0.000305185094f * fVec37[((IOTA - 61) & 511)]) + (0.0106814783f * fVec37[((IOTA - 65) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000396740623f * ((((fVec37[((IOTA - 218) & 511)] - fVec37[((IOTA - 369) & 511)]) - fVec37[((IOTA - 413) & 511)]) - fVec37[((IOTA - 440) & 511)]) + fVec37[((IOTA - 511) & 511)])))))) : (iSlow80 ? (iSlow88 ? (((0.000335703604f * ((fVec36[((IOTA - 56) & 511)] + fVec36[((IOTA - 303) & 511)]) + fVec36[((IOTA - 508) & 511)])) + ((0.000457777642f * (fVec36[((IOTA - 507) & 511)] - ((((((fVec36[((IOTA - 225) & 511)] + fVec36[((IOTA - 245) & 511)]) - fVec36[((IOTA - 274) & 511)]) + fVec36[((IOTA - 299) & 511)]) + fVec36[((IOTA - 385) & 511)]) + fVec36[((IOTA - 388) & 511)]) - fVec36[((IOTA - 502) & 511)]))) + ((0.000183111057f * (((((((((fVec36[((IOTA - 3) & 511)] - fVec36[((IOTA - 18) & 511)]) + fVec36[((IOTA - 19) & 511)]) + fVec36[((IOTA - 26) & 511)]) - fVec36[((IOTA - 28) & 511)]) - fVec36[((IOTA - 40) & 511)]) + fVec36[((IOTA - 54) & 511)]) - fVec36[((IOTA - 60) & 511)]) - fVec36[((IOTA - 367) & 511)]) + fVec36[((IOTA - 501) & 511)])) + ((0.000488296151f * (fVec36[((IOTA - 23) & 511)] + fVec36[((IOTA - 496) & 511)])) + ((0.0012817774f * ((((((fVec36[((IOTA - 218) & 511)] + fVec36[((IOTA - 313) & 511)]) + fVec36[((IOTA - 324) & 511)]) - fVec36[((IOTA - 387) & 511)]) + fVec36[((IOTA - 389) & 511)]) + fVec36[((IOTA - 410) & 511)]) + fVec36[((IOTA - 491) & 511)])) + ((0.00183111057f * (((fVec36[((IOTA - 209) & 511)] + fVec36[((IOTA - 486) & 511)]) + fVec36[((IOTA - 487) & 511)]) + fVec36[((IOTA - 489) & 511)])) + ((0.00189214759f * fVec36[((IOTA - 485) & 511)]) + ((0.00180059206f * (((((fVec36[((IOTA - 334) & 511)] + fVec36[((IOTA - 347) & 511)]) + fVec36[((IOTA - 348) & 511)]) + fVec36[((IOTA - 467) & 511)]) + fVec36[((IOTA - 482) & 511)]) + fVec36[((IOTA - 483) & 511)])) + ((0.00256355479f * ((fVec36[((IOTA - 336) & 511)] + fVec36[((IOTA - 413) & 511)]) + fVec36[((IOTA - 479) & 511)])) + ((0.00292977691f * fVec36[((IOTA - 478) & 511)]) + ((0.00314340647f * fVec36[((IOTA - 477) & 511)]) + ((0.00299081393f * (fVec36[((IOTA - 426) & 511)] + fVec36[((IOTA - 475) & 511)])) + ((0.00277718436f * (fVec36[((IOTA - 465) & 511)] + fVec36[((IOTA - 474) & 511)])) + ((0.00250251777f * fVec36[((IOTA - 473) & 511)]) + ((0.00216681417f * (((fVec36[((IOTA - 310) & 511)] + fVec36[((IOTA - 339) & 511)]) + fVec36[((IOTA - 423) & 511)]) + fVec36[((IOTA - 472) & 511)])) + ((0.00177007355f * (((((((((fVec36[((IOTA - 207) & 511)] - fVec36[((IOTA - 240) & 511)]) - fVec36[((IOTA - 256) & 511)]) - fVec36[((IOTA - 287) & 511)]) - fVec36[((IOTA - 288) & 511)]) + fVec36[((IOTA - 330) & 511)]) + fVec36[((IOTA - 331) & 511)]) + fVec36[((IOTA - 344) & 511)]) + fVec36[((IOTA - 379) & 511)]) + fVec36[((IOTA - 471) & 511)])) + ((0.00137333293f * (((((fVec36[((IOTA - 38) & 511)] + fVec36[((IOTA - 223) & 511)]) - fVec36[((IOTA - 239) & 511)]) - fVec36[((IOTA - 289) & 511)]) + fVec36[((IOTA - 468) & 511)]) + fVec36[((IOTA - 470) & 511)])) + ((0.00122074038f * (fVec36[((IOTA - 263) & 511)] + fVec36[((IOTA - 469) & 511)])) + ((0.00234992523f * ((((((fVec36[((IOTA - 96) & 511)] + fVec36[((IOTA - 133) & 511)]) - fVec36[((IOTA - 248) & 511)]) - fVec36[((IOTA - 249) & 511)]) + fVec36[((IOTA - 378) & 511)]) + fVec36[((IOTA - 399) & 511)]) + fVec36[((IOTA - 466) & 511)])) + ((0.00296029542f * (fVec36[((IOTA - 365) & 511)] + fVec36[((IOTA - 462) & 511)])) + ((0.00265511032f * fVec36[((IOTA - 461) & 511)]) + ((0.001617481f * ((fVec36[((IOTA - 406) & 511)] + fVec36[((IOTA - 411) & 511)]) + fVec36[((IOTA - 459) & 511)])) + ((0.00106814783f * ((fVec36[((IOTA - 382) & 511)] - fVec36[((IOTA - 386) & 511)]) + fVec36[((IOTA - 458) & 511)])) + ((0.000427259132f * (((fVec36[((IOTA - 2) & 511)] + fVec36[((IOTA - 20) & 511)]) - fVec36[((IOTA - 29) & 511)]) + fVec36[((IOTA - 454) & 511)])) + ((0.00158696249f * ((((((fVec36[((IOTA - 37) & 511)] + fVec36[((IOTA - 64) & 511)]) - fVec36[((IOTA - 232) & 511)]) - fVec36[((IOTA - 257) & 511)]) - fVec36[((IOTA - 258) & 511)]) + fVec36[((IOTA - 321) & 511)]) + fVec36[((IOTA - 453) & 511)])) + ((0.00405896176f * fVec36[((IOTA - 451) & 511)]) + ((0.00457777642f * fVec36[((IOTA - 450) & 511)]) + ((0.00454725791f * (fVec36[((IOTA - 432) & 511)] + fVec36[((IOTA - 449) & 511)])) + ((0.00408948027f * ((fVec36[((IOTA - 111) & 511)] + fVec36[((IOTA - 417) & 511)]) + fVec36[((IOTA - 448) & 511)])) + ((0.00286873989f * (fVec36[((IOTA - 440) & 511)] + fVec36[((IOTA - 445) & 511)])) + ((0.00268562883f * (fVec36[((IOTA - 441) & 511)] + fVec36[((IOTA - 444) & 511)])) + ((0.0025940733f * (fVec36[((IOTA - 442) & 511)] + fVec36[((IOTA - 443) & 511)])) + ((0.00360118411f * fVec36[((IOTA - 438) & 511)]) + ((0.00396740623f * (fVec36[((IOTA - 418) & 511)] + fVec36[((IOTA - 437) & 511)])) + ((0.00418103579f * fVec36[((IOTA - 436) & 511)]) + ((0.00430310983f * fVec36[((IOTA - 434) & 511)]) + ((0.00497451704f * (fVec36[((IOTA - 391) & 511)] + fVec36[((IOTA - 430) & 511)])) + ((0.00448622089f * fVec36[((IOTA - 428) & 511)]) + ((0.00238044374f * ((fVec36[((IOTA - 141) & 511)] - fVec36[((IOTA - 231) & 511)]) + fVec36[((IOTA - 425) & 511)])) + ((0.00213629566f * ((fVec36[((IOTA - 317) & 511)] + fVec36[((IOTA - 372) & 511)]) + fVec36[((IOTA - 424) & 511)])) + ((0.00241096225f * (fVec36[((IOTA - 311) & 511)] + fVec36[((IOTA - 422) & 511)])) + ((0.00280770287f * (fVec36[((IOTA - 337) & 511)] + fVec36[((IOTA - 421) & 511)])) + ((0.00326548051f * fVec36[((IOTA - 420) & 511)]) + ((0.00369273964f * (fVec36[((IOTA - 364) & 511)] + fVec36[((IOTA - 419) & 511)])) + ((0.0028992584f * (fVec36[((IOTA - 398) & 511)] + fVec36[((IOTA - 452) & 511)])) + ((0.00393688772f * fVec36[((IOTA - 416) & 511)]) + ((0.00357066561f * fVec36[((IOTA - 415) & 511)]) + ((0.00305185094f * fVec36[((IOTA - 414) & 511)]) + ((0.00115970336f * ((((((fVec36[((IOTA - 62) & 511)] + fVec36[((IOTA - 217) & 511)]) - fVec36[((IOTA - 286) & 511)]) + fVec36[((IOTA - 359) & 511)]) + fVec36[((IOTA - 381) & 511)]) + fVec36[((IOTA - 408) & 511)]) + fVec36[((IOTA - 409) & 511)])) + ((0.00131229591f * ((((fVec36[((IOTA - 36) & 511)] - fVec36[((IOTA - 147) & 511)]) - fVec36[((IOTA - 246) & 511)]) - fVec36[((IOTA - 293) & 511)]) + fVec36[((IOTA - 407) & 511)])) + ((0.00210577715f * ((fVec36[((IOTA - 335) & 511)] + fVec36[((IOTA - 403) & 511)]) + fVec36[((IOTA - 404) & 511)])) + ((0.00341807306f * (fVec36[((IOTA - 390) & 511)] + fVec36[((IOTA - 397) & 511)])) + ((0.00384533219f * fVec36[((IOTA - 395) & 511)]) + ((0.0051576281f * fVec36[((IOTA - 393) & 511)]) + ((0.0054933317f * fVec36[((IOTA - 392) & 511)]) + ((0.000305185094f * (((((fVec36[((IOTA - 25) & 511)] + fVec36[((IOTA - 146) & 511)]) + fVec36[((IOTA - 216) & 511)]) + fVec36[((IOTA - 282) & 511)]) + fVec36[((IOTA - 304) & 511)]) + fVec36[((IOTA - 384) & 511)])) + ((0.00329599902f * fVec36[((IOTA - 377) & 511)]) + ((0.00607318338f * (fVec36[((IOTA - 102) & 511)] + fVec36[((IOTA - 374) & 511)])) + ((0.00482192449f * fVec36[((IOTA - 373) & 511)]) + ((0.000915555283f * (((fVec36[((IOTA - 10) & 511)] + fVec36[((IOTA - 11) & 511)]) + fVec36[((IOTA - 224) & 511)]) - fVec36[((IOTA - 371) & 511)])) + ((0.00335703604f * fVec36[((IOTA - 362) & 511)]) + ((0.00262459181f * (fVec36[((IOTA - 338) & 511)] + fVec36[((IOTA - 361) & 511)])) + ((0.000122074038f * ((((fTemp37 - fVec36[((IOTA - 34) & 511)]) + fVec36[((IOTA - 204) & 511)]) - fVec36[((IOTA - 261) & 511)]) + fVec36[((IOTA - 357) & 511)])) + ((0.000274666585f * ((((fVec36[((IOTA - 170) & 511)] + fVec36[((IOTA - 283) & 511)]) + fVec36[((IOTA - 302) & 511)]) + fVec36[((IOTA - 305) & 511)]) - fVec36[((IOTA - 356) & 511)])) + ((0.000518814661f * (((fVec36[((IOTA - 21) & 511)] + fVec36[((IOTA - 265) & 511)]) + fVec36[((IOTA - 280) & 511)]) - fVec36[((IOTA - 353) & 511)])) + ((0.00112918485f * (((fVec36[((IOTA - 314) & 511)] - ((fVec36[((IOTA - 211) & 511)] - fVec36[((IOTA - 222) & 511)]) + fVec36[((IOTA - 297) & 511)])) + fVec36[((IOTA - 326) & 511)]) + fVec36[((IOTA - 350) & 511)])) + ((0.00152592547f * (fVec36[((IOTA - 329) & 511)] + fVec36[((IOTA - 349) & 511)])) + ((0.00173955504f * ((((fVec36[((IOTA - 97) & 511)] - fVec36[((IOTA - 164) & 511)]) + fVec36[((IOTA - 341) & 511)]) + fVec36[((IOTA - 345) & 511)]) + fVec36[((IOTA - 346) & 511)])) + ((0.00167851802f * (fVec36[((IOTA - 63) & 511)] + fVec36[((IOTA - 342) & 511)])) + ((0.00589007232f * fVec36[((IOTA - 375) & 511)]) + ((0.00109866634f * ((fVec36[((IOTA - 46) & 511)] - fVec36[((IOTA - 66) & 511)]) + fVec36[((IOTA - 327) & 511)])) + ((0.0035401471f * (fVec36[((IOTA - 165) & 511)] + fVec36[((IOTA - 396) & 511)])) + ((3.05185094e-05f * ((fVec36[((IOTA - 27) & 511)] + fVec36[((IOTA - 266) & 511)]) + fVec36[((IOTA - 301) & 511)])) + ((0.00479140598f * fVec36[((IOTA - 431) & 511)]) + ((0.00100711081f * (fVec36[((IOTA - 47) & 511)] - fVec36[((IOTA - 290) & 511)])) + ((0.000396740623f * (((((fVec36[((IOTA - 1) & 511)] + fVec36[((IOTA - 24) & 511)]) + fVec36[((IOTA - 55) & 511)]) + fVec36[((IOTA - 61) & 511)]) + fVec36[((IOTA - 244) & 511)]) - fVec36[((IOTA - 285) & 511)])) + ((0.000976592302f * fVec36[((IOTA - 262) & 511)]) + ((0.000762962736f * (fVec36[((IOTA - 205) & 511)] + fVec36[((IOTA - 219) & 511)])) + ((0.00555436872f * fVec36[((IOTA - 169) & 511)]) + ((0.0093691824f * fVec36[((IOTA - 168) & 511)]) + ((0.0104373302f * fVec36[((IOTA - 167) & 511)]) + ((0.00811792351f * fVec36[((IOTA - 166) & 511)]) + ((0.00332651753f * fVec36[((IOTA - 145) & 511)]) + ((0.0045167394f * fVec36[((IOTA - 144) & 511)]) + ((0.00628681295f * fVec36[((IOTA - 143) & 511)]) + ((0.00531022064f * fVec36[((IOTA - 142) & 511)]) + ((0.0164799951f * fVec36[((IOTA - 132) & 511)]) + ((0.0193182174f * fVec36[((IOTA - 131) & 511)]) + ((0.00784325693f * fVec36[((IOTA - 130) & 511)]) + ((0.00521866512f * fVec36[((IOTA - 119) & 511)]) + ((0.0112918485f * fVec36[((IOTA - 118) & 511)]) + ((0.0137638478f * fVec36[((IOTA - 116) & 511)]) + ((0.0145268105f * fVec36[((IOTA - 115) & 511)]) + ((0.0209051799f * fVec36[((IOTA - 114) & 511)]) + ((0.0205694754f * fVec36[((IOTA - 113) & 511)]) + ((0.0167241432f * fVec36[((IOTA - 112) & 511)]) + ((0.0189519953f * fVec36[((IOTA - 105) & 511)]) + ((0.0423596911f * fVec36[((IOTA - 104) & 511)]) + ((0.0131229591f * fVec36[((IOTA - 117) & 511)]) + ((0.0235908087f * fVec36[((IOTA - 87) & 511)]) + ((0.0653706491f * fVec36[((IOTA - 86) & 511)]) + ((0.0753807202f * fVec36[((IOTA - 85) & 511)]) + ((0.00802636798f * fVec36[((IOTA - 84) & 511)]) + ((0.159428701f * fVec36[((IOTA - 79) & 511)]) + ((0.304940939f * fVec36[((IOTA - 78) & 511)]) + ((0.280495614f * fVec36[((IOTA - 77) & 511)]) + ((0.140049443f * fVec36[((IOTA - 76) & 511)]) + ((0.0376903601f * fVec36[((IOTA - 75) & 511)]) + ((0.008087405f * fVec36[((IOTA - 74) & 511)]) + ((9.15555283e-05f * ((fVec36[((IOTA - 8) & 511)] - fVec36[((IOTA - 49) & 511)]) + fVec36[((IOTA - 57) & 511)])) + (0.00311288796f * fVec36[((IOTA - 73) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000244148076f * (fVec36[((IOTA - 242) & 511)] - fVec36[((IOTA - 509) & 511)])) + ((0.000640888698f * ((((fVec36[((IOTA - 6) & 511)] + fVec36[((IOTA - 33) & 511)]) - fVec36[((IOTA - 39) & 511)]) + fVec36[((IOTA - 50) & 511)]) - fVec36[((IOTA - 506) & 511)])) + ((0.000823999755f * ((fVec36[((IOTA - 51) & 511)] - fVec36[((IOTA - 504) & 511)]) - fVec36[((IOTA - 505) & 511)])) + ((0.000701925717f * ((((((fVec36[((IOTA - 43) & 511)] - fVec36[((IOTA - 45) & 511)]) - fVec36[((IOTA - 65) & 511)]) - fVec36[((IOTA - 243) & 511)]) + fVec36[((IOTA - 354) & 511)]) - fVec36[((IOTA - 493) & 511)]) - fVec36[((IOTA - 503) & 511)])) + ((0.000366222113f * (((((fVec36[((IOTA - 7) & 511)] + fVec36[((IOTA - 59) & 511)]) + fVec36[((IOTA - 269) & 511)]) - fVec36[((IOTA - 281) & 511)]) - fVec36[((IOTA - 306) & 511)]) - fVec36[((IOTA - 497) & 511)])) + ((0.00054933317f * ((((((fVec36[((IOTA - 14) & 511)] - fVec36[((IOTA - 22) & 511)]) + fVec36[((IOTA - 179) & 511)]) + fVec36[((IOTA - 267) & 511)]) - fVec36[((IOTA - 351) & 511)]) - fVec36[((IOTA - 457) & 511)]) - fVec36[((IOTA - 495) & 511)])) + ((0.00057985168f * (((((((((fVec36[((IOTA - 5) & 511)] - fVec36[((IOTA - 9) & 511)]) - fVec36[((IOTA - 12) & 511)]) + fVec36[((IOTA - 17) & 511)]) - fVec36[((IOTA - 35) & 511)]) - fVec36[((IOTA - 48) & 511)]) - fVec36[((IOTA - 210) & 511)]) - fVec36[((IOTA - 307) & 511)]) + fVec36[((IOTA - 355) & 511)]) - fVec36[((IOTA - 494) & 511)])) + ((0.000946073793f * ((((fVec36[((IOTA - 203) & 511)] - fVec36[((IOTA - 264) & 511)]) - fVec36[((IOTA - 276) & 511)]) - fVec36[((IOTA - 277) & 511)]) - fVec36[((IOTA - 492) & 511)])) + ((0.00164799951f * (fVec36[((IOTA - 233) & 511)] - fVec36[((IOTA - 490) & 511)])) + ((0.00186162908f * (((((fVec36[((IOTA - 172) & 511)] + fVec36[((IOTA - 236) & 511)]) - fVec36[((IOTA - 340) & 511)]) - fVec36[((IOTA - 360) & 511)]) - fVec36[((IOTA - 484) & 511)]) - fVec36[((IOTA - 488) & 511)])) + ((0.0019226661f * (((((fVec36[((IOTA - 247) & 511)] - fVec36[((IOTA - 312) & 511)]) - fVec36[((IOTA - 319) & 511)]) - fVec36[((IOTA - 401) & 511)]) - fVec36[((IOTA - 405) & 511)]) - fVec36[((IOTA - 481) & 511)])) + ((0.00219733268f * (((fVec36[((IOTA - 250) & 511)] - fVec36[((IOTA - 318) & 511)]) - fVec36[((IOTA - 460) & 511)]) - fVec36[((IOTA - 480) & 511)])) + ((0.00317392498f * ((fVec36[((IOTA - 72) & 511)] - fVec36[((IOTA - 446) & 511)]) - fVec36[((IOTA - 476) & 511)])) + ((0.00302133244f * (fVec36[((IOTA - 213) & 511)] - fVec36[((IOTA - 464) & 511)])) + ((0.00308236945f * (fVec36[((IOTA - 140) & 511)] - fVec36[((IOTA - 463) & 511)])) + ((6.10370189e-05f * ((((fVec36[((IOTA - 271) & 511)] - fVec36[((IOTA - 272) & 511)]) + fVec36[((IOTA - 352) & 511)]) + fVec36[((IOTA - 455) & 511)]) - fVec36[((IOTA - 456) & 511)])) + ((0.00363170262f * (fVec36[((IOTA - 369) & 511)] - fVec36[((IOTA - 447) & 511)])) + ((0.003234962f * ((((fVec36[((IOTA - 174) & 511)] + fVec36[((IOTA - 227) & 511)]) + fVec36[((IOTA - 230) & 511)]) + fVec36[((IOTA - 370) & 511)]) - fVec36[((IOTA - 439) & 511)])) + ((0.00427259132f * (fVec36[((IOTA - 67) & 511)] - fVec36[((IOTA - 435) & 511)])) + ((0.00439466536f * ((fVec36[((IOTA - 155) & 511)] - fVec36[((IOTA - 394) & 511)]) - fVec36[((IOTA - 433) & 511)])) + ((0.00488296151f * (fVec36[((IOTA - 151) & 511)] - fVec36[((IOTA - 429) & 511)])) + ((0.00378429517f * ((fVec36[((IOTA - 180) & 511)] + fVec36[((IOTA - 229) & 511)]) - fVec36[((IOTA - 427) & 511)])) + ((0.00207525864f * (((fVec36[((IOTA - 202) & 511)] + fVec36[((IOTA - 252) & 511)]) + fVec36[((IOTA - 255) & 511)]) - fVec36[((IOTA - 412) & 511)])) + ((0.00201422162f * (((fVec36[((IOTA - 178) & 511)] - fVec36[((IOTA - 208) & 511)]) + fVec36[((IOTA - 234) & 511)]) - fVec36[((IOTA - 402) & 511)])) + ((0.00198370311f * (fVec36[((IOTA - 251) & 511)] - fVec36[((IOTA - 400) & 511)])) + ((0.000793481246f * ((fVec36[((IOTA - 32) & 511)] - fVec36[((IOTA - 275) & 511)]) - fVec36[((IOTA - 383) & 511)])) + ((0.00140385143f * (fVec36[((IOTA - 241) & 511)] - fVec36[((IOTA - 380) & 511)])) + ((0.00463881344f * (fVec36[((IOTA - 197) & 511)] - fVec36[((IOTA - 376) & 511)])) + ((0.00228888821f * (fVec36[((IOTA - 254) & 511)] + fVec36[((IOTA - 368) & 511)])) + ((0.00170903653f * (((((fVec36[((IOTA - 259) & 511)] - fVec36[((IOTA - 316) & 511)]) - fVec36[((IOTA - 332) & 511)]) - fVec36[((IOTA - 333) & 511)]) - fVec36[((IOTA - 343) & 511)]) - fVec36[((IOTA - 366) & 511)])) + ((0.00381481368f * (fVec36[((IOTA - 228) & 511)] - fVec36[((IOTA - 363) & 511)])) + ((0.000610370189f * ((((fVec36[((IOTA - 52) & 511)] - fVec36[((IOTA - 220) & 511)]) - fVec36[((IOTA - 221) & 511)]) + fVec36[((IOTA - 268) & 511)]) - fVec36[((IOTA - 358) & 511)])) + ((0.00125125889f * ((fVec36[((IOTA - 120) & 511)] + fVec36[((IOTA - 173) & 511)]) - fVec36[((IOTA - 328) & 511)])) + ((0.00119022187f * ((fVec36[((IOTA - 150) & 511)] + fVec36[((IOTA - 260) & 511)]) - fVec36[((IOTA - 325) & 511)])) + ((0.00146488845f * (fVec36[((IOTA - 294) & 511)] - fVec36[((IOTA - 323) & 511)])) + ((0.00155644398f * ((fVec36[((IOTA - 295) & 511)] - fVec36[((IOTA - 320) & 511)]) - fVec36[((IOTA - 322) & 511)])) + ((0.00134281442f * ((fVec36[((IOTA - 215) & 511)] + fVec36[((IOTA - 237) & 511)]) - fVec36[((IOTA - 315) & 511)])) + ((0.00143436994f * (fVec36[((IOTA - 296) & 511)] - fVec36[((IOTA - 309) & 511)])) + ((0.000854518265f * (((fVec36[((IOTA - 15) & 511)] + fVec36[((IOTA - 16) & 511)]) + fVec36[((IOTA - 291) & 511)]) - fVec36[((IOTA - 308) & 511)])) + ((0.000213629566f * (((((fVec36[((IOTA - 4) & 511)] + fVec36[((IOTA - 53) & 511)]) + fVec36[((IOTA - 58) & 511)]) - fVec36[((IOTA - 149) & 511)]) - fVec36[((IOTA - 273) & 511)]) + fVec36[((IOTA - 300) & 511)])) + ((0.000732444227f * ((fVec36[((IOTA - 31) & 511)] - fVec36[((IOTA - 279) & 511)]) + fVec36[((IOTA - 298) & 511)])) + ((0.00103762932f * ((fVec36[((IOTA - 42) & 511)] + fVec36[((IOTA - 238) & 511)]) + fVec36[((IOTA - 292) & 511)])) + ((0.000885036774f * (fVec36[((IOTA - 41) & 511)] - fVec36[((IOTA - 278) & 511)])) + ((0.0022583697f * (fVec36[((IOTA - 156) & 511)] + fVec36[((IOTA - 253) & 511)])) + ((0.00222785119f * fVec36[((IOTA - 235) & 511)]) + ((0.00204474013f * (fVec36[((IOTA - 171) & 511)] + fVec36[((IOTA - 226) & 511)])) + ((0.00247199927f * (fVec36[((IOTA - 212) & 511)] + fVec36[((IOTA - 214) & 511)])) + ((0.00149540696f * (fVec36[((IOTA - 148) & 511)] - fVec36[((IOTA - 206) & 511)])) + ((0.0038758507f * fVec36[((IOTA - 201) & 511)]) + ((0.00527970213f * fVec36[((IOTA - 200) & 511)]) + ((0.00564592425f * fVec36[((IOTA - 199) & 511)]) + ((0.00460829493f * fVec36[((IOTA - 198) & 511)]) + ((0.0061342204f * fVec36[((IOTA - 196) & 511)]) + ((0.00845362712f * fVec36[((IOTA - 195) & 511)]) + ((0.009704886f * fVec36[((IOTA - 194) & 511)]) + ((0.00704977568f * fVec36[((IOTA - 191) & 511)]) + ((0.00622577593f * fVec36[((IOTA - 190) & 511)]) + ((0.00540177617f * fVec36[((IOTA - 189) & 511)]) + ((0.00537125766f * fVec36[((IOTA - 188) & 511)]) + ((0.00592059083f * fVec36[((IOTA - 187) & 511)]) + ((0.00625629444f * fVec36[((IOTA - 186) & 511)]) + ((0.006469924f * fVec36[((IOTA - 185) & 511)]) + ((0.00643940549f * (fVec36[((IOTA - 129) & 511)] + fVec36[((IOTA - 184) & 511)])) + ((0.00744651631f * fVec36[((IOTA - 183) & 511)]) + ((0.0077517014f * fVec36[((IOTA - 182) & 511)]) + ((0.00686666463f * fVec36[((IOTA - 181) & 511)]) + ((0.00512710959f * fVec36[((IOTA - 177) & 511)]) + ((0.00698873866f * fVec36[((IOTA - 176) & 511)]) + ((0.00552385021f * fVec36[((IOTA - 175) & 511)]) + ((0.00964384899f * fVec36[((IOTA - 193) & 511)]) + ((0.00503555406f * fVec36[((IOTA - 163) & 511)]) + ((0.00830103457f * fVec36[((IOTA - 162) & 511)]) + ((0.0142826624f * fVec36[((IOTA - 161) & 511)]) + ((0.0202032533f * fVec36[((IOTA - 160) & 511)]) + ((0.0206305124f * fVec36[((IOTA - 159) & 511)]) + ((0.0147709586f * fVec36[((IOTA - 158) & 511)]) + ((0.00650044251f * fVec36[((IOTA - 157) & 511)]) + ((0.0100100711f * fVec36[((IOTA - 154) & 511)]) + ((0.00982696004f * (fVec36[((IOTA - 121) & 511)] + fVec36[((IOTA - 152) & 511)])) + ((0.00805688649f * fVec36[((IOTA - 192) & 511)]) + ((0.00857570115f * fVec36[((IOTA - 139) & 511)]) + ((0.0180059206f * fVec36[((IOTA - 138) & 511)]) + ((0.0284127332f * fVec36[((IOTA - 137) & 511)]) + ((0.0347300656f * fVec36[((IOTA - 136) & 511)]) + ((0.0307321399f * fVec36[((IOTA - 135) & 511)]) + ((0.0177007355f * fVec36[((IOTA - 134) & 511)]) + ((0.0206915494f * fVec36[((IOTA - 128) & 511)]) + ((0.0282601397f * fVec36[((IOTA - 127) & 511)]) + ((0.0303964354f * fVec36[((IOTA - 126) & 511)]) + ((0.0278939176f * fVec36[((IOTA - 125) & 511)]) + ((0.0269783624f * fVec36[((IOTA - 124) & 511)]) + ((0.0247199927f * fVec36[((IOTA - 123) & 511)]) + ((0.017914366f * fVec36[((IOTA - 122) & 511)]) + ((0.0100711081f * fVec36[((IOTA - 110) & 511)]) + ((0.021088291f * fVec36[((IOTA - 109) & 511)]) + ((0.024323253f * fVec36[((IOTA - 108) & 511)]) + ((0.0267342143f * fVec36[((IOTA - 107) & 511)]) + ((0.00967436749f * fVec36[((IOTA - 106) & 511)]) + ((0.0296945106f * (fVec36[((IOTA - 92) & 511)] - fVec36[((IOTA - 103) & 511)])) + ((0.0127567369f * fVec36[((IOTA - 153) & 511)]) + ((0.029114658f * fVec36[((IOTA - 101) & 511)]) + ((0.0460829511f * fVec36[((IOTA - 100) & 511)]) + ((0.0426648781f * fVec36[((IOTA - 99) & 511)]) + ((0.0208136234f * fVec36[((IOTA - 98) & 511)]) + ((0.0129093295f * fVec36[((IOTA - 95) & 511)]) + ((0.0345469527f * fVec36[((IOTA - 94) & 511)]) + ((0.0318002887f * fVec36[((IOTA - 93) & 511)]) + ((0.0187383648f * fVec36[((IOTA - 91) & 511)]) + ((0.0301217698f * fVec36[((IOTA - 90) & 511)]) + ((0.0219122898f * fVec36[((IOTA - 89) & 511)]) + ((0.01617481f * fVec36[((IOTA - 88) & 511)]) + ((0.10299997f * fVec36[((IOTA - 83) & 511)]) + ((0.172734767f * fVec36[((IOTA - 82) & 511)]) + ((0.176122323f * fVec36[((IOTA - 81) & 511)]) + ((0.0458388031f * fVec36[((IOTA - 80) & 511)]) + ((0.00924710836f * fVec36[((IOTA - 71) & 511)]) + ((0.0121158483f * fVec36[((IOTA - 70) & 511)]) + ((0.0115970336f * fVec36[((IOTA - 69) & 511)]) + ((0.000671407208f * fVec36[((IOTA - 30) & 511)]) + (0.00848414563f * fVec36[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000152592547f * ((((fVec36[((IOTA - 270) & 511)] - fVec36[((IOTA - 284) & 511)]) - fVec36[((IOTA - 498) & 511)]) - fVec36[((IOTA - 510) & 511)]) - fVec36[((IOTA - 511) & 511)])))) : (((6.10370189e-05f * (((((((fVec35[((IOTA - 188) & 511)] + fVec35[((IOTA - 227) & 511)]) - fVec35[((IOTA - 232) & 511)]) + fVec35[((IOTA - 275) & 511)]) + fVec35[((IOTA - 446) & 511)]) - fVec35[((IOTA - 456) & 511)]) - fVec35[((IOTA - 474) & 511)]) - fVec35[((IOTA - 508) & 511)])) + ((3.05185094e-05f * ((((((fVec35[((IOTA - 4) & 511)] - fVec35[((IOTA - 38) & 511)]) + fVec35[((IOTA - 384) & 511)]) + fVec35[((IOTA - 435) & 511)]) - fVec35[((IOTA - 470) & 511)]) + fVec35[((IOTA - 475) & 511)]) + fVec35[((IOTA - 507) & 511)])) + ((9.15555283e-05f * ((((((((fVec35[((IOTA - 153) & 511)] - fVec35[((IOTA - 203) & 511)]) - fVec35[((IOTA - 223) & 511)]) + fVec35[((IOTA - 269) & 511)]) + fVec35[((IOTA - 284) & 511)]) + fVec35[((IOTA - 432) & 511)]) + fVec35[((IOTA - 486) & 511)]) - fVec35[((IOTA - 500) & 511)]) + fVec35[((IOTA - 502) & 511)])) + ((0.000305185094f * (((fVec35[((IOTA - 229) & 511)] + fVec35[((IOTA - 245) & 511)]) + fVec35[((IOTA - 380) & 511)]) - fVec35[((IOTA - 498) & 511)])) + ((0.000396740623f * (((((fVec35[((IOTA - 218) & 511)] + fVec35[((IOTA - 396) & 511)]) - fVec35[((IOTA - 442) & 511)]) - fVec35[((IOTA - 462) & 511)]) + fVec35[((IOTA - 483) & 511)]) - fVec35[((IOTA - 497) & 511)])) + ((0.000366222113f * (((((fVec35[((IOTA - 8) & 511)] + fVec35[((IOTA - 268) & 511)]) + fVec35[((IOTA - 431) & 511)]) + fVec35[((IOTA - 463) & 511)]) + fVec35[((IOTA - 488) & 511)]) - fVec35[((IOTA - 496) & 511)])) + ((0.00057985168f * (((((((((fVec35[((IOTA - 167) & 511)] + fVec35[((IOTA - 279) & 511)]) + fVec35[((IOTA - 369) & 511)]) + fVec35[((IOTA - 401) & 511)]) + fVec35[((IOTA - 419) & 511)]) + fVec35[((IOTA - 422) & 511)]) + fVec35[((IOTA - 430) & 511)]) + fVec35[((IOTA - 478) & 511)]) + fVec35[((IOTA - 481) & 511)]) + fVec35[((IOTA - 493) & 511)])) + ((0.000885036774f * ((((fVec35[((IOTA - 294) & 511)] + fVec35[((IOTA - 328) & 511)]) + fVec35[((IOTA - 413) & 511)]) + fVec35[((IOTA - 449) & 511)]) + fVec35[((IOTA - 492) & 511)])) + ((0.00100711081f * ((((((fVec35[((IOTA - 16) & 511)] + fVec35[((IOTA - 327) & 511)]) + fVec35[((IOTA - 333) & 511)]) + fVec35[((IOTA - 348) & 511)]) + fVec35[((IOTA - 355) & 511)]) - fVec35[((IOTA - 459) & 511)]) + fVec35[((IOTA - 491) & 511)])) + ((0.000701925717f * ((((((fVec35[((IOTA - 250) & 511)] + fVec35[((IOTA - 321) & 511)]) + fVec35[((IOTA - 364) & 511)]) + fVec35[((IOTA - 414) & 511)]) + fVec35[((IOTA - 423) & 511)]) + fVec35[((IOTA - 468) & 511)]) + fVec35[((IOTA - 489) & 511)])) + ((0.000518814661f * ((((((fVec35[((IOTA - 47) & 511)] + fVec35[((IOTA - 131) & 511)]) + fVec35[((IOTA - 415) & 511)]) + fVec35[((IOTA - 420) & 511)]) + fVec35[((IOTA - 447) & 511)]) - fVec35[((IOTA - 457) & 511)]) + fVec35[((IOTA - 482) & 511)])) + ((0.000457777642f * (((fVec35[((IOTA - 262) & 511)] + fVec35[((IOTA - 264) & 511)]) - fVec35[((IOTA - 383) & 511)]) + fVec35[((IOTA - 477) & 511)])) + ((0.001617481f * ((((((fVec35[((IOTA - 15) & 511)] + fVec35[((IOTA - 48) & 511)]) - fVec35[((IOTA - 179) & 511)]) - fVec35[((IOTA - 193) & 511)]) + fVec35[((IOTA - 406) & 511)]) + fVec35[((IOTA - 465) & 511)]) + fVec35[((IOTA - 466) & 511)])) + ((0.00119022187f * (((fVec35[((IOTA - 259) & 511)] - fVec35[((IOTA - 191) & 511)]) + fVec35[((IOTA - 288) & 511)]) + fVec35[((IOTA - 464) & 511)])) + ((0.000915555283f * (((((((((fVec35[((IOTA - 202) & 511)] + fVec35[((IOTA - 238) & 511)]) + fVec35[((IOTA - 272) & 511)]) + fVec35[((IOTA - 320) & 511)]) + fVec35[((IOTA - 330) & 511)]) + fVec35[((IOTA - 337) & 511)]) + fVec35[((IOTA - 358) & 511)]) + fVec35[((IOTA - 394) & 511)]) + fVec35[((IOTA - 428) & 511)]) - fVec35[((IOTA - 461) & 511)])) + ((0.00106814783f * (((((((fVec35[((IOTA - 5) & 511)] - fVec35[((IOTA - 183) & 511)]) + fVec35[((IOTA - 310) & 511)]) + fVec35[((IOTA - 317) & 511)]) + fVec35[((IOTA - 319) & 511)]) + fVec35[((IOTA - 353) & 511)]) + fVec35[((IOTA - 411) & 511)]) - fVec35[((IOTA - 460) & 511)])) + ((0.00143436994f * ((((fVec35[((IOTA - 14) & 511)] + fVec35[((IOTA - 375) & 511)]) + fVec35[((IOTA - 389) & 511)]) - fVec35[((IOTA - 443) & 511)]) + fVec35[((IOTA - 454) & 511)])) + ((0.00216681417f * fVec35[((IOTA - 451) & 511)]) + ((0.00109866634f * (((((((((fVec35[((IOTA - 22) & 511)] + fVec35[((IOTA - 201) & 511)]) + fVec35[((IOTA - 306) & 511)]) + fVec35[((IOTA - 309) & 511)]) + fVec35[((IOTA - 318) & 511)]) + fVec35[((IOTA - 326) & 511)]) + fVec35[((IOTA - 338) & 511)]) + fVec35[((IOTA - 346) & 511)]) + fVec35[((IOTA - 408) & 511)]) + fVec35[((IOTA - 441) & 511)])) + ((0.00234992523f * fVec35[((IOTA - 440) & 511)]) + ((0.00277718436f * (fVec35[((IOTA - 86) & 511)] + fVec35[((IOTA - 439) & 511)])) + ((0.000762962736f * ((fVec35[((IOTA - 249) & 511)] + fVec35[((IOTA - 366) & 511)]) + fVec35[((IOTA - 429) & 511)])) + ((0.000854518265f * ((((fVec35[((IOTA - 329) & 511)] - (((((fVec35[((IOTA - 46) & 511)] + fVec35[((IOTA - 204) & 511)]) - fVec35[((IOTA - 239) & 511)]) - fVec35[((IOTA - 280) & 511)]) - fVec35[((IOTA - 281) & 511)]) - fVec35[((IOTA - 303) & 511)])) + fVec35[((IOTA - 359) & 511)]) + fVec35[((IOTA - 379) & 511)]) + fVec35[((IOTA - 424) & 511)])) + ((0.00054933317f * ((((((((fVec35[((IOTA - 13) & 511)] + fVec35[((IOTA - 25) & 511)]) + fVec35[((IOTA - 42) & 511)]) + fVec35[((IOTA - 282) & 511)]) + fVec35[((IOTA - 286) & 511)]) + fVec35[((IOTA - 291) & 511)]) + fVec35[((IOTA - 362) & 511)]) - fVec35[((IOTA - 382) & 511)]) + fVec35[((IOTA - 417) & 511)])) + ((0.00134281442f * (((fVec35[((IOTA - 350) & 511)] + fVec35[((IOTA - 374) & 511)]) + fVec35[((IOTA - 390) & 511)]) + fVec35[((IOTA - 407) & 511)])) + ((0.00186162908f * (fVec35[((IOTA - 23) & 511)] + fVec35[((IOTA - 405) & 511)])) + ((0.0019226661f * (((fVec35[((IOTA - 32) & 511)] - fVec35[((IOTA - 36) & 511)]) - fVec35[((IOTA - 164) & 511)]) + fVec35[((IOTA - 404) & 511)])) + ((0.00164799951f * (fVec35[((IOTA - 41) & 511)] + fVec35[((IOTA - 403) & 511)])) + ((0.00112918485f * (((fVec35[((IOTA - 289) & 511)] + fVec35[((IOTA - 325) & 511)]) + fVec35[((IOTA - 393) & 511)]) + fVec35[((IOTA - 402) & 511)])) + ((0.000640888698f * (((((((fVec35[((IOTA - 299) & 511)] - (((((fVec35[((IOTA - 12) & 511)] + fVec35[((IOTA - 29) & 511)]) + fVec35[((IOTA - 51) & 511)]) - fVec35[((IOTA - 261) & 511)]) - fVec35[((IOTA - 271) & 511)]) - fVec35[((IOTA - 298) & 511)])) + fVec35[((IOTA - 300) & 511)]) + fVec35[((IOTA - 301) & 511)]) + fVec35[((IOTA - 322) & 511)]) + fVec35[((IOTA - 367) & 511)]) + fVec35[((IOTA - 370) & 511)]) + fVec35[((IOTA - 395) & 511)])) + ((0.00122074038f * ((((fVec35[((IOTA - 39) & 511)] - fVec35[((IOTA - 184) & 511)]) + fVec35[((IOTA - 373) & 511)]) + fVec35[((IOTA - 386) & 511)]) + fVec35[((IOTA - 392) & 511)])) + ((0.0012817774f * (((((fVec35[((IOTA - 7) & 511)] - fVec35[((IOTA - 37) & 511)]) - fVec35[((IOTA - 180) & 511)]) + fVec35[((IOTA - 241) & 511)]) + fVec35[((IOTA - 345) & 511)]) + fVec35[((IOTA - 378) & 511)])) + ((0.000732444227f * ((((((fVec35[((IOTA - 30) & 511)] - fVec35[((IOTA - 190) & 511)]) + fVec35[((IOTA - 236) & 511)]) + fVec35[((IOTA - 267) & 511)]) + fVec35[((IOTA - 296) & 511)]) + fVec35[((IOTA - 302) & 511)]) + fVec35[((IOTA - 360) & 511)])) + ((0.00115970336f * (((((fVec35[((IOTA - 33) & 511)] + fVec35[((IOTA - 240) & 511)]) + fVec35[((IOTA - 307) & 511)]) + fVec35[((IOTA - 308) & 511)]) + fVec35[((IOTA - 349) & 511)]) + fVec35[((IOTA - 352) & 511)])) + ((0.000427259132f * (fVec35[((IOTA - 243) & 511)] + fVec35[((IOTA - 263) & 511)])) + ((0.00183111057f * fVec35[((IOTA - 256) & 511)]) + ((0.0019531846f * fVec35[((IOTA - 254) & 511)]) + ((0.00167851802f * ((fVec35[((IOTA - 24) & 511)] + fVec35[((IOTA - 57) & 511)]) + fVec35[((IOTA - 253) & 511)])) + ((0.000335703604f * (((((fVec35[((IOTA - 165) & 511)] - fVec35[((IOTA - 206) & 511)]) - fVec35[((IOTA - 225) & 511)]) + fVec35[((IOTA - 235) & 511)]) + fVec35[((IOTA - 244) & 511)]) + fVec35[((IOTA - 247) & 511)])) + ((0.00198370311f * (fVec35[((IOTA - 49) & 511)] - fVec35[((IOTA - 213) & 511)])) + ((0.00704977568f * (fVec35[((IOTA - 95) & 511)] - fVec35[((IOTA - 173) & 511)])) + ((0.00173955504f * ((fVec35[((IOTA - 31) & 511)] - fVec35[((IOTA - 28) & 511)]) - fVec35[((IOTA - 154) & 511)])) + ((0.00256355479f * fVec35[((IOTA - 151) & 511)]) + ((0.0071108127f * fVec35[((IOTA - 150) & 511)]) + ((0.0087282937f * fVec35[((IOTA - 149) & 511)]) + ((0.00610370189f * fVec35[((IOTA - 148) & 511)]) + ((0.0117191076f * (fVec35[((IOTA - 127) & 511)] - fVec35[((IOTA - 143) & 511)])) + ((0.00158696249f * (fVec35[((IOTA - 6) & 511)] - fVec35[((IOTA - 142) & 511)])) + ((0.00701925717f * fVec35[((IOTA - 141) & 511)]) + ((0.00909451582f * fVec35[((IOTA - 140) & 511)]) + ((0.00314340647f * fVec35[((IOTA - 139) & 511)]) + ((0.0118717002f * fVec35[((IOTA - 130) & 511)]) + ((0.0228278451f * fVec35[((IOTA - 129) & 511)]) + ((0.00506607257f * fVec35[((IOTA - 124) & 511)]) + ((0.0103152562f * fVec35[((IOTA - 123) & 511)]) + ((0.00274666585f * fVec35[((IOTA - 122) & 511)]) + ((0.021332439f * fVec35[((IOTA - 115) & 511)]) + ((0.0315256193f * fVec35[((IOTA - 114) & 511)]) + ((0.022461623f * fVec35[((IOTA - 113) & 511)]) + ((0.00411999878f * fVec35[((IOTA - 102) & 511)]) + ((0.00366222113f * fVec35[((IOTA - 101) & 511)]) + ((0.00781273842f * fVec35[((IOTA - 100) & 511)]) + ((0.012939848f * fVec35[((IOTA - 99) & 511)]) + ((0.0154728843f * fVec35[((IOTA - 98) & 511)]) + ((0.0264595486f * fVec35[((IOTA - 97) & 511)]) + ((0.0250862148f * fVec35[((IOTA - 96) & 511)]) + ((0.0375988036f * fVec35[((IOTA - 89) & 511)]) + ((0.0542008728f * fVec35[((IOTA - 88) & 511)]) + ((0.0334177688f * fVec35[((IOTA - 87) & 511)]) + ((0.00454725791f * fVec35[((IOTA - 79) & 511)]) + ((0.0231330302f * fVec35[((IOTA - 78) & 511)]) + ((0.0183721427f * fVec35[((IOTA - 77) & 511)]) + ((0.00567644276f * fVec35[((IOTA - 76) & 511)]) + ((0.0159306619f * fVec35[((IOTA - 71) & 511)]) + ((0.0519119836f * fVec35[((IOTA - 70) & 511)]) + ((0.0460524298f * fVec35[((IOTA - 69) & 511)]) + ((0.0713522732f * fVec35[((IOTA - 64) & 511)]) + ((0.274483472f * fVec35[((IOTA - 63) & 511)]) + ((0.296670437f * fVec35[((IOTA - 62) & 511)]) + ((0.160100102f * fVec35[((IOTA - 61) & 511)]) + ((0.0446485803f * fVec35[((IOTA - 60) & 511)]) + ((0.00753807183f * fVec35[((IOTA - 58) & 511)]) + (0.011383404f * fVec35[((IOTA - 59) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.000213629566f * (((((((((((((fVec35[((IOTA - 21) & 511)] + fVec35[((IOTA - 34) & 511)]) - fVec35[((IOTA - 152) & 511)]) + fVec35[((IOTA - 220) & 511)]) + fVec35[((IOTA - 226) & 511)]) - fVec35[((IOTA - 234) & 511)]) - fVec35[((IOTA - 246) & 511)]) - fVec35[((IOTA - 283) & 511)]) + fVec35[((IOTA - 381) & 511)]) - fVec35[((IOTA - 400) & 511)]) + fVec35[((IOTA - 434) & 511)]) - fVec35[((IOTA - 476) & 511)]) - fVec35[((IOTA - 494) & 511)]) + fVec35[((IOTA - 499) & 511)])) + ((0.000152592547f * (((((fVec35[((IOTA - 17) & 511)] + fVec35[((IOTA - 216) & 511)]) - fVec35[((IOTA - 219) & 511)]) - fVec35[((IOTA - 398) & 511)]) + fVec35[((IOTA - 433) & 511)]) + fVec35[((IOTA - 495) & 511)])) + ((0.000946073793f * (((((((((fVec35[((IOTA - 26) & 511)] - fVec35[((IOTA - 260) & 511)]) - fVec35[((IOTA - 273) & 511)]) - fVec35[((IOTA - 287) & 511)]) - fVec35[((IOTA - 304) & 511)]) - fVec35[((IOTA - 334) & 511)]) - fVec35[((IOTA - 357) & 511)]) - fVec35[((IOTA - 409) & 511)]) - fVec35[((IOTA - 425) & 511)]) - fVec35[((IOTA - 490) & 511)])) + ((0.000244148076f * (((((fTemp36 + fVec35[((IOTA - 224) & 511)]) + fVec35[((IOTA - 277) & 511)]) - fVec35[((IOTA - 397) & 511)]) - fVec35[((IOTA - 469) & 511)]) - fVec35[((IOTA - 484) & 511)])) + ((0.000610370189f * (((((((((((fVec35[((IOTA - 215) & 511)] - fVec35[((IOTA - 265) & 511)]) - fVec35[((IOTA - 274) & 511)]) - fVec35[((IOTA - 292) & 511)]) - fVec35[((IOTA - 361) & 511)]) - fVec35[((IOTA - 363) & 511)]) - fVec35[((IOTA - 368) & 511)]) - fVec35[((IOTA - 418) & 511)]) - fVec35[((IOTA - 448) & 511)]) - fVec35[((IOTA - 455) & 511)]) - fVec35[((IOTA - 479) & 511)]) - fVec35[((IOTA - 480) & 511)])) + ((0.00125125889f * ((((fVec35[((IOTA - 1) & 511)] + fVec35[((IOTA - 214) & 511)]) - fVec35[((IOTA - 252) & 511)]) - fVec35[((IOTA - 391) & 511)]) - fVec35[((IOTA - 467) & 511)])) + ((0.000823999755f * ((((((((((fVec35[((IOTA - 43) & 511)] - fVec35[((IOTA - 242) & 511)]) - fVec35[((IOTA - 251) & 511)]) - fVec35[((IOTA - 266) & 511)]) - fVec35[((IOTA - 295) & 511)]) - fVec35[((IOTA - 323) & 511)]) - fVec35[((IOTA - 335) & 511)]) - fVec35[((IOTA - 336) & 511)]) - fVec35[((IOTA - 371) & 511)]) + fVec35[((IOTA - 445) & 511)]) + fVec35[((IOTA - 458) & 511)])) + ((0.00213629566f * ((fVec35[((IOTA - 134) & 511)] + fVec35[((IOTA - 181) & 511)]) - fVec35[((IOTA - 453) & 511)])) + ((0.00244148076f * (fVec35[((IOTA - 194) & 511)] - fVec35[((IOTA - 452) & 511)])) + ((0.00152592547f * ((((fVec35[((IOTA - 10) & 511)] - fVec35[((IOTA - 376) & 511)]) - fVec35[((IOTA - 387) & 511)]) + fVec35[((IOTA - 444) & 511)]) - fVec35[((IOTA - 450) & 511)])) + ((0.00241096225f * (fVec35[((IOTA - 212) & 511)] - fVec35[((IOTA - 438) & 511)])) + ((0.00155644398f * (((fVec35[((IOTA - 2) & 511)] - fVec35[((IOTA - 257) & 511)]) - fVec35[((IOTA - 388) & 511)]) - fVec35[((IOTA - 437) & 511)])) + ((0.000671407208f * (((((fVec35[((IOTA - 112) & 511)] + fVec35[((IOTA - 205) & 511)]) - fVec35[((IOTA - 248) & 511)]) - fVec35[((IOTA - 297) & 511)]) - fVec35[((IOTA - 385) & 511)]) - fVec35[((IOTA - 436) & 511)])) + ((0.000976592302f * ((((((fVec35[((IOTA - 199) & 511)] - fVec35[((IOTA - 331) & 511)]) - fVec35[((IOTA - 347) & 511)]) - fVec35[((IOTA - 356) & 511)]) - fVec35[((IOTA - 410) & 511)]) - fVec35[((IOTA - 426) & 511)]) - fVec35[((IOTA - 427) & 511)])) + ((0.000488296151f * ((fVec35[((IOTA - 187) & 511)] - fVec35[((IOTA - 416) & 511)]) - fVec35[((IOTA - 421) & 511)])) + ((0.00103762932f * (((((((((((((fVec35[((IOTA - 3) & 511)] - fVec35[((IOTA - 237) & 511)]) - fVec35[((IOTA - 305) & 511)]) - fVec35[((IOTA - 311) & 511)]) - fVec35[((IOTA - 312) & 511)]) - fVec35[((IOTA - 313) & 511)]) - fVec35[((IOTA - 314) & 511)]) - fVec35[((IOTA - 315) & 511)]) - fVec35[((IOTA - 316) & 511)]) - fVec35[((IOTA - 324) & 511)]) - fVec35[((IOTA - 332) & 511)]) - fVec35[((IOTA - 354) & 511)]) - fVec35[((IOTA - 372) & 511)]) - fVec35[((IOTA - 412) & 511)])) + ((0.00149540696f * (((fVec35[((IOTA - 35) & 511)] + fVec35[((IOTA - 126) & 511)]) - fVec35[((IOTA - 166) & 511)]) - fVec35[((IOTA - 377) & 511)])) + ((0.000793481246f * ((((((fVec35[((IOTA - 9) & 511)] - fVec35[((IOTA - 90) & 511)]) - fVec35[((IOTA - 147) & 511)]) + fVec35[((IOTA - 207) & 511)]) - fVec35[((IOTA - 290) & 511)]) - fVec35[((IOTA - 293) & 511)]) - fVec35[((IOTA - 365) & 511)])) + ((0.00131229591f * (((fVec35[((IOTA - 18) & 511)] - fVec35[((IOTA - 50) & 511)]) - fVec35[((IOTA - 339) & 511)]) - fVec35[((IOTA - 351) & 511)])) + ((0.00137333293f * ((((((((fVec35[((IOTA - 20) & 511)] + fVec35[((IOTA - 116) & 511)]) + fVec35[((IOTA - 192) & 511)]) - fVec35[((IOTA - 258) & 511)]) - fVec35[((IOTA - 340) & 511)]) - fVec35[((IOTA - 341) & 511)]) - fVec35[((IOTA - 342) & 511)]) - fVec35[((IOTA - 343) & 511)]) - fVec35[((IOTA - 344) & 511)])) + ((0.000274666585f * ((((fVec35[((IOTA - 221) & 511)] - (fVec35[((IOTA - 200) & 511)] + fVec35[((IOTA - 217) & 511)])) - fVec35[((IOTA - 228) & 511)]) - fVec35[((IOTA - 270) & 511)]) + fVec35[((IOTA - 276) & 511)])) + ((0.00201422162f * (fVec35[((IOTA - 208) & 511)] - fVec35[((IOTA - 255) & 511)])) + ((0.00271614734f * fVec35[((IOTA - 211) & 511)]) + ((0.00305185094f * fVec35[((IOTA - 210) & 511)]) + ((0.00292977691f * fVec35[((IOTA - 209) & 511)]) + ((0.0022583697f * fVec35[((IOTA - 198) & 511)]) + ((0.00341807306f * fVec35[((IOTA - 197) & 511)]) + ((0.00384533219f * fVec35[((IOTA - 196) & 511)]) + ((0.00335703604f * fVec35[((IOTA - 195) & 511)]) + ((0.00204474013f * fVec35[((IOTA - 182) & 511)]) + ((0.00268562883f * fVec35[((IOTA - 178) & 511)]) + ((0.00283822138f * fVec35[((IOTA - 177) & 511)]) + ((0.00344859157f * fVec35[((IOTA - 176) & 511)]) + ((0.00512710959f * (fVec35[((IOTA - 155) & 511)] + fVec35[((IOTA - 175) & 511)])) + ((0.00207525864f * fVec35[((IOTA - 185) & 511)]) + ((0.00662251655f * fVec35[((IOTA - 174) & 511)]) + ((0.00732444227f * fVec35[((IOTA - 172) & 511)]) + ((0.00769066438f * (fVec35[((IOTA - 157) & 511)] + fVec35[((IOTA - 171) & 511)])) + ((0.00726340525f * fVec35[((IOTA - 170) & 511)]) + ((0.004852443f * fVec35[((IOTA - 169) & 511)]) + ((0.00170903653f * fVec35[((IOTA - 168) & 511)]) + ((0.00531022064f * (fVec35[((IOTA - 135) & 511)] + fVec35[((IOTA - 162) & 511)])) + ((0.0061342204f * fVec35[((IOTA - 161) & 511)]) + ((0.00708029419f * fVec35[((IOTA - 160) & 511)]) + ((0.00735496078f * fVec35[((IOTA - 159) & 511)]) + ((0.00729392376f * fVec35[((IOTA - 158) & 511)]) + ((0.00756859034f * fVec35[((IOTA - 156) & 511)]) + ((0.00418103579f * fVec35[((IOTA - 163) & 511)]) + ((0.00622577593f * fVec35[((IOTA - 146) & 511)]) + ((0.0138859218f * fVec35[((IOTA - 145) & 511)]) + ((0.0167851802f * fVec35[((IOTA - 144) & 511)]) + ((0.00177007355f * fVec35[((IOTA - 186) & 511)]) + ((0.00524918362f * fVec35[((IOTA - 138) & 511)]) + ((0.00985747855f * fVec35[((IOTA - 137) & 511)]) + ((0.00897244178f * fVec35[((IOTA - 136) & 511)]) + ((0.0239875484f * ((fVec35[((IOTA - 81) & 511)] + fVec35[((IOTA - 117) & 511)]) - fVec35[((IOTA - 128) & 511)])) + ((0.00482192449f * fVec35[((IOTA - 132) & 511)]) + ((0.00399792474f * fVec35[((IOTA - 125) & 511)]) + ((0.0142826624f * fVec35[((IOTA - 121) & 511)]) + ((0.0306405835f * fVec35[((IOTA - 120) & 511)]) + ((0.0390331745f * fVec35[((IOTA - 119) & 511)]) + ((0.0371410251f * fVec35[((IOTA - 118) & 511)]) + ((0.0249946602f * fVec35[((IOTA - 111) & 511)]) + ((0.0371715464f * fVec35[((IOTA - 110) & 511)]) + ((0.0361033976f * fVec35[((IOTA - 109) & 511)]) + ((0.0281685852f * fVec35[((IOTA - 108) & 511)]) + ((0.0200506616f * fVec35[((IOTA - 107) & 511)]) + ((0.0140995514f * fVec35[((IOTA - 106) & 511)]) + ((0.0137028107f * fVec35[((IOTA - 105) & 511)]) + ((0.00927762687f * fVec35[((IOTA - 104) & 511)]) + ((0.0137943663f * fVec35[((IOTA - 94) & 511)]) + ((0.0304269549f * fVec35[((IOTA - 93) & 511)]) + ((0.0408948027f * fVec35[((IOTA - 92) & 511)]) + ((0.0339671001f * fVec35[((IOTA - 91) & 511)]) + ((0.0038758507f * fVec35[((IOTA - 133) & 511)]) + ((0.0221259203f * fVec35[((IOTA - 85) & 511)]) + ((0.0463881344f * fVec35[((IOTA - 84) & 511)]) + ((0.0592669472f * fVec35[((IOTA - 83) & 511)]) + ((0.0484023578f * fVec35[((IOTA - 82) & 511)]) + ((0.0123905148f * fVec35[((IOTA - 80) & 511)]) + ((0.022644734f * fVec35[((IOTA - 75) & 511)]) + ((0.0379345082f * fVec35[((IOTA - 74) & 511)]) + ((0.0450148024f * fVec35[((IOTA - 73) & 511)]) + ((0.0171208847f * fVec35[((IOTA - 72) & 511)]) + ((0.0385753959f * fVec35[((IOTA - 68) & 511)]) + ((0.148197889f * fVec35[((IOTA - 67) & 511)]) + ((0.218634605f * fVec35[((IOTA - 66) & 511)]) + ((0.14209418f * fVec35[((IOTA - 65) & 511)]) + ((0.0054933317f * fVec35[((IOTA - 56) & 511)]) + ((0.0101016266f * fVec35[((IOTA - 55) & 511)]) + ((0.0112308115f * fVec35[((IOTA - 54) & 511)]) + ((0.00885036774f * fVec35[((IOTA - 53) & 511)]) + ((0.00439466536f * fVec35[((IOTA - 52) & 511)]) + ((0.00180059206f * ((fVec35[((IOTA - 19) & 511)] + fVec35[((IOTA - 44) & 511)]) + fVec35[((IOTA - 45) & 511)])) + ((0.00146488845f * fVec35[((IOTA - 11) & 511)]) + (0.00189214759f * (fVec35[((IOTA - 27) & 511)] - fVec35[((IOTA - 40) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000122074038f * (fVec35[((IOTA - 509) & 511)] - (((((((fVec35[((IOTA - 399) & 511)] - ((((fVec35[((IOTA - 103) & 511)] + fVec35[((IOTA - 189) & 511)]) - fVec35[((IOTA - 230) & 511)]) + fVec35[((IOTA - 231) & 511)]) - fVec35[((IOTA - 278) & 511)])) - fVec35[((IOTA - 471) & 511)]) - fVec35[((IOTA - 472) & 511)]) - fVec35[((IOTA - 473) & 511)]) + fVec35[((IOTA - 485) & 511)]) + fVec35[((IOTA - 487) & 511)]) + fVec35[((IOTA - 506) & 511)])))) + (0.000183111057f * (((((((fVec35[((IOTA - 222) & 511)] - fVec35[((IOTA - 233) & 511)]) - fVec35[((IOTA - 285) & 511)]) - fVec35[((IOTA - 503) & 511)]) - fVec35[((IOTA - 504) & 511)]) - fVec35[((IOTA - 505) & 511)]) + fVec35[((IOTA - 510) & 511)]) + fVec35[((IOTA - 511) & 511)]))))) : (iSlow81 ? ((((0.000640888698f * (((((fVec34[((IOTA - 89) & 511)] - fVec34[((IOTA - 166) & 511)]) + fVec34[((IOTA - 437) & 511)]) + fVec34[((IOTA - 466) & 511)]) + fVec34[((IOTA - 492) & 511)]) + fVec34[((IOTA - 507) & 511)])) + ((0.00137333293f * (((fVec34[((IOTA - 250) & 511)] + fVec34[((IOTA - 297) & 511)]) + fVec34[((IOTA - 372) & 511)]) + fVec34[((IOTA - 502) & 511)])) + ((0.00134281442f * ((((fVec34[((IOTA - 265) & 511)] + fVec34[((IOTA - 369) & 511)]) - fVec34[((IOTA - 381) & 511)]) + fVec34[((IOTA - 430) & 511)]) + fVec34[((IOTA - 501) & 511)])) + ((0.0012817774f * (((((((fVec34[((IOTA - 251) & 511)] + fVec34[((IOTA - 252) & 511)]) - fVec34[((IOTA - 284) & 511)]) + fVec34[((IOTA - 348) & 511)]) + fVec34[((IOTA - 388) & 511)]) + fVec34[((IOTA - 401) & 511)]) + fVec34[((IOTA - 461) & 511)]) + fVec34[((IOTA - 500) & 511)])) + ((0.000701925717f * ((((((fVec34[((IOTA - 144) & 511)] - fVec34[((IOTA - 181) & 511)]) + fVec34[((IOTA - 393) & 511)]) + fVec34[((IOTA - 400) & 511)]) + fVec34[((IOTA - 420) & 511)]) + fVec34[((IOTA - 465) & 511)]) + fVec34[((IOTA - 494) & 511)])) + ((0.000885036774f * (((fVec34[((IOTA - 387) & 511)] + fVec34[((IOTA - 438) & 511)]) + fVec34[((IOTA - 486) & 511)]) + fVec34[((IOTA - 487) & 511)])) + ((0.000457777642f * ((((((fVec34[((IOTA - 279) & 511)] + fVec34[((IOTA - 289) & 511)]) + fVec34[((IOTA - 471) & 511)]) + fVec34[((IOTA - 472) & 511)]) + fVec34[((IOTA - 473) & 511)]) + fVec34[((IOTA - 477) & 511)]) + fVec34[((IOTA - 481) & 511)])) + ((0.000396740623f * (((((fVec34[((IOTA - 145) & 511)] - fVec34[((IOTA - 341) & 511)]) + fVec34[((IOTA - 394) & 511)]) + fVec34[((IOTA - 478) & 511)]) + fVec34[((IOTA - 479) & 511)]) + fVec34[((IOTA - 480) & 511)])) + ((0.00146488845f * (((fVec34[((IOTA - 127) & 511)] + fVec34[((IOTA - 237) & 511)]) + fVec34[((IOTA - 309) & 511)]) + fVec34[((IOTA - 459) & 511)])) + ((0.00152592547f * ((((fVec34[((IOTA - 267) & 511)] + fVec34[((IOTA - 325) & 511)]) - fVec34[((IOTA - 385) & 511)]) + fVec34[((IOTA - 457) & 511)]) + fVec34[((IOTA - 458) & 511)])) + ((0.00122074038f * (fVec34[((IOTA - 239) & 511)] + fVec34[((IOTA - 453) & 511)])) + ((0.00155644398f * (fVec34[((IOTA - 241) & 511)] + fVec34[((IOTA - 450) & 511)])) + ((0.00170903653f * ((fVec34[((IOTA - 253) & 511)] + fVec34[((IOTA - 264) & 511)]) + fVec34[((IOTA - 449) & 511)])) + ((0.00189214759f * ((fVec34[((IOTA - 95) & 511)] - fVec34[((IOTA - 229) & 511)]) + fVec34[((IOTA - 448) & 511)])) + ((0.00207525864f * ((((fVec34[((IOTA - 275) & 511)] + fVec34[((IOTA - 408) & 511)]) + fVec34[((IOTA - 409) & 511)]) + fVec34[((IOTA - 417) & 511)]) + fVec34[((IOTA - 447) & 511)])) + ((0.00219733268f * fVec34[((IOTA - 446) & 511)]) + ((0.00222785119f * ((((fVec34[((IOTA - 365) & 511)] - fVec34[((IOTA - 382) & 511)]) + fVec34[((IOTA - 403) & 511)]) + fVec34[((IOTA - 406) & 511)]) + fVec34[((IOTA - 445) & 511)])) + ((0.0019531846f * ((fVec34[((IOTA - 274) & 511)] + fVec34[((IOTA - 276) & 511)]) + fVec34[((IOTA - 441) & 511)])) + ((0.00164799951f * ((((fVec34[((IOTA - 131) & 511)] - fVec34[((IOTA - 172) & 511)]) - fVec34[((IOTA - 226) & 511)]) + fVec34[((IOTA - 418) & 511)]) + fVec34[((IOTA - 440) & 511)])) + ((0.000854518265f * ((fVec34[((IOTA - 72) & 511)] - fVec34[((IOTA - 222) & 511)]) + fVec34[((IOTA - 434) & 511)])) + ((0.00115970336f * (fVec34[((IOTA - 499) & 511)] - (((((fVec34[((IOTA - 220) & 511)] + fVec34[((IOTA - 224) & 511)]) - fVec34[((IOTA - 235) & 511)]) - fVec34[((IOTA - 240) & 511)]) - fVec34[((IOTA - 355) & 511)]) - fVec34[((IOTA - 433) & 511)]))) + ((0.00231940672f * (fVec34[((IOTA - 405) & 511)] + fVec34[((IOTA - 416) & 511)])) + ((0.00253303628f * fVec34[((IOTA - 413) & 511)]) + ((0.000183111057f * (((fVec34[((IOTA - 96) & 511)] + fVec34[((IOTA - 199) & 511)]) - fVec34[((IOTA - 386) & 511)]) + fVec34[((IOTA - 399) & 511)])) + ((0.000274666585f * (fVec34[((IOTA - 332) & 511)] - fVec34[((IOTA - 398) & 511)])) + ((9.15555283e-05f * (((fVec34[((IOTA - 198) & 511)] - fVec34[((IOTA - 200) & 511)]) - fVec34[((IOTA - 233) & 511)]) - fVec34[((IOTA - 395) & 511)])) + ((0.000244148076f * ((fVec34[((IOTA - 350) & 511)] - fVec34[((IOTA - 354) & 511)]) - fVec34[((IOTA - 380) & 511)])) + ((0.0038758507f * ((fVec34[((IOTA - 361) & 511)] + fVec34[((IOTA - 375) & 511)]) + fVec34[((IOTA - 377) & 511)])) + ((0.00436414685f * (fVec34[((IOTA - 71) & 511)] + fVec34[((IOTA - 376) & 511)])) + ((0.00280770287f * ((((fVec34[((IOTA - 54) & 511)] - fVec34[((IOTA - 191) & 511)]) + fVec34[((IOTA - 261) & 511)]) + fVec34[((IOTA - 364) & 511)]) + fVec34[((IOTA - 374) & 511)])) + ((0.00106814783f * ((((fVec34[((IOTA - 244) & 511)] - fVec34[((IOTA - 282) & 511)]) + fVec34[((IOTA - 349) & 511)]) + fVec34[((IOTA - 389) & 511)]) + fVec34[((IOTA - 429) & 511)])) + ((0.00112918485f * (fVec34[((IOTA - 462) & 511)] - (((fVec34[((IOTA - 97) & 511)] + fVec34[((IOTA - 202) & 511)]) + fVec34[((IOTA - 287) & 511)]) - fVec34[((IOTA - 347) & 511)]))) + ((0.00158696249f * ((fVec34[((IOTA - 272) & 511)] + fVec34[((IOTA - 277) & 511)]) - fVec34[((IOTA - 339) & 511)])) + ((0.00305185094f * fVec34[((IOTA - 324) & 511)]) + ((0.00430310983f * fVec34[((IOTA - 323) & 511)]) + ((0.00473036896f * fVec34[((IOTA - 322) & 511)]) + ((0.00314340647f * (fVec34[((IOTA - 291) & 511)] - fVec34[((IOTA - 315) & 511)])) + ((0.00378429517f * fVec34[((IOTA - 307) & 511)]) + ((0.00427259132f * (fVec34[((IOTA - 44) & 511)] + fVec34[((IOTA - 304) & 511)])) + ((0.00375377666f * fVec34[((IOTA - 303) & 511)]) + ((0.00396740623f * fVec34[((IOTA - 296) & 511)]) + ((0.0051576281f * fVec34[((IOTA - 294) & 511)]) + ((0.00482192449f * fVec34[((IOTA - 293) & 511)]) + ((0.00415051728f * fVec34[((IOTA - 292) & 511)]) + ((0.000152592547f * (fVec34[((IOTA - 245) & 511)] - fVec34[((IOTA - 280) & 511)])) + ((0.00256355479f * fVec34[((IOTA - 262) & 511)]) + ((0.00308236945f * fVec34[((IOTA - 259) & 511)]) + ((0.00341807306f * ((fVec34[((IOTA - 91) & 511)] + fVec34[((IOTA - 130) & 511)]) + fVec34[((IOTA - 257) & 511)])) + ((0.00338755455f * fVec34[((IOTA - 256) & 511)]) + ((0.00183111057f * (fVec34[((IOTA - 320) & 511)] - fVec34[((IOTA - 228) & 511)])) + ((0.00402844325f * (fVec34[((IOTA - 94) & 511)] - fVec34[((IOTA - 214) & 511)])) + ((0.00103762932f * (fVec34[((IOTA - 22) & 511)] - fVec34[((IOTA - 196) & 511)])) + ((0.00286873989f * (fVec34[((IOTA - 90) & 511)] + fVec34[((IOTA - 128) & 511)])) + ((0.0106509598f * (fVec34[((IOTA - 69) & 511)] - fVec34[((IOTA - 116) & 511)])) + ((0.00405896176f * fVec34[((IOTA - 92) & 511)]) + ((0.00521866512f * fVec34[((IOTA - 93) & 511)]) + ((0.00833155308f * fVec34[((IOTA - 70) & 511)]) + ((0.00930814538f * fVec34[((IOTA - 68) & 511)]) + ((0.00784325693f * fVec34[((IOTA - 67) & 511)]) + ((0.00408948027f * fVec34[((IOTA - 66) & 511)]) + ((0.0393383577f * (fTemp35 - fVec34[((IOTA - 62) & 511)])) + ((0.0416577645f * (fVec34[((IOTA - 13) & 511)] - fVec34[((IOTA - 60) & 511)])) + ((0.011383404f * fVec34[((IOTA - 57) & 511)]) + ((0.0233466607f * fVec34[((IOTA - 56) & 511)]) + ((0.0191961434f * fVec34[((IOTA - 55) & 511)]) + ((0.0147404401f * fVec34[((IOTA - 43) & 511)]) + ((0.0185552537f * fVec34[((IOTA - 42) & 511)]) + ((0.0198675506f * fVec34[((IOTA - 41) & 511)]) + ((0.0234992523f * (fVec34[((IOTA - 39) & 511)] + fVec34[((IOTA - 40) & 511)])) + ((0.0208746605f * fVec34[((IOTA - 38) & 511)]) + ((0.0159611814f * fVec34[((IOTA - 37) & 511)]) + ((0.0195013285f * (fVec34[((IOTA - 30) & 511)] - fVec34[((IOTA - 35) & 511)])) + ((0.0419324338f * fVec34[((IOTA - 29) & 511)]) + ((0.0110782189f * fVec34[((IOTA - 14) & 511)]) + ((0.0483718365f * fVec34[((IOTA - 12) & 511)]) + ((0.0236518458f * fVec34[((IOTA - 11) & 511)]) + ((0.00628681295f * fVec34[((IOTA - 10) & 511)]) + ((0.0325327329f * fVec34[((IOTA - 5) & 511)]) + ((0.255470455f * fVec34[((IOTA - 4) & 511)]) + ((0.383617669f * fVec34[((IOTA - 3) & 511)]) + ((0.301461846f * fVec34[((IOTA - 2) & 511)]) + ((0.141636401f * fVec34[((IOTA - 1) & 511)]) + ((0.0111392559f * fVec34[((IOTA - 27) & 511)]) + (0.0365306549f * fVec34[((IOTA - 28) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000305185094f * (fVec34[((IOTA - 510) & 511)] + fVec34[((IOTA - 511) & 511)]))) - (((0.000488296151f * (((((((fVec34[((IOTA - 147) & 511)] + fVec34[((IOTA - 182) & 511)]) + fVec34[((IOTA - 396) & 511)]) - fVec34[((IOTA - 470) & 511)]) - fVec34[((IOTA - 474) & 511)]) - fVec34[((IOTA - 475) & 511)]) - fVec34[((IOTA - 476) & 511)]) - fVec34[((IOTA - 508) & 511)])) + ((0.000823999755f * ((((((fVec34[((IOTA - 137) & 511)] + fVec34[((IOTA - 232) & 511)]) - fVec34[((IOTA - 390) & 511)]) - fVec34[((IOTA - 485) & 511)]) - fVec34[((IOTA - 488) & 511)]) - fVec34[((IOTA - 496) & 511)]) - fVec34[((IOTA - 506) & 511)])) + ((0.00100711081f * ((((fVec34[((IOTA - 109) & 511)] + fVec34[((IOTA - 167) & 511)]) - fVec34[((IOTA - 278) & 511)]) - fVec34[((IOTA - 498) & 511)]) - fVec34[((IOTA - 505) & 511)])) + ((0.00119022187f * ((fVec34[((IOTA - 185) & 511)] - fVec34[((IOTA - 379) & 511)]) - fVec34[((IOTA - 504) & 511)])) + ((0.00131229591f * ((((fVec34[((IOTA - 285) & 511)] + fVec34[((IOTA - 286) & 511)]) - fVec34[((IOTA - 370) & 511)]) - fVec34[((IOTA - 452) & 511)]) - fVec34[((IOTA - 503) & 511)])) + ((0.000915555283f * (((fVec34[((IOTA - 168) & 511)] + fVec34[((IOTA - 171) & 511)]) - fVec34[((IOTA - 346) & 511)]) - fVec34[((IOTA - 497) & 511)])) + ((0.000762962736f * (((((fVec34[((IOTA - 184) & 511)] + fVec34[((IOTA - 310) & 511)]) - fVec34[((IOTA - 345) & 511)]) - fVec34[((IOTA - 484) & 511)]) - fVec34[((IOTA - 489) & 511)]) - fVec34[((IOTA - 495) & 511)])) + ((0.000671407208f * ((((fVec34[((IOTA - 281) & 511)] - fVec34[((IOTA - 343) & 511)]) - fVec34[((IOTA - 483) & 511)]) - fVec34[((IOTA - 490) & 511)]) - fVec34[((IOTA - 493) & 511)])) + ((0.000610370189f * (((fVec34[((IOTA - 334) & 511)] - (fVec34[((IOTA - 234) & 511)] + fVec34[((IOTA - 302) & 511)])) - fVec34[((IOTA - 435) & 511)]) - fVec34[((IOTA - 491) & 511)])) + ((0.00054933317f * (((((fVec34[((IOTA - 170) & 511)] + fVec34[((IOTA - 201) & 511)]) + fVec34[((IOTA - 328) & 511)]) - fVec34[((IOTA - 436) & 511)]) - fVec34[((IOTA - 468) & 511)]) - fVec34[((IOTA - 482) & 511)])) + ((0.000518814661f * ((((fVec34[((IOTA - 183) & 511)] + fVec34[((IOTA - 288) & 511)]) + fVec34[((IOTA - 327) & 511)]) + fVec34[((IOTA - 397) & 511)]) - fVec34[((IOTA - 469) & 511)])) + ((0.00057985168f * ((fVec34[((IOTA - 169) & 511)] - fVec34[((IOTA - 248) & 511)]) - fVec34[((IOTA - 467) & 511)])) + ((0.000793481246f * ((fVec34[((IOTA - 148) & 511)] + fVec34[((IOTA - 351) & 511)]) - fVec34[((IOTA - 464) & 511)])) + ((0.000946073793f * ((fVec34[((IOTA - 221) & 511)] + fVec34[((IOTA - 223) & 511)]) - fVec34[((IOTA - 463) & 511)])) + ((0.00140385143f * (((((fVec34[((IOTA - 231) & 511)] - fVec34[((IOTA - 238) & 511)]) - fVec34[((IOTA - 368) & 511)]) - fVec34[((IOTA - 432) & 511)]) - fVec34[((IOTA - 455) & 511)]) - fVec34[((IOTA - 460) & 511)])) + ((0.00149540696f * (((fVec34[((IOTA - 160) & 511)] - fVec34[((IOTA - 367) & 511)]) - fVec34[((IOTA - 431) & 511)]) - fVec34[((IOTA - 456) & 511)])) + ((0.00125125889f * (((((((((fVec34[((IOTA - 161) & 511)] + fVec34[((IOTA - 180) & 511)]) - fVec34[((IOTA - 249) & 511)]) - fVec34[((IOTA - 266) & 511)]) + fVec34[((IOTA - 283) & 511)]) + fVec34[((IOTA - 335) & 511)]) + fVec34[((IOTA - 353) & 511)]) - fVec34[((IOTA - 371) & 511)]) - fVec34[((IOTA - 439) & 511)]) - fVec34[((IOTA - 454) & 511)])) + ((0.00143436994f * (((fVec34[((IOTA - 225) & 511)] - fVec34[((IOTA - 236) & 511)]) + fVec34[((IOTA - 352) & 511)]) - fVec34[((IOTA - 451) & 511)])) + ((0.0022583697f * ((fVec34[((IOTA - 218) & 511)] - fVec34[((IOTA - 443) & 511)]) - fVec34[((IOTA - 444) & 511)])) + ((0.00216681417f * ((fVec34[((IOTA - 138) & 511)] - fVec34[((IOTA - 410) & 511)]) - fVec34[((IOTA - 442) & 511)])) + ((0.000732444227f * ((((fVec34[((IOTA - 132) & 511)] - fVec34[((IOTA - 344) & 511)]) - fVec34[((IOTA - 391) & 511)]) - fVec34[((IOTA - 392) & 511)]) - fVec34[((IOTA - 428) & 511)])) + ((6.10370189e-05f * ((fVec34[((IOTA - 424) & 511)] + fVec34[((IOTA - 425) & 511)]) - fVec34[((IOTA - 426) & 511)])) + ((3.05185094e-05f * (fVec34[((IOTA - 329) & 511)] - fVec34[((IOTA - 423) & 511)])) + ((0.000213629566f * (((fVec34[((IOTA - 143) & 511)] + fVec34[((IOTA - 247) & 511)]) - fVec34[((IOTA - 326) & 511)]) - fVec34[((IOTA - 422) & 511)])) + ((0.000427259132f * ((fVec34[((IOTA - 126) & 511)] - fVec34[((IOTA - 331) & 511)]) - fVec34[((IOTA - 421) & 511)])) + ((0.00109866634f * ((fVec34[((IOTA - 108) & 511)] + fVec34[((IOTA - 340) & 511)]) - fVec34[((IOTA - 419) & 511)])) + ((0.00247199927f * ((fVec34[((IOTA - 123) & 511)] - fVec34[((IOTA - 412) & 511)]) - fVec34[((IOTA - 415) & 511)])) + ((0.00250251777f * (fVec34[((IOTA - 384) & 511)] - fVec34[((IOTA - 414) & 511)])) + ((0.00234992523f * (fVec34[((IOTA - 298) & 511)] - fVec34[((IOTA - 411) & 511)])) + ((0.00210577715f * (((fVec34[((IOTA - 107) & 511)] + fVec34[((IOTA - 158) & 511)]) - fVec34[((IOTA - 263) & 511)]) - fVec34[((IOTA - 407) & 511)])) + ((0.00238044374f * (fVec34[((IOTA - 204) & 511)] - fVec34[((IOTA - 404) & 511)])) + ((0.00186162908f * ((((fVec34[((IOTA - 149) & 511)] - fVec34[((IOTA - 268) & 511)]) - fVec34[((IOTA - 269) & 511)]) - fVec34[((IOTA - 373) & 511)]) - fVec34[((IOTA - 402) & 511)])) + ((0.00265511032f * ((fVec34[((IOTA - 178) & 511)] + fVec34[((IOTA - 311) & 511)]) + fVec34[((IOTA - 383) & 511)])) + ((0.00271614734f * (fVec34[((IOTA - 133) & 511)] - fVec34[((IOTA - 378) & 511)])) + ((0.00177007355f * ((((((fVec34[((IOTA - 142) & 511)] + fVec34[((IOTA - 203) & 511)]) + fVec34[((IOTA - 227) & 511)]) + fVec34[((IOTA - 230) & 511)]) - fVec34[((IOTA - 270) & 511)]) + fVec34[((IOTA - 338) & 511)]) - fVec34[((IOTA - 366) & 511)])) + ((0.00335703604f * (fVec34[((IOTA - 141) & 511)] - fVec34[((IOTA - 363) & 511)])) + ((0.00369273964f * (fVec34[((IOTA - 134) & 511)] - fVec34[((IOTA - 362) & 511)])) + ((0.00393688772f * ((fVec34[((IOTA - 211) & 511)] + fVec34[((IOTA - 213) & 511)]) - fVec34[((IOTA - 360) & 511)])) + ((0.00384533219f * (fVec34[((IOTA - 212) & 511)] - fVec34[((IOTA - 359) & 511)])) + ((0.00363170262f * (fVec34[((IOTA - 216) & 511)] - fVec34[((IOTA - 358) & 511)])) + ((0.003234962f * (((fVec34[((IOTA - 135) & 511)] + fVec34[((IOTA - 177) & 511)]) + fVec34[((IOTA - 316) & 511)]) - fVec34[((IOTA - 357) & 511)])) + ((0.00241096225f * ((fVec34[((IOTA - 173) & 511)] - fVec34[((IOTA - 254) & 511)]) - fVec34[((IOTA - 356) & 511)])) + ((0.000335703604f * ((fVec34[((IOTA - 197) & 511)] - fVec34[((IOTA - 330) & 511)]) - fVec34[((IOTA - 342) & 511)])) + ((0.00180059206f * ((fVec34[((IOTA - 186) & 511)] - fVec34[((IOTA - 290) & 511)]) + fVec34[((IOTA - 337) & 511)])) + ((0.001617481f * (((fVec34[((IOTA - 136) & 511)] + fVec34[((IOTA - 219) & 511)]) - fVec34[((IOTA - 271) & 511)]) + fVec34[((IOTA - 336) & 511)])) + ((0.00372325815f * (fVec34[((IOTA - 73) & 511)] - fVec34[((IOTA - 321) & 511)])) + ((0.00204474013f * (fVec34[((IOTA - 110) & 511)] + fVec34[((IOTA - 318) & 511)])) + ((0.00292977691f * ((fVec34[((IOTA - 174) & 511)] + fVec34[((IOTA - 192) & 511)]) + fVec34[((IOTA - 317) & 511)])) + ((0.00326548051f * fVec34[((IOTA - 314) & 511)]) + ((0.00347911008f * (fVec34[((IOTA - 176) & 511)] + fVec34[((IOTA - 313) & 511)])) + ((0.00350962859f * fVec34[((IOTA - 312) & 511)]) + ((0.00329599902f * ((fVec34[((IOTA - 111) & 511)] - fVec34[((IOTA - 258) & 511)]) - fVec34[((IOTA - 308) & 511)])) + ((0.00360118411f * (fVec34[((IOTA - 301) & 511)] - fVec34[((IOTA - 306) & 511)])) + ((0.00366222113f * ((fVec34[((IOTA - 122) & 511)] - fVec34[((IOTA - 129) & 511)]) - fVec34[((IOTA - 305) & 511)])) + ((0.00607318338f * fVec34[((IOTA - 300) & 511)]) + ((0.00543229468f * fVec34[((IOTA - 299) & 511)]) + ((0.00503555406f * (fVec34[((IOTA - 155) & 511)] - fVec34[((IOTA - 295) & 511)])) + ((0.00173955504f * (fVec34[((IOTA - 159) & 511)] - fVec34[((IOTA - 273) & 511)])) + ((0.0028992584f * (((fVec34[((IOTA - 157) & 511)] + fVec34[((IOTA - 189) & 511)]) + fVec34[((IOTA - 190) & 511)]) - fVec34[((IOTA - 260) & 511)])) + ((0.00311288796f * (fVec34[((IOTA - 205) & 511)] - fVec34[((IOTA - 255) & 511)])) + ((0.0019226661f * (fVec34[((IOTA - 195) & 511)] - fVec34[((IOTA - 243) & 511)])) + ((0.00213629566f * (fVec34[((IOTA - 124) & 511)] - fVec34[((IOTA - 242) & 511)])) + ((0.00296029542f * fVec34[((IOTA - 217) & 511)]) + ((0.00399792474f * ((fVec34[((IOTA - 98) & 511)] + fVec34[((IOTA - 156) & 511)]) + fVec34[((IOTA - 215) & 511)])) + ((0.00418103579f * (fVec34[((IOTA - 139) & 511)] + fVec34[((IOTA - 210) & 511)])) + ((0.00439466536f * fVec34[((IOTA - 209) & 511)]) + ((0.00442518387f * fVec34[((IOTA - 208) & 511)]) + ((0.00424207281f * fVec34[((IOTA - 207) & 511)]) + ((0.00381481368f * fVec34[((IOTA - 206) & 511)]) + ((0.00262459181f * (fVec34[((IOTA - 188) & 511)] + fVec34[((IOTA - 194) & 511)])) + ((0.00302133244f * (fVec34[((IOTA - 150) & 511)] + fVec34[((IOTA - 193) & 511)])) + ((0.00228888821f * fVec34[((IOTA - 187) & 511)]) + ((0.00201422162f * (fVec34[((IOTA - 125) & 511)] + fVec34[((IOTA - 179) & 511)])) + ((0.00332651753f * fVec34[((IOTA - 175) & 511)]) + ((0.000122074038f * fVec34[((IOTA - 165) & 511)]) + ((0.000976592302f * fVec34[((IOTA - 162) & 511)]) + ((0.00570696127f * fVec34[((IOTA - 154) & 511)]) + ((0.00589007232f * fVec34[((IOTA - 153) & 511)]) + ((0.00527970213f * fVec34[((IOTA - 152) & 511)]) + ((0.00411999878f * (fVec34[((IOTA - 88) & 511)] + fVec34[((IOTA - 151) & 511)])) + ((0.00454725791f * fVec34[((IOTA - 140) & 511)]) + ((0.00512710959f * fVec34[((IOTA - 121) & 511)]) + ((0.00692770164f * fVec34[((IOTA - 120) & 511)]) + ((0.00836207159f * fVec34[((IOTA - 119) & 511)]) + ((0.00869777519f * (fVec34[((IOTA - 58) & 511)] + fVec34[((IOTA - 118) & 511)])) + ((0.00939970091f * fVec34[((IOTA - 117) & 511)]) + ((0.0107730338f * fVec34[((IOTA - 115) & 511)]) + ((0.00915555283f * (fVec34[((IOTA - 104) & 511)] + fVec34[((IOTA - 114) & 511)])) + ((0.00735496078f * fVec34[((IOTA - 113) & 511)]) + ((0.00534073915f * fVec34[((IOTA - 112) & 511)]) + ((0.00479140598f * fVec34[((IOTA - 106) & 511)]) + ((0.00759910885f * fVec34[((IOTA - 105) & 511)]) + ((0.00900296029f * fVec34[((IOTA - 103) & 511)]) + ((0.00863673817f * fVec34[((IOTA - 102) & 511)]) + ((0.00827051606f * fVec34[((IOTA - 101) & 511)]) + ((0.00747703481f * fVec34[((IOTA - 100) & 511)]) + ((0.0061342204f * fVec34[((IOTA - 99) & 511)]) + ((0.00976592302f * fVec34[((IOTA - 87) & 511)]) + ((0.0138248848f * fVec34[((IOTA - 86) & 511)]) + ((0.0148014771f * fVec34[((IOTA - 85) & 511)]) + ((0.0106204413f * fVec34[((IOTA - 84) & 511)]) + ((0.00817896053f * fVec34[((IOTA - 83) & 511)]) + ((0.00769066438f * fVec34[((IOTA - 82) & 511)]) + ((0.00909451582f * (fVec34[((IOTA - 31) & 511)] + fVec34[((IOTA - 81) & 511)])) + ((0.0120242927f * fVec34[((IOTA - 80) & 511)]) + ((0.0183111057f * fVec34[((IOTA - 79) & 511)]) + ((0.021271402f * fVec34[((IOTA - 78) & 511)]) + ((0.019348735f * fVec34[((IOTA - 77) & 511)]) + ((0.016296884f * fVec34[((IOTA - 76) & 511)]) + ((0.0122074038f * fVec34[((IOTA - 75) & 511)]) + ((0.0083925901f * fVec34[((IOTA - 74) & 511)]) + ((0.00460829493f * fVec34[((IOTA - 65) & 511)]) + ((0.015991699f * fVec34[((IOTA - 64) & 511)]) + ((0.0294198431f * fVec34[((IOTA - 63) & 511)]) + ((0.0448011719f * fVec34[((IOTA - 61) & 511)]) + ((0.0285653248f * fVec34[((IOTA - 59) & 511)]) + ((0.0171514023f * fVec34[((IOTA - 53) & 511)]) + ((0.0317087322f * (fVec34[((IOTA - 20) & 511)] + fVec34[((IOTA - 52) & 511)])) + ((0.035950806f * fVec34[((IOTA - 51) & 511)]) + ((0.0352488793f * fVec34[((IOTA - 50) & 511)]) + ((0.0334788039f * fVec34[((IOTA - 49) & 511)]) + ((0.0343638435f * fVec34[((IOTA - 48) & 511)]) + ((0.0337839909f * fVec34[((IOTA - 47) & 511)]) + ((0.0215460677f * fVec34[((IOTA - 46) & 511)]) + ((0.00567644276f * fVec34[((IOTA - 45) & 511)]) + ((0.00494399853f * fVec34[((IOTA - 36) & 511)]) + ((0.0297555476f * fVec34[((IOTA - 34) & 511)]) + ((0.0332346559f * fVec34[((IOTA - 33) & 511)]) + ((0.0281380657f * fVec34[((IOTA - 32) & 511)]) + ((0.0200506616f * fVec34[((IOTA - 26) & 511)]) + ((0.0443739146f * fVec34[((IOTA - 25) & 511)]) + ((0.0518204309f * fVec34[((IOTA - 24) & 511)]) + ((0.0286568813f * fVec34[((IOTA - 23) & 511)]) + ((((((((((0.145725876f * fVec34[((IOTA - 6) & 511)]) + (0.171391949f * fVec34[((IOTA - 7) & 511)])) + (0.116550185f * fVec34[((IOTA - 8) & 511)])) + (0.0523392446f * fVec34[((IOTA - 9) & 511)])) + (0.00616473891f * fVec34[((IOTA - 15) & 511)])) + (0.00500503555f * fVec34[((IOTA - 16) & 511)])) + (0.0286873989f * fVec34[((IOTA - 17) & 511)])) + (0.0347911008f * fVec34[((IOTA - 18) & 511)])) + (0.0331431031f * fVec34[((IOTA - 19) & 511)])) + (0.0116885891f * fVec34[((IOTA - 21) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * (((((fVec34[((IOTA - 146) & 511)] + fVec34[((IOTA - 163) & 511)]) + fVec34[((IOTA - 246) & 511)]) + fVec34[((IOTA - 319) & 511)]) - fVec34[((IOTA - 427) & 511)]) - fVec34[((IOTA - 509) & 511)])))) : (iSlow82 ? ((((0.000305185094f * ((((((((((((fVec33[((IOTA - 191) & 511)] + fVec33[((IOTA - 197) & 511)]) + fVec33[((IOTA - 202) & 511)]) + fVec33[((IOTA - 271) & 511)]) + fVec33[((IOTA - 272) & 511)]) + fVec33[((IOTA - 283) & 511)]) + fVec33[((IOTA - 311) & 511)]) - fVec33[((IOTA - 428) & 511)]) + fVec33[((IOTA - 430) & 511)]) + fVec33[((IOTA - 443) & 511)]) + fVec33[((IOTA - 486) & 511)]) + fVec33[((IOTA - 497) & 511)]) + fVec33[((IOTA - 498) & 511)])) + ((0.000457777642f * (((((((((fVec33[((IOTA - 90) & 511)] - fVec33[((IOTA - 222) & 511)]) + fVec33[((IOTA - 248) & 511)]) + fVec33[((IOTA - 304) & 511)]) + fVec33[((IOTA - 313) & 511)]) + fVec33[((IOTA - 370) & 511)]) + fVec33[((IOTA - 392) & 511)]) + fVec33[((IOTA - 412) & 511)]) + fVec33[((IOTA - 459) & 511)]) + fVec33[((IOTA - 492) & 511)])) + ((0.000396740623f * (((((((((((((fVec33[((IOTA - 199) & 511)] - ((fVec33[((IOTA - 151) & 511)] + fVec33[((IOTA - 182) & 511)]) + fVec33[((IOTA - 183) & 511)])) - fVec33[((IOTA - 209) & 511)]) - fVec33[((IOTA - 232) & 511)]) + fVec33[((IOTA - 237) & 511)]) + fVec33[((IOTA - 266) & 511)]) + fVec33[((IOTA - 297) & 511)]) + fVec33[((IOTA - 367) & 511)]) + fVec33[((IOTA - 381) & 511)]) - fVec33[((IOTA - 387) & 511)]) - fVec33[((IOTA - 398) & 511)]) + fVec33[((IOTA - 415) & 511)]) + fVec33[((IOTA - 419) & 511)]) + fVec33[((IOTA - 490) & 511)])) + ((3.05185094e-05f * ((((((((((fVec33[((IOTA - 186) & 511)] - fVec33[((IOTA - 205) & 511)]) + fVec33[((IOTA - 208) & 511)]) + fVec33[((IOTA - 250) & 511)]) - fVec33[((IOTA - 403) & 511)]) + fVec33[((IOTA - 417) & 511)]) - fVec33[((IOTA - 434) & 511)]) - fVec33[((IOTA - 437) & 511)]) - fVec33[((IOTA - 450) & 511)]) + fVec33[((IOTA - 465) & 511)]) + fVec33[((IOTA - 472) & 511)])) + ((0.000701925717f * ((fVec33[((IOTA - 339) & 511)] - (((fVec33[((IOTA - 229) & 511)] - fVec33[((IOTA - 253) & 511)]) - fVec33[((IOTA - 321) & 511)]) - fVec33[((IOTA - 323) & 511)])) + fVec33[((IOTA - 461) & 511)])) + ((0.000427259132f * (((((fVec33[((IOTA - 312) & 511)] - (((fVec33[((IOTA - 148) & 511)] + fVec33[((IOTA - 220) & 511)]) + fVec33[((IOTA - 224) & 511)]) - fVec33[((IOTA - 286) & 511)])) + fVec33[((IOTA - 314) & 511)]) + fVec33[((IOTA - 330) & 511)]) + fVec33[((IOTA - 405) & 511)]) + fVec33[((IOTA - 420) & 511)])) + ((0.000366222113f * (((fVec33[((IOTA - 267) & 511)] + fVec33[((IOTA - 288) & 511)]) + fVec33[((IOTA - 400) & 511)]) + fVec33[((IOTA - 411) & 511)])) + ((0.000915555283f * ((fVec33[((IOTA - 254) & 511)] + fVec33[((IOTA - 362) & 511)]) + fVec33[((IOTA - 380) & 511)])) + ((0.00146488845f * (fVec33[((IOTA - 342) & 511)] + fVec33[((IOTA - 379) & 511)])) + ((0.00140385143f * fVec33[((IOTA - 377) & 511)]) + ((0.000946073793f * ((((fVec33[((IOTA - 301) & 511)] + fVec33[((IOTA - 319) & 511)]) + fVec33[((IOTA - 344) & 511)]) + fVec33[((IOTA - 361) & 511)]) + fVec33[((IOTA - 373) & 511)])) + ((0.00103762932f * ((((fVec33[((IOTA - 43) & 511)] + fVec33[((IOTA - 59) & 511)]) - fVec33[((IOTA - 218) & 511)]) + fVec33[((IOTA - 360) & 511)]) + fVec33[((IOTA - 391) & 511)])) + ((0.000885036774f * ((((fVec33[((IOTA - 147) & 511)] - fVec33[((IOTA - 176) & 511)]) + fVec33[((IOTA - 325) & 511)]) + fVec33[((IOTA - 337) & 511)]) + fVec33[((IOTA - 363) & 511)])) + ((0.00122074038f * fVec33[((IOTA - 359) & 511)]) + ((0.00131229591f * (fVec33[((IOTA - 306) & 511)] + fVec33[((IOTA - 358) & 511)])) + ((0.00112918485f * (fVec33[((IOTA - 145) & 511)] + fVec33[((IOTA - 354) & 511)])) + ((0.000976592302f * ((((fVec33[((IOTA - 331) & 511)] + fVec33[((IOTA - 332) & 511)]) + fVec33[((IOTA - 347) & 511)]) + fVec33[((IOTA - 348) & 511)]) + fVec33[((IOTA - 353) & 511)])) + ((0.000823999755f * (((fVec33[((IOTA - 302) & 511)] + fVec33[((IOTA - 324) & 511)]) + fVec33[((IOTA - 346) & 511)]) + fVec33[((IOTA - 352) & 511)])) + ((0.00152592547f * (fVec33[((IOTA - 146) & 511)] + fVec33[((IOTA - 341) & 511)])) + ((0.000732444227f * (((((fVec33[((IOTA - 93) & 511)] - fVec33[((IOTA - 149) & 511)]) - fVec33[((IOTA - 179) & 511)]) + fVec33[((IOTA - 290) & 511)]) + fVec33[((IOTA - 294) & 511)]) + fVec33[((IOTA - 322) & 511)])) + ((0.00158696249f * (fVec33[((IOTA - 11) & 511)] + fVec33[((IOTA - 307) & 511)])) + ((0.00241096225f * ((fVec33[((IOTA - 73) & 511)] - fVec33[((IOTA - 76) & 511)]) - fVec33[((IOTA - 167) & 511)])) + ((0.00280770287f * (fVec33[((IOTA - 96) & 511)] - fVec33[((IOTA - 121) & 511)])) + ((0.00820947904f * fVec33[((IOTA - 92) & 511)]) + ((0.0112918485f * fVec33[((IOTA - 86) & 511)]) + ((0.0071108127f * fVec33[((IOTA - 85) & 511)]) + ((0.00589007232f * fVec33[((IOTA - 72) & 511)]) + ((0.00335703604f * fVec33[((IOTA - 71) & 511)]) + ((0.00143436994f * (fVec33[((IOTA - 44) & 511)] + fVec33[((IOTA - 70) & 511)])) + ((0.0105899228f * fVec33[((IOTA - 91) & 511)]) + ((0.00448622089f * fVec33[((IOTA - 69) & 511)]) + ((0.00137333293f * fVec33[((IOTA - 68) & 511)]) + ((0.00698873866f * fVec33[((IOTA - 58) & 511)]) + ((0.00283822138f * fVec33[((IOTA - 45) & 511)]) + ((0.00955229346f * fVec33[((IOTA - 42) & 511)]) + ((0.0117191076f * fVec33[((IOTA - 41) & 511)]) + ((0.0172124393f * fVec33[((IOTA - 40) & 511)]) + ((0.00109866634f * fVec33[((IOTA - 32) & 511)]) + ((0.0190130323f * fVec33[((IOTA - 31) & 511)]) + ((0.0087282937f * fVec33[((IOTA - 30) & 511)]) + ((0.00750755332f * fVec33[((IOTA - 25) & 511)]) + ((0.318369091f * fVec33[((IOTA - 5) & 511)]) + ((0.0673543513f * fVec33[((IOTA - 3) & 511)]) + (((0.024567401f * fVec33[((IOTA - 13) & 511)]) + ((fSlow86 * fTemp0) + ((0.358836621f * fVec33[((IOTA - 6) & 511)]) + ((0.0691549405f * fVec33[((IOTA - 12) & 511)]) + ((0.0831018984f * fVec33[((IOTA - 1) & 511)]) + ((((0.081240274f * fVec33[((IOTA - 2) & 511)]) + (0.14441359f * fVec33[((IOTA - 4) & 511)])) + (0.117618337f * fVec33[((IOTA - 7) & 511)])) + (0.0104983672f * fVec33[((IOTA - 16) & 511)]))))))) + (0.00491348002f * fVec33[((IOTA - 17) & 511)]))))))))))))))))))))))))))))))))))))))))))))) + (0.000671407208f * ((((((((fVec33[((IOTA - 200) & 511)] + fVec33[((IOTA - 291) & 511)]) + fVec33[((IOTA - 296) & 511)]) + fVec33[((IOTA - 300) & 511)]) + fVec33[((IOTA - 320) & 511)]) + fVec33[((IOTA - 374) & 511)]) + fVec33[((IOTA - 460) & 511)]) + fVec33[((IOTA - 503) & 511)]) + fVec33[((IOTA - 504) & 511)]))) - (((0.000244148076f * ((((((((((((((((fVec33[((IOTA - 144) & 511)] + fVec33[((IOTA - 181) & 511)]) + fVec33[((IOTA - 184) & 511)]) - fVec33[((IOTA - 198) & 511)]) + fVec33[((IOTA - 225) & 511)]) - fVec33[((IOTA - 244) & 511)]) - fVec33[((IOTA - 249) & 511)]) - fVec33[((IOTA - 369) & 511)]) + fVec33[((IOTA - 383) & 511)]) + fVec33[((IOTA - 384) & 511)]) - fVec33[((IOTA - 402) & 511)]) + fVec33[((IOTA - 423) & 511)]) + fVec33[((IOTA - 426) & 511)]) - fVec33[((IOTA - 454) & 511)]) - fVec33[((IOTA - 458) & 511)]) - fVec33[((IOTA - 506) & 511)]) - fVec33[((IOTA - 509) & 511)])) + ((9.15555283e-05f * (((((((((((((((((fVec33[((IOTA - 97) & 511)] + fVec33[((IOTA - 187) & 511)]) - fVec33[((IOTA - 242) & 511)]) - fVec33[((IOTA - 246) & 511)]) - fVec33[((IOTA - 251) & 511)]) - fVec33[((IOTA - 262) & 511)]) - fVec33[((IOTA - 269) & 511)]) + fVec33[((IOTA - 429) & 511)]) - fVec33[((IOTA - 448) & 511)]) - fVec33[((IOTA - 449) & 511)]) + fVec33[((IOTA - 451) & 511)]) + fVec33[((IOTA - 452) & 511)]) - fVec33[((IOTA - 453) & 511)]) + fVec33[((IOTA - 471) & 511)]) + fVec33[((IOTA - 475) & 511)]) - fVec33[((IOTA - 495) & 511)]) - fVec33[((IOTA - 507) & 511)]) - fVec33[((IOTA - 508) & 511)])) + ((0.000518814661f * (((((((((((((fVec33[((IOTA - 87) & 511)] - fVec33[((IOTA - 95) & 511)]) + fVec33[((IOTA - 140) & 511)]) + fVec33[((IOTA - 188) & 511)]) + fVec33[((IOTA - 234) & 511)]) - fVec33[((IOTA - 261) & 511)]) - fVec33[((IOTA - 292) & 511)]) - fVec33[((IOTA - 375) & 511)]) - fVec33[((IOTA - 401) & 511)]) - fVec33[((IOTA - 413) & 511)]) - fVec33[((IOTA - 414) & 511)]) - fVec33[((IOTA - 491) & 511)]) - fVec33[((IOTA - 502) & 511)]) - fVec33[((IOTA - 505) & 511)])) + ((0.000274666585f * ((((((((((((((((fVec33[((IOTA - 221) & 511)] + fVec33[((IOTA - 226) & 511)]) + fVec33[((IOTA - 230) & 511)]) - fVec33[((IOTA - 243) & 511)]) - fVec33[((IOTA - 258) & 511)]) - fVec33[((IOTA - 277) & 511)]) - fVec33[((IOTA - 310) & 511)]) + fVec33[((IOTA - 329) & 511)]) - fVec33[((IOTA - 368) & 511)]) - fVec33[((IOTA - 397) & 511)]) + fVec33[((IOTA - 427) & 511)]) + fVec33[((IOTA - 468) & 511)]) + fVec33[((IOTA - 469) & 511)]) - fVec33[((IOTA - 480) & 511)]) - fVec33[((IOTA - 493) & 511)]) - fVec33[((IOTA - 499) & 511)]) - fVec33[((IOTA - 500) & 511)])) + ((0.000213629566f * (((((((((((((((fVec33[((IOTA - 131) & 511)] + fVec33[((IOTA - 215) & 511)]) - fVec33[((IOTA - 236) & 511)]) + fVec33[((IOTA - 240) & 511)]) - fVec33[((IOTA - 265) & 511)]) - fVec33[((IOTA - 274) & 511)]) - fVec33[((IOTA - 298) & 511)]) + fVec33[((IOTA - 399) & 511)]) - fVec33[((IOTA - 410) & 511)]) + fVec33[((IOTA - 439) & 511)]) - fVec33[((IOTA - 455) & 511)]) + fVec33[((IOTA - 476) & 511)]) + fVec33[((IOTA - 477) & 511)]) - fVec33[((IOTA - 487) & 511)]) - fVec33[((IOTA - 489) & 511)]) - fVec33[((IOTA - 496) & 511)])) + ((0.000122074038f * (((((((((((((fVec33[((IOTA - 150) & 511)] + fVec33[((IOTA - 203) & 511)]) - fVec33[((IOTA - 206) & 511)]) + fVec33[((IOTA - 213) & 511)]) - fVec33[((IOTA - 257) & 511)]) - fVec33[((IOTA - 275) & 511)]) + fVec33[((IOTA - 280) & 511)]) - fVec33[((IOTA - 416) & 511)]) - fVec33[((IOTA - 421) & 511)]) - fVec33[((IOTA - 433) & 511)]) - fVec33[((IOTA - 457) & 511)]) - fVec33[((IOTA - 473) & 511)]) - fVec33[((IOTA - 488) & 511)]) - fVec33[((IOTA - 494) & 511)])) + ((0.000183111057f * ((((((((((((((((fVec33[((IOTA - 195) & 511)] - fVec33[((IOTA - 196) & 511)]) - fVec33[((IOTA - 207) & 511)]) + fVec33[((IOTA - 231) & 511)]) + fVec33[((IOTA - 235) & 511)]) - fVec33[((IOTA - 270) & 511)]) + fVec33[((IOTA - 281) & 511)]) + fVec33[((IOTA - 385) & 511)]) - fVec33[((IOTA - 404) & 511)]) + fVec33[((IOTA - 422) & 511)]) + fVec33[((IOTA - 424) & 511)]) + fVec33[((IOTA - 425) & 511)]) + fVec33[((IOTA - 467) & 511)]) + fVec33[((IOTA - 470) & 511)]) - fVec33[((IOTA - 479) & 511)]) - fVec33[((IOTA - 481) & 511)]) - fVec33[((IOTA - 484) & 511)])) + ((6.10370189e-05f * (((((((((((((fVec33[((IOTA - 185) & 511)] - fVec33[((IOTA - 214) & 511)]) - fVec33[((IOTA - 245) & 511)]) + fVec33[((IOTA - 327) & 511)]) + fVec33[((IOTA - 382) & 511)]) - fVec33[((IOTA - 409) & 511)]) + fVec33[((IOTA - 435) & 511)]) + fVec33[((IOTA - 440) & 511)]) - fVec33[((IOTA - 444) & 511)]) + fVec33[((IOTA - 466) & 511)]) - fVec33[((IOTA - 474) & 511)]) + fVec33[((IOTA - 478) & 511)]) - fVec33[((IOTA - 482) & 511)]) - fVec33[((IOTA - 483) & 511)])) + ((0.000152592547f * ((((((((((((((fVec33[((IOTA - 39) & 511)] + fVec33[((IOTA - 204) & 511)]) + fVec33[((IOTA - 241) & 511)]) + fVec33[((IOTA - 263) & 511)]) - fVec33[((IOTA - 268) & 511)]) - fVec33[((IOTA - 276) & 511)]) - fVec33[((IOTA - 279) & 511)]) - fVec33[((IOTA - 407) & 511)]) - fVec33[((IOTA - 418) & 511)]) + fVec33[((IOTA - 438) & 511)]) - fVec33[((IOTA - 441) & 511)]) + fVec33[((IOTA - 445) & 511)]) + fVec33[((IOTA - 446) & 511)]) - fVec33[((IOTA - 456) & 511)]) - fVec33[((IOTA - 464) & 511)])) + ((0.00057985168f * ((((((fVec33[((IOTA - 223) & 511)] + fVec33[((IOTA - 227) & 511)]) - fVec33[((IOTA - 284) & 511)]) - fVec33[((IOTA - 285) & 511)]) - fVec33[((IOTA - 289) & 511)]) - fVec33[((IOTA - 303) & 511)]) - fVec33[((IOTA - 462) & 511)])) + ((0.000488296151f * ((((((fVec33[((IOTA - 132) & 511)] + fVec33[((IOTA - 211) & 511)]) - fVec33[((IOTA - 315) & 511)]) + fVec33[((IOTA - 328) & 511)]) - fVec33[((IOTA - 334) & 511)]) - fVec33[((IOTA - 366) & 511)]) - fVec33[((IOTA - 431) & 511)])) + ((0.00106814783f * ((fVec33[((IOTA - 177) & 511)] + fVec33[((IOTA - 217) & 511)]) - fVec33[((IOTA - 396) & 511)])) + ((0.00125125889f * ((((fVec33[((IOTA - 152) & 511)] - fVec33[((IOTA - 318) & 511)]) - fVec33[((IOTA - 343) & 511)]) - fVec33[((IOTA - 356) & 511)]) - fVec33[((IOTA - 395) & 511)])) + ((0.000762962736f * ((((((((((((((fVec33[((IOTA - 174) & 511)] + fVec33[((IOTA - 193) & 511)]) - fVec33[((IOTA - 201) & 511)]) - fVec33[((IOTA - 255) & 511)]) - fVec33[((IOTA - 260) & 511)]) - fVec33[((IOTA - 305) & 511)]) - fVec33[((IOTA - 316) & 511)]) - fVec33[((IOTA - 335) & 511)]) - fVec33[((IOTA - 345) & 511)]) - fVec33[((IOTA - 350) & 511)]) - fVec33[((IOTA - 351) & 511)]) - fVec33[((IOTA - 364) & 511)]) - fVec33[((IOTA - 371) & 511)]) - fVec33[((IOTA - 376) & 511)]) - fVec33[((IOTA - 394) & 511)])) + ((0.00155644398f * (fVec33[((IOTA - 129) & 511)] - fVec33[((IOTA - 390) & 511)])) + ((0.00119022187f * (((fVec33[((IOTA - 77) & 511)] + fVec33[((IOTA - 173) & 511)]) - fVec33[((IOTA - 355) & 511)]) - fVec33[((IOTA - 389) & 511)])) + ((0.00173955504f * (fVec33[((IOTA - 74) & 511)] - fVec33[((IOTA - 378) & 511)])) + ((0.00100711081f * ((fVec33[((IOTA - 130) & 511)] - fVec33[((IOTA - 336) & 511)]) - fVec33[((IOTA - 372) & 511)])) + ((0.000640888698f * ((((fVec33[((IOTA - 175) & 511)] + fVec33[((IOTA - 189) & 511)]) + fVec33[((IOTA - 194) & 511)]) - fVec33[((IOTA - 333) & 511)]) - fVec33[((IOTA - 365) & 511)])) + ((0.0012817774f * (fVec33[((IOTA - 172) & 511)] - fVec33[((IOTA - 357) & 511)])) + ((0.000854518265f * ((fVec33[((IOTA - 57) & 511)] + fVec33[((IOTA - 178) & 511)]) - fVec33[((IOTA - 349) & 511)])) + ((0.00115970336f * (((fVec33[((IOTA - 46) & 511)] - fVec33[((IOTA - 308) & 511)]) - fVec33[((IOTA - 317) & 511)]) - fVec33[((IOTA - 340) & 511)])) + ((0.000610370189f * ((((fVec33[((IOTA - 210) & 511)] + fVec33[((IOTA - 233) & 511)]) - fVec33[((IOTA - 259) & 511)]) - fVec33[((IOTA - 326) & 511)]) - fVec33[((IOTA - 338) & 511)])) + ((0.00054933317f * ((fVec33[((IOTA - 139) & 511)] - fVec33[((IOTA - 293) & 511)]) - fVec33[((IOTA - 309) & 511)])) + ((0.000793481246f * (((fVec33[((IOTA - 216) & 511)] + fVec33[((IOTA - 219) & 511)]) + fVec33[((IOTA - 228) & 511)]) - fVec33[((IOTA - 295) & 511)])) + ((0.00134281442f * (((fVec33[((IOTA - 135) & 511)] + fVec33[((IOTA - 143) & 511)]) + fVec33[((IOTA - 156) & 511)]) + fVec33[((IOTA - 171) & 511)])) + ((0.00167851802f * fVec33[((IOTA - 170) & 511)]) + ((0.0019226661f * fVec33[((IOTA - 169) & 511)]) + ((0.0019531846f * fVec33[((IOTA - 168) & 511)]) + ((0.00302133244f * fVec33[((IOTA - 166) & 511)]) + ((0.00372325815f * fVec33[((IOTA - 165) & 511)]) + ((0.00375377666f * fVec33[((IOTA - 164) & 511)]) + ((0.00277718436f * fVec33[((IOTA - 163) & 511)]) + ((0.00219733268f * fVec33[((IOTA - 162) & 511)]) + ((0.00231940672f * ((fVec33[((IOTA - 94) & 511)] + fVec33[((IOTA - 137) & 511)]) + fVec33[((IOTA - 161) & 511)])) + ((0.00317392498f * fVec33[((IOTA - 160) & 511)]) + ((0.003234962f * (fVec33[((IOTA - 127) & 511)] + fVec33[((IOTA - 159) & 511)])) + ((0.00244148076f * fVec33[((IOTA - 158) & 511)]) + ((0.001617481f * (fVec33[((IOTA - 138) & 511)] + fVec33[((IOTA - 157) & 511)])) + ((0.00170903653f * fVec33[((IOTA - 155) & 511)]) + ((0.00189214759f * (fVec33[((IOTA - 153) & 511)] + fVec33[((IOTA - 154) & 511)])) + ((0.00201422162f * (fVec33[((IOTA - 125) & 511)] + fVec33[((IOTA - 142) & 511)])) + ((0.00149540696f * fVec33[((IOTA - 141) & 511)]) + ((0.00177007355f * (fVec33[((IOTA - 134) & 511)] + fVec33[((IOTA - 136) & 511)])) + ((0.00186162908f * fVec33[((IOTA - 133) & 511)]) + ((0.00299081393f * fVec33[((IOTA - 128) & 511)]) + ((0.00216681417f * fVec33[((IOTA - 126) & 511)]) + ((0.00469985045f * fVec33[((IOTA - 124) & 511)]) + ((0.00585955381f * fVec33[((IOTA - 123) & 511)]) + ((0.00424207281f * (fVec33[((IOTA - 98) & 511)] + fVec33[((IOTA - 122) & 511)])) + ((0.0045167394f * (fVec33[((IOTA - 101) & 511)] + fVec33[((IOTA - 120) & 511)])) + ((0.00784325693f * fVec33[((IOTA - 119) & 511)]) + ((0.00863673817f * fVec33[((IOTA - 118) & 511)]) + ((0.00628681295f * fVec33[((IOTA - 117) & 511)]) + ((0.00408948027f * fVec33[((IOTA - 116) & 511)]) + ((0.0061342204f * fVec33[((IOTA - 115) & 511)]) + ((0.00860621966f * fVec33[((IOTA - 114) & 511)]) + ((0.00845362712f * fVec33[((IOTA - 113) & 511)]) + ((0.00509659108f * fVec33[((IOTA - 112) & 511)]) + ((0.0025940733f * fVec33[((IOTA - 111) & 511)]) + ((0.00552385021f * fVec33[((IOTA - 110) & 511)]) + ((0.00885036774f * fVec33[((IOTA - 109) & 511)]) + ((0.00927762687f * (fVec33[((IOTA - 89) & 511)] + fVec33[((IOTA - 108) & 511)])) + ((0.00732444227f * fVec33[((IOTA - 107) & 511)]) + ((0.00622577593f * fVec33[((IOTA - 106) & 511)]) + ((0.00720236823f * (fVec33[((IOTA - 104) & 511)] + fVec33[((IOTA - 105) & 511)])) + ((0.00759910885f * fVec33[((IOTA - 103) & 511)]) + ((0.00497451704f * fVec33[((IOTA - 102) & 511)]) + ((0.0058290353f * fVec33[((IOTA - 100) & 511)]) + ((0.00665303506f * fVec33[((IOTA - 99) & 511)]) + ((0.0120242927f * fVec33[((IOTA - 88) & 511)]) + ((0.00521866512f * fVec33[((IOTA - 84) & 511)]) + ((0.0106814783f * fVec33[((IOTA - 83) & 511)]) + ((0.00878933072f * fVec33[((IOTA - 82) & 511)]) + ((0.00915555283f * (fVec33[((IOTA - 79) & 511)] + fVec33[((IOTA - 81) & 511)])) + ((0.0110782189f * fVec33[((IOTA - 80) & 511)]) + ((0.00445570238f * fVec33[((IOTA - 78) & 511)]) + ((0.00329599902f * fVec33[((IOTA - 75) & 511)]) + ((0.00457777642f * fVec33[((IOTA - 67) & 511)]) + ((0.0110477004f * fVec33[((IOTA - 66) & 511)]) + ((0.0136112552f * fVec33[((IOTA - 65) & 511)]) + ((0.0169988107f * fVec33[((IOTA - 64) & 511)]) + ((0.0196844395f * fVec33[((IOTA - 63) & 511)]) + ((0.0208746605f * fVec33[((IOTA - 62) & 511)]) + ((0.0189519953f * fVec33[((IOTA - 61) & 511)]) + ((0.0104068117f * fVec33[((IOTA - 60) & 511)]) + ((0.011322367f * fVec33[((IOTA - 56) & 511)]) + ((0.0204474013f * fVec33[((IOTA - 55) & 511)]) + ((0.0210577715f * fVec33[((IOTA - 54) & 511)]) + ((0.0178228095f * fVec33[((IOTA - 53) & 511)]) + ((0.0156865139f * fVec33[((IOTA - 52) & 511)]) + ((0.0222479943f * fVec33[((IOTA - 51) & 511)]) + ((0.0302438438f * fVec33[((IOTA - 50) & 511)]) + ((0.0233771782f * fVec33[((IOTA - 49) & 511)]) + ((0.0126041444f * fVec33[((IOTA - 48) & 511)]) + ((((((((((((((0.0535905026f * fVec33[((IOTA - 14) & 511)]) + ((0.279580057f * fVec33[((IOTA - 9) & 511)]) + ((((0.163701281f * fVec33[((IOTA - 8) & 511)]) + ((0.142124698f * fVec33[((IOTA - 10) & 511)]) + ((0.0269478448f * fVec33[((IOTA - 19) & 511)]) + ((0.0470595434f * fVec33[((IOTA - 20) & 511)]) + (((0.016296884f * fVec33[((IOTA - 15) & 511)]) + (0.0271614734f * fVec33[((IOTA - 18) & 511)])) + (0.0251167342f * fVec33[((IOTA - 21) & 511)])))))) + (0.0218207352f * fVec33[((IOTA - 22) & 511)])) + (0.0429090261f * fVec33[((IOTA - 23) & 511)])))) + (0.0146488845f * fVec33[((IOTA - 24) & 511)])) + (0.0173039958f * fVec33[((IOTA - 26) & 511)])) + (0.037324138f * fVec33[((IOTA - 27) & 511)])) + (0.0247810297f * fVec33[((IOTA - 28) & 511)])) + (0.00650044251f * fVec33[((IOTA - 29) & 511)])) + (0.022766808f * fVec33[((IOTA - 33) & 511)])) + (0.0292367321f * fVec33[((IOTA - 34) & 511)])) + (0.018097477f * fVec33[((IOTA - 35) & 511)])) + (0.00555436872f * fVec33[((IOTA - 36) & 511)])) + (0.00512710959f * fVec33[((IOTA - 37) & 511)])) + (0.0122989593f * fVec33[((IOTA - 38) & 511)])) + (0.00891140476f * fVec33[((IOTA - 47) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000335703604f * (((((((((((((((((((((fVec33[((IOTA - 180) & 511)] + fVec33[((IOTA - 192) & 511)]) + fVec33[((IOTA - 212) & 511)]) - fVec33[((IOTA - 238) & 511)]) - fVec33[((IOTA - 247) & 511)]) - fVec33[((IOTA - 252) & 511)]) - fVec33[((IOTA - 256) & 511)]) - fVec33[((IOTA - 273) & 511)]) - fVec33[((IOTA - 278) & 511)]) - fVec33[((IOTA - 287) & 511)]) - fVec33[((IOTA - 299) & 511)]) + fVec33[((IOTA - 386) & 511)]) - fVec33[((IOTA - 388) & 511)]) - fVec33[((IOTA - 393) & 511)]) - fVec33[((IOTA - 406) & 511)]) - fVec33[((IOTA - 432) & 511)]) - fVec33[((IOTA - 442) & 511)]) - fVec33[((IOTA - 463) & 511)]) - fVec33[((IOTA - 485) & 511)]) - fVec33[((IOTA - 501) & 511)]) - fVec33[((IOTA - 510) & 511)]) - fVec33[((IOTA - 511) & 511)])))) : ((((9.15555283e-05f * (((((fVec32[((IOTA - 255) & 511)] - fVec32[((IOTA - 476) & 511)]) + fVec32[((IOTA - 493) & 511)]) - fVec32[((IOTA - 505) & 511)]) + fVec32[((IOTA - 507) & 511)]) + fVec32[((IOTA - 508) & 511)])) + ((0.000122074038f * ((((((((fVec32[((IOTA - 430) & 511)] - fVec32[((IOTA - 431) & 511)]) - fVec32[((IOTA - 472) & 511)]) - fVec32[((IOTA - 473) & 511)]) - fVec32[((IOTA - 474) & 511)]) - fVec32[((IOTA - 475) & 511)]) - fVec32[((IOTA - 477) & 511)]) + fVec32[((IOTA - 497) & 511)]) - fVec32[((IOTA - 504) & 511)])) + ((0.000183111057f * (((((((fVec32[((IOTA - 261) & 511)] + fVec32[((IOTA - 381) & 511)]) + fVec32[((IOTA - 422) & 511)]) - fVec32[((IOTA - 426) & 511)]) - fVec32[((IOTA - 427) & 511)]) + fVec32[((IOTA - 483) & 511)]) + fVec32[((IOTA - 490) & 511)]) - fVec32[((IOTA - 503) & 511)])) + ((0.000671407208f * (((fVec32[((IOTA - 189) & 511)] + fVec32[((IOTA - 384) & 511)]) - fVec32[((IOTA - 446) & 511)]) - fVec32[((IOTA - 500) & 511)])) + ((0.00057985168f * (((fVec32[((IOTA - 112) & 511)] + fVec32[((IOTA - 160) & 511)]) - fVec32[((IOTA - 445) & 511)]) - fVec32[((IOTA - 499) & 511)])) + ((0.000396740623f * (((fVec32[((IOTA - 192) & 511)] - fVec32[((IOTA - 253) & 511)]) + fVec32[((IOTA - 320) & 511)]) + fVec32[((IOTA - 496) & 511)])) + ((0.000427259132f * (((((fVec32[((IOTA - 270) & 511)] + fVec32[((IOTA - 376) & 511)]) + fVec32[((IOTA - 452) & 511)]) - fVec32[((IOTA - 461) & 511)]) - fVec32[((IOTA - 469) & 511)]) + fVec32[((IOTA - 495) & 511)])) + ((0.000335703604f * ((((((fVec32[((IOTA - 423) & 511)] - fVec32[((IOTA - 432) & 511)]) + fVec32[((IOTA - 454) & 511)]) + fVec32[((IOTA - 455) & 511)]) - fVec32[((IOTA - 479) & 511)]) + fVec32[((IOTA - 484) & 511)]) + fVec32[((IOTA - 487) & 511)])) + ((0.000244148076f * (((fVec32[((IOTA - 262) & 511)] + fVec32[((IOTA - 390) & 511)]) - fVec32[((IOTA - 393) & 511)]) - fVec32[((IOTA - 478) & 511)])) + ((0.000885036774f * ((fVec32[((IOTA - 120) & 511)] - fVec32[((IOTA - 374) & 511)]) - fVec32[((IOTA - 466) & 511)])) + ((0.00103762932f * (((fVec32[((IOTA - 182) & 511)] - fVec32[((IOTA - 389) & 511)]) - fVec32[((IOTA - 464) & 511)]) - fVec32[((IOTA - 465) & 511)])) + ((0.000823999755f * ((fVec32[((IOTA - 191) & 511)] + fVec32[((IOTA - 268) & 511)]) - fVec32[((IOTA - 463) & 511)])) + ((0.00054933317f * ((fVec32[((IOTA - 248) & 511)] + fVec32[((IOTA - 386) & 511)]) - fVec32[((IOTA - 462) & 511)])) + ((0.000976592302f * ((fVec32[((IOTA - 180) & 511)] - fVec32[((IOTA - 187) & 511)]) + fVec32[((IOTA - 450) & 511)])) + ((0.000701925717f * (((fVec32[((IOTA - 87) & 511)] - fVec32[((IOTA - 382) & 511)]) - fVec32[((IOTA - 387) & 511)]) + fVec32[((IOTA - 449) & 511)])) + ((0.00100711081f * (fVec32[((IOTA - 148) & 511)] - fVec32[((IOTA - 444) & 511)])) + ((0.00183111057f * (fVec32[((IOTA - 184) & 511)] - fVec32[((IOTA - 443) & 511)])) + ((0.00170903653f * (fVec32[((IOTA - 380) & 511)] - fVec32[((IOTA - 436) & 511)])) + ((0.000946073793f * (fVec32[((IOTA - 193) & 511)] - fVec32[((IOTA - 435) & 511)])) + ((0.000854518265f * (fVec32[((IOTA - 260) & 511)] + fVec32[((IOTA - 420) & 511)])) + ((0.00155644398f * (fVec32[((IOTA - 415) & 511)] + fVec32[((IOTA - 419) & 511)])) + ((0.0019226661f * fVec32[((IOTA - 418) & 511)]) + ((0.00186162908f * (fVec32[((IOTA - 200) & 511)] + fVec32[((IOTA - 416) & 511)])) + ((0.00204474013f * ((fVec32[((IOTA - 143) & 511)] - fVec32[((IOTA - 237) & 511)]) - fVec32[((IOTA - 411) & 511)])) + ((0.00518814661f * (fVec32[((IOTA - 171) & 511)] - fVec32[((IOTA - 406) & 511)])) + ((0.00427259132f * ((fVec32[((IOTA - 247) & 511)] - fVec32[((IOTA - 342) & 511)]) - fVec32[((IOTA - 403) & 511)])) + ((0.00360118411f * (fVec32[((IOTA - 178) & 511)] - fVec32[((IOTA - 401) & 511)])) + ((0.00213629566f * ((fVec32[((IOTA - 231) & 511)] + fVec32[((IOTA - 327) & 511)]) - fVec32[((IOTA - 399) & 511)])) + ((0.0022583697f * (fVec32[((IOTA - 258) & 511)] - fVec32[((IOTA - 397) & 511)])) + ((0.00286873989f * ((fVec32[((IOTA - 174) & 511)] + fVec32[((IOTA - 267) & 511)]) - fVec32[((IOTA - 395) & 511)])) + ((0.00198370311f * (fVec32[((IOTA - 183) & 511)] - fVec32[((IOTA - 394) & 511)])) + ((0.00125125889f * fVec32[((IOTA - 392) & 511)]) + ((0.00137333293f * fVec32[((IOTA - 391) & 511)]) + ((0.00146488845f * ((fVec32[((IOTA - 349) & 511)] + fVec32[((IOTA - 377) & 511)]) - fVec32[((IOTA - 388) & 511)])) + ((0.00201422162f * ((fVec32[((IOTA - 147) & 511)] + fVec32[((IOTA - 230) & 511)]) - fVec32[((IOTA - 373) & 511)])) + ((0.0035401471f * (fVec32[((IOTA - 214) & 511)] - fVec32[((IOTA - 372) & 511)])) + ((0.00543229468f * (fVec32[((IOTA - 283) & 511)] - fVec32[((IOTA - 370) & 511)])) + ((0.00418103579f * (fVec32[((IOTA - 222) & 511)] - fVec32[((IOTA - 367) & 511)])) + ((0.00241096225f * ((fVec32[((IOTA - 179) & 511)] + fVec32[((IOTA - 232) & 511)]) - fVec32[((IOTA - 366) & 511)])) + ((0.00250251777f * (fVec32[((IOTA - 201) & 511)] + fVec32[((IOTA - 364) & 511)])) + ((0.00445570238f * fVec32[((IOTA - 363) & 511)]) + ((0.00558488723f * fVec32[((IOTA - 362) & 511)]) + ((0.00314340647f * (fVec32[((IOTA - 240) & 511)] + fVec32[((IOTA - 360) & 511)])) + ((0.00344859157f * (fVec32[((IOTA - 175) & 511)] - fVec32[((IOTA - 358) & 511)])) + ((0.00790429395f * (fVec32[((IOTA - 137) & 511)] - fVec32[((IOTA - 356) & 511)])) + ((0.00729392376f * fVec32[((IOTA - 348) & 511)]) + ((0.0108035523f * fVec32[((IOTA - 347) & 511)]) + ((0.0102542192f * fVec32[((IOTA - 346) & 511)]) + ((0.00628681295f * (fVec32[((IOTA - 275) & 511)] + fVec32[((IOTA - 345) & 511)])) + ((0.0012817774f * (fVec32[((IOTA - 284) & 511)] + fVec32[((IOTA - 344) & 511)])) + ((0.00494399853f * (fVec32[((IOTA - 196) & 511)] - fVec32[((IOTA - 340) & 511)])) + ((0.00512710959f * fVec32[((IOTA - 334) & 511)]) + ((0.00793481246f * fVec32[((IOTA - 333) & 511)]) + ((0.00878933072f * fVec32[((IOTA - 332) & 511)]) + ((0.00894192327f * (fVec32[((IOTA - 68) & 511)] + fVec32[((IOTA - 331) & 511)])) + ((0.00860621966f * fVec32[((IOTA - 330) & 511)]) + ((0.00717184972f * fVec32[((IOTA - 329) & 511)]) + ((0.00393688772f * fVec32[((IOTA - 328) & 511)]) + ((0.00390636921f * (fVec32[((IOTA - 63) & 511)] + fVec32[((IOTA - 324) & 511)])) + ((0.00668355357f * fVec32[((IOTA - 323) & 511)]) + ((0.008087405f * fVec32[((IOTA - 322) & 511)]) + ((0.00546281319f * fVec32[((IOTA - 321) & 511)]) + ((0.00692770164f * (fVec32[((IOTA - 169) & 511)] + fVec32[((IOTA - 311) & 511)])) + ((0.00277718436f * ((fVec32[((IOTA - 173) & 511)] + fVec32[((IOTA - 325) & 511)]) - fVec32[((IOTA - 396) & 511)])) + ((0.0156865139f * (fVec32[((IOTA - 75) & 511)] - fVec32[((IOTA - 301) & 511)])) + ((0.0268257707f * fVec32[((IOTA - 305) & 511)]) + ((0.00845362712f * fVec32[((IOTA - 310) & 511)]) + ((0.0228583645f * fVec32[((IOTA - 307) & 511)]) + ((0.0294808801f * fVec32[((IOTA - 306) & 511)]) + ((0.00991851557f * fVec32[((IOTA - 309) & 511)]) + ((0.0147099216f * fVec32[((IOTA - 308) & 511)]) + ((0.00701925717f * fVec32[((IOTA - 296) & 511)]) + ((0.00640888698f * (fVec32[((IOTA - 163) & 511)] - fVec32[((IOTA - 290) & 511)])) + ((0.00396740623f * ((fVec32[((IOTA - 161) & 511)] + fVec32[((IOTA - 213) & 511)]) - fVec32[((IOTA - 285) & 511)])) + ((0.00766014587f * (fVec32[((IOTA - 281) & 511)] + fVec32[((IOTA - 282) & 511)])) + ((0.00656147953f * fVec32[((IOTA - 280) & 511)]) + ((0.00610370189f * fVec32[((IOTA - 279) & 511)]) + ((0.00659199804f * fVec32[((IOTA - 278) & 511)]) + ((0.00744651631f * fVec32[((IOTA - 277) & 511)]) + ((0.00747703481f * (fVec32[((IOTA - 89) & 511)] + fVec32[((IOTA - 276) & 511)])) + ((0.00479140598f * fVec32[((IOTA - 274) & 511)]) + ((0.00332651753f * (fVec32[((IOTA - 198) & 511)] + fVec32[((IOTA - 272) & 511)])) + ((0.00180059206f * fVec32[((IOTA - 271) & 511)]) + ((0.00424207281f * fVec32[((IOTA - 266) & 511)]) + ((0.00369273964f * (fVec32[((IOTA - 223) & 511)] + fVec32[((IOTA - 265) & 511)])) + ((0.00158696249f * fVec32[((IOTA - 256) & 511)]) + ((0.00109866634f * (fVec32[((IOTA - 113) & 511)] + fVec32[((IOTA - 252) & 511)])) + ((0.0142826624f * fVec32[((IOTA - 292) & 511)]) + ((0.0390942097f * fVec32[((IOTA - 294) & 511)]) + ((0.0297860652f * fVec32[((IOTA - 295) & 511)]) + ((0.00244148076f * (fVec32[((IOTA - 194) & 511)] + fVec32[((IOTA - 242) & 511)])) + ((0.00375377666f * ((fVec32[((IOTA - 77) & 511)] + fVec32[((IOTA - 172) & 511)]) + fVec32[((IOTA - 235) & 511)])) + ((0.00311288796f * (fVec32[((IOTA - 215) & 511)] + fVec32[((IOTA - 234) & 511)])) + ((0.0314340666f * fVec32[((IOTA - 293) & 511)]) + ((0.00189214759f * fVec32[((IOTA - 229) & 511)]) + ((0.00207525864f * (fVec32[((IOTA - 38) & 511)] + fVec32[((IOTA - 228) & 511)])) + ((0.00308236945f * fVec32[((IOTA - 226) & 511)]) + ((0.00317392498f * fVec32[((IOTA - 225) & 511)]) + ((0.00326548051f * fVec32[((IOTA - 224) & 511)]) + ((0.00430310983f * fVec32[((IOTA - 221) & 511)]) + ((0.00357066561f * fVec32[((IOTA - 219) & 511)]) + ((0.00305185094f * fVec32[((IOTA - 218) & 511)]) + ((0.00268562883f * fVec32[((IOTA - 216) & 511)]) + ((0.00466933195f * fVec32[((IOTA - 212) & 511)]) + ((0.00527970213f * (fVec32[((IOTA - 165) & 511)] + fVec32[((IOTA - 211) & 511)])) + ((0.00534073915f * fVec32[((IOTA - 210) & 511)]) + ((0.00524918362f * fVec32[((IOTA - 209) & 511)]) + ((0.00567644276f * fVec32[((IOTA - 207) & 511)]) + ((0.00616473891f * fVec32[((IOTA - 206) & 511)]) + ((0.00604266487f * fVec32[((IOTA - 204) & 511)]) + ((0.00497451704f * fVec32[((IOTA - 203) & 511)]) + ((0.00463881344f * fVec32[((IOTA - 197) & 511)]) + ((0.00411999878f * fVec32[((IOTA - 177) & 511)]) + ((0.00402844325f * fVec32[((IOTA - 176) & 511)]) + ((0.00634784997f * fVec32[((IOTA - 170) & 511)]) + ((0.00683614612f * fVec32[((IOTA - 168) & 511)]) + ((0.00622577593f * fVec32[((IOTA - 167) & 511)]) + ((0.00555436872f * fVec32[((IOTA - 166) & 511)]) + ((0.00570696127f * fVec32[((IOTA - 164) & 511)]) + ((0.00619525742f * fVec32[((IOTA - 162) & 511)]) + ((0.0038758507f * fVec32[((IOTA - 142) & 511)]) + ((0.0118717002f * fVec32[((IOTA - 136) & 511)]) + ((0.0118106632f * fVec32[((IOTA - 135) & 511)]) + ((0.0061342204f * fVec32[((IOTA - 134) & 511)]) + ((0.00714133121f * fVec32[((IOTA - 128) & 511)]) + ((0.00347911008f * fVec32[((IOTA - 122) & 511)]) + ((0.00341807306f * fVec32[((IOTA - 121) & 511)]) + ((0.00772118289f * (fVec32[((IOTA - 26) & 511)] - fVec32[((IOTA - 102) & 511)])) + ((0.00662251655f * (fVec32[((IOTA - 53) & 511)] - fVec32[((IOTA - 101) & 511)])) + ((0.0114749596f * fVec32[((IOTA - 88) & 511)]) + ((0.018097477f * fVec32[((IOTA - 83) & 511)]) + ((0.0287484359f * fVec32[((IOTA - 82) & 511)]) + ((0.017975403f * fVec32[((IOTA - 81) & 511)]) + ((0.0110171819f * fVec32[((IOTA - 76) & 511)]) + ((0.0162053294f * fVec32[((IOTA - 74) & 511)]) + ((0.012939848f * fVec32[((IOTA - 73) & 511)]) + ((0.00909451582f * fVec32[((IOTA - 72) & 511)]) + ((0.00680562761f * fVec32[((IOTA - 71) & 511)]) + ((0.00653096102f * fVec32[((IOTA - 70) & 511)]) + ((0.00799584948f * fVec32[((IOTA - 69) & 511)]) + ((0.00875881221f * fVec32[((IOTA - 67) & 511)]) + ((0.00912503432f * fVec32[((IOTA - 66) & 511)]) + ((0.0109866634f * fVec32[((IOTA - 65) & 511)]) + ((0.0101016266f * fVec32[((IOTA - 64) & 511)]) + ((0.0183721427f * fVec32[((IOTA - 56) & 511)]) + ((0.0326853245f * fVec32[((IOTA - 55) & 511)]) + ((0.0272835474f * fVec32[((IOTA - 54) & 511)]) + ((0.00820947904f * fVec32[((IOTA - 43) & 511)]) + ((0.0104068117f * fVec32[((IOTA - 42) & 511)]) + ((0.00296029542f * fVec32[((IOTA - 41) & 511)]) + ((0.012878811f * fVec32[((IOTA - 37) & 511)]) + ((0.0159306619f * fVec32[((IOTA - 36) & 511)]) + ((0.00726340525f * fVec32[((IOTA - 35) & 511)]) + ((0.0321054719f * fVec32[((IOTA - 28) & 511)]) + (((((((((fSlow84 * fTemp0) + (0.221350744f * fVec32[((IOTA - 1) & 511)])) + (0.34589678f * fVec32[((IOTA - 2) & 511)])) + (0.224646747f * fVec32[((IOTA - 3) & 511)])) + (0.0679952428f * fVec32[((IOTA - 8) & 511)])) + (0.105929747f * fVec32[((IOTA - 9) & 511)])) + (0.0508743562f * fVec32[((IOTA - 10) & 511)])) + (0.00976592302f * fVec32[((IOTA - 21) & 511)])) + (0.0415662117f * fVec32[((IOTA - 27) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (6.10370189e-05f * (((((fVec32[((IOTA - 291) & 511)] + fVec32[((IOTA - 365) & 511)]) - fVec32[((IOTA - 482) & 511)]) + fVec32[((IOTA - 491) & 511)]) - fVec32[((IOTA - 510) & 511)]) - fVec32[((IOTA - 511) & 511)]))) - (((0.000305185094f * (((((((((((((fVec32[((IOTA - 188) & 511)] + fVec32[((IOTA - 243) & 511)]) + fVec32[((IOTA - 375) & 511)]) + fVec32[((IOTA - 383) & 511)]) - fVec32[((IOTA - 421) & 511)]) - fVec32[((IOTA - 424) & 511)]) - fVec32[((IOTA - 453) & 511)]) - fVec32[((IOTA - 456) & 511)]) + fVec32[((IOTA - 460) & 511)]) + fVec32[((IOTA - 470) & 511)]) + fVec32[((IOTA - 480) & 511)]) - fVec32[((IOTA - 485) & 511)]) - fVec32[((IOTA - 489) & 511)]) + fVec32[((IOTA - 502) & 511)])) + ((0.000518814661f * fVec32[((IOTA - 501) & 511)]) + ((0.000274666585f * ((((fVec32[((IOTA - 359) & 511)] - fVec32[((IOTA - 457) & 511)]) - fVec32[((IOTA - 486) & 511)]) - fVec32[((IOTA - 494) & 511)]) + fVec32[((IOTA - 498) & 511)])) + ((0.000366222113f * (((((fVec32[((IOTA - 97) & 511)] - fVec32[((IOTA - 181) & 511)]) - fVec32[((IOTA - 335) & 511)]) + fVec32[((IOTA - 413) & 511)]) + fVec32[((IOTA - 433) & 511)]) - fVec32[((IOTA - 488) & 511)])) + ((0.000213629566f * (((((fVec32[((IOTA - 152) & 511)] - fVec32[((IOTA - 154) & 511)]) - fVec32[((IOTA - 429) & 511)]) - fVec32[((IOTA - 458) & 511)]) + fVec32[((IOTA - 471) & 511)]) + fVec32[((IOTA - 481) & 511)])) + ((0.000610370189f * (((((fVec32[((IOTA - 107) & 511)] + fVec32[((IOTA - 140) & 511)]) - fVec32[((IOTA - 185) & 511)]) - fVec32[((IOTA - 251) & 511)]) + fVec32[((IOTA - 447) & 511)]) + fVec32[((IOTA - 468) & 511)])) + ((0.000762962736f * fVec32[((IOTA - 467) & 511)]) + ((0.000732444227f * (((fVec32[((IOTA - 93) & 511)] + fVec32[((IOTA - 145) & 511)]) - fVec32[((IOTA - 245) & 511)]) - fVec32[((IOTA - 451) & 511)])) + ((0.00253303628f * (fVec32[((IOTA - 343) & 511)] + fVec32[((IOTA - 442) & 511)])) + ((0.00283822138f * ((((fVec32[((IOTA - 84) & 511)] - fVec32[((IOTA - 379) & 511)]) + fVec32[((IOTA - 409) & 511)]) + fVec32[((IOTA - 440) & 511)]) + fVec32[((IOTA - 441) & 511)])) + ((0.00274666585f * ((fVec32[((IOTA - 90) & 511)] - fVec32[((IOTA - 138) & 511)]) + fVec32[((IOTA - 439) & 511)])) + ((0.00265511032f * fVec32[((IOTA - 438) & 511)]) + ((0.000488296151f * fVec32[((IOTA - 434) & 511)]) + ((0.0019531846f * (fVec32[((IOTA - 398) & 511)] - fVec32[((IOTA - 417) & 511)])) + ((0.000793481246f * (((fVec32[((IOTA - 108) & 511)] + fVec32[((IOTA - 126) & 511)]) - fVec32[((IOTA - 146) & 511)]) - fVec32[((IOTA - 414) & 511)])) + ((0.00143436994f * fVec32[((IOTA - 412) & 511)]) + ((0.00491348002f * (((fVec32[((IOTA - 62) & 511)] + fVec32[((IOTA - 78) & 511)]) + fVec32[((IOTA - 339) & 511)]) + fVec32[((IOTA - 405) & 511)])) + ((0.00442518387f * fVec32[((IOTA - 404) & 511)]) + ((0.00415051728f * fVec32[((IOTA - 402) & 511)]) + ((0.00280770287f * ((fVec32[((IOTA - 111) & 511)] + fVec32[((IOTA - 150) & 511)]) + fVec32[((IOTA - 400) & 511)])) + ((0.00234992523f * (fVec32[((IOTA - 410) & 511)] + fVec32[((IOTA - 437) & 511)])) + ((0.00119022187f * (fVec32[((IOTA - 254) & 511)] - fVec32[((IOTA - 385) & 511)])) + ((0.0025940733f * (((fVec32[((IOTA - 133) & 511)] - fVec32[((IOTA - 227) & 511)]) + fVec32[((IOTA - 249) & 511)]) - fVec32[((IOTA - 378) & 511)])) + ((0.00488296151f * fVec32[((IOTA - 371) & 511)]) + ((0.00537125766f * (fVec32[((IOTA - 369) & 511)] - (fVec32[((IOTA - 208) & 511)] + fVec32[((IOTA - 361) & 511)]))) + ((0.00503555406f * fVec32[((IOTA - 368) & 511)]) + ((0.0058290353f * fVec32[((IOTA - 357) & 511)]) + ((0.00982696004f * (fVec32[((IOTA - 300) & 511)] + fVec32[((IOTA - 355) & 511)])) + ((0.0110782189f * fVec32[((IOTA - 354) & 511)]) + ((0.0116275521f * fVec32[((IOTA - 353) & 511)]) + ((0.0112918485f * fVec32[((IOTA - 352) & 511)]) + ((0.00924710836f * (fVec32[((IOTA - 288) & 511)] + fVec32[((IOTA - 351) & 511)])) + ((0.00473036896f * fVec32[((IOTA - 350) & 511)]) + ((0.00366222113f * fVec32[((IOTA - 408) & 511)]) + ((0.00552385021f * fVec32[((IOTA - 338) & 511)]) + ((0.00625629444f * fVec32[((IOTA - 337) & 511)]) + ((0.00436414685f * fVec32[((IOTA - 336) & 511)]) + ((0.00231940672f * (fVec32[((IOTA - 155) & 511)] - fVec32[((IOTA - 326) & 511)])) + ((0.00573747978f * fVec32[((IOTA - 319) & 511)]) + ((0.013061922f * fVec32[((IOTA - 318) & 511)]) + ((0.0204474013f * fVec32[((IOTA - 317) & 511)]) + ((0.0237434004f * fVec32[((IOTA - 316) & 511)]) + ((0.0221869573f * fVec32[((IOTA - 315) & 511)]) + ((0.0157780703f * fVec32[((IOTA - 314) & 511)]) + ((0.00650044251f * ((fVec32[((IOTA - 91) & 511)] - fVec32[((IOTA - 205) & 511)]) + fVec32[((IOTA - 313) & 511)])) + ((0.00177007355f * ((fVec32[((IOTA - 250) & 511)] - fVec32[((IOTA - 259) & 511)]) - fVec32[((IOTA - 312) & 511)])) + ((0.0133976256f * (fVec32[((IOTA - 22) & 511)] - fVec32[((IOTA - 304) & 511)])) + ((0.00592059083f * (fVec32[((IOTA - 115) & 511)] + fVec32[((IOTA - 303) & 511)])) + ((0.0176396985f * fVec32[((IOTA - 302) & 511)]) + ((0.0125736259f * (fVec32[((IOTA - 52) & 511)] + fVec32[((IOTA - 299) & 511)])) + ((0.004852443f * fVec32[((IOTA - 341) & 511)]) + ((0.00469985045f * fVec32[((IOTA - 407) & 511)]) + ((0.0197759941f * fVec32[((IOTA - 298) & 511)]) + ((0.0140995514f * fVec32[((IOTA - 297) & 511)]) + ((0.00827051606f * fVec32[((IOTA - 289) & 511)]) + ((0.00958281197f * fVec32[((IOTA - 287) & 511)]) + ((0.00805688649f * fVec32[((IOTA - 286) & 511)]) + ((0.00408948027f * ((((fVec32[((IOTA - 49) & 511)] - fVec32[((IOTA - 129) & 511)]) - fVec32[((IOTA - 220) & 511)]) - fVec32[((IOTA - 246) & 511)]) - fVec32[((IOTA - 273) & 511)])) + ((0.000152592547f * (fVec32[((IOTA - 98) & 511)] + fVec32[((IOTA - 269) & 511)])) + ((0.00247199927f * ((fVec32[((IOTA - 151) & 511)] - fVec32[((IOTA - 236) & 511)]) - fVec32[((IOTA - 264) & 511)])) + ((0.000915555283f * (fVec32[((IOTA - 139) & 511)] - fVec32[((IOTA - 263) & 511)])) + ((0.00228888821f * ((fVec32[((IOTA - 130) & 511)] - fVec32[((IOTA - 141) & 511)]) - fVec32[((IOTA - 257) & 511)])) + ((0.00149540696f * (fVec32[((IOTA - 239) & 511)] + fVec32[((IOTA - 244) & 511)])) + ((0.00454725791f * (fVec32[((IOTA - 238) & 511)] - fVec32[((IOTA - 241) & 511)])) + ((0.00262459181f * ((fVec32[((IOTA - 95) & 511)] - fVec32[((IOTA - 217) & 511)]) - fVec32[((IOTA - 233) & 511)])) + ((0.00363170262f * (fVec32[((IOTA - 109) & 511)] - fVec32[((IOTA - 202) & 511)])) + ((0.00399792474f * ((fVec32[((IOTA - 92) & 511)] + fVec32[((IOTA - 156) & 511)]) - fVec32[((IOTA - 195) & 511)])) + ((0.00115970336f * (fVec32[((IOTA - 123) & 511)] - fVec32[((IOTA - 190) & 511)])) + ((0.000640888698f * (fVec32[((IOTA - 144) & 511)] + fVec32[((IOTA - 186) & 511)])) + ((0.00216681417f * (fVec32[((IOTA - 159) & 511)] - fVec32[((IOTA - 199) & 511)])) + ((0.00372325815f * fVec32[((IOTA - 158) & 511)]) + ((0.00122074038f * (fVec32[((IOTA - 94) & 511)] - fVec32[((IOTA - 153) & 511)])) + ((0.00112918485f * fVec32[((IOTA - 149) & 511)]) + ((0.00848414563f * fVec32[((IOTA - 132) & 511)]) + ((0.00787377544f * fVec32[((IOTA - 131) & 511)]) + ((0.00509659108f * (fVec32[((IOTA - 110) & 511)] - fVec32[((IOTA - 127) & 511)])) + ((0.00433362834f * fVec32[((IOTA - 157) & 511)]) + ((0.00598162785f * fVec32[((IOTA - 125) & 511)]) + ((0.00595110934f * fVec32[((IOTA - 124) & 511)]) + ((0.00219733268f * fVec32[((IOTA - 119) & 511)]) + ((0.0057985168f * fVec32[((IOTA - 118) & 511)]) + ((0.00863673817f * fVec32[((IOTA - 117) & 511)]) + ((0.00888088625f * fVec32[((IOTA - 116) & 511)]) + ((0.00167851802f * (fVec32[((IOTA - 48) & 511)] + fVec32[((IOTA - 114) & 511)])) + ((0.00384533219f * fVec32[((IOTA - 106) & 511)]) + ((0.00762962736f * fVec32[((IOTA - 105) & 511)]) + ((0.00943021942f * fVec32[((IOTA - 104) & 511)]) + ((0.00946073793f * fVec32[((IOTA - 103) & 511)]) + ((0.00506607257f * fVec32[((IOTA - 100) & 511)]) + ((0.00238044374f * fVec32[((IOTA - 99) & 511)]) + ((0.0028992584f * fVec32[((IOTA - 96) & 511)]) + ((0.0145878475f * fVec32[((IOTA - 86) & 511)]) + ((0.0174260698f * fVec32[((IOTA - 85) & 511)]) + ((0.00134281442f * fVec32[((IOTA - 80) & 511)]) + ((0.00985747855f * fVec32[((IOTA - 79) & 511)]) + ((0.0166020691f * fVec32[((IOTA - 61) & 511)]) + ((0.0284432508f * fVec32[((IOTA - 60) & 511)]) + ((0.0336924344f * fVec32[((IOTA - 59) & 511)]) + ((0.025757622f * (fVec32[((IOTA - 18) & 511)] + fVec32[((IOTA - 58) & 511)])) + ((0.00585955381f * fVec32[((IOTA - 57) & 511)]) + ((0.0184026621f * fVec32[((IOTA - 51) & 511)]) + ((0.013000885f * fVec32[((IOTA - 50) & 511)]) + ((0.0115359966f * fVec32[((IOTA - 47) & 511)]) + ((0.0213629566f * fVec32[((IOTA - 46) & 511)]) + ((0.0167546626f * fVec32[((IOTA - 45) & 511)]) + ((0.00210577715f * fVec32[((IOTA - 44) & 511)]) + ((0.00698873866f * fVec32[((IOTA - 40) & 511)]) + ((0.00738547929f * fVec32[((IOTA - 39) & 511)]) + ((0.00973540451f * fVec32[((IOTA - 34) & 511)]) + ((0.0231025126f * fVec32[((IOTA - 33) & 511)]) + ((0.0384228043f * fVec32[((IOTA - 32) & 511)]) + ((0.0503555425f * fVec32[((IOTA - 31) & 511)]) + ((0.0411999896f * fVec32[((IOTA - 30) & 511)]) + ((0.00674459059f * fVec32[((IOTA - 29) & 511)]) + ((0.0326242857f * fVec32[((IOTA - 25) & 511)]) + ((0.0501724295f * fVec32[((IOTA - 24) & 511)]) + ((0.0436109491f * fVec32[((IOTA - 23) & 511)]) + ((0.00906399731f * fVec32[((IOTA - 20) & 511)]) + ((0.0324411765f * fVec32[((IOTA - 19) & 511)]) + ((0.0169682913f * fVec32[((IOTA - 17) & 511)]) + ((0.022766808f * fVec32[((IOTA - 16) & 511)]) + ((0.0262154005f * fVec32[((IOTA - 15) & 511)]) + ((0.0307626575f * fVec32[((IOTA - 14) & 511)]) + ((0.0299081393f * fVec32[((IOTA - 13) & 511)]) + (((((0.0617389455f * fVec32[((IOTA - 4) & 511)]) + (0.264473408f * fVec32[((IOTA - 5) & 511)])) + (0.265022725f * fVec32[((IOTA - 6) & 511)])) + (0.102603227f * fVec32[((IOTA - 7) & 511)])) + (0.0157475509f * fVec32[((IOTA - 12) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (3.05185094e-05f * ((((fVec32[((IOTA - 11) & 511)] - fVec32[((IOTA - 425) & 511)]) - fVec32[((IOTA - 428) & 511)]) + fVec32[((IOTA - 459) & 511)]) - fVec32[((IOTA - 509) & 511)])))))))))) : (iSlow2 ? (iSlow40 ? (iSlow59 ? (iSlow68 ? (iSlow73 ? (((0.000274666585f * (fVec31[((IOTA - 159) & 511)] + fVec31[((IOTA - 511) & 511)])) + ((0.000396740623f * fVec31[((IOTA - 510) & 511)]) + ((0.000518814661f * fVec31[((IOTA - 508) & 511)]) + ((0.00057985168f * (fVec31[((IOTA - 503) & 511)] + fVec31[((IOTA - 505) & 511)])) + ((0.00054933317f * fVec31[((IOTA - 504) & 511)]) + ((0.000854518265f * ((fVec31[((IOTA - 248) & 511)] - fVec31[((IOTA - 302) & 511)]) + fVec31[((IOTA - 498) & 511)])) + ((0.000976592302f * ((fVec31[((IOTA - 484) & 511)] + fVec31[((IOTA - 485) & 511)]) + fVec31[((IOTA - 496) & 511)])) + ((0.00106814783f * ((fVec31[((IOTA - 469) & 511)] + fVec31[((IOTA - 478) & 511)]) + fVec31[((IOTA - 495) & 511)])) + ((0.00115970336f * ((((fVec31[((IOTA - 262) & 511)] + fVec31[((IOTA - 395) & 511)]) + fVec31[((IOTA - 491) & 511)]) + fVec31[((IOTA - 492) & 511)]) + fVec31[((IOTA - 494) & 511)])) + ((0.000885036774f * ((fVec31[((IOTA - 483) & 511)] + fVec31[((IOTA - 486) & 511)]) + fVec31[((IOTA - 487) & 511)])) + ((0.000946073793f * ((fVec31[((IOTA - 474) & 511)] - ((fVec31[((IOTA - 184) & 511)] - fVec31[((IOTA - 435) & 511)]) - fVec31[((IOTA - 472) & 511)])) + fVec31[((IOTA - 482) & 511)])) + ((0.00125125889f * (((((fVec31[((IOTA - 254) & 511)] - (fVec31[((IOTA - 172) & 511)] + fVec31[((IOTA - 190) & 511)])) + fVec31[((IOTA - 289) & 511)]) + fVec31[((IOTA - 314) & 511)]) + fVec31[((IOTA - 394) & 511)]) + fVec31[((IOTA - 476) & 511)])) + ((0.00155644398f * (((fVec31[((IOTA - 20) & 511)] + fVec31[((IOTA - 459) & 511)]) + fVec31[((IOTA - 461) & 511)]) + fVec31[((IOTA - 467) & 511)])) + ((0.00164799951f * ((((((fVec31[((IOTA - 134) & 511)] - fVec31[((IOTA - 186) & 511)]) - fVec31[((IOTA - 199) & 511)]) + fVec31[((IOTA - 255) & 511)]) + fVec31[((IOTA - 263) & 511)]) + fVec31[((IOTA - 420) & 511)]) + fVec31[((IOTA - 466) & 511)])) + ((0.00143436994f * ((((fVec31[((IOTA - 146) & 511)] - fVec31[((IOTA - 183) & 511)]) + fVec31[((IOTA - 261) & 511)]) + fVec31[((IOTA - 460) & 511)]) + fVec31[((IOTA - 465) & 511)])) + ((0.00140385143f * ((fVec31[((IOTA - 320) & 511)] + fVec31[((IOTA - 424) & 511)]) + fVec31[((IOTA - 463) & 511)])) + ((0.00158696249f * ((fVec31[((IOTA - 286) & 511)] + fVec31[((IOTA - 450) & 511)]) + fVec31[((IOTA - 462) & 511)])) + ((0.0019226661f * (((((fVec31[((IOTA - 256) & 511)] + fVec31[((IOTA - 258) & 511)]) + fVec31[((IOTA - 271) & 511)]) + fVec31[((IOTA - 418) & 511)]) + fVec31[((IOTA - 440) & 511)]) + fVec31[((IOTA - 458) & 511)])) + ((0.00219733268f * (fVec31[((IOTA - 269) & 511)] + fVec31[((IOTA - 457) & 511)])) + ((0.0022583697f * (fVec31[((IOTA - 456) & 511)] - (fVec31[((IOTA - 221) & 511)] - fVec31[((IOTA - 443) & 511)]))) + ((0.00180059206f * ((((fVec31[((IOTA - 136) & 511)] - fVec31[((IOTA - 194) & 511)]) - fVec31[((IOTA - 232) & 511)]) + fVec31[((IOTA - 431) & 511)]) + fVec31[((IOTA - 451) & 511)])) + ((0.00177007355f * (((fVec31[((IOTA - 83) & 511)] - fVec31[((IOTA - 169) & 511)]) + fVec31[((IOTA - 379) & 511)]) + fVec31[((IOTA - 449) & 511)])) + ((0.00207525864f * ((fVec31[((IOTA - 267) & 511)] + fVec31[((IOTA - 270) & 511)]) + fVec31[((IOTA - 427) & 511)])) + ((0.00170903653f * (fVec31[((IOTA - 380) & 511)] + fVec31[((IOTA - 425) & 511)])) + ((0.00131229591f * (((fVec31[((IOTA - 246) & 511)] + fVec31[((IOTA - 251) & 511)]) + fVec31[((IOTA - 285) & 511)]) + fVec31[((IOTA - 423) & 511)])) + ((0.00167851802f * (fVec31[((IOTA - 419) & 511)] - (fVec31[((IOTA - 191) & 511)] - fVec31[((IOTA - 398) & 511)]))) + ((0.00231940672f * (((((fVec31[((IOTA - 149) & 511)] - fVec31[((IOTA - 214) & 511)]) - fVec31[((IOTA - 215) & 511)]) + fVec31[((IOTA - 281) & 511)]) + fVec31[((IOTA - 282) & 511)]) + fVec31[((IOTA - 417) & 511)])) + ((0.00308236945f * (fVec31[((IOTA - 356) & 511)] + fVec31[((IOTA - 415) & 511)])) + ((0.00332651753f * (fVec31[((IOTA - 322) & 511)] + fVec31[((IOTA - 414) & 511)])) + ((0.00314340647f * ((fVec31[((IOTA - 293) & 511)] + fVec31[((IOTA - 357) & 511)]) + fVec31[((IOTA - 412) & 511)])) + ((0.00296029542f * ((((fVec31[((IOTA - 265) & 511)] + fVec31[((IOTA - 278) & 511)]) + fVec31[((IOTA - 331) & 511)]) + fVec31[((IOTA - 332) & 511)]) + fVec31[((IOTA - 408) & 511)])) + ((0.00305185094f * ((fVec31[((IOTA - 135) & 511)] + fVec31[((IOTA - 300) & 511)]) + fVec31[((IOTA - 406) & 511)])) + ((0.00326548051f * (fVec31[((IOTA - 330) & 511)] + fVec31[((IOTA - 405) & 511)])) + ((0.00366222113f * (fVec31[((IOTA - 147) & 511)] + fVec31[((IOTA - 402) & 511)])) + ((0.00357066561f * ((fVec31[((IOTA - 294) & 511)] + fVec31[((IOTA - 368) & 511)]) + fVec31[((IOTA - 401) & 511)])) + ((0.003234962f * ((fVec31[((IOTA - 91) & 511)] + fVec31[((IOTA - 390) & 511)]) + fVec31[((IOTA - 400) & 511)])) + ((0.00338755455f * fVec31[((IOTA - 389) & 511)]) + ((0.00433362834f * fVec31[((IOTA - 386) & 511)]) + ((0.00320444349f * (fVec31[((IOTA - 338) & 511)] + fVec31[((IOTA - 384) & 511)])) + ((0.00247199927f * (fVec31[((IOTA - 274) & 511)] + fVec31[((IOTA - 382) & 511)])) + ((0.0045167394f * fVec31[((IOTA - 377) & 511)]) + ((0.00576799829f * (fVec31[((IOTA - 364) & 511)] + fVec31[((IOTA - 376) & 511)])) + ((0.00616473891f * fVec31[((IOTA - 375) & 511)]) + ((0.0058290353f * fVec31[((IOTA - 374) & 511)]) + ((0.00503555406f * fVec31[((IOTA - 373) & 511)]) + ((0.00424207281f * (fVec31[((IOTA - 348) & 511)] + fVec31[((IOTA - 367) & 511)])) + ((0.00463881344f * fVec31[((IOTA - 366) & 511)]) + ((0.00589007232f * fVec31[((IOTA - 363) & 511)]) + ((0.00534073915f * fVec31[((IOTA - 362) & 511)]) + ((0.00466933195f * fVec31[((IOTA - 361) & 511)]) + ((0.00430310983f * fVec31[((IOTA - 360) & 511)]) + ((0.00418103579f * (fVec31[((IOTA - 148) & 511)] + fVec31[((IOTA - 354) & 511)])) + ((0.00448622089f * (fVec31[((IOTA - 352) & 511)] + fVec31[((IOTA - 353) & 511)])) + ((0.00268562883f * fVec31[((IOTA - 383) & 511)]) + ((0.00100711081f * fVec31[((IOTA - 396) & 511)]) + ((0.00454725791f * fVec31[((IOTA - 349) & 511)]) + ((0.00292977691f * fVec31[((IOTA - 339) & 511)]) + ((0.00216681417f * (((fVec31[((IOTA - 272) & 511)] + fVec31[((IOTA - 381) & 511)]) + fVec31[((IOTA - 428) & 511)]) + fVec31[((IOTA - 430) & 511)])) + ((0.00411999878f * fVec31[((IOTA - 329) & 511)]) + ((0.00518814661f * fVec31[((IOTA - 328) & 511)]) + ((0.00604266487f * fVec31[((IOTA - 327) & 511)]) + ((0.0071108127f * fVec31[((IOTA - 325) & 511)]) + ((0.00665303506f * fVec31[((IOTA - 324) & 511)]) + ((0.0051576281f * fVec31[((IOTA - 323) & 511)]) + ((0.000183111057f * fVec31[((IOTA - 317) & 511)]) + ((0.000366222113f * fVec31[((IOTA - 315) & 511)]) + ((0.00244148076f * (fVec31[((IOTA - 280) & 511)] + fVec31[((IOTA - 313) & 511)])) + ((0.00659199804f * fVec31[((IOTA - 310) & 511)]) + ((0.00650044251f * fVec31[((IOTA - 309) & 511)]) + ((0.00567644276f * fVec31[((IOTA - 308) & 511)]) + ((0.00488296151f * fVec31[((IOTA - 307) & 511)]) + ((0.00390636921f * fVec31[((IOTA - 306) & 511)]) + ((0.00473036896f * fVec31[((IOTA - 298) & 511)]) + ((0.00524918362f * fVec31[((IOTA - 297) & 511)]) + ((0.00512710959f * (fVec31[((IOTA - 21) & 511)] + fVec31[((IOTA - 296) & 511)])) + ((0.00280770287f * fVec31[((IOTA - 279) & 511)]) + ((0.00265511032f * fVec31[((IOTA - 277) & 511)]) + ((0.000213629566f * (fVec31[((IOTA - 201) & 511)] - fVec31[((IOTA - 241) & 511)])) + ((0.000244148076f * fVec31[((IOTA - 202) & 511)]) + ((0.01126133f * (fVec31[((IOTA - 67) & 511)] - fVec31[((IOTA - 113) & 511)])) + ((0.00469985045f * fVec31[((IOTA - 95) & 511)]) + ((0.011383404f * fVec31[((IOTA - 94) & 511)]) + ((0.0139469588f * fVec31[((IOTA - 93) & 511)]) + ((0.0102542192f * fVec31[((IOTA - 92) & 511)]) + ((0.0181890316f * fVec31[((IOTA - 82) & 511)]) + ((0.0226142164f * fVec31[((IOTA - 81) & 511)]) + ((0.0117191076f * fVec31[((IOTA - 80) & 511)]) + ((0.00698873866f * fVec31[((IOTA - 70) & 511)]) + ((0.0121768853f * fVec31[((IOTA - 69) & 511)]) + ((0.0130314035f * fVec31[((IOTA - 68) & 511)]) + ((0.00643940549f * fVec31[((IOTA - 66) & 511)]) + ((0.0152897732f * fVec31[((IOTA - 57) & 511)]) + ((0.0218512528f * fVec31[((IOTA - 56) & 511)]) + ((0.0136722922f * fVec31[((IOTA - 55) & 511)]) + ((0.00607318338f * fVec31[((IOTA - 43) & 511)]) + ((0.0127262184f * fVec31[((IOTA - 42) & 511)]) + ((0.0202642903f * ((fVec31[((IOTA - 9) & 511)] - fVec31[((IOTA - 19) & 511)]) + fVec31[((IOTA - 41) & 511)])) + ((0.0298471022f * fVec31[((IOTA - 40) & 511)]) + ((0.0380260646f * fVec31[((IOTA - 39) & 511)]) + ((0.032898955f * fVec31[((IOTA - 38) & 511)]) + (((0.0131839961f * fVec31[((IOTA - 14) & 511)]) + ((0.0350047313f * fVec31[((IOTA - 13) & 511)]) + ((0.0401623584f * fVec31[((IOTA - 12) & 511)]) + ((0.0446790978f * fVec31[((IOTA - 11) & 511)]) + ((0.0420850255f * fVec31[((IOTA - 10) & 511)]) + ((0.141178623f * fVec31[((IOTA - 4) & 511)]) + ((0.334330261f * fVec31[((IOTA - 3) & 511)]) + ((0.332468629f * fVec31[((IOTA - 2) & 511)]) + ((0.185613573f * fVec31[((IOTA - 1) & 511)]) + ((fSlow76 * fTemp0) + ((((0.032776881f * fVec31[((IOTA - 27) & 511)]) + (0.058656577f * fVec31[((IOTA - 28) & 511)])) + (0.0522476882f * fVec31[((IOTA - 29) & 511)])) + (0.0103152562f * fVec31[((IOTA - 30) & 511)])))))))))))) + (0.0159611814f * fVec31[((IOTA - 37) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000610370189f * (((fVec31[((IOTA - 238) & 511)] + fVec31[((IOTA - 240) & 511)]) - fVec31[((IOTA - 243) & 511)]) - fVec31[((IOTA - 507) & 511)])) + ((0.000640888698f * ((fVec31[((IOTA - 239) & 511)] + fVec31[((IOTA - 304) & 511)]) - fVec31[((IOTA - 506) & 511)])) + ((0.000671407208f * (((fVec31[((IOTA - 170) & 511)] - fVec31[((IOTA - 318) & 511)]) - fVec31[((IOTA - 501) & 511)]) - fVec31[((IOTA - 502) & 511)])) + ((0.000701925717f * ((fVec31[((IOTA - 234) & 511)] + fVec31[((IOTA - 237) & 511)]) - fVec31[((IOTA - 500) & 511)])) + ((0.000762962736f * (((((fVec31[((IOTA - 188) & 511)] + fVec31[((IOTA - 225) & 511)]) + fVec31[((IOTA - 235) & 511)]) - fVec31[((IOTA - 244) & 511)]) - fVec31[((IOTA - 249) & 511)]) - fVec31[((IOTA - 499) & 511)])) + ((0.000915555283f * (fVec31[((IOTA - 145) & 511)] - fVec31[((IOTA - 497) & 511)])) + ((0.00119022187f * (((((fVec31[((IOTA - 224) & 511)] + fVec31[((IOTA - 226) & 511)]) - fVec31[((IOTA - 252) & 511)]) - fVec31[((IOTA - 475) & 511)]) - fVec31[((IOTA - 479) & 511)]) - fVec31[((IOTA - 493) & 511)])) + ((0.00122074038f * ((((fVec31[((IOTA - 58) & 511)] + fVec31[((IOTA - 211) & 511)]) - fVec31[((IOTA - 247) & 511)]) - fVec31[((IOTA - 489) & 511)]) - fVec31[((IOTA - 490) & 511)])) + ((0.00103762932f * (((((((fVec31[((IOTA - 105) & 511)] + fVec31[((IOTA - 133) & 511)]) + fVec31[((IOTA - 233) & 511)]) - fVec31[((IOTA - 245) & 511)]) - fVec31[((IOTA - 253) & 511)]) - fVec31[((IOTA - 434) & 511)]) - fVec31[((IOTA - 437) & 511)]) - fVec31[((IOTA - 488) & 511)])) + ((0.00112918485f * (fVec31[((IOTA - 203) & 511)] - fVec31[((IOTA - 481) & 511)])) + ((0.0012817774f * ((((fVec31[((IOTA - 185) & 511)] - fVec31[((IOTA - 301) & 511)]) - fVec31[((IOTA - 464) & 511)]) - fVec31[((IOTA - 468) & 511)]) - fVec31[((IOTA - 480) & 511)])) + ((0.00109866634f * (((((((fVec31[((IOTA - 137) & 511)] - fVec31[((IOTA - 250) & 511)]) - fVec31[((IOTA - 319) & 511)]) - fVec31[((IOTA - 397) & 511)]) - fVec31[((IOTA - 433) & 511)]) - fVec31[((IOTA - 470) & 511)]) - fVec31[((IOTA - 471) & 511)]) - fVec31[((IOTA - 477) & 511)])) + ((0.000823999755f * ((fVec31[((IOTA - 236) & 511)] - fVec31[((IOTA - 436) & 511)]) - fVec31[((IOTA - 473) & 511)])) + ((0.00238044374f * ((fVec31[((IOTA - 180) & 511)] + fVec31[((IOTA - 196) & 511)]) - fVec31[((IOTA - 455) & 511)])) + ((0.0025940733f * ((((((fVec31[((IOTA - 65) & 511)] + fVec31[((IOTA - 179) & 511)]) + fVec31[((IOTA - 181) & 511)]) - fVec31[((IOTA - 266) & 511)]) - fVec31[((IOTA - 342) & 511)]) - fVec31[((IOTA - 343) & 511)]) - fVec31[((IOTA - 454) & 511)])) + ((0.00262459181f * (fVec31[((IOTA - 230) & 511)] - fVec31[((IOTA - 453) & 511)])) + ((0.00228888821f * (((((fVec31[((IOTA - 182) & 511)] - fVec31[((IOTA - 276) & 511)]) - fVec31[((IOTA - 370) & 511)]) - fVec31[((IOTA - 429) & 511)]) - fVec31[((IOTA - 444) & 511)]) - fVec31[((IOTA - 452) & 511)])) + ((0.00189214759f * ((((fVec31[((IOTA - 198) & 511)] - fVec31[((IOTA - 257) & 511)]) - fVec31[((IOTA - 305) & 511)]) - fVec31[((IOTA - 441) & 511)]) - fVec31[((IOTA - 448) & 511)])) + ((0.00183111057f * ((fVec31[((IOTA - 303) & 511)] - fVec31[((IOTA - 446) & 511)]) - fVec31[((IOTA - 447) & 511)])) + ((0.00204474013f * (fVec31[((IOTA - 213) & 511)] - fVec31[((IOTA - 445) & 511)])) + ((0.00201422162f * (((((fVec31[((IOTA - 96) & 511)] + fVec31[((IOTA - 223) & 511)]) - fVec31[((IOTA - 259) & 511)]) - fVec31[((IOTA - 321) & 511)]) - fVec31[((IOTA - 392) & 511)]) - fVec31[((IOTA - 442) & 511)])) + ((0.00186162908f * (((fVec31[((IOTA - 227) & 511)] - fVec31[((IOTA - 260) & 511)]) - fVec31[((IOTA - 287) & 511)]) - fVec31[((IOTA - 439) & 511)])) + ((0.00146488845f * (((fVec31[((IOTA - 193) & 511)] - fVec31[((IOTA - 393) & 511)]) - fVec31[((IOTA - 422) & 511)]) - fVec31[((IOTA - 438) & 511)])) + ((0.00134281442f * (fVec31[((IOTA - 187) & 511)] - fVec31[((IOTA - 432) & 511)])) + ((0.00198370311f * ((fVec31[((IOTA - 210) & 511)] - fVec31[((IOTA - 268) & 511)]) - fVec31[((IOTA - 426) & 511)])) + ((0.001617481f * ((fVec31[((IOTA - 192) & 511)] - fVec31[((IOTA - 288) & 511)]) - fVec31[((IOTA - 421) & 511)])) + ((0.00271614734f * ((fVec31[((IOTA - 107) & 511)] - fVec31[((IOTA - 369) & 511)]) - fVec31[((IOTA - 416) & 511)])) + ((0.00335703604f * (fVec31[((IOTA - 36) & 511)] - fVec31[((IOTA - 413) & 511)])) + ((0.00283822138f * ((fVec31[((IOTA - 168) & 511)] - fVec31[((IOTA - 292) & 511)]) - fVec31[((IOTA - 411) & 511)])) + ((0.00274666585f * (((fVec31[((IOTA - 216) & 511)] - fVec31[((IOTA - 341) & 511)]) - fVec31[((IOTA - 391) & 511)]) - fVec31[((IOTA - 410) & 511)])) + ((0.00286873989f * ((((((fVec31[((IOTA - 123) & 511)] + fVec31[((IOTA - 204) & 511)]) - fVec31[((IOTA - 333) & 511)]) - fVec31[((IOTA - 334) & 511)]) - fVec31[((IOTA - 340) & 511)]) - fVec31[((IOTA - 378) & 511)]) - fVec31[((IOTA - 409) & 511)])) + ((0.00299081393f * ((fVec31[((IOTA - 209) & 511)] - fVec31[((IOTA - 344) & 511)]) - fVec31[((IOTA - 407) & 511)])) + ((0.00347911008f * (fVec31[((IOTA - 207) & 511)] - fVec31[((IOTA - 404) & 511)])) + ((0.00360118411f * (((fVec31[((IOTA - 127) & 511)] - fVec31[((IOTA - 336) & 511)]) - fVec31[((IOTA - 337) & 511)]) - fVec31[((IOTA - 403) & 511)])) + ((0.00256355479f * ((fVec31[((IOTA - 229) & 511)] - fVec31[((IOTA - 264) & 511)]) - fVec31[((IOTA - 399) & 511)])) + ((0.00363170262f * (((fVec31[((IOTA - 132) & 511)] + fVec31[((IOTA - 206) & 511)]) - fVec31[((IOTA - 358) & 511)]) - fVec31[((IOTA - 388) & 511)])) + ((0.00405896176f * (fVec31[((IOTA - 176) & 511)] - fVec31[((IOTA - 387) & 511)])) + ((0.00399792474f * (fVec31[((IOTA - 138) & 511)] - fVec31[((IOTA - 385) & 511)])) + ((0.00384533219f * (((fVec31[((IOTA - 218) & 511)] - fVec31[((IOTA - 312) & 511)]) - fVec31[((IOTA - 347) & 511)]) - fVec31[((IOTA - 372) & 511)])) + ((0.00277718436f * (fVec31[((IOTA - 90) & 511)] - fVec31[((IOTA - 371) & 511)])) + ((0.00521866512f * (fVec31[((IOTA - 118) & 511)] - fVec31[((IOTA - 365) & 511)])) + ((0.00408948027f * ((fVec31[((IOTA - 126) & 511)] - fVec31[((IOTA - 299) & 511)]) - fVec31[((IOTA - 359) & 511)])) + ((0.0035401471f * (fVec31[((IOTA - 217) & 511)] - fVec31[((IOTA - 355) & 511)])) + ((0.00445570238f * ((fVec31[((IOTA - 71) & 511)] + fVec31[((IOTA - 121) & 511)]) - fVec31[((IOTA - 351) & 511)])) + ((0.00460829493f * (fVec31[((IOTA - 143) & 511)] - fVec31[((IOTA - 350) & 511)])) + ((0.00369273964f * (fVec31[((IOTA - 205) & 511)] - fVec31[((IOTA - 346) & 511)])) + ((0.00341807306f * (fVec31[((IOTA - 175) & 511)] - fVec31[((IOTA - 345) & 511)])) + ((0.00317392498f * (fVec31[((IOTA - 219) & 511)] - fVec31[((IOTA - 335) & 511)])) + ((0.00671407208f * (fVec31[((IOTA - 152) & 511)] - fVec31[((IOTA - 326) & 511)])) + ((3.05185094e-05f * fVec31[((IOTA - 316) & 511)]) + ((0.00543229468f * (fVec31[((IOTA - 130) & 511)] - fVec31[((IOTA - 311) & 511)])) + ((0.00436414685f * ((fVec31[((IOTA - 124) & 511)] + fVec31[((IOTA - 166) & 511)]) - fVec31[((IOTA - 295) & 511)])) + ((0.00222785119f * ((fVec31[((IOTA - 173) & 511)] - fVec31[((IOTA - 275) & 511)]) - fVec31[((IOTA - 291) & 511)])) + ((0.00149540696f * (fVec31[((IOTA - 150) & 511)] - fVec31[((IOTA - 290) & 511)])) + ((0.00152592547f * (fVec31[((IOTA - 106) & 511)] - fVec31[((IOTA - 284) & 511)])) + ((0.00210577715f * ((fVec31[((IOTA - 161) & 511)] + fVec31[((IOTA - 197) & 511)]) - fVec31[((IOTA - 283) & 511)])) + ((0.00241096225f * (((fVec31[((IOTA - 220) & 511)] + fVec31[((IOTA - 222) & 511)]) + fVec31[((IOTA - 231) & 511)]) - fVec31[((IOTA - 273) & 511)])) + ((0.000305185094f * (fVec31[((IOTA - 158) & 511)] - fVec31[((IOTA - 242) & 511)])) + ((0.00234992523f * (fVec31[((IOTA - 195) & 511)] + fVec31[((IOTA - 228) & 511)])) + ((0.00137333293f * fVec31[((IOTA - 212) & 511)]) + ((0.000793481246f * fVec31[((IOTA - 200) & 511)]) + ((0.000732444227f * fVec31[((IOTA - 189) & 511)]) + ((0.0042115543f * (fVec31[((IOTA - 162) & 511)] + fVec31[((IOTA - 177) & 511)])) + ((0.0028992584f * fVec31[((IOTA - 174) & 511)]) + ((0.000427259132f * fVec31[((IOTA - 171) & 511)]) + ((0.00537125766f * fVec31[((IOTA - 165) & 511)]) + ((0.00610370189f * ((fVec31[((IOTA - 79) & 511)] + fVec31[((IOTA - 140) & 511)]) + fVec31[((IOTA - 164) & 511)])) + ((0.00570696127f * fVec31[((IOTA - 163) & 511)]) + ((0.0019531846f * fVec31[((IOTA - 157) & 511)]) + ((0.00442518387f * fVec31[((IOTA - 156) & 511)]) + ((0.00637836847f * fVec31[((IOTA - 155) & 511)]) + ((0.00717184972f * (fVec31[((IOTA - 153) & 511)] + fVec31[((IOTA - 154) & 511)])) + ((0.00350962859f * (fVec31[((IOTA - 167) & 511)] + fVec31[((IOTA - 178) & 511)])) + ((0.00344859157f * fVec31[((IOTA - 208) & 511)]) + ((0.00497451704f * fVec31[((IOTA - 151) & 511)]) + ((0.00311288796f * fVec31[((IOTA - 144) & 511)]) + ((0.0054933317f * fVec31[((IOTA - 142) & 511)]) + ((0.00592059083f * fVec31[((IOTA - 141) & 511)]) + ((0.00506607257f * (fVec31[((IOTA - 108) & 511)] + fVec31[((IOTA - 131) & 511)])) + ((0.00500503555f * (fVec31[((IOTA - 54) & 511)] + fVec31[((IOTA - 129) & 511)])) + ((0.00402844325f * fVec31[((IOTA - 128) & 511)]) + ((0.00476088747f * fVec31[((IOTA - 125) & 511)]) + ((0.00250251777f * fVec31[((IOTA - 122) & 511)]) + ((0.00701925717f * fVec31[((IOTA - 120) & 511)]) + ((0.00726340525f * (fVec31[((IOTA - 97) & 511)] + fVec31[((IOTA - 119) & 511)])) + ((0.00381481368f * fVec31[((IOTA - 117) & 511)]) + ((0.00546281319f * fVec31[((IOTA - 116) & 511)]) + ((0.00878933072f * fVec31[((IOTA - 115) & 511)]) + ((0.0108340709f * fVec31[((IOTA - 114) & 511)]) + ((0.00564592425f * fVec31[((IOTA - 139) & 511)]) + ((0.0110782189f * fVec31[((IOTA - 112) & 511)]) + ((0.0105899228f * fVec31[((IOTA - 111) & 511)]) + ((0.00933866389f * fVec31[((IOTA - 110) & 511)]) + ((0.00756859034f * fVec31[((IOTA - 109) & 511)]) + ((0.00173955504f * fVec31[((IOTA - 104) & 511)]) + ((0.00491348002f * fVec31[((IOTA - 103) & 511)]) + ((0.0104068117f * fVec31[((IOTA - 102) & 511)]) + ((0.0150761437f * fVec31[((IOTA - 101) & 511)]) + ((0.016235847f * fVec31[((IOTA - 100) & 511)]) + ((0.014679403f * fVec31[((IOTA - 99) & 511)]) + ((0.0112918485f * fVec31[((IOTA - 98) & 511)]) + ((0.00714133121f * fVec31[((IOTA - 89) & 511)]) + ((0.0120242927f * fVec31[((IOTA - 88) & 511)]) + ((0.01803644f * fVec31[((IOTA - 87) & 511)]) + ((0.024506364f * fVec31[((IOTA - 86) & 511)]) + ((0.0252082888f * fVec31[((IOTA - 85) & 511)]) + ((0.01617481f * fVec31[((IOTA - 84) & 511)]) + ((0.0174871068f * fVec31[((IOTA - 78) & 511)]) + ((0.0184636991f * fVec31[((IOTA - 77) & 511)]) + ((0.0137943663f * fVec31[((IOTA - 76) & 511)]) + ((0.012939848f * fVec31[((IOTA - 75) & 511)]) + ((0.0166936256f * fVec31[((IOTA - 74) & 511)]) + ((0.0201116987f * fVec31[((IOTA - 73) & 511)]) + ((0.0159306619f * fVec31[((IOTA - 72) & 511)]) + ((0.0133365886f * fVec31[((IOTA - 64) & 511)]) + ((0.0241096225f * fVec31[((IOTA - 63) & 511)]) + ((0.034272287f * fVec31[((IOTA - 62) & 511)]) + ((0.0387279876f * fVec31[((IOTA - 61) & 511)]) + ((0.0333872512f * fVec31[((IOTA - 60) & 511)]) + ((0.019226661f * fVec31[((IOTA - 59) & 511)]) + ((0.0228888821f * fVec31[((IOTA - 53) & 511)]) + ((0.0311288796f * fVec31[((IOTA - 52) & 511)]) + ((0.0297860652f * fVec31[((IOTA - 51) & 511)]) + ((0.0236518458f * fVec31[((IOTA - 50) & 511)]) + ((0.021210365f * fVec31[((IOTA - 49) & 511)]) + ((0.0234992523f * fVec31[((IOTA - 48) & 511)]) + ((0.02438429f * fVec31[((IOTA - 47) & 511)]) + ((0.021271402f * fVec31[((IOTA - 46) & 511)]) + ((0.0134586627f * fVec31[((IOTA - 45) & 511)]) + ((((((9.15555283e-05f * fVec31[((IOTA - 22) & 511)]) + ((0.0310068056f * fVec31[((IOTA - 18) & 511)]) + ((0.0454725809f * fVec31[((IOTA - 17) & 511)]) + ((0.0351878405f * fVec31[((IOTA - 16) & 511)]) + ((0.0181585141f * fVec31[((IOTA - 15) & 511)]) + ((0.0666524246f * fVec31[((IOTA - 8) & 511)]) + ((0.178106025f * fVec31[((IOTA - 7) & 511)]) + ((0.230353713f * fVec31[((IOTA - 6) & 511)]) + ((0.11023286f * fVec31[((IOTA - 5) & 511)]) + ((0.0328073986f * fVec31[((IOTA - 23) & 511)]) + ((0.0507522821f * fVec31[((IOTA - 25) & 511)]) + ((0.0283211768f * fVec31[((IOTA - 31) & 511)]) + (((0.0562150963f * fVec31[((IOTA - 24) & 511)]) + (0.0111697745f * fVec31[((IOTA - 26) & 511)])) + (0.0408032462f * fVec31[((IOTA - 32) & 511)])))))))))))))) + (0.0361949541f * fVec31[((IOTA - 33) & 511)])) + (0.0297250282f * fVec31[((IOTA - 34) & 511)])) + (0.0209967345f * fVec31[((IOTA - 35) & 511)])) + (0.00427259132f * fVec31[((IOTA - 44) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000457777642f * (fVec31[((IOTA - 160) & 511)] - fVec31[((IOTA - 509) & 511)])))) : (((0.00109866634f * (fVec30[((IOTA - 416) & 511)] - fVec30[((IOTA - 510) & 511)])) + ((0.00122074038f * ((((((fVec30[((IOTA - 322) & 511)] + fVec30[((IOTA - 328) & 511)]) + fVec30[((IOTA - 371) & 511)]) + fVec30[((IOTA - 397) & 511)]) - fVec30[((IOTA - 435) & 511)]) + fVec30[((IOTA - 453) & 511)]) - fVec30[((IOTA - 509) & 511)])) + ((0.00149540696f * ((fVec30[((IOTA - 219) & 511)] - fVec30[((IOTA - 499) & 511)]) - fVec30[((IOTA - 508) & 511)])) + ((0.0019226661f * (((fVec30[((IOTA - 332) & 511)] + fVec30[((IOTA - 407) & 511)]) - fVec30[((IOTA - 491) & 511)]) - fVec30[((IOTA - 507) & 511)])) + ((0.00231940672f * ((fVec30[((IOTA - 275) & 511)] + fVec30[((IOTA - 310) & 511)]) - fVec30[((IOTA - 506) & 511)])) + ((0.00268562883f * (fVec30[((IOTA - 343) & 511)] - fVec30[((IOTA - 505) & 511)])) + ((0.00286873989f * ((((fVec30[((IOTA - 215) & 511)] + fVec30[((IOTA - 272) & 511)]) + fVec30[((IOTA - 285) & 511)]) + fVec30[((IOTA - 405) & 511)]) - fVec30[((IOTA - 504) & 511)])) + ((0.00292977691f * (fVec30[((IOTA - 375) & 511)] - fVec30[((IOTA - 503) & 511)])) + ((0.00253303628f * ((fVec30[((IOTA - 247) & 511)] - fVec30[((IOTA - 460) & 511)]) - fVec30[((IOTA - 501) & 511)])) + ((0.00204474013f * (fVec30[((IOTA - 301) & 511)] - fVec30[((IOTA - 500) & 511)])) + ((0.000976592302f * (fVec30[((IOTA - 330) & 511)] - fVec30[((IOTA - 498) & 511)])) + ((0.000762962736f * (((((fVec30[((IOTA - 224) & 511)] - fVec30[((IOTA - 389) & 511)]) - fVec30[((IOTA - 390) & 511)]) - fVec30[((IOTA - 441) & 511)]) - fVec30[((IOTA - 447) & 511)]) - fVec30[((IOTA - 496) & 511)])) + ((0.00198370311f * ((fVec30[((IOTA - 316) & 511)] - fVec30[((IOTA - 489) & 511)]) - fVec30[((IOTA - 490) & 511)])) + ((0.00189214759f * ((fVec30[((IOTA - 340) & 511)] + fVec30[((IOTA - 374) & 511)]) - fVec30[((IOTA - 488) & 511)])) + ((0.00173955504f * (((fVec30[((IOTA - 327) & 511)] + fVec30[((IOTA - 399) & 511)]) - fVec30[((IOTA - 459) & 511)]) - fVec30[((IOTA - 487) & 511)])) + ((0.00155644398f * (((fVec30[((IOTA - 302) & 511)] - fVec30[((IOTA - 355) & 511)]) - fVec30[((IOTA - 422) & 511)]) - fVec30[((IOTA - 486) & 511)])) + ((0.00152592547f * ((fVec30[((IOTA - 264) & 511)] - fVec30[((IOTA - 484) & 511)]) - fVec30[((IOTA - 485) & 511)])) + ((0.00277718436f * (fVec30[((IOTA - 359) & 511)] - fVec30[((IOTA - 476) & 511)])) + ((0.0028992584f * (fVec30[((IOTA - 271) & 511)] - fVec30[((IOTA - 475) & 511)])) + ((0.00271614734f * ((((fVec30[((IOTA - 283) & 511)] + fVec30[((IOTA - 309) & 511)]) + fVec30[((IOTA - 337) & 511)]) - fVec30[((IOTA - 465) & 511)]) - fVec30[((IOTA - 474) & 511)])) + ((0.00222785119f * (((fVec30[((IOTA - 249) & 511)] + fVec30[((IOTA - 313) & 511)]) + fVec30[((IOTA - 333) & 511)]) - fVec30[((IOTA - 473) & 511)])) + ((0.00106814783f * (fVec30[((IOTA - 372) & 511)] - fVec30[((IOTA - 471) & 511)])) + ((0.000671407208f * ((fVec30[((IOTA - 213) & 511)] - fVec30[((IOTA - 468) & 511)]) - fVec30[((IOTA - 470) & 511)])) + ((0.000518814661f * ((fVec30[((IOTA - 395) & 511)] - fVec30[((IOTA - 451) & 511)]) - fVec30[((IOTA - 469) & 511)])) + ((0.00186162908f * (((fVec30[((IOTA - 248) & 511)] + fVec30[((IOTA - 303) & 511)]) - fVec30[((IOTA - 423) & 511)]) - fVec30[((IOTA - 466) & 511)])) + ((0.00344859157f * (fVec30[((IOTA - 345) & 511)] - fVec30[((IOTA - 464) & 511)])) + ((0.00384533219f * (fVec30[((IOTA - 258) & 511)] - fVec30[((IOTA - 463) & 511)])) + ((0.00375377666f * (fVec30[((IOTA - 296) & 511)] - fVec30[((IOTA - 462) & 511)])) + ((0.00100711081f * (fVec30[((IOTA - 209) & 511)] - fVec30[((IOTA - 458) & 511)])) + ((0.000946073793f * (((fVec30[((IOTA - 320) & 511)] + fVec30[((IOTA - 329) & 511)]) + fVec30[((IOTA - 358) & 511)]) + fVec30[((IOTA - 455) & 511)])) + ((0.00137333293f * (((fVec30[((IOTA - 352) & 511)] + fVec30[((IOTA - 383) & 511)]) - fVec30[((IOTA - 448) & 511)]) + fVec30[((IOTA - 454) & 511)])) + ((0.00131229591f * ((fVec30[((IOTA - 133) & 511)] + fVec30[((IOTA - 319) & 511)]) - fVec30[((IOTA - 450) & 511)])) + ((0.000427259132f * fVec30[((IOTA - 445) & 511)]) + ((0.000335703604f * fVec30[((IOTA - 443) & 511)]) + ((0.00140385143f * ((fVec30[((IOTA - 214) & 511)] - fVec30[((IOTA - 433) & 511)]) - fVec30[((IOTA - 439) & 511)])) + ((0.00146488845f * (fVec30[((IOTA - 398) & 511)] - fVec30[((IOTA - 437) & 511)])) + ((0.00177007355f * (fVec30[((IOTA - 208) & 511)] - fVec30[((IOTA - 431) & 511)])) + ((0.00167851802f * (fVec30[((IOTA - 317) & 511)] - fVec30[((IOTA - 425) & 511)])) + ((0.00183111057f * (fVec30[((IOTA - 341) & 511)] - fVec30[((IOTA - 424) & 511)])) + ((0.000823999755f * (fVec30[((IOTA - 174) & 511)] - fVec30[((IOTA - 421) & 511)])) + ((0.000793481246f * ((fVec30[((IOTA - 65) & 511)] - fVec30[((IOTA - 385) & 511)]) + fVec30[((IOTA - 419) & 511)])) + ((0.00241096225f * (((fVec30[((IOTA - 157) & 511)] + fVec30[((IOTA - 266) & 511)]) + fVec30[((IOTA - 335) & 511)]) + fVec30[((IOTA - 406) & 511)])) + ((0.00302133244f * ((fVec30[((IOTA - 267) & 511)] + fVec30[((IOTA - 273) & 511)]) + fVec30[((IOTA - 404) & 511)])) + ((0.00299081393f * fVec30[((IOTA - 403) & 511)]) + ((0.00280770287f * ((fVec30[((IOTA - 66) & 511)] + fVec30[((IOTA - 300) & 511)]) + fVec30[((IOTA - 402) & 511)])) + ((0.00250251777f * fVec30[((IOTA - 401) & 511)]) + ((0.00210577715f * (fVec30[((IOTA - 262) & 511)] + fVec30[((IOTA - 400) & 511)])) + ((0.000854518265f * (fVec30[((IOTA - 321) & 511)] + fVec30[((IOTA - 396) & 511)])) + ((0.00469985045f * fVec30[((IOTA - 381) & 511)]) + ((0.00573747978f * fVec30[((IOTA - 380) & 511)]) + ((0.0058290353f * fVec30[((IOTA - 379) & 511)]) + ((0.00567644276f * fVec30[((IOTA - 378) & 511)]) + ((0.00491348002f * fVec30[((IOTA - 377) & 511)]) + ((0.00408948027f * ((fVec30[((IOTA - 228) & 511)] + fVec30[((IOTA - 245) & 511)]) + fVec30[((IOTA - 376) & 511)])) + ((0.000885036774f * fVec30[((IOTA - 370) & 511)]) + ((0.00262459181f * ((fVec30[((IOTA - 261) & 511)] + fVec30[((IOTA - 338) & 511)]) + fVec30[((IOTA - 365) & 511)])) + ((0.00894192327f * (fVec30[((IOTA - 129) & 511)] + fVec30[((IOTA - 362) & 511)])) + ((0.00750755332f * fVec30[((IOTA - 361) & 511)]) + ((0.0051576281f * fVec30[((IOTA - 360) & 511)]) + ((0.00274666585f * fVec30[((IOTA - 351) & 511)]) + ((0.00378429517f * fVec30[((IOTA - 350) & 511)]) + ((0.00424207281f * fVec30[((IOTA - 349) & 511)]) + ((0.00411999878f * ((((fVec30[((IOTA - 156) & 511)] + fVec30[((IOTA - 234) & 511)]) + fVec30[((IOTA - 237) & 511)]) + fVec30[((IOTA - 257) & 511)]) + fVec30[((IOTA - 348) & 511)])) + ((0.0038758507f * (((fVec30[((IOTA - 280) & 511)] + fVec30[((IOTA - 288) & 511)]) + fVec30[((IOTA - 307) & 511)]) + fVec30[((IOTA - 347) & 511)])) + ((0.00216681417f * ((fVec30[((IOTA - 311) & 511)] + fVec30[((IOTA - 312) & 511)]) + fVec30[((IOTA - 342) & 511)])) + ((0.0022583697f * fVec30[((IOTA - 339) & 511)]) + ((0.0025940733f * (fVec30[((IOTA - 304) & 511)] + fVec30[((IOTA - 336) & 511)])) + ((0.00228888821f * ((fVec30[((IOTA - 226) & 511)] + fVec30[((IOTA - 315) & 511)]) + fVec30[((IOTA - 334) & 511)])) + ((0.00213629566f * (fVec30[((IOTA - 278) & 511)] + fVec30[((IOTA - 326) & 511)])) + ((0.00234992523f * fVec30[((IOTA - 325) & 511)]) + ((0.00219733268f * fVec30[((IOTA - 324) & 511)]) + ((0.00238044374f * fVec30[((IOTA - 314) & 511)]) + ((0.00332651753f * (fVec30[((IOTA - 291) & 511)] + fVec30[((IOTA - 308) & 511)])) + ((0.00390636921f * (fVec30[((IOTA - 236) & 511)] + fVec30[((IOTA - 306) & 511)])) + ((0.00830103457f * fVec30[((IOTA - 363) & 511)]) + ((0.00347911008f * fVec30[((IOTA - 305) & 511)]) + ((0.0057985168f * fVec30[((IOTA - 364) & 511)]) + ((0.00320444349f * (fVec30[((IOTA - 184) & 511)] + fVec30[((IOTA - 299) & 511)])) + ((0.00335703604f * (fVec30[((IOTA - 289) & 511)] + fVec30[((IOTA - 298) & 511)])) + ((0.00341807306f * fVec30[((IOTA - 297) & 511)]) + ((0.00415051728f * fVec30[((IOTA - 295) & 511)]) + ((0.00460829493f * fVec30[((IOTA - 294) & 511)]) + ((0.00445570238f * (fVec30[((IOTA - 175) & 511)] + fVec30[((IOTA - 293) & 511)])) + ((0.00402844325f * fVec30[((IOTA - 292) & 511)]) + ((0.00311288796f * ((fVec30[((IOTA - 227) & 511)] + fVec30[((IOTA - 269) & 511)]) + fVec30[((IOTA - 290) & 511)])) + ((0.00399792474f * fVec30[((IOTA - 287) & 511)]) + ((0.00357066561f * (fVec30[((IOTA - 259) & 511)] + fVec30[((IOTA - 286) & 511)])) + ((0.00247199927f * fVec30[((IOTA - 284) & 511)]) + ((0.00338755455f * (fVec30[((IOTA - 246) & 511)] + fVec30[((IOTA - 282) & 511)])) + ((0.00314340647f * (fVec30[((IOTA - 268) & 511)] + fVec30[((IOTA - 279) & 511)])) + ((0.00296029542f * fVec30[((IOTA - 274) & 511)]) + ((0.00305185094f * fVec30[((IOTA - 270) & 511)]) + ((0.00427259132f * (((fVec30[((IOTA - 110) & 511)] + fVec30[((IOTA - 148) & 511)]) + fVec30[((IOTA - 255) & 511)]) + fVec30[((IOTA - 256) & 511)])) + ((0.00396740623f * fVec30[((IOTA - 281) & 511)]) + ((0.00439466536f * fVec30[((IOTA - 254) & 511)]) + ((0.00466933195f * ((fVec30[((IOTA - 195) & 511)] + fVec30[((IOTA - 244) & 511)]) + fVec30[((IOTA - 253) & 511)])) + ((0.00503555406f * (fVec30[((IOTA - 71) & 511)] + fVec30[((IOTA - 252) & 511)])) + ((0.00476088747f * fVec30[((IOTA - 251) & 511)]) + ((0.00350962859f * ((fVec30[((IOTA - 147) & 511)] + fVec30[((IOTA - 196) & 511)]) + fVec30[((IOTA - 250) & 511)])) + ((0.00500503555f * fVec30[((IOTA - 243) & 511)]) + ((0.00527970213f * fVec30[((IOTA - 242) & 511)]) + ((0.00561540574f * fVec30[((IOTA - 241) & 511)]) + ((0.00589007232f * (fVec30[((IOTA - 206) & 511)] + fVec30[((IOTA - 240) & 511)])) + ((0.00546281319f * (fVec30[((IOTA - 230) & 511)] + fVec30[((IOTA - 239) & 511)])) + ((0.00482192449f * fVec30[((IOTA - 238) & 511)]) + ((0.00372325815f * (fVec30[((IOTA - 207) & 511)] + fVec30[((IOTA - 235) & 511)])) + ((0.00524918362f * (fVec30[((IOTA - 155) & 511)] + fVec30[((IOTA - 232) & 511)])) + ((0.00543229468f * fVec30[((IOTA - 231) & 511)]) + ((0.00521866512f * fVec30[((IOTA - 229) & 511)]) + ((0.003234962f * (fVec30[((IOTA - 185) & 511)] + fVec30[((IOTA - 218) & 511)])) + ((0.00430310983f * fVec30[((IOTA - 217) & 511)]) + ((0.00405896176f * fVec30[((IOTA - 216) & 511)]) + ((0.00473036896f * fVec30[((IOTA - 233) & 511)]) + ((0.00762962736f * fVec30[((IOTA - 205) & 511)]) + ((0.00772118289f * fVec30[((IOTA - 204) & 511)]) + ((0.00671407208f * fVec30[((IOTA - 203) & 511)]) + ((0.006469924f * fVec30[((IOTA - 202) & 511)]) + ((0.00692770164f * fVec30[((IOTA - 201) & 511)]) + ((0.00778221991f * fVec30[((IOTA - 200) & 511)]) + ((0.0077517014f * fVec30[((IOTA - 199) & 511)]) + ((0.0061342204f * fVec30[((IOTA - 198) & 511)]) + ((0.00595110934f * fVec30[((IOTA - 194) & 511)]) + ((0.00735496078f * fVec30[((IOTA - 193) & 511)]) + ((0.00747703481f * fVec30[((IOTA - 192) & 511)]) + ((0.00909451582f * fVec30[((IOTA - 191) & 511)]) + ((0.0107425153f * fVec30[((IOTA - 190) & 511)]) + ((0.0110171819f * fVec30[((IOTA - 189) & 511)]) + ((0.00958281197f * fVec30[((IOTA - 188) & 511)]) + ((0.00820947904f * fVec30[((IOTA - 187) & 511)]) + ((0.00607318338f * fVec30[((IOTA - 186) & 511)]) + ((0.00601214636f * fVec30[((IOTA - 183) & 511)]) + ((0.00964384899f * fVec30[((IOTA - 182) & 511)]) + ((0.00973540451f * (fVec30[((IOTA - 68) & 511)] + fVec30[((IOTA - 181) & 511)])) + ((0.0045167394f * fVec30[((IOTA - 197) & 511)]) + ((0.00906399731f * fVec30[((IOTA - 180) & 511)]) + ((0.00851466414f * fVec30[((IOTA - 179) & 511)]) + ((0.00866725668f * (fVec30[((IOTA - 150) & 511)] + fVec30[((IOTA - 178) & 511)])) + ((0.00869777519f * fVec30[((IOTA - 177) & 511)]) + ((0.00781273842f * fVec30[((IOTA - 176) & 511)]) + ((0.00497451704f * fVec30[((IOTA - 165) & 511)]) + ((0.0159306619f * fVec30[((IOTA - 164) & 511)]) + ((0.0237128828f * fVec30[((IOTA - 163) & 511)]) + ((0.0202337727f * fVec30[((IOTA - 162) & 511)]) + ((0.0109866634f * fVec30[((IOTA - 161) & 511)]) + ((0.00622577593f * fVec30[((IOTA - 154) & 511)]) + ((0.00787377544f * fVec30[((IOTA - 153) & 511)]) + ((0.0093691824f * fVec30[((IOTA - 152) & 511)]) + ((0.0102847377f * fVec30[((IOTA - 151) & 511)]) + ((0.00704977568f * fVec30[((IOTA - 149) & 511)]) + ((0.00540177617f * fVec30[((IOTA - 140) & 511)]) + ((0.0111392559f * fVec30[((IOTA - 139) & 511)]) + ((0.0155644398f * fVec30[((IOTA - 138) & 511)]) + ((0.0207220688f * fVec30[((IOTA - 137) & 511)]) + ((0.0247505121f * fVec30[((IOTA - 136) & 511)]) + ((0.0236213263f * fVec30[((IOTA - 135) & 511)]) + ((0.0146488845f * fVec30[((IOTA - 134) & 511)]) + ((0.0123294778f * (fVec30[((IOTA - 107) & 511)] - fVec30[((IOTA - 132) & 511)])) + ((0.0235908087f * fVec30[((IOTA - 128) & 511)]) + ((0.0324716941f * fVec30[((IOTA - 127) & 511)]) + ((0.0323191024f * fVec30[((IOTA - 126) & 511)]) + ((0.0296029542f * fVec30[((IOTA - 125) & 511)]) + ((0.0256660674f * fVec30[((IOTA - 124) & 511)]) + ((0.0245368816f * fVec30[((IOTA - 123) & 511)]) + ((0.0194402914f * fVec30[((IOTA - 122) & 511)]) + ((0.00885036774f * fVec30[((IOTA - 121) & 511)]) + ((0.0119022187f * (fVec30[((IOTA - 106) & 511)] - fVec30[((IOTA - 112) & 511)])) + ((0.0117191076f * fVec30[((IOTA - 109) & 511)]) + ((0.0145268105f * fVec30[((IOTA - 108) & 511)]) + ((0.0332041383f * fVec30[((IOTA - 100) & 511)]) + ((0.0390026569f * fVec30[((IOTA - 99) & 511)]) + ((0.0314951017f * fVec30[((IOTA - 98) & 511)]) + ((0.00592059083f * fVec30[((IOTA - 97) & 511)]) + ((0.0158696249f * fVec30[((IOTA - 94) & 511)]) + ((0.0350352488f * fVec30[((IOTA - 93) & 511)]) + ((0.0300607327f * fVec30[((IOTA - 92) & 511)]) + ((0.00662251655f * fVec30[((IOTA - 90) & 511)]) + ((0.0169377737f * fVec30[((IOTA - 89) & 511)]) + ((0.0156559963f * fVec30[((IOTA - 88) & 511)]) + ((0.0231635496f * fVec30[((IOTA - 87) & 511)]) + ((0.011383404f * (fVec30[((IOTA - 69) & 511)] - fVec30[((IOTA - 86) & 511)])) + ((0.0269173253f * fVec30[((IOTA - 91) & 511)]) + ((0.0999175981f * fVec30[((IOTA - 82) & 511)]) + ((0.160618916f * fVec30[((IOTA - 81) & 511)]) + ((0.134189889f * fVec30[((IOTA - 80) & 511)]) + ((0.00625629444f * fVec30[((IOTA - 67) & 511)]) + (0.0104983672f * fVec30[((IOTA - 70) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.000732444227f * ((fVec30[((IOTA - 221) & 511)] - fVec30[((IOTA - 415) & 511)]) + fVec30[((IOTA - 497) & 511)])) + ((0.00103762932f * ((fVec30[((IOTA - 354) & 511)] + fVec30[((IOTA - 368) & 511)]) + fVec30[((IOTA - 495) & 511)])) + ((0.00134281442f * (((fVec30[((IOTA - 169) & 511)] + fVec30[((IOTA - 356) & 511)]) + fVec30[((IOTA - 436) & 511)]) + fVec30[((IOTA - 494) & 511)])) + ((0.001617481f * (((fVec30[((IOTA - 426) & 511)] + fVec30[((IOTA - 449) & 511)]) + fVec30[((IOTA - 483) & 511)]) + fVec30[((IOTA - 493) & 511)])) + ((0.00180059206f * (((((((fVec30[((IOTA - 159) & 511)] - fVec30[((IOTA - 160) & 511)]) - fVec30[((IOTA - 263) & 511)]) - fVec30[((IOTA - 265) & 511)]) - fVec30[((IOTA - 323) & 511)]) + fVec30[((IOTA - 428) & 511)]) + fVec30[((IOTA - 479) & 511)]) + fVec30[((IOTA - 492) & 511)])) + ((0.00164799951f * ((((((fVec30[((IOTA - 141) & 511)] - fVec30[((IOTA - 225) & 511)]) + fVec30[((IOTA - 427) & 511)]) + fVec30[((IOTA - 472) & 511)]) + fVec30[((IOTA - 480) & 511)]) + fVec30[((IOTA - 481) & 511)]) + fVec30[((IOTA - 482) & 511)])) + ((0.00112918485f * ((fVec30[((IOTA - 367) & 511)] + fVec30[((IOTA - 388) & 511)]) + fVec30[((IOTA - 467) & 511)])) + ((0.00326548051f * (fVec30[((IOTA - 168) & 511)] + fVec30[((IOTA - 461) & 511)])) + ((0.00207525864f * fVec30[((IOTA - 478) & 511)]) + ((0.00244148076f * fVec30[((IOTA - 477) & 511)]) + ((0.000366222113f * ((fVec30[((IOTA - 62) & 511)] - fVec30[((IOTA - 414) & 511)]) + fVec30[((IOTA - 457) & 511)])) + ((0.000274666585f * (fVec30[((IOTA - 63) & 511)] - fVec30[((IOTA - 456) & 511)])) + ((0.000457777642f * (((fVec30[((IOTA - 222) & 511)] + fVec30[((IOTA - 357) & 511)]) + fVec30[((IOTA - 391) & 511)]) - fVec30[((IOTA - 452) & 511)])) + ((9.15555283e-05f * ((((((((((((((((((((fTemp31 + fVec30[((IOTA - 1) & 511)]) + fVec30[((IOTA - 2) & 511)]) + fVec30[((IOTA - 10) & 511)]) + fVec30[((IOTA - 12) & 511)]) + fVec30[((IOTA - 17) & 511)]) + fVec30[((IOTA - 23) & 511)]) + fVec30[((IOTA - 31) & 511)]) + fVec30[((IOTA - 32) & 511)]) + fVec30[((IOTA - 39) & 511)]) + fVec30[((IOTA - 43) & 511)]) + fVec30[((IOTA - 45) & 511)]) + fVec30[((IOTA - 56) & 511)]) - fVec30[((IOTA - 210) & 511)]) - fVec30[((IOTA - 211) & 511)]) + fVec30[((IOTA - 223) & 511)]) - fVec30[((IOTA - 393) & 511)]) + fVec30[((IOTA - 411) & 511)]) + fVec30[((IOTA - 412) & 511)]) - fVec30[((IOTA - 420) & 511)]) + fVec30[((IOTA - 446) & 511)])) + ((0.00057985168f * ((fVec30[((IOTA - 158) & 511)] - fVec30[((IOTA - 409) & 511)]) - fVec30[((IOTA - 444) & 511)])) + ((0.000183111057f * ((fVec30[((IOTA - 57) & 511)] + fVec30[((IOTA - 58) & 511)]) + fVec30[((IOTA - 442) & 511)])) + ((0.00119022187f * ((fVec30[((IOTA - 387) & 511)] - fVec30[((IOTA - 418) & 511)]) + fVec30[((IOTA - 440) & 511)])) + ((0.00143436994f * (((fVec30[((IOTA - 170) & 511)] - fVec30[((IOTA - 277) & 511)]) - fVec30[((IOTA - 331) & 511)]) + fVec30[((IOTA - 438) & 511)])) + ((0.00125125889f * (((fVec30[((IOTA - 386) & 511)] - fVec30[((IOTA - 408) & 511)]) - fVec30[((IOTA - 417) & 511)]) + fVec30[((IOTA - 434) & 511)])) + ((0.00158696249f * (((fVec30[((IOTA - 95) & 511)] - fVec30[((IOTA - 276) & 511)]) - fVec30[((IOTA - 318) & 511)]) + fVec30[((IOTA - 432) & 511)])) + ((0.0019531846f * (fVec30[((IOTA - 429) & 511)] + fVec30[((IOTA - 430) & 511)])) + ((6.10370189e-05f * (((((((((((((fVec30[((IOTA - 3) & 511)] + fVec30[((IOTA - 13) & 511)]) + fVec30[((IOTA - 20) & 511)]) + fVec30[((IOTA - 26) & 511)]) + fVec30[((IOTA - 30) & 511)]) + fVec30[((IOTA - 33) & 511)]) + fVec30[((IOTA - 36) & 511)]) + fVec30[((IOTA - 42) & 511)]) + fVec30[((IOTA - 48) & 511)]) + fVec30[((IOTA - 212) & 511)]) - fVec30[((IOTA - 220) & 511)]) - fVec30[((IOTA - 366) & 511)]) - fVec30[((IOTA - 410) & 511)]) - fVec30[((IOTA - 413) & 511)])) + ((0.000244148076f * (fVec30[((IOTA - 392) & 511)] - fVec30[((IOTA - 394) & 511)])) + ((0.00317392498f * (fVec30[((IOTA - 173) & 511)] - fVec30[((IOTA - 382) & 511)])) + ((0.0012817774f * (fVec30[((IOTA - 146) & 511)] - fVec30[((IOTA - 373) & 511)])) + ((0.00363170262f * ((fVec30[((IOTA - 120) & 511)] + fVec30[((IOTA - 166) & 511)]) - fVec30[((IOTA - 346) & 511)])) + ((0.00308236945f * ((fVec30[((IOTA - 101) & 511)] - fVec30[((IOTA - 260) & 511)]) - fVec30[((IOTA - 344) & 511)])) + ((3.05185094e-05f * ((((((((((((((((fVec30[((IOTA - 4) & 511)] + fVec30[((IOTA - 6) & 511)]) + fVec30[((IOTA - 7) & 511)]) + fVec30[((IOTA - 8) & 511)]) + fVec30[((IOTA - 9) & 511)]) + fVec30[((IOTA - 16) & 511)]) + fVec30[((IOTA - 21) & 511)]) + fVec30[((IOTA - 22) & 511)]) - fVec30[((IOTA - 27) & 511)]) - fVec30[((IOTA - 28) & 511)]) + fVec30[((IOTA - 40) & 511)]) + fVec30[((IOTA - 46) & 511)]) + fVec30[((IOTA - 53) & 511)]) + fVec30[((IOTA - 55) & 511)]) - fVec30[((IOTA - 353) & 511)]) - fVec30[((IOTA - 369) & 511)]) + fVec30[((IOTA - 384) & 511)])) + ((0.00442518387f * fVec30[((IOTA - 172) & 511)]) + ((0.00448622089f * fVec30[((IOTA - 167) & 511)]) + ((0.00570696127f * fVec30[((IOTA - 145) & 511)]) + ((0.0105899228f * fVec30[((IOTA - 144) & 511)]) + ((0.0105288858f * fVec30[((IOTA - 143) & 511)]) + ((0.00799584948f * fVec30[((IOTA - 142) & 511)]) + ((0.0157475509f * fVec30[((IOTA - 131) & 511)]) + ((0.00796533097f * fVec30[((IOTA - 130) & 511)]) + ((0.0132145146f * fVec30[((IOTA - 119) & 511)]) + ((0.0155949583f * fVec30[((IOTA - 118) & 511)]) + ((0.0184636991f * fVec30[((IOTA - 117) & 511)]) + ((0.0181279946f * fVec30[((IOTA - 116) & 511)]) + ((0.0189825129f * fVec30[((IOTA - 115) & 511)]) + ((0.0176091809f * fVec30[((IOTA - 114) & 511)]) + ((0.0174260698f * fVec30[((IOTA - 113) & 511)]) + ((0.00552385021f * fVec30[((IOTA - 111) & 511)]) + ((0.00537125766f * fVec30[((IOTA - 105) & 511)]) + ((0.0246894751f * fVec30[((IOTA - 104) & 511)]) + ((0.0411084332f * fVec30[((IOTA - 103) & 511)]) + ((0.0263679922f * fVec30[((IOTA - 102) & 511)]) + ((0.00836207159f * fVec30[((IOTA - 96) & 511)]) + ((0.0527359843f * fVec30[((IOTA - 85) & 511)]) + ((0.0715353861f * fVec30[((IOTA - 84) & 511)]) + ((0.0164494775f * fVec30[((IOTA - 83) & 511)]) + ((0.0123599963f * fVec30[((IOTA - 79) & 511)]) + ((0.200506613f * fVec30[((IOTA - 78) & 511)]) + ((0.314279616f * fVec30[((IOTA - 77) & 511)]) + ((0.27979371f * fVec30[((IOTA - 76) & 511)]) + ((0.145146027f * fVec30[((IOTA - 75) & 511)]) + ((0.0468153954f * fVec30[((IOTA - 74) & 511)]) + ((0.0107730338f * fVec30[((IOTA - 73) & 511)]) + ((0.000915555283f * fVec30[((IOTA - 72) & 511)]) + ((0.000305185094f * fVec30[((IOTA - 61) & 511)]) + ((0.000213629566f * ((fVec30[((IOTA - 50) & 511)] + fVec30[((IOTA - 51) & 511)]) + fVec30[((IOTA - 60) & 511)])) + ((0.000122074038f * ((((((fVec30[((IOTA - 11) & 511)] + fVec30[((IOTA - 18) & 511)]) + fVec30[((IOTA - 19) & 511)]) + fVec30[((IOTA - 24) & 511)]) + fVec30[((IOTA - 37) & 511)]) + fVec30[((IOTA - 38) & 511)]) + fVec30[((IOTA - 44) & 511)])) + (0.000152592547f * (((fVec30[((IOTA - 25) & 511)] + fVec30[((IOTA - 49) & 511)]) + fVec30[((IOTA - 52) & 511)]) + fVec30[((IOTA - 59) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00283822138f * (fVec30[((IOTA - 171) & 511)] + fVec30[((IOTA - 502) & 511)]))) + (0.00115970336f * fVec30[((IOTA - 511) & 511)])))) : (iSlow69 ? (((0.000610370189f * ((fVec29[((IOTA - 412) & 511)] + fVec29[((IOTA - 491) & 511)]) + fVec29[((IOTA - 509) & 511)])) + ((0.000915555283f * ((((fVec29[((IOTA - 140) & 511)] - fVec29[((IOTA - 334) & 511)]) - fVec29[((IOTA - 335) & 511)]) + fVec29[((IOTA - 467) & 511)]) + fVec29[((IOTA - 507) & 511)])) + ((0.00122074038f * (fVec29[((IOTA - 472) & 511)] + fVec29[((IOTA - 503) & 511)])) + ((0.000122074038f * (((((((((fTemp30 + fVec29[((IOTA - 12) & 511)]) + fVec29[((IOTA - 18) & 511)]) + fVec29[((IOTA - 19) & 511)]) + fVec29[((IOTA - 23) & 511)]) + fVec29[((IOTA - 24) & 511)]) + fVec29[((IOTA - 41) & 511)]) - fVec29[((IOTA - 408) & 511)]) - fVec29[((IOTA - 496) & 511)]) + fVec29[((IOTA - 498) & 511)])) + ((9.15555283e-05f * ((((((((fVec29[((IOTA - 9) & 511)] + fVec29[((IOTA - 10) & 511)]) + fVec29[((IOTA - 11) & 511)]) + fVec29[((IOTA - 13) & 511)]) + fVec29[((IOTA - 17) & 511)]) + fVec29[((IOTA - 42) & 511)]) + fVec29[((IOTA - 43) & 511)]) + fVec29[((IOTA - 51) & 511)]) - fVec29[((IOTA - 497) & 511)])) + ((6.10370189e-05f * ((((((fVec29[((IOTA - 8) & 511)] + fVec29[((IOTA - 25) & 511)]) - fVec29[((IOTA - 53) & 511)]) + fVec29[((IOTA - 63) & 511)]) - fVec29[((IOTA - 368) & 511)]) + fVec29[((IOTA - 451) & 511)]) + fVec29[((IOTA - 495) & 511)])) + ((0.000244148076f * ((((((((((fVec29[((IOTA - 29) & 511)] + fVec29[((IOTA - 35) & 511)]) + fVec29[((IOTA - 37) & 511)]) + fVec29[((IOTA - 49) & 511)]) + fVec29[((IOTA - 59) & 511)]) + fVec29[((IOTA - 60) & 511)]) + fVec29[((IOTA - 61) & 511)]) + fVec29[((IOTA - 224) & 511)]) + fVec29[((IOTA - 394) & 511)]) + fVec29[((IOTA - 413) & 511)]) + fVec29[((IOTA - 494) & 511)])) + ((0.000427259132f * ((fVec29[((IOTA - 392) & 511)] + fVec29[((IOTA - 393) & 511)]) + fVec29[((IOTA - 493) & 511)])) + ((0.001617481f * ((fVec29[((IOTA - 72) & 511)] - fVec29[((IOTA - 397) & 511)]) + fVec29[((IOTA - 487) & 511)])) + ((0.00241096225f * ((((fVec29[((IOTA - 142) & 511)] - fVec29[((IOTA - 226) & 511)]) - fVec29[((IOTA - 271) & 511)]) - fVec29[((IOTA - 279) & 511)]) + fVec29[((IOTA - 478) & 511)])) + ((0.00256355479f * ((fVec29[((IOTA - 141) & 511)] + fVec29[((IOTA - 448) & 511)]) + fVec29[((IOTA - 476) & 511)])) + ((0.000976592302f * ((((fVec29[((IOTA - 120) & 511)] + fVec29[((IOTA - 143) & 511)]) - fVec29[((IOTA - 289) & 511)]) - fVec29[((IOTA - 317) & 511)]) + fVec29[((IOTA - 471) & 511)])) + ((0.000793481246f * (((fVec29[((IOTA - 357) & 511)] + fVec29[((IOTA - 411) & 511)]) + fVec29[((IOTA - 443) & 511)]) + fVec29[((IOTA - 468) & 511)])) + ((0.00189214759f * (fVec29[((IOTA - 439) & 511)] + fVec29[((IOTA - 464) & 511)])) + ((3.05185094e-05f * (((((((fVec29[((IOTA - 5) & 511)] - fVec29[((IOTA - 52) & 511)]) + fVec29[((IOTA - 64) & 511)]) - fVec29[((IOTA - 329) & 511)]) + fVec29[((IOTA - 330) & 511)]) - fVec29[((IOTA - 358) & 511)]) - fVec29[((IOTA - 395) & 511)]) + fVec29[((IOTA - 456) & 511)])) + ((0.000366222113f * (((fVec29[((IOTA - 46) & 511)] + fVec29[((IOTA - 56) & 511)]) + fVec29[((IOTA - 57) & 511)]) - fVec29[((IOTA - 455) & 511)])) + ((0.00204474013f * ((fVec29[((IOTA - 387) & 511)] + fVec29[((IOTA - 422) & 511)]) + fVec29[((IOTA - 428) & 511)])) + ((0.00234992523f * fVec29[((IOTA - 425) & 511)]) + ((0.00137333293f * ((fVec29[((IOTA - 388) & 511)] - ((fVec29[((IOTA - 274) & 511)] + fVec29[((IOTA - 316) & 511)]) + fVec29[((IOTA - 342) & 511)])) + fVec29[((IOTA - 421) & 511)])) + ((0.000488296151f * fVec29[((IOTA - 420) & 511)]) + ((0.000305185094f * (((fVec29[((IOTA - 38) & 511)] + fVec29[((IOTA - 39) & 511)]) + fVec29[((IOTA - 48) & 511)]) - fVec29[((IOTA - 414) & 511)])) + ((0.00057985168f * ((fVec29[((IOTA - 355) & 511)] + fVec29[((IOTA - 389) & 511)]) + fVec29[((IOTA - 410) & 511)])) + ((0.000335703604f * ((fVec29[((IOTA - 58) & 511)] - fVec29[((IOTA - 328) & 511)]) + fVec29[((IOTA - 409) & 511)])) + ((0.00228888821f * (fVec29[((IOTA - 423) & 511)] - ((fVec29[((IOTA - 280) & 511)] + fVec29[((IOTA - 308) & 511)]) + fVec29[((IOTA - 398) & 511)]))) + ((0.000213629566f * (((((((fVec29[((IOTA - 27) & 511)] + fVec29[((IOTA - 28) & 511)]) + fVec29[((IOTA - 33) & 511)]) + fVec29[((IOTA - 34) & 511)]) + fVec29[((IOTA - 36) & 511)]) + fVec29[((IOTA - 44) & 511)]) + fVec29[((IOTA - 55) & 511)]) + fVec29[((IOTA - 391) & 511)])) + ((0.000183111057f * (((((((((fVec29[((IOTA - 2) & 511)] + fVec29[((IOTA - 3) & 511)]) + fVec29[((IOTA - 22) & 511)]) + fVec29[((IOTA - 26) & 511)]) + fVec29[((IOTA - 30) & 511)]) + fVec29[((IOTA - 31) & 511)]) + fVec29[((IOTA - 50) & 511)]) + fVec29[((IOTA - 62) & 511)]) - fVec29[((IOTA - 331) & 511)]) + fVec29[((IOTA - 390) & 511)])) + ((0.00265511032f * fVec29[((IOTA - 386) & 511)]) + ((0.00296029542f * fVec29[((IOTA - 385) & 511)]) + ((0.00103762932f * (fVec29[((IOTA - 223) & 511)] + fVec29[((IOTA - 383) & 511)])) + ((0.000274666585f * (((fVec29[((IOTA - 40) & 511)] + fVec29[((IOTA - 45) & 511)]) + fVec29[((IOTA - 221) & 511)]) + fVec29[((IOTA - 367) & 511)])) + ((0.00802636798f * (fVec29[((IOTA - 96) & 511)] - fVec29[((IOTA - 362) & 511)])) + ((0.000396740623f * ((fVec29[((IOTA - 47) & 511)] - fVec29[((IOTA - 319) & 511)]) - fVec29[((IOTA - 320) & 511)])) + ((0.00244148076f * (fVec29[((IOTA - 94) & 511)] - fVec29[((IOTA - 292) & 511)])) + ((0.00622577593f * fVec29[((IOTA - 170) & 511)]) + ((0.0117496261f * fVec29[((IOTA - 169) & 511)]) + ((0.0105288858f * fVec29[((IOTA - 168) & 511)]) + ((0.00338755455f * fVec29[((IOTA - 167) & 511)]) + ((0.0163579211f * (fVec29[((IOTA - 95) & 511)] + fVec29[((IOTA - 131) & 511)])) + ((0.0164494775f * fVec29[((IOTA - 130) & 511)]) + ((0.0054933317f * fVec29[((IOTA - 129) & 511)]) + ((0.0108035523f * fVec29[((IOTA - 119) & 511)]) + ((0.00994903408f * fVec29[((IOTA - 118) & 511)]) + ((0.0164799951f * fVec29[((IOTA - 117) & 511)]) + ((0.0126346629f * fVec29[((IOTA - 116) & 511)]) + ((0.0124820704f * fVec29[((IOTA - 115) & 511)]) + ((0.00576799829f * fVec29[((IOTA - 114) & 511)]) + ((0.0169377737f * fVec29[((IOTA - 113) & 511)]) + ((0.00817896053f * fVec29[((IOTA - 112) & 511)]) + ((0.00604266487f * fVec29[((IOTA - 111) & 511)]) + ((0.0330820642f * fVec29[((IOTA - 103) & 511)]) + ((0.0249031037f * fVec29[((IOTA - 102) & 511)]) + ((0.0288094729f * fVec29[((IOTA - 101) & 511)]) + ((0.0265205856f * fVec29[((IOTA - 86) & 511)]) + ((0.037324138f * fVec29[((IOTA - 85) & 511)]) + ((0.0773644224f * fVec29[((IOTA - 84) & 511)]) + ((0.0752281249f * fVec29[((IOTA - 83) & 511)]) + ((0.0120853297f * fVec29[((IOTA - 82) & 511)]) + ((0.0992156714f * fVec29[((IOTA - 78) & 511)]) + ((0.295083463f * fVec29[((IOTA - 77) & 511)]) + ((0.345622122f * fVec29[((IOTA - 76) & 511)]) + ((0.207495347f * fVec29[((IOTA - 75) & 511)]) + ((0.0593584999f * fVec29[((IOTA - 74) & 511)]) + ((0.000152592547f * ((((fVec29[((IOTA - 1) & 511)] + fVec29[((IOTA - 4) & 511)]) + fVec29[((IOTA - 20) & 511)]) + fVec29[((IOTA - 21) & 511)]) + fVec29[((IOTA - 32) & 511)])) + (0.00558488723f * fVec29[((IOTA - 73) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.00109866634f * (((fVec29[((IOTA - 325) & 511)] + fVec29[((IOTA - 337) & 511)]) - fVec29[((IOTA - 489) & 511)]) - fVec29[((IOTA - 506) & 511)])) + ((0.00119022187f * (((((fVec29[((IOTA - 323) & 511)] + fVec29[((IOTA - 341) & 511)]) + fVec29[((IOTA - 382) & 511)]) - fVec29[((IOTA - 460) & 511)]) - fVec29[((IOTA - 504) & 511)]) - fVec29[((IOTA - 505) & 511)])) + ((0.00115970336f * (((((fVec29[((IOTA - 268) & 511)] + fVec29[((IOTA - 324) & 511)]) + fVec29[((IOTA - 340) & 511)]) - fVec29[((IOTA - 441) & 511)]) + fVec29[((IOTA - 453) & 511)]) - fVec29[((IOTA - 502) & 511)])) + ((0.00100711081f * (((fVec29[((IOTA - 288) & 511)] + fVec29[((IOTA - 322) & 511)]) + fVec29[((IOTA - 336) & 511)]) - fVec29[((IOTA - 501) & 511)])) + ((0.000762962736f * (((fVec29[((IOTA - 333) & 511)] + fVec29[((IOTA - 353) & 511)]) + fVec29[((IOTA - 396) & 511)]) - fVec29[((IOTA - 500) & 511)])) + ((0.000457777642f * ((fVec29[((IOTA - 407) & 511)] - fVec29[((IOTA - 457) & 511)]) - fVec29[((IOTA - 499) & 511)])) + ((0.00054933317f * (fVec29[((IOTA - 419) & 511)] - fVec29[((IOTA - 492) & 511)])) + ((0.000823999755f * ((((fVec29[((IOTA - 406) & 511)] + fVec29[((IOTA - 415) & 511)]) + fVec29[((IOTA - 454) & 511)]) - fVec29[((IOTA - 469) & 511)]) - fVec29[((IOTA - 490) & 511)])) + ((0.00143436994f * (fVec29[((IOTA - 282) & 511)] - fVec29[((IOTA - 488) & 511)])) + ((0.00167851802f * ((fVec29[((IOTA - 266) & 511)] - fVec29[((IOTA - 465) & 511)]) - fVec29[((IOTA - 486) & 511)])) + ((0.00177007355f * (((fVec29[((IOTA - 269) & 511)] + fVec29[((IOTA - 352) & 511)]) - fVec29[((IOTA - 481) & 511)]) - fVec29[((IOTA - 485) & 511)])) + ((0.00180059206f * ((((fVec29[((IOTA - 315) & 511)] + fVec29[((IOTA - 359) & 511)]) - fVec29[((IOTA - 434) & 511)]) - fVec29[((IOTA - 483) & 511)]) - fVec29[((IOTA - 484) & 511)])) + ((0.00173955504f * (((fVec29[((IOTA - 291) & 511)] - fVec29[((IOTA - 430) & 511)]) - fVec29[((IOTA - 433) & 511)]) - fVec29[((IOTA - 482) & 511)])) + ((0.0019226661f * (((fVec29[((IOTA - 265) & 511)] + fVec29[((IOTA - 343) & 511)]) - fVec29[((IOTA - 446) & 511)]) - fVec29[((IOTA - 480) & 511)])) + ((0.00219733268f * ((((fVec29[((IOTA - 171) & 511)] + fVec29[((IOTA - 304) & 511)]) + fVec29[((IOTA - 313) & 511)]) - fVec29[((IOTA - 449) & 511)]) - fVec29[((IOTA - 479) & 511)])) + ((0.00250251777f * ((fVec29[((IOTA - 401) & 511)] - fVec29[((IOTA - 475) & 511)]) - fVec29[((IOTA - 477) & 511)])) + ((0.00222785119f * ((fVec29[((IOTA - 307) & 511)] - fVec29[((IOTA - 427) & 511)]) - fVec29[((IOTA - 474) & 511)])) + ((0.00170903653f * (((((fVec29[((IOTA - 157) & 511)] + fVec29[((IOTA - 311) & 511)]) + fVec29[((IOTA - 372) & 511)]) - fVec29[((IOTA - 431) & 511)]) - fVec29[((IOTA - 432) & 511)]) - fVec29[((IOTA - 473) & 511)])) + ((0.000885036774f * (((fVec29[((IOTA - 275) & 511)] - fVec29[((IOTA - 444) & 511)]) + fVec29[((IOTA - 452) & 511)]) - fVec29[((IOTA - 470) & 511)])) + ((0.00125125889f * ((fVec29[((IOTA - 287) & 511)] - fVec29[((IOTA - 450) & 511)]) - fVec29[((IOTA - 466) & 511)])) + ((0.00152592547f * (((fVec29[((IOTA - 210) & 511)] + fVec29[((IOTA - 286) & 511)]) + fVec29[((IOTA - 417) & 511)]) - fVec29[((IOTA - 462) & 511)])) + ((0.00134281442f * (((fVec29[((IOTA - 290) & 511)] + fVec29[((IOTA - 339) & 511)]) + fVec29[((IOTA - 374) & 511)]) - fVec29[((IOTA - 461) & 511)])) + ((0.00112918485f * ((fVec29[((IOTA - 133) & 511)] + fVec29[((IOTA - 276) & 511)]) - fVec29[((IOTA - 459) & 511)])) + ((0.000854518265f * ((((fVec29[((IOTA - 284) & 511)] - fVec29[((IOTA - 356) & 511)]) + fVec29[((IOTA - 369) & 511)]) - fVec29[((IOTA - 442) & 511)]) - fVec29[((IOTA - 458) & 511)])) + ((0.00238044374f * ((fVec29[((IOTA - 402) & 511)] - fVec29[((IOTA - 424) & 511)]) - fVec29[((IOTA - 447) & 511)])) + ((0.00131229591f * (fVec29[((IOTA - 373) & 511)] - fVec29[((IOTA - 445) & 511)])) + ((0.00149540696f * (fVec29[((IOTA - 225) & 511)] - fVec29[((IOTA - 440) & 511)])) + ((0.00216681417f * ((fVec29[((IOTA - 281) & 511)] + fVec29[((IOTA - 306) & 511)]) - fVec29[((IOTA - 437) & 511)])) + ((0.0019531846f * (fVec29[((IOTA - 375) & 511)] - fVec29[((IOTA - 435) & 511)])) + ((0.00231940672f * ((fVec29[((IOTA - 218) & 511)] + fVec29[((IOTA - 344) & 511)]) - fVec29[((IOTA - 426) & 511)])) + ((0.0012817774f * (((fVec29[((IOTA - 219) & 511)] + fVec29[((IOTA - 338) & 511)]) + fVec29[((IOTA - 416) & 511)]) + fVec29[((IOTA - 418) & 511)])) + ((0.00106814783f * (fVec29[((IOTA - 283) & 511)] + fVec29[((IOTA - 405) & 511)])) + ((0.00146488845f * (fVec29[((IOTA - 267) & 511)] + fVec29[((IOTA - 404) & 511)])) + ((0.00198370311f * ((((fVec29[((IOTA - 264) & 511)] + fVec29[((IOTA - 272) & 511)]) + fVec29[((IOTA - 312) & 511)]) + fVec29[((IOTA - 371) & 511)]) + fVec29[((IOTA - 403) & 511)])) + ((0.0025940733f * (fVec29[((IOTA - 399) & 511)] + fVec29[((IOTA - 400) & 511)])) + ((0.00268562883f * ((fVec29[((IOTA - 144) & 511)] + fVec29[((IOTA - 293) & 511)]) - fVec29[((IOTA - 384) & 511)])) + ((0.00305185094f * (fVec29[((IOTA - 345) & 511)] + fVec29[((IOTA - 381) & 511)])) + ((0.00402844325f * ((fVec29[((IOTA - 248) & 511)] + fVec29[((IOTA - 260) & 511)]) + fVec29[((IOTA - 380) & 511)])) + ((0.00445570238f * fVec29[((IOTA - 379) & 511)]) + ((0.00457777642f * fVec29[((IOTA - 378) & 511)]) + ((0.00408948027f * ((fVec29[((IOTA - 216) & 511)] + fVec29[((IOTA - 364) & 511)]) + fVec29[((IOTA - 377) & 511)])) + ((0.00299081393f * ((fVec29[((IOTA - 217) & 511)] + fVec29[((IOTA - 302) & 511)]) + fVec29[((IOTA - 376) & 511)])) + ((0.00207525864f * ((fVec29[((IOTA - 309) & 511)] - fVec29[((IOTA - 436) & 511)]) - fVec29[((IOTA - 438) & 511)])) + ((0.00140385143f * ((fVec29[((IOTA - 211) & 511)] + fVec29[((IOTA - 285) & 511)]) + fVec29[((IOTA - 365) & 511)])) + ((0.00698873866f * (fVec29[((IOTA - 256) & 511)] + fVec29[((IOTA - 363) & 511)])) + ((0.00680562761f * (fVec29[((IOTA - 252) & 511)] + fVec29[((IOTA - 361) & 511)])) + ((0.00183111057f * ((fVec29[((IOTA - 370) & 511)] - fVec29[((IOTA - 429) & 511)]) - fVec29[((IOTA - 463) & 511)])) + ((0.00427259132f * (fVec29[((IOTA - 247) & 511)] + fVec29[((IOTA - 360) & 511)])) + ((0.00271614734f * ((fVec29[((IOTA - 212) & 511)] + fVec29[((IOTA - 263) & 511)]) + fVec29[((IOTA - 351) & 511)])) + ((0.00350962859f * fVec29[((IOTA - 350) & 511)]) + ((0.0038758507f * fVec29[((IOTA - 349) & 511)]) + ((0.00399792474f * fVec29[((IOTA - 348) & 511)]) + ((0.00396740623f * ((fVec29[((IOTA - 71) & 511)] + fVec29[((IOTA - 156) & 511)]) + fVec29[((IOTA - 347) & 511)])) + ((0.00360118411f * fVec29[((IOTA - 346) & 511)]) + ((0.000946073793f * fVec29[((IOTA - 326) & 511)]) + ((0.000640888698f * (fVec29[((IOTA - 65) & 511)] + fVec29[((IOTA - 321) & 511)])) + ((0.00213629566f * fVec29[((IOTA - 314) & 511)]) + ((0.00201422162f * (fVec29[((IOTA - 305) & 511)] + fVec29[((IOTA - 310) & 511)])) + ((0.00277718436f * fVec29[((IOTA - 303) & 511)]) + ((0.00292977691f * (fVec29[((IOTA - 294) & 511)] + fVec29[((IOTA - 301) & 511)])) + ((0.00274666585f * fVec29[((IOTA - 300) & 511)]) + ((0.00280770287f * fVec29[((IOTA - 299) & 511)]) + ((0.0028992584f * (fVec29[((IOTA - 295) & 511)] + fVec29[((IOTA - 298) & 511)])) + ((0.00308236945f * fVec29[((IOTA - 297) & 511)]) + ((0.00317392498f * fVec29[((IOTA - 296) & 511)]) + ((0.0022583697f * fVec29[((IOTA - 278) & 511)]) + ((0.00164799951f * fVec29[((IOTA - 277) & 511)]) + ((0.00155644398f * fVec29[((IOTA - 273) & 511)]) + ((0.00253303628f * fVec29[((IOTA - 270) & 511)]) + ((0.00314340647f * fVec29[((IOTA - 262) & 511)]) + ((0.00332651753f * fVec29[((IOTA - 261) & 511)]) + ((0.00476088747f * fVec29[((IOTA - 259) & 511)]) + ((0.00561540574f * (fVec29[((IOTA - 231) & 511)] + fVec29[((IOTA - 258) & 511)])) + ((0.00607318338f * (fVec29[((IOTA - 206) & 511)] + fVec29[((IOTA - 257) & 511)])) + ((0.00735496078f * fVec29[((IOTA - 255) & 511)]) + ((0.00738547929f * (fVec29[((IOTA - 242) & 511)] + fVec29[((IOTA - 254) & 511)])) + ((0.00701925717f * (fVec29[((IOTA - 178) & 511)] + fVec29[((IOTA - 253) & 511)])) + ((0.00628681295f * fVec29[((IOTA - 251) & 511)]) + ((0.00521866512f * (fVec29[((IOTA - 158) & 511)] + fVec29[((IOTA - 250) & 511)])) + ((0.00439466536f * fVec29[((IOTA - 249) & 511)]) + ((0.00473036896f * fVec29[((IOTA - 246) & 511)]) + ((0.00518814661f * fVec29[((IOTA - 245) & 511)]) + ((0.00595110934f * fVec29[((IOTA - 244) & 511)]) + ((0.0067751091f * fVec29[((IOTA - 243) & 511)]) + ((0.00720236823f * fVec29[((IOTA - 241) & 511)]) + ((0.00689718314f * fVec29[((IOTA - 240) & 511)]) + ((0.00631733146f * (fVec29[((IOTA - 121) & 511)] + fVec29[((IOTA - 239) & 511)])) + ((0.00540177617f * fVec29[((IOTA - 238) & 511)]) + ((0.00469985045f * fVec29[((IOTA - 237) & 511)]) + ((0.00479140598f * fVec29[((IOTA - 236) & 511)]) + ((0.00527970213f * fVec29[((IOTA - 235) & 511)]) + ((0.00564592425f * fVec29[((IOTA - 234) & 511)]) + ((0.0058290353f * (fVec29[((IOTA - 232) & 511)] + fVec29[((IOTA - 233) & 511)])) + ((0.00534073915f * fVec29[((IOTA - 230) & 511)]) + ((0.00506607257f * fVec29[((IOTA - 229) & 511)]) + ((0.00436414685f * (fVec29[((IOTA - 139) & 511)] + fVec29[((IOTA - 228) & 511)])) + ((0.00329599902f * (fVec29[((IOTA - 213) & 511)] + fVec29[((IOTA - 227) & 511)])) + ((0.00454725791f * fVec29[((IOTA - 215) & 511)]) + ((0.00430310983f * fVec29[((IOTA - 214) & 511)]) + ((0.00311288796f * fVec29[((IOTA - 209) & 511)]) + ((0.00531022064f * fVec29[((IOTA - 208) & 511)]) + ((0.00482192449f * fVec29[((IOTA - 207) & 511)]) + ((0.00726340525f * fVec29[((IOTA - 205) & 511)]) + ((0.0093691824f * fVec29[((IOTA - 204) & 511)]) + ((0.00891140476f * (fVec29[((IOTA - 192) & 511)] + fVec29[((IOTA - 203) & 511)])) + ((0.00955229346f * (fVec29[((IOTA - 123) & 511)] + fVec29[((IOTA - 202) & 511)])) + ((0.00875881221f * fVec29[((IOTA - 201) & 511)]) + ((0.00991851557f * fVec29[((IOTA - 200) & 511)]) + ((0.0108645894f * (fVec29[((IOTA - 164) & 511)] + fVec29[((IOTA - 199) & 511)])) + ((0.00973540451f * fVec29[((IOTA - 198) & 511)]) + ((0.00723288674f * fVec29[((IOTA - 197) & 511)]) + ((0.00433362834f * fVec29[((IOTA - 196) & 511)]) + ((0.00442518387f * fVec29[((IOTA - 195) & 511)]) + ((0.00503555406f * fVec29[((IOTA - 194) & 511)]) + ((0.00881984923f * fVec29[((IOTA - 193) & 511)]) + ((0.0120242927f * fVec29[((IOTA - 191) & 511)]) + ((0.0121768853f * fVec29[((IOTA - 190) & 511)]) + ((0.0131534776f * fVec29[((IOTA - 189) & 511)]) + ((0.0109561449f * fVec29[((IOTA - 188) & 511)]) + ((0.0113528855f * fVec29[((IOTA - 187) & 511)]) + ((0.0142826624f * fVec29[((IOTA - 186) & 511)]) + ((0.0127567369f * fVec29[((IOTA - 185) & 511)]) + ((0.0108340709f * fVec29[((IOTA - 184) & 511)]) + ((0.00762962736f * (fVec29[((IOTA - 177) & 511)] + fVec29[((IOTA - 183) & 511)])) + ((0.0117191076f * fVec29[((IOTA - 182) & 511)]) + ((0.0105899228f * fVec29[((IOTA - 181) & 511)]) + ((0.00946073793f * fVec29[((IOTA - 180) & 511)]) + ((0.00546281319f * fVec29[((IOTA - 176) & 511)]) + ((0.00823999755f * fVec29[((IOTA - 175) & 511)]) + ((0.00708029419f * fVec29[((IOTA - 174) & 511)]) + ((0.00686666463f * fVec29[((IOTA - 173) & 511)]) + ((0.00424207281f * fVec29[((IOTA - 172) & 511)]) + ((0.00448622089f * fVec29[((IOTA - 166) & 511)]) + ((0.00592059083f * fVec29[((IOTA - 165) & 511)]) + ((0.0183416251f * fVec29[((IOTA - 163) & 511)]) + ((0.0252693258f * fVec29[((IOTA - 162) & 511)]) + ((0.025818659f * fVec29[((IOTA - 161) & 511)]) + ((0.021088291f * fVec29[((IOTA - 160) & 511)]) + ((0.0137943663f * (fVec29[((IOTA - 151) & 511)] + fVec29[((IOTA - 159) & 511)])) + ((0.00692770164f * fVec29[((IOTA - 155) & 511)]) + ((0.0104068117f * fVec29[((IOTA - 154) & 511)]) + ((0.0123599963f * fVec29[((IOTA - 153) & 511)]) + ((0.0149235511f * (fVec29[((IOTA - 137) & 511)] + fVec29[((IOTA - 152) & 511)])) + ((0.00933866389f * fVec29[((IOTA - 179) & 511)]) + ((0.0117801446f * fVec29[((IOTA - 150) & 511)]) + ((0.0101626636f * fVec29[((IOTA - 149) & 511)]) + ((0.00961333048f * fVec29[((IOTA - 148) & 511)]) + ((0.0106204413f * fVec29[((IOTA - 147) & 511)]) + ((0.0100711081f * fVec29[((IOTA - 146) & 511)]) + ((0.00769066438f * fVec29[((IOTA - 145) & 511)]) + ((0.0106814783f * fVec29[((IOTA - 138) & 511)]) + ((0.0178228095f * fVec29[((IOTA - 136) & 511)]) + ((0.0175176244f * fVec29[((IOTA - 135) & 511)]) + ((0.0102542192f * fVec29[((IOTA - 134) & 511)]) + ((0.00952177495f * (fVec29[((IOTA - 70) & 511)] - fVec29[((IOTA - 132) & 511)])) + ((0.00967436749f * fVec29[((IOTA - 128) & 511)]) + ((0.0177312549f * fVec29[((IOTA - 127) & 511)]) + ((0.0188299213f * fVec29[((IOTA - 126) & 511)]) + ((0.0161442924f * fVec29[((IOTA - 125) & 511)]) + ((0.00997955259f * fVec29[((IOTA - 124) & 511)]) + ((0.0107425153f * fVec29[((IOTA - 122) & 511)]) + ((0.00491348002f * fVec29[((IOTA - 110) & 511)]) + ((0.0181279946f * fVec29[((IOTA - 109) & 511)]) + ((0.0252998453f * fVec29[((IOTA - 108) & 511)]) + ((0.0245368816f * fVec29[((IOTA - 107) & 511)]) + ((0.0239875484f * fVec29[((IOTA - 106) & 511)]) + ((0.022644734f * fVec29[((IOTA - 105) & 511)]) + ((0.00982696004f * fVec29[((IOTA - 104) & 511)]) + ((0.0138248848f * fVec29[((IOTA - 100) & 511)]) + ((0.0272530299f * fVec29[((IOTA - 99) & 511)]) + ((0.0552995391f * fVec29[((IOTA - 98) & 511)]) + ((0.0225531794f * fVec29[((IOTA - 97) & 511)]) + ((0.0268257707f * fVec29[((IOTA - 93) & 511)]) + ((0.0309457686f * fVec29[((IOTA - 92) & 511)]) + ((0.0490737632f * fVec29[((IOTA - 91) & 511)]) + ((0.0249336231f * fVec29[((IOTA - 90) & 511)]) + ((0.0542008728f * fVec29[((IOTA - 89) & 511)]) + ((0.0325022116f * fVec29[((IOTA - 88) & 511)]) + ((0.0277108066f * fVec29[((IOTA - 87) & 511)]) + ((0.0426648781f * fVec29[((IOTA - 81) & 511)]) + ((0.121433146f * fVec29[((IOTA - 80) & 511)]) + ((0.0690633878f * fVec29[((IOTA - 79) & 511)]) + ((0.0119937742f * fVec29[((IOTA - 69) & 511)]) + ((0.0109256264f * fVec29[((IOTA - 68) & 511)]) + ((0.00347911008f * fVec29[((IOTA - 66) & 511)]) + (0.00759910885f * fVec29[((IOTA - 67) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000671407208f * ((((fVec29[((IOTA - 220) & 511)] - fVec29[((IOTA - 222) & 511)]) + fVec29[((IOTA - 318) & 511)]) + fVec29[((IOTA - 332) & 511)]) - fVec29[((IOTA - 510) & 511)]))) + (0.000732444227f * ((fVec29[((IOTA - 327) & 511)] - fVec29[((IOTA - 508) & 511)]) - fVec29[((IOTA - 511) & 511)])))) : (((0.000457777642f * (((((((((((fVec28[((IOTA - 189) & 511)] + fVec28[((IOTA - 195) & 511)]) - fVec28[((IOTA - 203) & 511)]) + fVec28[((IOTA - 271) & 511)]) - fVec28[((IOTA - 278) & 511)]) + fVec28[((IOTA - 343) & 511)]) + fVec28[((IOTA - 419) & 511)]) + fVec28[((IOTA - 443) & 511)]) + fVec28[((IOTA - 457) & 511)]) - fVec28[((IOTA - 471) & 511)]) - fVec28[((IOTA - 472) & 511)]) + fVec28[((IOTA - 511) & 511)])) + ((6.10370189e-05f * (((((((((((((((fVec28[((IOTA - 194) & 511)] + fVec28[((IOTA - 208) & 511)]) - fVec28[((IOTA - 223) & 511)]) - fVec28[((IOTA - 236) & 511)]) - fVec28[((IOTA - 336) & 511)]) + fVec28[((IOTA - 421) & 511)]) - fVec28[((IOTA - 422) & 511)]) - fVec28[((IOTA - 423) & 511)]) + fVec28[((IOTA - 432) & 511)]) + fVec28[((IOTA - 452) & 511)]) - fVec28[((IOTA - 459) & 511)]) + fVec28[((IOTA - 479) & 511)]) + fVec28[((IOTA - 487) & 511)]) - fVec28[((IOTA - 505) & 511)]) - fVec28[((IOTA - 506) & 511)]) + fVec28[((IOTA - 508) & 511)])) + ((0.000152592547f * ((((((((((((fVec28[((IOTA - 182) & 511)] - fVec28[((IOTA - 229) & 511)]) + fVec28[((IOTA - 235) & 511)]) + fVec28[((IOTA - 288) & 511)]) + fVec28[((IOTA - 426) & 511)]) - fVec28[((IOTA - 449) & 511)]) - fVec28[((IOTA - 450) & 511)]) - fVec28[((IOTA - 484) & 511)]) + fVec28[((IOTA - 489) & 511)]) + fVec28[((IOTA - 490) & 511)]) + fVec28[((IOTA - 491) & 511)]) + fVec28[((IOTA - 492) & 511)]) + fVec28[((IOTA - 503) & 511)])) + ((0.000305185094f * ((((((((fVec28[((IOTA - 120) & 511)] - fVec28[((IOTA - 218) & 511)]) + fVec28[((IOTA - 240) & 511)]) + fVec28[((IOTA - 245) & 511)]) + fVec28[((IOTA - 257) & 511)]) - fVec28[((IOTA - 358) & 511)]) - fVec28[((IOTA - 372) & 511)]) - fVec28[((IOTA - 475) & 511)]) + fVec28[((IOTA - 502) & 511)])) + ((0.000335703604f * ((((((((((((fVec28[((IOTA - 103) & 511)] + fVec28[((IOTA - 141) & 511)]) + fVec28[((IOTA - 248) & 511)]) - fVec28[((IOTA - 345) & 511)]) + fVec28[((IOTA - 428) & 511)]) + fVec28[((IOTA - 429) & 511)]) + fVec28[((IOTA - 430) & 511)]) + fVec28[((IOTA - 444) & 511)]) + fVec28[((IOTA - 453) & 511)]) - fVec28[((IOTA - 466) & 511)]) - fVec28[((IOTA - 469) & 511)]) - fVec28[((IOTA - 474) & 511)]) + fVec28[((IOTA - 498) & 511)])) + ((0.000244148076f * (((((((((((((((((fVec28[((IOTA - 232) & 511)] + fVec28[((IOTA - 267) & 511)]) - fVec28[((IOTA - 303) & 511)]) - fVec28[((IOTA - 373) & 511)]) + fVec28[((IOTA - 380) & 511)]) + fVec28[((IOTA - 407) & 511)]) + fVec28[((IOTA - 408) & 511)]) + fVec28[((IOTA - 409) & 511)]) + fVec28[((IOTA - 420) & 511)]) + fVec28[((IOTA - 427) & 511)]) + fVec28[((IOTA - 431) & 511)]) - fVec28[((IOTA - 433) & 511)]) - fVec28[((IOTA - 438) & 511)]) - fVec28[((IOTA - 460) & 511)]) - fVec28[((IOTA - 467) & 511)]) - fVec28[((IOTA - 468) & 511)]) - fVec28[((IOTA - 476) & 511)]) + fVec28[((IOTA - 497) & 511)])) + ((0.000122074038f * ((((((((((fVec28[((IOTA - 230) & 511)] - fVec28[((IOTA - 317) & 511)]) - fVec28[((IOTA - 335) & 511)]) - fVec28[((IOTA - 392) & 511)]) + fVec28[((IOTA - 439) & 511)]) + fVec28[((IOTA - 445) & 511)]) - fVec28[((IOTA - 448) & 511)]) - fVec28[((IOTA - 477) & 511)]) + fVec28[((IOTA - 493) & 511)]) + fVec28[((IOTA - 494) & 511)]) + fVec28[((IOTA - 495) & 511)])) + (((0.000732444227f * ((((fVec28[((IOTA - 221) & 511)] + fVec28[((IOTA - 316) & 511)]) - fVec28[((IOTA - 435) & 511)]) - fVec28[((IOTA - 436) & 511)]) + fVec28[((IOTA - 456) & 511)])) + ((0.000640888698f * ((((((fVec28[((IOTA - 180) & 511)] + fVec28[((IOTA - 196) & 511)]) + fVec28[((IOTA - 241) & 511)]) + fVec28[((IOTA - 272) & 511)]) - fVec28[((IOTA - 290) & 511)]) + fVec28[((IOTA - 349) & 511)]) + fVec28[((IOTA - 454) & 511)])) + ((0.00054933317f * (((((((fVec28[((IOTA - 200) & 511)] + fVec28[((IOTA - 209) & 511)]) - fVec28[((IOTA - 359) & 511)]) - fVec28[((IOTA - 397) & 511)]) - fVec28[((IOTA - 434) & 511)]) - fVec28[((IOTA - 437) & 511)]) + fVec28[((IOTA - 441) & 511)]) + fVec28[((IOTA - 442) & 511)])) + ((0.00115970336f * (((fVec28[((IOTA - 197) & 511)] + fVec28[((IOTA - 333) & 511)]) + fVec28[((IOTA - 369) & 511)]) + fVec28[((IOTA - 416) & 511)])) + ((0.00140385143f * fVec28[((IOTA - 415) & 511)]) + ((0.00180059206f * ((fVec28[((IOTA - 351) & 511)] + fVec28[((IOTA - 368) & 511)]) + fVec28[((IOTA - 402) & 511)])) + ((0.00170903653f * fVec28[((IOTA - 401) & 511)]) + ((0.000885036774f * ((fVec28[((IOTA - 262) & 511)] + fVec28[((IOTA - 284) & 511)]) + fVec28[((IOTA - 399) & 511)])) + ((0.00106814783f * ((fVec28[((IOTA - 130) & 511)] + fVec28[((IOTA - 286) & 511)]) - fVec28[((IOTA - 393) & 511)])) + ((0.00183111057f * (((fVec28[((IOTA - 89) & 511)] + fVec28[((IOTA - 121) & 511)]) - fVec28[((IOTA - 152) & 511)]) + fVec28[((IOTA - 390) & 511)])) + ((0.00228888821f * (fVec28[((IOTA - 365) & 511)] + fVec28[((IOTA - 387) & 511)])) + ((0.00173955504f * (fVec28[((IOTA - 326) & 511)] - fVec28[((IOTA - 382) & 511)])) + ((0.00247199927f * ((fVec28[((IOTA - 353) & 511)] + fVec28[((IOTA - 366) & 511)]) + fVec28[((IOTA - 378) & 511)])) + ((0.000915555283f * (((fVec28[((IOTA - 339) & 511)] - (fVec28[((IOTA - 171) & 511)] + fVec28[((IOTA - 318) & 511)])) + fVec28[((IOTA - 341) & 511)]) + fVec28[((IOTA - 417) & 511)])) + ((0.00207525864f * (fVec28[((IOTA - 82) & 511)] + fVec28[((IOTA - 376) & 511)])) + ((0.00112918485f * (fVec28[((IOTA - 265) & 511)] + fVec28[((IOTA - 375) & 511)])) + ((0.000274666585f * ((fVec28[((IOTA - 231) & 511)] + fVec28[((IOTA - 334) & 511)]) + fVec28[((IOTA - 374) & 511)])) + ((0.000518814661f * (((((((fVec28[((IOTA - 64) & 511)] - fVec28[((IOTA - 156) & 511)]) + fVec28[((IOTA - 179) & 511)]) + fVec28[((IOTA - 181) & 511)]) - fVec28[((IOTA - 207) & 511)]) + fVec28[((IOTA - 220) & 511)]) - fVec28[((IOTA - 224) & 511)]) + fVec28[((IOTA - 370) & 511)])) + ((0.00231940672f * (fVec28[((IOTA - 300) & 511)] + fVec28[((IOTA - 367) & 511)])) + ((0.000610370189f * ((((fVec28[((IOTA - 16) & 511)] - fVec28[((IOTA - 206) & 511)]) - fVec28[((IOTA - 346) & 511)]) - fVec28[((IOTA - 347) & 511)]) + fVec28[((IOTA - 362) & 511)])) + ((0.00201422162f * (fVec28[((IOTA - 311) & 511)] + fVec28[((IOTA - 355) & 511)])) + ((0.00219733268f * fVec28[((IOTA - 352) & 511)]) + ((0.00213629566f * fVec28[((IOTA - 332) & 511)]) + ((0.00402844325f * fVec28[((IOTA - 330) & 511)]) + ((0.00460829493f * fVec28[((IOTA - 329) & 511)]) + ((0.00448622089f * fVec28[((IOTA - 328) & 511)]) + ((0.00338755455f * ((fVec28[((IOTA - 28) & 511)] - fVec28[((IOTA - 162) & 511)]) + fVec28[((IOTA - 327) & 511)])) + ((0.0025940733f * (fVec28[((IOTA - 314) & 511)] + fVec28[((IOTA - 377) & 511)])) + ((0.00177007355f * fVec28[((IOTA - 315) & 511)]) + ((0.00137333293f * fVec28[((IOTA - 310) & 511)]) + ((0.000396740623f * (((fVec28[((IOTA - 183) & 511)] - fVec28[((IOTA - 228) & 511)]) - fVec28[((IOTA - 280) & 511)]) + fVec28[((IOTA - 309) & 511)])) + ((0.00100711081f * (fVec28[((IOTA - 147) & 511)] - fVec28[((IOTA - 308) & 511)])) + ((0.00167851802f * fVec28[((IOTA - 301) & 511)]) + ((0.00109866634f * ((fVec28[((IOTA - 198) & 511)] + fVec28[((IOTA - 263) & 511)]) + fVec28[((IOTA - 285) & 511)])) + ((0.00149540696f * (fVec28[((IOTA - 187) & 511)] - fVec28[((IOTA - 215) & 511)])) + ((0.00152592547f * fVec28[((IOTA - 188) & 511)]) + ((0.0019226661f * fVec28[((IOTA - 146) & 511)]) + ((0.00250251777f * (fVec28[((IOTA - 145) & 511)] - fVec28[((IOTA - 138) & 511)])) + ((0.00253303628f * fVec28[((IOTA - 134) & 511)]) + ((0.00405896176f * fVec28[((IOTA - 133) & 511)]) + ((0.00442518387f * fVec28[((IOTA - 132) & 511)]) + ((0.00143436994f * fVec28[((IOTA - 122) & 511)]) + ((0.00286873989f * fVec28[((IOTA - 144) & 511)]) + ((0.00927762687f * (fVec28[((IOTA - 79) & 511)] - fVec28[((IOTA - 99) & 511)])) + ((0.00146488845f * fVec28[((IOTA - 95) & 511)]) + ((0.0071108127f * fVec28[((IOTA - 94) & 511)]) + ((0.0104983672f * fVec28[((IOTA - 93) & 511)]) + ((0.0115970336f * fVec28[((IOTA - 92) & 511)]) + ((0.0114749596f * fVec28[((IOTA - 91) & 511)]) + ((0.00738547929f * fVec28[((IOTA - 90) & 511)]) + ((0.0127872555f * fVec28[((IOTA - 81) & 511)]) + ((0.0180059206f * fVec28[((IOTA - 80) & 511)]) + ((0.0115665151f * fVec28[((IOTA - 69) & 511)]) + ((0.0228888821f * fVec28[((IOTA - 68) & 511)]) + ((0.0277718436f * fVec28[((IOTA - 67) & 511)]) + ((0.0238959938f * fVec28[((IOTA - 66) & 511)]) + ((0.0126956999f * fVec28[((IOTA - 65) & 511)]) + ((0.00509659108f * fVec28[((IOTA - 57) & 511)]) + ((0.0155034028f * fVec28[((IOTA - 56) & 511)]) + ((0.0144657735f * fVec28[((IOTA - 55) & 511)]) + ((0.00726340525f * fVec28[((IOTA - 54) & 511)]) + ((0.03869747f * fVec28[((IOTA - 39) & 511)]) + ((0.0460219122f * fVec28[((IOTA - 38) & 511)]) + ((0.0478225052f * fVec28[((IOTA - 37) & 511)]) + ((0.0248115491f * fVec28[((IOTA - 36) & 511)]) + ((0.0285958443f * fVec28[((IOTA - 27) & 511)]) + ((0.0415051728f * fVec28[((IOTA - 26) & 511)]) + ((0.0421765819f * fVec28[((IOTA - 25) & 511)]) + ((0.0339060649f * fVec28[((IOTA - 24) & 511)]) + ((0.0345774703f * fVec28[((IOTA - 23) & 511)]) + ((0.0108340709f * fVec28[((IOTA - 22) & 511)]) + ((0.0360423587f * fVec28[((IOTA - 15) & 511)]) + ((0.0933561176f * fVec28[((IOTA - 14) & 511)]) + ((0.131076992f * fVec28[((IOTA - 13) & 511)]) + ((0.139591664f * fVec28[((IOTA - 12) & 511)]) + ((0.0569170192f * fVec28[((IOTA - 11) & 511)]) + ((0.156132698f * fVec28[((IOTA - 4) & 511)]) + ((0.300515771f * fVec28[((IOTA - 3) & 511)]) + ((0.25452438f * fVec28[((IOTA - 2) & 511)]) + ((0.114261299f * fVec28[((IOTA - 1) & 511)]) + ((fSlow71 * fTemp0) + ((0.0198370311f * fVec28[((IOTA - 40) & 511)]) + ((0.00854518265f * fVec28[((IOTA - 41) & 511)]) + (0.00671407208f * fVec28[((IOTA - 42) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (9.15555283e-05f * ((((((((((((((fVec28[((IOTA - 135) & 511)] - fVec28[((IOTA - 178) & 511)]) - fVec28[((IOTA - 190) & 511)]) - fVec28[((IOTA - 238) & 511)]) + fVec28[((IOTA - 246) & 511)]) + fVec28[((IOTA - 247) & 511)]) - fVec28[((IOTA - 277) & 511)]) - fVec28[((IOTA - 281) & 511)]) + fVec28[((IOTA - 325) & 511)]) - fVec28[((IOTA - 348) & 511)]) - fVec28[((IOTA - 447) & 511)]) - fVec28[((IOTA - 451) & 511)]) - fVec28[((IOTA - 481) & 511)]) - fVec28[((IOTA - 485) & 511)]) + fVec28[((IOTA - 488) & 511)])))))))))) - (((0.000213629566f * ((((((((fVec28[((IOTA - 129) & 511)] + fVec28[((IOTA - 177) & 511)]) - fVec28[((IOTA - 201) & 511)]) - fVec28[((IOTA - 270) & 511)]) - fVec28[((IOTA - 344) & 511)]) - fVec28[((IOTA - 398) & 511)]) + fVec28[((IOTA - 482) & 511)]) + fVec28[((IOTA - 483) & 511)]) - fVec28[((IOTA - 509) & 511)])) + ((0.000427259132f * ((((((((((((((fVec28[((IOTA - 168) & 511)] - fVec28[((IOTA - 249) & 511)]) - fVec28[((IOTA - 250) & 511)]) - fVec28[((IOTA - 256) & 511)]) - fVec28[((IOTA - 276) & 511)]) + fVec28[((IOTA - 289) & 511)]) - fVec28[((IOTA - 294) & 511)]) + fVec28[((IOTA - 360) & 511)]) - fVec28[((IOTA - 410) & 511)]) - fVec28[((IOTA - 440) & 511)]) + fVec28[((IOTA - 461) & 511)]) + fVec28[((IOTA - 470) & 511)]) + fVec28[((IOTA - 473) & 511)]) - fVec28[((IOTA - 499) & 511)]) - fVec28[((IOTA - 501) & 511)])) + ((0.000488296151f * ((((((((fVec28[((IOTA - 157) & 511)] - fVec28[((IOTA - 185) & 511)]) + fVec28[((IOTA - 193) & 511)]) + fVec28[((IOTA - 204) & 511)]) - fVec28[((IOTA - 222) & 511)]) - fVec28[((IOTA - 258) & 511)]) + fVec28[((IOTA - 279) & 511)]) - fVec28[((IOTA - 385) & 511)]) - fVec28[((IOTA - 500) & 511)])) + ((0.000183111057f * (((((fVec28[((IOTA - 102) & 511)] - fVec28[((IOTA - 219) & 511)]) - fVec28[((IOTA - 234) & 511)]) - fVec28[((IOTA - 282) & 511)]) - fVec28[((IOTA - 458) & 511)]) - fVec28[((IOTA - 496) & 511)])) + ((0.00057985168f * ((fVec28[((IOTA - 164) & 511)] - fVec28[((IOTA - 283) & 511)]) + fVec28[((IOTA - 465) & 511)])) + ((0.000793481246f * ((((fVec28[((IOTA - 153) & 511)] - fVec28[((IOTA - 275) & 511)]) - fVec28[((IOTA - 455) & 511)]) + fVec28[((IOTA - 463) & 511)]) + fVec28[((IOTA - 464) & 511)])) + ((0.000671407208f * ((((((((fVec28[((IOTA - 154) & 511)] - fVec28[((IOTA - 166) & 511)]) + fVec28[((IOTA - 205) & 511)]) - fVec28[((IOTA - 251) & 511)]) - fVec28[((IOTA - 266) & 511)]) - fVec28[((IOTA - 287) & 511)]) + fVec28[((IOTA - 384) & 511)]) - fVec28[((IOTA - 418) & 511)]) + fVec28[((IOTA - 462) & 511)])) + ((3.05185094e-05f * (((((((((fVec28[((IOTA - 293) & 511)] - ((fVec28[((IOTA - 212) & 511)] - fVec28[((IOTA - 239) & 511)]) + fVec28[((IOTA - 269) & 511)])) - fVec28[((IOTA - 361) & 511)]) + fVec28[((IOTA - 424) & 511)]) - fVec28[((IOTA - 425) & 511)]) + fVec28[((IOTA - 446) & 511)]) - fVec28[((IOTA - 480) & 511)]) + fVec28[((IOTA - 486) & 511)]) - fVec28[((IOTA - 504) & 511)]) + fVec28[((IOTA - 507) & 511)])) + ((0.00155644398f * ((((((fVec28[((IOTA - 127) & 511)] + fVec28[((IOTA - 140) & 511)]) - fVec28[((IOTA - 296) & 511)]) + fVec28[((IOTA - 319) & 511)]) + fVec28[((IOTA - 383) & 511)]) - fVec28[((IOTA - 386) & 511)]) - fVec28[((IOTA - 414) & 511)])) + ((0.00158696249f * (((fVec28[((IOTA - 106) & 511)] - fVec28[((IOTA - 379) & 511)]) + fVec28[((IOTA - 395) & 511)]) - fVec28[((IOTA - 413) & 511)])) + ((0.00134281442f * ((((fVec28[((IOTA - 43) & 511)] + fVec28[((IOTA - 123) & 511)]) + fVec28[((IOTA - 304) & 511)]) - fVec28[((IOTA - 400) & 511)]) - fVec28[((IOTA - 412) & 511)])) + ((0.000854518265f * ((((((fVec28[((IOTA - 169) & 511)] + fVec28[((IOTA - 174) & 511)]) + fVec28[((IOTA - 191) & 511)]) + fVec28[((IOTA - 217) & 511)]) + fVec28[((IOTA - 225) & 511)]) + fVec28[((IOTA - 226) & 511)]) - fVec28[((IOTA - 411) & 511)])) + ((0.000701925717f * ((((((fVec28[((IOTA - 192) & 511)] - fVec28[((IOTA - 211) & 511)]) - fVec28[((IOTA - 259) & 511)]) - fVec28[((IOTA - 273) & 511)]) + fVec28[((IOTA - 291) & 511)]) - fVec28[((IOTA - 338) & 511)]) - fVec28[((IOTA - 405) & 511)])) + ((0.00119022187f * (fVec28[((IOTA - 396) & 511)] - fVec28[((IOTA - 404) & 511)])) + ((0.001617481f * ((fVec28[((IOTA - 136) & 511)] + fVec28[((IOTA - 394) & 511)]) - fVec28[((IOTA - 403) & 511)])) + ((0.000946073793f * (((fVec28[((IOTA - 172) & 511)] - fVec28[((IOTA - 243) & 511)]) - fVec28[((IOTA - 295) & 511)]) - fVec28[((IOTA - 391) & 511)])) + ((0.00238044374f * ((fVec28[((IOTA - 305) & 511)] - fVec28[((IOTA - 354) & 511)]) - fVec28[((IOTA - 389) & 511)])) + ((0.00256355479f * (fVec28[((IOTA - 160) & 511)] - fVec28[((IOTA - 388) & 511)])) + ((0.00103762932f * (((((fVec28[((IOTA - 148) & 511)] - fVec28[((IOTA - 186) & 511)]) - fVec28[((IOTA - 242) & 511)]) - fVec28[((IOTA - 254) & 511)]) - fVec28[((IOTA - 340) & 511)]) + fVec28[((IOTA - 381) & 511)])) + ((0.00186162908f * (fVec28[((IOTA - 159) & 511)] - fVec28[((IOTA - 364) & 511)])) + ((0.0012817774f * (((fVec28[((IOTA - 216) & 511)] + fVec28[((IOTA - 324) & 511)]) - fVec28[((IOTA - 350) & 511)]) - fVec28[((IOTA - 363) & 511)])) + ((0.00125125889f * ((((fVec28[((IOTA - 104) & 511)] + fVec28[((IOTA - 173) & 511)]) - fVec28[((IOTA - 199) & 511)]) - fVec28[((IOTA - 253) & 511)]) - fVec28[((IOTA - 356) & 511)])) + ((0.000762962736f * (((((fVec28[((IOTA - 158) & 511)] + fVec28[((IOTA - 213) & 511)]) + fVec28[((IOTA - 227) & 511)]) - fVec28[((IOTA - 255) & 511)]) - fVec28[((IOTA - 261) & 511)]) - fVec28[((IOTA - 342) & 511)])) + ((0.00311288796f * (fVec28[((IOTA - 322) & 511)] - fVec28[((IOTA - 331) & 511)])) + ((0.00241096225f * fVec28[((IOTA - 323) & 511)]) + ((0.00302133244f * fVec28[((IOTA - 321) & 511)]) + ((0.00234992523f * (fVec28[((IOTA - 307) & 511)] + fVec28[((IOTA - 320) & 511)])) + ((0.00292977691f * (((fVec28[((IOTA - 124) & 511)] - fVec28[((IOTA - 143) & 511)]) + fVec28[((IOTA - 149) & 511)]) - fVec28[((IOTA - 313) & 511)])) + ((0.00262459181f * ((fVec28[((IOTA - 117) & 511)] - fVec28[((IOTA - 298) & 511)]) - fVec28[((IOTA - 312) & 511)])) + ((0.00283822138f * (fVec28[((IOTA - 108) & 511)] + fVec28[((IOTA - 306) & 511)])) + ((0.000823999755f * (((((fVec28[((IOTA - 107) & 511)] - fVec28[((IOTA - 165) & 511)]) - fVec28[((IOTA - 244) & 511)]) - fVec28[((IOTA - 260) & 511)]) - fVec28[((IOTA - 274) & 511)]) - fVec28[((IOTA - 302) & 511)])) + ((0.00268562883f * (fVec28[((IOTA - 126) & 511)] - fVec28[((IOTA - 299) & 511)])) + ((0.00222785119f * (fVec28[((IOTA - 118) & 511)] - fVec28[((IOTA - 297) & 511)])) + ((0.00131229591f * (fVec28[((IOTA - 214) & 511)] - fVec28[((IOTA - 264) & 511)])) + ((0.000976592302f * ((((fVec28[((IOTA - 128) & 511)] + fVec28[((IOTA - 155) & 511)]) + fVec28[((IOTA - 170) & 511)]) - fVec28[((IOTA - 210) & 511)]) - fVec28[((IOTA - 252) & 511)])) + ((0.00216681417f * fVec28[((IOTA - 163) & 511)]) + ((0.00320444349f * ((fVec28[((IOTA - 70) & 511)] - fVec28[((IOTA - 131) & 511)]) + fVec28[((IOTA - 161) & 511)])) + ((0.00308236945f * (fVec28[((IOTA - 125) & 511)] + fVec28[((IOTA - 151) & 511)])) + ((0.00381481368f * fVec28[((IOTA - 150) & 511)]) + ((0.00210577715f * (fVec28[((IOTA - 119) & 511)] - fVec28[((IOTA - 142) & 511)])) + ((0.00265511032f * fVec28[((IOTA - 139) & 511)]) + ((0.00244148076f * fVec28[((IOTA - 137) & 511)]) + ((0.00506607257f * (fVec28[((IOTA - 88) & 511)] + fVec28[((IOTA - 116) & 511)])) + ((0.00756859034f * fVec28[((IOTA - 115) & 511)]) + ((0.00772118289f * fVec28[((IOTA - 114) & 511)]) + ((0.00555436872f * fVec28[((IOTA - 113) & 511)]) + ((0.00418103579f * fVec28[((IOTA - 112) & 511)]) + ((0.00296029542f * fVec28[((IOTA - 105) & 511)]) + ((0.00543229468f * fVec28[((IOTA - 101) & 511)]) + ((0.00860621966f * fVec28[((IOTA - 100) & 511)]) + ((0.00439466536f * fVec28[((IOTA - 109) & 511)]) + ((0.00979644153f * (fVec28[((IOTA - 51) & 511)] + fVec28[((IOTA - 98) & 511)])) + ((0.00396740623f * fVec28[((IOTA - 110) & 511)]) + ((0.00280770287f * fVec28[((IOTA - 111) & 511)]) + ((0.0108035523f * fVec28[((IOTA - 97) & 511)]) + ((0.00723288674f * fVec28[((IOTA - 96) & 511)]) + ((0.013000885f * fVec28[((IOTA - 87) & 511)]) + ((0.0181585141f * fVec28[((IOTA - 86) & 511)]) + ((0.0172429588f * fVec28[((IOTA - 85) & 511)]) + ((0.012817774f * fVec28[((IOTA - 84) & 511)]) + ((0.00640888698f * fVec28[((IOTA - 83) & 511)]) + ((0.00357066561f * fVec28[((IOTA - 78) & 511)]) + ((0.00778221991f * fVec28[((IOTA - 77) & 511)]) + ((0.00433362834f * fVec28[((IOTA - 76) & 511)]) + ((0.0038758507f * fVec28[((IOTA - 75) & 511)]) + ((0.00952177495f * fVec28[((IOTA - 74) & 511)]) + ((0.0180669576f * fVec28[((IOTA - 73) & 511)]) + ((0.0216986611f * fVec28[((IOTA - 72) & 511)]) + ((0.0162053294f * fVec28[((IOTA - 71) & 511)]) + ((0.0140385143f * fVec28[((IOTA - 63) & 511)]) + ((0.0287484359f * fVec28[((IOTA - 62) & 511)]) + ((0.0396435447f * fVec28[((IOTA - 61) & 511)]) + ((0.0420239866f * fVec28[((IOTA - 60) & 511)]) + ((0.0325632505f * fVec28[((IOTA - 59) & 511)]) + ((0.0149235511f * fVec28[((IOTA - 58) & 511)]) + ((0.00622577593f * fVec28[((IOTA - 52) & 511)]) + ((0.00732444227f * fVec28[((IOTA - 50) & 511)]) + ((0.00964384899f * fVec28[((IOTA - 49) & 511)]) + ((0.0129703665f * fVec28[((IOTA - 48) & 511)]) + ((0.0217291787f * fVec28[((IOTA - 47) & 511)]) + ((0.0271004364f * fVec28[((IOTA - 46) & 511)]) + ((0.028931547f * fVec28[((IOTA - 45) & 511)]) + (((((((((((((((((((0.035401471f * fVec28[((IOTA - 5) & 511)]) + (0.160588399f * fVec28[((IOTA - 6) & 511)])) + (0.178899497f * fVec28[((IOTA - 7) & 511)])) + (0.169713438f * fVec28[((IOTA - 8) & 511)])) + (0.135929435f * fVec28[((IOTA - 9) & 511)])) + (0.0429090261f * fVec28[((IOTA - 10) & 511)])) + (0.0565813184f * fVec28[((IOTA - 17) & 511)])) + (0.113284707f * fVec28[((IOTA - 18) & 511)])) + (0.142765582f * fVec28[((IOTA - 19) & 511)])) + (0.116855375f * fVec28[((IOTA - 20) & 511)])) + (0.043671988f * fVec28[((IOTA - 21) & 511)])) + (0.0156559963f * fVec28[((IOTA - 29) & 511)])) + (0.0334177688f * fVec28[((IOTA - 30) & 511)])) + (0.048341319f * fVec28[((IOTA - 31) & 511)])) + (0.0417798385f * fVec28[((IOTA - 32) & 511)])) + (0.0314340666f * fVec28[((IOTA - 33) & 511)])) + (0.0259712525f * fVec28[((IOTA - 34) & 511)])) + (0.00469985045f * fVec28[((IOTA - 35) & 511)])) + (0.0186468102f * fVec28[((IOTA - 44) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * ((((((((((fVec28[((IOTA - 53) & 511)] - fVec28[((IOTA - 167) & 511)]) + fVec28[((IOTA - 175) & 511)]) - fVec28[((IOTA - 184) & 511)]) + fVec28[((IOTA - 202) & 511)]) - fVec28[((IOTA - 233) & 511)]) + fVec28[((IOTA - 292) & 511)]) - fVec28[((IOTA - 337) & 511)]) - fVec28[((IOTA - 357) & 511)]) - fVec28[((IOTA - 406) & 511)]) - fVec28[((IOTA - 510) & 511)])))))) : (iSlow60 ? (iSlow64 ? (((9.15555283e-05f * (((((fVec27[((IOTA - 167) & 511)] - fVec27[((IOTA - 264) & 511)]) + fVec27[((IOTA - 273) & 511)]) - fVec27[((IOTA - 289) & 511)]) + fVec27[((IOTA - 290) & 511)]) - fVec27[((IOTA - 511) & 511)])) + ((0.000335703604f * (((((((((fVec27[((IOTA - 179) & 511)] - fVec27[((IOTA - 191) & 511)]) - fVec27[((IOTA - 254) & 511)]) + fVec27[((IOTA - 258) & 511)]) - fVec27[((IOTA - 357) & 511)]) - fVec27[((IOTA - 414) & 511)]) - fVec27[((IOTA - 463) & 511)]) - fVec27[((IOTA - 492) & 511)]) + fVec27[((IOTA - 502) & 511)]) - fVec27[((IOTA - 509) & 511)])) + ((0.000366222113f * (((((fVec27[((IOTA - 292) & 511)] + fVec27[((IOTA - 312) & 511)]) - fVec27[((IOTA - 362) & 511)]) + fVec27[((IOTA - 489) & 511)]) - fVec27[((IOTA - 507) & 511)]) - fVec27[((IOTA - 508) & 511)])) + ((0.000305185094f * ((((((((((fVec27[((IOTA - 233) & 511)] + fVec27[((IOTA - 235) & 511)]) - fVec27[((IOTA - 280) & 511)]) + fVec27[((IOTA - 291) & 511)]) - fVec27[((IOTA - 296) & 511)]) + fVec27[((IOTA - 307) & 511)]) + fVec27[((IOTA - 356) & 511)]) + fVec27[((IOTA - 421) & 511)]) - fVec27[((IOTA - 441) & 511)]) - fVec27[((IOTA - 495) & 511)]) - fVec27[((IOTA - 506) & 511)])) + ((0.000152592547f * ((((((((((((fVec27[((IOTA - 174) & 511)] - fVec27[((IOTA - 206) & 511)]) + fVec27[((IOTA - 222) & 511)]) + fVec27[((IOTA - 259) & 511)]) + fVec27[((IOTA - 262) & 511)]) - fVec27[((IOTA - 279) & 511)]) - fVec27[((IOTA - 287) & 511)]) - fVec27[((IOTA - 288) & 511)]) - fVec27[((IOTA - 295) & 511)]) - fVec27[((IOTA - 393) & 511)]) + fVec27[((IOTA - 434) & 511)]) - fVec27[((IOTA - 496) & 511)]) - fVec27[((IOTA - 505) & 511)])) + ((3.05185094e-05f * (((((fVec27[((IOTA - 344) & 511)] - ((((((fVec27[((IOTA - 187) & 511)] + fVec27[((IOTA - 190) & 511)]) - fVec27[((IOTA - 261) & 511)]) + fVec27[((IOTA - 268) & 511)]) + fVec27[((IOTA - 300) & 511)]) + fVec27[((IOTA - 302) & 511)]) + fVec27[((IOTA - 313) & 511)])) + fVec27[((IOTA - 476) & 511)]) - fVec27[((IOTA - 483) & 511)]) + fVec27[((IOTA - 497) & 511)]) + fVec27[((IOTA - 504) & 511)])) + ((0.000213629566f * (((((((((fVec27[((IOTA - 188) & 511)] + fVec27[((IOTA - 213) & 511)]) + fVec27[((IOTA - 237) & 511)]) + fVec27[((IOTA - 257) & 511)]) - fVec27[((IOTA - 272) & 511)]) - fVec27[((IOTA - 281) & 511)]) + fVec27[((IOTA - 293) & 511)]) - fVec27[((IOTA - 303) & 511)]) - fVec27[((IOTA - 449) & 511)]) + fVec27[((IOTA - 503) & 511)])) + ((0.000457777642f * (((((((((fVec27[((IOTA - 153) & 511)] - fVec27[((IOTA - 231) & 511)]) + fVec27[((IOTA - 234) & 511)]) + fVec27[((IOTA - 238) & 511)]) - fVec27[((IOTA - 244) & 511)]) + fVec27[((IOTA - 351) & 511)]) + fVec27[((IOTA - 442) & 511)]) - fVec27[((IOTA - 481) & 511)]) + fVec27[((IOTA - 485) & 511)]) + fVec27[((IOTA - 500) & 511)])) + ((0.000396740623f * ((((((((fVec27[((IOTA - 108) & 511)] - fVec27[((IOTA - 186) & 511)]) - fVec27[((IOTA - 194) & 511)]) + fVec27[((IOTA - 242) & 511)]) + fVec27[((IOTA - 275) & 511)]) - fVec27[((IOTA - 284) & 511)]) - fVec27[((IOTA - 285) & 511)]) - fVec27[((IOTA - 298) & 511)]) + fVec27[((IOTA - 499) & 511)])) + ((0.000640888698f * ((((fVec27[((IOTA - 163) & 511)] + fVec27[((IOTA - 209) & 511)]) - fVec27[((IOTA - 320) & 511)]) - fVec27[((IOTA - 468) & 511)]) + fVec27[((IOTA - 487) & 511)])) + ((0.000610370189f * (((((fVec27[((IOTA - 156) & 511)] + fVec27[((IOTA - 239) & 511)]) + fVec27[((IOTA - 240) & 511)]) - fVec27[((IOTA - 271) & 511)]) - fVec27[((IOTA - 479) & 511)]) + fVec27[((IOTA - 486) & 511)])) + ((0.00057985168f * ((((((((fVec27[((IOTA - 12) & 511)] + fVec27[((IOTA - 166) & 511)]) - fVec27[((IOTA - 246) & 511)]) + fVec27[((IOTA - 276) & 511)]) + fVec27[((IOTA - 308) & 511)]) - fVec27[((IOTA - 350) & 511)]) + fVec27[((IOTA - 368) & 511)]) - fVec27[((IOTA - 408) & 511)]) - fVec27[((IOTA - 480) & 511)])) + ((0.000488296151f * ((((((fVec27[((IOTA - 195) & 511)] + fVec27[((IOTA - 226) & 511)]) - fVec27[((IOTA - 229) & 511)]) + fVec27[((IOTA - 375) & 511)]) + fVec27[((IOTA - 401) & 511)]) + fVec27[((IOTA - 448) & 511)]) - fVec27[((IOTA - 478) & 511)])) + ((0.000274666585f * (((((fVec27[((IOTA - 73) & 511)] + fVec27[((IOTA - 214) & 511)]) + fVec27[((IOTA - 267) & 511)]) + fVec27[((IOTA - 364) & 511)]) - fVec27[((IOTA - 380) & 511)]) + fVec27[((IOTA - 475) & 511)])) + ((0.000732444227f * ((((((fVec27[((IOTA - 210) & 511)] + fVec27[((IOTA - 223) & 511)]) + fVec27[((IOTA - 322) & 511)]) + fVec27[((IOTA - 415) & 511)]) - fVec27[((IOTA - 422) & 511)]) - fVec27[((IOTA - 435) & 511)]) + fVec27[((IOTA - 472) & 511)])) + ((0.000183111057f * (((((fVec27[((IOTA - 184) & 511)] - ((fVec27[((IOTA - 142) & 511)] + fVec27[((IOTA - 149) & 511)]) - fVec27[((IOTA - 172) & 511)])) + fVec27[((IOTA - 189) & 511)]) + fVec27[((IOTA - 266) & 511)]) + fVec27[((IOTA - 462) & 511)]) + fVec27[((IOTA - 470) & 511)])) + ((0.00109866634f * ((((fVec27[((IOTA - 225) & 511)] - fVec27[((IOTA - 319) & 511)]) - fVec27[((IOTA - 360) & 511)]) - fVec27[((IOTA - 373) & 511)]) - fVec27[((IOTA - 451) & 511)])) + ((0.00189214759f * ((((fVec27[((IOTA - 155) & 511)] + fVec27[((IOTA - 197) & 511)]) + fVec27[((IOTA - 388) & 511)]) + fVec27[((IOTA - 391) & 511)]) + fVec27[((IOTA - 431) & 511)])) + ((0.00177007355f * fVec27[((IOTA - 430) & 511)]) + ((0.00119022187f * (((fVec27[((IOTA - 183) & 511)] - fVec27[((IOTA - 372) & 511)]) + fVec27[((IOTA - 379) & 511)]) + fVec27[((IOTA - 429) & 511)])) + ((0.00201422162f * (((fVec27[((IOTA - 154) & 511)] + fVec27[((IOTA - 182) & 511)]) - fVec27[((IOTA - 384) & 511)]) - fVec27[((IOTA - 424) & 511)])) + ((0.00155644398f * (fVec27[((IOTA - 354) & 511)] - fVec27[((IOTA - 423) & 511)])) + ((0.00213629566f * fVec27[((IOTA - 419) & 511)]) + ((0.00244148076f * ((fVec27[((IOTA - 324) & 511)] - fVec27[((IOTA - 330) & 511)]) + fVec27[((IOTA - 418) & 511)])) + ((0.00222785119f * fVec27[((IOTA - 417) & 511)]) + ((0.00219733268f * ((fVec27[((IOTA - 378) & 511)] - fVec27[((IOTA - 410) & 511)]) - fVec27[((IOTA - 412) & 511)])) + ((0.00137333293f * fVec27[((IOTA - 444) & 511)]) + ((0.000427259132f * (fVec27[((IOTA - 501) & 511)] - ((((((((fVec27[((IOTA - 185) & 511)] - fVec27[((IOTA - 208) & 511)]) + fVec27[((IOTA - 228) & 511)]) + fVec27[((IOTA - 297) & 511)]) + fVec27[((IOTA - 314) & 511)]) + fVec27[((IOTA - 370) & 511)]) + fVec27[((IOTA - 386) & 511)]) + fVec27[((IOTA - 493) & 511)]) + fVec27[((IOTA - 494) & 511)]))) + ((0.00302133244f * fVec27[((IOTA - 404) & 511)]) + ((0.00271614734f * fVec27[((IOTA - 403) & 511)]) + ((0.00228888821f * ((fVec27[((IOTA - 326) & 511)] + fVec27[((IOTA - 377) & 511)]) - fVec27[((IOTA - 399) & 511)])) + ((0.00265511032f * fVec27[((IOTA - 390) & 511)]) + ((0.00268562883f * (fVec27[((IOTA - 325) & 511)] + fVec27[((IOTA - 389) & 511)])) + ((0.000701925717f * (((fVec27[((IOTA - 173) & 511)] - fVec27[((IOTA - 192) & 511)]) + fVec27[((IOTA - 311) & 511)]) + fVec27[((IOTA - 387) & 511)])) + ((0.00158696249f * fVec27[((IOTA - 376) & 511)]) + ((0.000915555283f * ((fVec27[((IOTA - 250) & 511)] + fVec27[((IOTA - 310) & 511)]) - fVec27[((IOTA - 371) & 511)])) + ((0.000762962736f * (((fVec27[((IOTA - 248) & 511)] + fVec27[((IOTA - 251) & 511)]) - fVec27[((IOTA - 361) & 511)]) + fVec27[((IOTA - 366) & 511)])) + ((0.00207525864f * (fVec27[((IOTA - 181) & 511)] + fVec27[((IOTA - 340) & 511)])) + ((0.00234992523f * (fVec27[((IOTA - 338) & 511)] + fVec27[((IOTA - 339) & 511)])) + ((0.00149540696f * fVec27[((IOTA - 199) & 511)]) + (((0.00125125889f * fVec27[((IOTA - 164) & 511)]) + ((0.00253303628f * (fVec27[((IOTA - 121) & 511)] - fVec27[((IOTA - 158) & 511)])) + ((0.00216681417f * (fVec27[((IOTA - 87) & 511)] - fVec27[((IOTA - 146) & 511)])) + ((0.00381481368f * fVec27[((IOTA - 140) & 511)]) + ((0.00595110934f * fVec27[((IOTA - 139) & 511)]) + ((0.00637836847f * fVec27[((IOTA - 138) & 511)]) + ((0.00460829493f * fVec27[((IOTA - 137) & 511)]) + ((0.0012817774f * fVec27[((IOTA - 136) & 511)]) + ((0.00112918485f * fVec27[((IOTA - 129) & 511)]) + ((0.0028992584f * fVec27[((IOTA - 128) & 511)]) + ((0.00357066561f * fVec27[((IOTA - 127) & 511)]) + ((0.00399792474f * fVec27[((IOTA - 126) & 511)]) + ((0.004852443f * fVec27[((IOTA - 125) & 511)]) + ((0.00589007232f * fVec27[((IOTA - 124) & 511)]) + ((0.00631733146f * (fVec27[((IOTA - 94) & 511)] + fVec27[((IOTA - 123) & 511)])) + ((0.00537125766f * fVec27[((IOTA - 122) & 511)]) + ((0.00384533219f * fVec27[((IOTA - 113) & 511)]) + ((0.0093691824f * fVec27[((IOTA - 112) & 511)]) + ((0.0119327372f * fVec27[((IOTA - 110) & 511)]) + ((0.00683614612f * fVec27[((IOTA - 109) & 511)]) + ((0.00286873989f * fVec27[((IOTA - 99) & 511)]) + ((0.00909451582f * fVec27[((IOTA - 98) & 511)]) + ((0.014557329f * fVec27[((IOTA - 97) & 511)]) + ((0.016296884f * fVec27[((IOTA - 96) & 511)]) + ((0.0131534776f * fVec27[((IOTA - 95) & 511)]) + ((0.0143742179f * fVec27[((IOTA - 86) & 511)]) + ((0.0253608823f * fVec27[((IOTA - 85) & 511)]) + ((0.0321665108f * fVec27[((IOTA - 84) & 511)]) + ((0.0336313993f * fVec27[((IOTA - 83) & 511)]) + ((0.0283822138f * fVec27[((IOTA - 82) & 511)]) + ((0.0153508103f * fVec27[((IOTA - 81) & 511)]) + ((0.0200811792f * fVec27[((IOTA - 72) & 511)]) + ((0.0401013233f * fVec27[((IOTA - 71) & 511)]) + ((0.0548417605f * fVec27[((IOTA - 70) & 511)]) + ((0.0593584999f * fVec27[((IOTA - 69) & 511)]) + ((0.0502945036f * fVec27[((IOTA - 68) & 511)]) + ((0.0283211768f * fVec27[((IOTA - 67) & 511)]) + ((0.012878811f * fVec27[((IOTA - 111) & 511)]) + ((0.00912503432f * fVec27[((IOTA - 59) & 511)]) + ((0.0415356904f * fVec27[((IOTA - 58) & 511)]) + ((0.0637836829f * fVec27[((IOTA - 57) & 511)]) + ((0.0726340562f * fVec27[((IOTA - 56) & 511)]) + ((0.0677816123f * fVec27[((IOTA - 55) & 511)]) + ((0.0482802838f * fVec27[((IOTA - 54) & 511)]) + ((0.016235847f * fVec27[((IOTA - 53) & 511)]) + ((0.0228278451f * fVec27[((IOTA - 45) & 511)]) + ((0.0547196865f * fVec27[((IOTA - 44) & 511)]) + ((0.0648823529f * fVec27[((IOTA - 43) & 511)]) + ((0.0584429465f * fVec27[((IOTA - 42) & 511)]) + ((0.0456556901f * fVec27[((IOTA - 41) & 511)]) + ((0.0292672515f * fVec27[((IOTA - 40) & 511)]) + ((0.00503555406f * fVec27[((IOTA - 39) & 511)]) + ((0.0959501937f * fVec27[((IOTA - 29) & 511)]) + ((0.0980254561f * fVec27[((IOTA - 28) & 511)]) + ((0.0644856095f * fVec27[((IOTA - 27) & 511)]) + ((0.00347911008f * fVec27[((IOTA - 26) & 511)]) + ((0.0180669576f * fVec27[((IOTA - 18) & 511)]) + ((0.0412915424f * fVec27[((IOTA - 17) & 511)]) + ((0.0662556812f * fVec27[((IOTA - 16) & 511)]) + ((0.0982390791f * fVec27[((IOTA - 15) & 511)]) + ((0.106448561f * fVec27[((IOTA - 14) & 511)]) + ((0.0617389455f * fVec27[((IOTA - 13) & 511)]) + ((0.148503065f * fVec27[((IOTA - 4) & 511)]) + ((0.212622449f * fVec27[((IOTA - 3) & 511)]) + ((0.164616838f * fVec27[((IOTA - 2) & 511)]) + ((0.0819727182f * fVec27[((IOTA - 1) & 511)]) + ((fSlow67 * fTemp0) + ((0.0712302029f * fVec27[((IOTA - 30) & 511)]) + (0.0344859175f * fVec27[((IOTA - 31) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00167851802f * (fVec27[((IOTA - 323) & 511)] + fVec27[((IOTA - 406) & 511)]))))))))))))))))))))))))))))))))))))))))))) - (((0.000122074038f * ((((((((((fVec27[((IOTA - 227) & 511)] + fVec27[((IOTA - 232) & 511)]) - fVec27[((IOTA - 236) & 511)]) - fVec27[((IOTA - 247) & 511)]) - fVec27[((IOTA - 253) & 511)]) + fVec27[((IOTA - 282) & 511)]) + fVec27[((IOTA - 305) & 511)]) - fVec27[((IOTA - 335) & 511)]) - fVec27[((IOTA - 369) & 511)]) - fVec27[((IOTA - 490) & 511)]) + fVec27[((IOTA - 491) & 511)])) + ((0.00054933317f * (((((fVec27[((IOTA - 230) & 511)] + fVec27[((IOTA - 269) & 511)]) - fVec27[((IOTA - 277) & 511)]) - fVec27[((IOTA - 365) & 511)]) - fVec27[((IOTA - 471) & 511)]) - fVec27[((IOTA - 488) & 511)])) + ((0.000518814661f * (((((((((fVec27[((IOTA - 168) & 511)] - fVec27[((IOTA - 211) & 511)]) + fVec27[((IOTA - 220) & 511)]) - fVec27[((IOTA - 241) & 511)]) - fVec27[((IOTA - 252) & 511)]) + fVec27[((IOTA - 255) & 511)]) + fVec27[((IOTA - 374) & 511)]) - fVec27[((IOTA - 407) & 511)]) + fVec27[((IOTA - 454) & 511)]) - fVec27[((IOTA - 474) & 511)])) + ((0.000671407208f * (((fVec27[((IOTA - 66) & 511)] - fVec27[((IOTA - 456) & 511)]) - fVec27[((IOTA - 461) & 511)]) - fVec27[((IOTA - 473) & 511)])) + ((0.000885036774f * (((fVec27[((IOTA - 315) & 511)] - fVec27[((IOTA - 343) & 511)]) + fVec27[((IOTA - 358) & 511)]) + fVec27[((IOTA - 467) & 511)])) + ((0.00103762932f * (((((((fVec27[((IOTA - 143) & 511)] + fVec27[((IOTA - 162) & 511)]) - fVec27[((IOTA - 165) & 511)]) + fVec27[((IOTA - 175) & 511)]) + fVec27[((IOTA - 394) & 511)]) - fVec27[((IOTA - 443) & 511)]) - fVec27[((IOTA - 457) & 511)]) + fVec27[((IOTA - 466) & 511)])) + ((0.00100711081f * (((fVec27[((IOTA - 157) & 511)] - fVec27[((IOTA - 249) & 511)]) - fVec27[((IOTA - 355) & 511)]) + fVec27[((IOTA - 465) & 511)])) + ((0.000793481246f * ((((((fVec27[((IOTA - 193) & 511)] - fVec27[((IOTA - 200) & 511)]) + fVec27[((IOTA - 216) & 511)]) + fVec27[((IOTA - 245) & 511)]) + fVec27[((IOTA - 270) & 511)]) + fVec27[((IOTA - 450) & 511)]) + fVec27[((IOTA - 464) & 511)])) + ((0.000976592302f * (((fVec27[((IOTA - 219) & 511)] + fVec27[((IOTA - 400) & 511)]) - fVec27[((IOTA - 433) & 511)]) - fVec27[((IOTA - 460) & 511)])) + ((0.00115970336f * ((((fVec27[((IOTA - 329) & 511)] - fVec27[((IOTA - 336) & 511)]) + fVec27[((IOTA - 359) & 511)]) + fVec27[((IOTA - 452) & 511)]) - fVec27[((IOTA - 459) & 511)])) + ((6.10370189e-05f * (((((((fVec27[((IOTA - 215) & 511)] - fVec27[((IOTA - 243) & 511)]) - fVec27[((IOTA - 263) & 511)]) + fVec27[((IOTA - 265) & 511)]) - fVec27[((IOTA - 301) & 511)]) - fVec27[((IOTA - 306) & 511)]) + fVec27[((IOTA - 321) & 511)]) - fVec27[((IOTA - 455) & 511)])) + ((0.000946073793f * ((fVec27[((IOTA - 205) & 511)] + fVec27[((IOTA - 345) & 511)]) + fVec27[((IOTA - 453) & 511)])) + ((0.00106814783f * ((fVec27[((IOTA - 334) & 511)] + fVec27[((IOTA - 440) & 511)]) - fVec27[((IOTA - 447) & 511)])) + ((0.00143436994f * ((fVec27[((IOTA - 202) & 511)] + fVec27[((IOTA - 217) & 511)]) - fVec27[((IOTA - 446) & 511)])) + ((0.00152592547f * ((fVec27[((IOTA - 317) & 511)] + fVec27[((IOTA - 409) & 511)]) - fVec27[((IOTA - 445) & 511)])) + ((0.001617481f * ((fVec27[((IOTA - 381) & 511)] - fVec27[((IOTA - 432) & 511)]) + fVec27[((IOTA - 439) & 511)])) + ((0.00186162908f * (((fVec27[((IOTA - 120) & 511)] + fVec27[((IOTA - 176) & 511)]) - fVec27[((IOTA - 198) & 511)]) + fVec27[((IOTA - 438) & 511)])) + ((0.00180059206f * ((fVec27[((IOTA - 204) & 511)] - fVec27[((IOTA - 402) & 511)]) + fVec27[((IOTA - 437) & 511)])) + ((0.00140385143f * (((((fVec27[((IOTA - 318) & 511)] - ((fVec27[((IOTA - 141) & 511)] + fVec27[((IOTA - 180) & 511)]) + fVec27[((IOTA - 196) & 511)])) - fVec27[((IOTA - 342) & 511)]) + fVec27[((IOTA - 349) & 511)]) + fVec27[((IOTA - 413) & 511)]) + fVec27[((IOTA - 436) & 511)])) + ((0.000854518265f * (((fVec27[((IOTA - 147) & 511)] + fVec27[((IOTA - 171) & 511)]) - fVec27[((IOTA - 309) & 511)]) + fVec27[((IOTA - 427) & 511)])) + ((0.00170903653f * ((fVec27[((IOTA - 177) & 511)] - fVec27[((IOTA - 353) & 511)]) + fVec27[((IOTA - 426) & 511)])) + ((0.00210577715f * (fVec27[((IOTA - 203) & 511)] + fVec27[((IOTA - 425) & 511)])) + ((0.00134281442f * (fVec27[((IOTA - 385) & 511)] - fVec27[((IOTA - 420) & 511)])) + ((0.00164799951f * (fVec27[((IOTA - 100) & 511)] - fVec27[((IOTA - 416) & 511)])) + ((0.00247199927f * ((fVec27[((IOTA - 145) & 511)] + fVec27[((IOTA - 383) & 511)]) + fVec27[((IOTA - 411) & 511)])) + ((0.0025940733f * (fVec27[((IOTA - 80) & 511)] - fVec27[((IOTA - 405) & 511)])) + ((0.00317392498f * fVec27[((IOTA - 398) & 511)]) + ((0.00335703604f * fVec27[((IOTA - 397) & 511)]) + ((0.00283822138f * fVec27[((IOTA - 396) & 511)]) + ((0.0019531846f * ((fVec27[((IOTA - 130) & 511)] - fVec27[((IOTA - 337) & 511)]) + fVec27[((IOTA - 395) & 511)])) + ((0.000823999755f * ((fVec27[((IOTA - 178) & 511)] - fVec27[((IOTA - 367) & 511)]) - fVec27[((IOTA - 392) & 511)])) + ((0.00238044374f * fVec27[((IOTA - 382) & 511)]) + (((0.00131229591f * ((fVec27[((IOTA - 114) & 511)] + fVec27[((IOTA - 316) & 511)]) - fVec27[((IOTA - 352) & 511)])) + ((0.0019226661f * (fVec27[((IOTA - 93) & 511)] + fVec27[((IOTA - 348) & 511)])) + ((0.00204474013f * fVec27[((IOTA - 347) & 511)]) + ((0.00173955504f * ((fVec27[((IOTA - 152) & 511)] - fVec27[((IOTA - 341) & 511)]) + fVec27[((IOTA - 346) & 511)])) + ((0.0022583697f * fVec27[((IOTA - 333) & 511)]) + ((0.00311288796f * fVec27[((IOTA - 332) & 511)]) + ((0.00320444349f * fVec27[((IOTA - 331) & 511)]) + ((0.00146488845f * ((fVec27[((IOTA - 170) & 511)] + fVec27[((IOTA - 218) & 511)]) - fVec27[((IOTA - 327) & 511)])) + ((0.00292977691f * fVec27[((IOTA - 161) & 511)]) + ((0.00396740623f * fVec27[((IOTA - 160) & 511)]) + ((0.00369273964f * fVec27[((IOTA - 159) & 511)]) + ((0.00183111057f * (fVec27[((IOTA - 144) & 511)] + fVec27[((IOTA - 150) & 511)])) + ((0.00241096225f * fVec27[((IOTA - 135) & 511)]) + ((0.0054933317f * (fVec27[((IOTA - 115) & 511)] + fVec27[((IOTA - 134) & 511)])) + ((0.00735496078f * fVec27[((IOTA - 133) & 511)]) + ((0.00732444227f * (fVec27[((IOTA - 106) & 511)] + fVec27[((IOTA - 132) & 511)])) + ((0.00521866512f * fVec27[((IOTA - 131) & 511)]) + ((0.00277718436f * fVec27[((IOTA - 151) & 511)]) + ((0.00671407208f * fVec27[((IOTA - 119) & 511)]) + ((0.0101016266f * fVec27[((IOTA - 118) & 511)]) + ((0.0107119968f * fVec27[((IOTA - 117) & 511)]) + ((0.00881984923f * fVec27[((IOTA - 116) & 511)]) + ((0.0045167394f * fVec27[((IOTA - 107) & 511)]) + ((0.0087282937f * fVec27[((IOTA - 105) & 511)]) + ((0.0090334788f * fVec27[((IOTA - 104) & 511)]) + ((0.00814844202f * fVec27[((IOTA - 103) & 511)]) + ((0.00634784997f * fVec27[((IOTA - 102) & 511)]) + ((0.00436414685f * fVec27[((IOTA - 101) & 511)]) + ((0.00946073793f * fVec27[((IOTA - 92) & 511)]) + ((0.0147709586f * fVec27[((IOTA - 91) & 511)]) + ((0.0170293283f * fVec27[((IOTA - 90) & 511)]) + ((0.0151371807f * fVec27[((IOTA - 89) & 511)]) + ((0.00857570115f * fVec27[((IOTA - 88) & 511)]) + ((0.0198065136f * fVec27[((IOTA - 79) & 511)]) + ((0.0306405835f * fVec27[((IOTA - 78) & 511)]) + ((0.0338145085f * fVec27[((IOTA - 77) & 511)]) + ((0.0315256193f * fVec27[((IOTA - 76) & 511)]) + ((0.0257881414f * fVec27[((IOTA - 75) & 511)]) + ((((((((0.0246589556f * fVec27[((IOTA - 60) & 511)]) + (((((((((((((0.0577715375f * fVec27[((IOTA - 25) & 511)]) + ((0.0908841193f * fVec27[((IOTA - 24) & 511)]) + ((0.0967436731f * fVec27[((IOTA - 23) & 511)]) + ((0.0929898992f * fVec27[((IOTA - 22) & 511)]) + ((0.0816064924f * fVec27[((IOTA - 21) & 511)]) + ((0.056855984f * fVec27[((IOTA - 20) & 511)]) + ((0.0155644398f * fVec27[((IOTA - 19) & 511)]) + ((0.0319833979f * fVec27[((IOTA - 11) & 511)]) + ((0.0308236945f * fVec27[((IOTA - 10) & 511)]) + ((0.0667439774f * fVec27[((IOTA - 9) & 511)]) + ((0.164738908f * fVec27[((IOTA - 8) & 511)]) + ((0.242408514f * fVec27[((IOTA - 7) & 511)]) + ((0.197058022f * fVec27[((IOTA - 6) & 511)]) + ((0.0251777712f * fVec27[((IOTA - 5) & 511)]) + ((0.00274666585f * fVec27[((IOTA - 32) & 511)]) + (0.0339976214f * fVec27[((IOTA - 33) & 511)])))))))))))))))) + (0.0545365773f * fVec27[((IOTA - 34) & 511)])) + (0.0651875362f * fVec27[((IOTA - 35) & 511)])) + (0.0663167238f * fVec27[((IOTA - 36) & 511)])) + (0.0533463545f * fVec27[((IOTA - 37) & 511)])) + (0.0269478448f * fVec27[((IOTA - 38) & 511)])) + (0.0173345134f * fVec27[((IOTA - 46) & 511)])) + (0.0485244319f * fVec27[((IOTA - 47) & 511)])) + (0.0639057606f * fVec27[((IOTA - 48) & 511)])) + (0.0684835389f * fVec27[((IOTA - 49) & 511)])) + (0.0655842796f * fVec27[((IOTA - 50) & 511)])) + (0.0209662169f * fVec27[((IOTA - 52) & 511)]))) + (0.0504470952f * (fVec27[((IOTA - 51) & 511)] + fVec27[((IOTA - 61) & 511)]))) + (0.0630512387f * fVec27[((IOTA - 62) & 511)])) + (0.0624713898f * fVec27[((IOTA - 63) & 511)])) + (0.05038606f * fVec27[((IOTA - 64) & 511)])) + (0.029053621f * fVec27[((IOTA - 65) & 511)])) + (0.0155339213f * fVec27[((IOTA - 74) & 511)])))))))))))))))))))))))))))))))))))))))) + (0.00122074038f * ((fVec27[((IOTA - 169) & 511)] - fVec27[((IOTA - 224) & 511)]) - fVec27[((IOTA - 458) & 511)]))))))))))))))))))))))))))))))))))) + (0.000244148076f * (((((fVec27[((IOTA - 477) & 511)] - ((((((((((((((fVec27[((IOTA - 148) & 511)] - fVec27[((IOTA - 201) & 511)]) + fVec27[((IOTA - 207) & 511)]) + fVec27[((IOTA - 212) & 511)]) - fVec27[((IOTA - 221) & 511)]) - fVec27[((IOTA - 256) & 511)]) + fVec27[((IOTA - 274) & 511)]) + fVec27[((IOTA - 278) & 511)]) - fVec27[((IOTA - 283) & 511)]) - fVec27[((IOTA - 286) & 511)]) - fVec27[((IOTA - 299) & 511)]) - fVec27[((IOTA - 304) & 511)]) + fVec27[((IOTA - 328) & 511)]) + fVec27[((IOTA - 428) & 511)]) - fVec27[((IOTA - 469) & 511)])) + fVec27[((IOTA - 482) & 511)]) - fVec27[((IOTA - 484) & 511)]) - fVec27[((IOTA - 498) & 511)]) + fVec27[((IOTA - 510) & 511)])))) : (((0.000183111057f * (((((fVec26[((IOTA - 330) & 511)] + fVec26[((IOTA - 399) & 511)]) - fVec26[((IOTA - 402) & 511)]) + fVec26[((IOTA - 449) & 511)]) - fVec26[((IOTA - 496) & 511)]) + fVec26[((IOTA - 509) & 511)])) + ((0.000213629566f * ((((((fVec26[((IOTA - 57) & 511)] + fVec26[((IOTA - 58) & 511)]) + fVec26[((IOTA - 59) & 511)]) - fVec26[((IOTA - 273) & 511)]) - fVec26[((IOTA - 490) & 511)]) + fVec26[((IOTA - 497) & 511)]) - fVec26[((IOTA - 506) & 511)])) + ((6.10370189e-05f * (((((((((((((((((((((((((((fVec26[((IOTA - 9) & 511)] + fVec26[((IOTA - 14) & 511)]) + fVec26[((IOTA - 15) & 511)]) + fVec26[((IOTA - 16) & 511)]) + fVec26[((IOTA - 17) & 511)]) + fVec26[((IOTA - 20) & 511)]) + fVec26[((IOTA - 21) & 511)]) + fVec26[((IOTA - 22) & 511)]) + fVec26[((IOTA - 23) & 511)]) - fVec26[((IOTA - 26) & 511)]) - fVec26[((IOTA - 29) & 511)]) - fVec26[((IOTA - 30) & 511)]) - fVec26[((IOTA - 31) & 511)]) - fVec26[((IOTA - 32) & 511)]) + fVec26[((IOTA - 41) & 511)]) + fVec26[((IOTA - 42) & 511)]) + fVec26[((IOTA - 43) & 511)]) + fVec26[((IOTA - 46) & 511)]) + fVec26[((IOTA - 50) & 511)]) + fVec26[((IOTA - 53) & 511)]) + fVec26[((IOTA - 54) & 511)]) + fVec26[((IOTA - 60) & 511)]) + fVec26[((IOTA - 128) & 511)]) - fVec26[((IOTA - 150) & 511)]) - fVec26[((IOTA - 345) & 511)]) + fVec26[((IOTA - 397) & 511)]) - fVec26[((IOTA - 421) & 511)]) + fVec26[((IOTA - 504) & 511)])) + ((0.000366222113f * (((fVec26[((IOTA - 386) & 511)] + fVec26[((IOTA - 433) & 511)]) + fVec26[((IOTA - 488) & 511)]) + fVec26[((IOTA - 503) & 511)])) + ((0.000793481246f * (((((((fVec26[((IOTA - 163) & 511)] - fVec26[((IOTA - 212) & 511)]) - fVec26[((IOTA - 405) & 511)]) + fVec26[((IOTA - 417) & 511)]) - fVec26[((IOTA - 419) & 511)]) + fVec26[((IOTA - 471) & 511)]) + fVec26[((IOTA - 478) & 511)]) + fVec26[((IOTA - 501) & 511)])) + ((0.00054933317f * ((fVec26[((IOTA - 479) & 511)] + fVec26[((IOTA - 480) & 511)]) + fVec26[((IOTA - 498) & 511)])) + ((0.000732444227f * (((((fVec26[((IOTA - 106) & 511)] - fVec26[((IOTA - 327) & 511)]) + fVec26[((IOTA - 442) & 511)]) - fVec26[((IOTA - 466) & 511)]) + fVec26[((IOTA - 486) & 511)]) - fVec26[((IOTA - 493) & 511)])) + ((9.15555283e-05f * (((fVec26[((IOTA - 55) & 511)] + fVec26[((IOTA - 434) & 511)]) + fVec26[((IOTA - 440) & 511)]) + fVec26[((IOTA - 489) & 511)])) + ((0.000854518265f * (fVec26[((IOTA - 422) & 511)] + fVec26[((IOTA - 485) & 511)])) + ((0.000640888698f * ((((fVec26[((IOTA - 152) & 511)] + fVec26[((IOTA - 215) & 511)]) - fVec26[((IOTA - 403) & 511)]) - fVec26[((IOTA - 467) & 511)]) + fVec26[((IOTA - 481) & 511)])) + ((0.00131229591f * ((fVec26[((IOTA - 443) & 511)] + fVec26[((IOTA - 448) & 511)]) + fVec26[((IOTA - 476) & 511)])) + ((0.000396740623f * (((fVec26[((IOTA - 335) & 511)] - fVec26[((IOTA - 344) & 511)]) + fVec26[((IOTA - 400) & 511)]) + fVec26[((IOTA - 463) & 511)])) + ((0.000885036774f * ((((fVec26[((IOTA - 203) & 511)] - fVec26[((IOTA - 342) & 511)]) - fVec26[((IOTA - 348) & 511)]) - fVec26[((IOTA - 404) & 511)]) + fVec26[((IOTA - 461) & 511)])) + ((0.00122074038f * ((fVec26[((IOTA - 413) & 511)] - (((fVec26[((IOTA - 270) & 511)] + fVec26[((IOTA - 339) & 511)]) - fVec26[((IOTA - 376) & 511)]) - fVec26[((IOTA - 412) & 511)])) + fVec26[((IOTA - 460) & 511)])) + ((0.000274666585f * ((fVec26[((IOTA - 436) & 511)] + fVec26[((IOTA - 437) & 511)]) + fVec26[((IOTA - 455) & 511)])) + ((0.00201422162f * (fVec26[((IOTA - 392) & 511)] + fVec26[((IOTA - 444) & 511)])) + ((0.00213629566f * ((fVec26[((IOTA - 374) & 511)] - (fVec26[((IOTA - 281) & 511)] + fVec26[((IOTA - 303) & 511)])) + fVec26[((IOTA - 426) & 511)])) + ((0.00109866634f * ((fVec26[((IOTA - 202) & 511)] - fVec26[((IOTA - 364) & 511)]) + fVec26[((IOTA - 409) & 511)])) + (((0.00119022187f * fVec26[((IOTA - 393) & 511)]) + ((0.00408948027f * ((fVec26[((IOTA - 92) & 511)] - fVec26[((IOTA - 223) & 511)]) + fVec26[((IOTA - 390) & 511)])) + ((0.00424207281f * fVec26[((IOTA - 389) & 511)]) + ((0.0035401471f * fVec26[((IOTA - 388) & 511)]) + ((0.00271614734f * ((fVec26[((IOTA - 136) & 511)] - fVec26[((IOTA - 297) & 511)]) - fVec26[((IOTA - 383) & 511)])) + ((0.00216681417f * fVec26[((IOTA - 372) & 511)]) + ((0.00286873989f * fVec26[((IOTA - 360) & 511)]) + ((0.004852443f * (fVec26[((IOTA - 159) & 511)] - fVec26[((IOTA - 189) & 511)])) + ((0.00494399853f * fVec26[((IOTA - 162) & 511)]) + ((0.00909451582f * fVec26[((IOTA - 161) & 511)]) + ((0.00918607134f * fVec26[((IOTA - 160) & 511)]) + ((0.0119937742f * (fVec26[((IOTA - 107) & 511)] - fVec26[((IOTA - 157) & 511)])) + ((0.0136417737f * (fVec26[((IOTA - 113) & 511)] - fVec26[((IOTA - 154) & 511)])) + ((0.00296029542f * fVec26[((IOTA - 151) & 511)]) + ((0.00439466536f * fVec26[((IOTA - 141) & 511)]) + ((0.00766014587f * fVec26[((IOTA - 140) & 511)]) + ((0.0100100711f * fVec26[((IOTA - 139) & 511)]) + ((0.00964384899f * fVec26[((IOTA - 138) & 511)]) + ((0.00802636798f * fVec26[((IOTA - 137) & 511)]) + ((0.0187994018f * fVec26[((IOTA - 127) & 511)]) + ((0.0244758446f * fVec26[((IOTA - 126) & 511)]) + ((0.0157780703f * fVec26[((IOTA - 125) & 511)]) + ((0.00756859034f * fVec26[((IOTA - 114) & 511)]) + ((0.0169682913f * fVec26[((IOTA - 112) & 511)]) + ((0.0212408826f * fVec26[((IOTA - 111) & 511)]) + ((0.0240180679f * fVec26[((IOTA - 110) & 511)]) + ((0.0238654744f * fVec26[((IOTA - 109) & 511)]) + ((0.0170293283f * fVec26[((IOTA - 108) & 511)]) + ((0.021210365f * fVec26[((IOTA - 100) & 511)]) + ((0.0464186519f * fVec26[((IOTA - 99) & 511)]) + ((0.0420239866f * fVec26[((IOTA - 98) & 511)]) + ((0.0171208847f * fVec26[((IOTA - 97) & 511)]) + ((0.008087405f * (fVec26[((IOTA - 85) & 511)] - fVec26[((IOTA - 93) & 511)])) + ((0.00302133244f * fVec26[((IOTA - 86) & 511)]) + ((0.0119327372f * fVec26[((IOTA - 84) & 511)]) + ((0.00540177617f * fVec26[((IOTA - 83) & 511)]) + ((0.0145878475f * fVec26[((IOTA - 82) & 511)]) + ((0.0268868078f * fVec26[((IOTA - 81) & 511)]) + ((0.0364391021f * fVec26[((IOTA - 80) & 511)]) + ((0.0696737543f * fVec26[((IOTA - 75) & 511)]) + ((0.263222158f * fVec26[((IOTA - 74) & 511)]) + ((0.311349839f * fVec26[((IOTA - 73) & 511)]) + ((0.211401716f * fVec26[((IOTA - 72) & 511)]) + ((0.0849940479f * fVec26[((IOTA - 71) & 511)]) + ((0.00585955381f * fVec26[((IOTA - 69) & 511)]) + (0.0218817722f * fVec26[((IOTA - 70) & 511)])))))))))))))))))))))))))))))))))))))))))))))) + (0.000823999755f * (((((((fVec26[((IOTA - 201) & 511)] - fVec26[((IOTA - 311) & 511)]) + fVec26[((IOTA - 322) & 511)]) - fVec26[((IOTA - 341) & 511)]) + fVec26[((IOTA - 432) & 511)]) - fVec26[((IOTA - 454) & 511)]) + fVec26[((IOTA - 482) & 511)]) + fVec26[((IOTA - 500) & 511)]))))))))))))))))))))) - (((0.000305185094f * (((fVec26[((IOTA - 329) & 511)] + fVec26[((IOTA - 347) & 511)]) + fVec26[((IOTA - 468) & 511)]) - fVec26[((IOTA - 510) & 511)])) + ((0.000152592547f * ((((fVec26[((IOTA - 68) & 511)] - fVec26[((IOTA - 200) & 511)]) - fVec26[((IOTA - 396) & 511)]) - fVec26[((IOTA - 435) & 511)]) + fVec26[((IOTA - 507) & 511)])) + ((0.000122074038f * (((((((((fVec26[((IOTA - 27) & 511)] - fVec26[((IOTA - 47) & 511)]) - fVec26[((IOTA - 48) & 511)]) - fVec26[((IOTA - 49) & 511)]) - fVec26[((IOTA - 56) & 511)]) + fVec26[((IOTA - 204) & 511)]) + fVec26[((IOTA - 418) & 511)]) - fVec26[((IOTA - 438) & 511)]) - fVec26[((IOTA - 469) & 511)]) + fVec26[((IOTA - 505) & 511)])) + ((0.000610370189f * ((((fVec26[((IOTA - 142) & 511)] - fVec26[((IOTA - 332) & 511)]) - fVec26[((IOTA - 333) & 511)]) - fVec26[((IOTA - 408) & 511)]) - fVec26[((IOTA - 502) & 511)])) + ((0.000762962736f * (((fVec26[((IOTA - 343) & 511)] + fVec26[((IOTA - 420) & 511)]) + fVec26[((IOTA - 450) & 511)]) - fVec26[((IOTA - 499) & 511)])) + ((0.000488296151f * (((((fVec26[((IOTA - 199) & 511)] + fVec26[((IOTA - 313) & 511)]) - fVec26[((IOTA - 325) & 511)]) + fVec26[((IOTA - 465) & 511)]) + fVec26[((IOTA - 491) & 511)]) + fVec26[((IOTA - 495) & 511)])) + ((0.000671407208f * ((fVec26[((IOTA - 328) & 511)] + fVec26[((IOTA - 492) & 511)]) + fVec26[((IOTA - 494) & 511)])) + ((0.00057985168f * ((fVec26[((IOTA - 91) & 511)] + fVec26[((IOTA - 377) & 511)]) - fVec26[((IOTA - 487) & 511)])) + ((0.000915555283f * ((fVec26[((IOTA - 340) & 511)] - fVec26[((IOTA - 483) & 511)]) - fVec26[((IOTA - 484) & 511)])) + ((0.00106814783f * (((((((fVec26[((IOTA - 198) & 511)] - fVec26[((IOTA - 213) & 511)]) + fVec26[((IOTA - 253) & 511)]) + fVec26[((IOTA - 268) & 511)]) - fVec26[((IOTA - 323) & 511)]) + fVec26[((IOTA - 354) & 511)]) + fVec26[((IOTA - 385) & 511)]) - fVec26[((IOTA - 477) & 511)])) + ((0.00146488845f * (((((fVec26[((IOTA - 62) & 511)] - fVec26[((IOTA - 214) & 511)]) + fVec26[((IOTA - 350) & 511)]) + fVec26[((IOTA - 453) & 511)]) - fVec26[((IOTA - 474) & 511)]) - fVec26[((IOTA - 475) & 511)])) + ((0.00137333293f * (((fVec26[((IOTA - 115) & 511)] + fVec26[((IOTA - 275) & 511)]) - fVec26[((IOTA - 357) & 511)]) - fVec26[((IOTA - 473) & 511)])) + ((0.00112918485f * (((fVec26[((IOTA - 227) & 511)] + fVec26[((IOTA - 267) & 511)]) + fVec26[((IOTA - 337) & 511)]) - fVec26[((IOTA - 472) & 511)])) + ((0.000457777642f * ((fVec26[((IOTA - 320) & 511)] + fVec26[((IOTA - 406) & 511)]) - fVec26[((IOTA - 470) & 511)])) + ((3.05185094e-05f * ((((((((((((((fVec26[((IOTA - 28) & 511)] - (((((((((((((((fVec26[((IOTA - 1) & 511)] + fVec26[((IOTA - 2) & 511)]) + fVec26[((IOTA - 3) & 511)]) + fVec26[((IOTA - 4) & 511)]) + fVec26[((IOTA - 5) & 511)]) + fVec26[((IOTA - 6) & 511)]) + fVec26[((IOTA - 7) & 511)]) + fVec26[((IOTA - 8) & 511)]) + fVec26[((IOTA - 10) & 511)]) + fVec26[((IOTA - 11) & 511)]) + fVec26[((IOTA - 12) & 511)]) + fVec26[((IOTA - 13) & 511)]) + fVec26[((IOTA - 18) & 511)]) + fVec26[((IOTA - 19) & 511)]) + fVec26[((IOTA - 24) & 511)]) + fVec26[((IOTA - 25) & 511)])) + fVec26[((IOTA - 33) & 511)]) - fVec26[((IOTA - 34) & 511)]) - fVec26[((IOTA - 35) & 511)]) - fVec26[((IOTA - 36) & 511)]) - fVec26[((IOTA - 37) & 511)]) - fVec26[((IOTA - 39) & 511)]) - fVec26[((IOTA - 40) & 511)]) - fVec26[((IOTA - 45) & 511)]) - fVec26[((IOTA - 51) & 511)]) - fVec26[((IOTA - 52) & 511)]) - fVec26[((IOTA - 398) & 511)]) - fVec26[((IOTA - 439) & 511)]) + fVec26[((IOTA - 464) & 511)])) + ((0.000701925717f * (((fVec26[((IOTA - 314) & 511)] - fVec26[((IOTA - 334) & 511)]) - fVec26[((IOTA - 394) & 511)]) - fVec26[((IOTA - 462) & 511)])) + ((0.00177007355f * (fVec26[((IOTA - 280) & 511)] - fVec26[((IOTA - 459) & 511)])) + ((0.00222785119f * ((((fVec26[((IOTA - 276) & 511)] + fVec26[((IOTA - 295) & 511)]) - fVec26[((IOTA - 362) & 511)]) + fVec26[((IOTA - 378) & 511)]) - fVec26[((IOTA - 458) & 511)])) + ((0.00219733268f * (fVec26[((IOTA - 288) & 511)] - fVec26[((IOTA - 457) & 511)])) + ((0.00143436994f * ((((fVec26[((IOTA - 252) & 511)] + fVec26[((IOTA - 266) & 511)]) + fVec26[((IOTA - 351) & 511)]) - fVec26[((IOTA - 431) & 511)]) - fVec26[((IOTA - 456) & 511)])) + ((0.001617481f * (fVec26[((IOTA - 308) & 511)] + fVec26[((IOTA - 452) & 511)])) + ((0.00134281442f * (((((fVec26[((IOTA - 318) & 511)] + fVec26[((IOTA - 353) & 511)]) - fVec26[((IOTA - 410) & 511)]) - fVec26[((IOTA - 411) & 511)]) - fVec26[((IOTA - 414) & 511)]) + fVec26[((IOTA - 451) & 511)])) + ((0.00231940672f * (((fVec26[((IOTA - 220) & 511)] + fVec26[((IOTA - 300) & 511)]) + fVec26[((IOTA - 368) & 511)]) - fVec26[((IOTA - 447) & 511)])) + ((0.00280770287f * ((fVec26[((IOTA - 196) & 511)] + fVec26[((IOTA - 282) & 511)]) - fVec26[((IOTA - 446) & 511)])) + ((0.00265511032f * (((fVec26[((IOTA - 229) & 511)] + fVec26[((IOTA - 298) & 511)]) - fVec26[((IOTA - 359) & 511)]) - fVec26[((IOTA - 445) & 511)])) + ((0.0019226661f * ((fVec26[((IOTA - 294) & 511)] + fVec26[((IOTA - 304) & 511)]) - fVec26[((IOTA - 430) & 511)])) + ((0.0022583697f * (((((fVec26[((IOTA - 124) & 511)] + fVec26[((IOTA - 289) & 511)]) + fVec26[((IOTA - 301) & 511)]) + fVec26[((IOTA - 302) & 511)]) - fVec26[((IOTA - 427) & 511)]) - fVec26[((IOTA - 429) & 511)])) + ((0.00234992523f * (((fVec26[((IOTA - 250) & 511)] + fVec26[((IOTA - 278) & 511)]) + fVec26[((IOTA - 291) & 511)]) - fVec26[((IOTA - 428) & 511)])) + ((0.00207525864f * ((fVec26[((IOTA - 264) & 511)] - fVec26[((IOTA - 358) & 511)]) - fVec26[((IOTA - 425) & 511)])) + ((0.0019531846f * (fVec26[((IOTA - 205) & 511)] - fVec26[((IOTA - 424) & 511)])) + ((0.00158696249f * ((fVec26[((IOTA - 239) & 511)] + fVec26[((IOTA - 309) & 511)]) - fVec26[((IOTA - 423) & 511)])) + ((0.00140385143f * (((fVec26[((IOTA - 317) & 511)] + fVec26[((IOTA - 338) & 511)]) + fVec26[((IOTA - 352) & 511)]) - fVec26[((IOTA - 416) & 511)])) + ((0.00152592547f * (((fVec26[((IOTA - 219) & 511)] + fVec26[((IOTA - 306) & 511)]) + fVec26[((IOTA - 307) & 511)]) - fVec26[((IOTA - 415) & 511)])) + ((0.000244148076f * (((fVec26[((IOTA - 61) & 511)] - fVec26[((IOTA - 321) & 511)]) + fVec26[((IOTA - 326) & 511)]) - fVec26[((IOTA - 401) & 511)])) + ((0.00308236945f * (fVec26[((IOTA - 380) & 511)] - fVec26[((IOTA - 391) & 511)])) + ((0.00204474013f * (fVec26[((IOTA - 225) & 511)] - fVec26[((IOTA - 387) & 511)])) + ((0.00210577715f * ((fVec26[((IOTA - 263) & 511)] + fVec26[((IOTA - 292) & 511)]) + fVec26[((IOTA - 384) & 511)])) + ((0.00299081393f * ((fVec26[((IOTA - 167) & 511)] + fVec26[((IOTA - 381) & 511)]) + fVec26[((IOTA - 382) & 511)])) + ((0.00292977691f * (fVec26[((IOTA - 236) & 511)] + fVec26[((IOTA - 379) & 511)])) + ((0.00228888821f * (fVec26[((IOTA - 241) & 511)] - fVec26[((IOTA - 375) & 511)])) + ((0.00167851802f * ((fVec26[((IOTA - 164) & 511)] + fVec26[((IOTA - 197) & 511)]) - fVec26[((IOTA - 373) & 511)])) + ((0.003234962f * (fVec26[((IOTA - 235) & 511)] - fVec26[((IOTA - 371) & 511)])) + ((0.00326548051f * (fVec26[((IOTA - 211) & 511)] - fVec26[((IOTA - 370) & 511)])) + ((0.00103762932f * ((fVec26[((IOTA - 217) & 511)] + fVec26[((IOTA - 319) & 511)]) - fVec26[((IOTA - 369) & 511)])) + ((0.00473036896f * fVec26[((IOTA - 367) & 511)]) + ((0.00497451704f * fVec26[((IOTA - 366) & 511)]) + ((0.00347911008f * (fVec26[((IOTA - 231) & 511)] + fVec26[((IOTA - 365) & 511)])) + ((0.000946073793f * (fVec26[((IOTA - 315) & 511)] - fVec26[((IOTA - 363) & 511)])) + ((0.000427259132f * (((fVec26[((IOTA - 216) & 511)] - fVec26[((IOTA - 331) & 511)]) + fVec26[((IOTA - 355) & 511)]) - fVec26[((IOTA - 356) & 511)])) + ((0.0012817774f * (fVec26[((IOTA - 316) & 511)] + fVec26[((IOTA - 349) & 511)])) + ((0.000976592302f * (fVec26[((IOTA - 271) & 511)] - fVec26[((IOTA - 324) & 511)])) + ((0.00277718436f * (fVec26[((IOTA - 248) & 511)] - fVec26[((IOTA - 361) & 511)])) + ((0.000518814661f * ((fVec26[((IOTA - 272) & 511)] + fVec26[((IOTA - 274) & 511)]) + fVec26[((IOTA - 312) & 511)])) + ((0.00125125889f * (fVec26[((IOTA - 226) & 511)] + fVec26[((IOTA - 310) & 511)])) + ((0.00164799951f * ((fVec26[((IOTA - 258) & 511)] + fVec26[((IOTA - 261) & 511)]) + fVec26[((IOTA - 305) & 511)])) + ((0.00247199927f * fVec26[((IOTA - 299) & 511)]) + ((0.00189214759f * (((fVec26[((IOTA - 165) & 511)] + fVec26[((IOTA - 262) & 511)]) + fVec26[((IOTA - 279) & 511)]) + fVec26[((IOTA - 293) & 511)])) + ((0.00238044374f * fVec26[((IOTA - 290) & 511)]) + ((0.00241096225f * (fVec26[((IOTA - 237) & 511)] + fVec26[((IOTA - 287) & 511)])) + ((0.0028992584f * fVec26[((IOTA - 286) & 511)]) + ((0.00344859157f * (fVec26[((IOTA - 283) & 511)] + fVec26[((IOTA - 285) & 511)])) + ((0.00369273964f * fVec26[((IOTA - 284) & 511)]) + ((0.00256355479f * fVec26[((IOTA - 296) & 511)]) + ((0.0025940733f * (fVec26[((IOTA - 249) & 511)] + fVec26[((IOTA - 277) & 511)])) + ((0.00115970336f * ((fVec26[((IOTA - 218) & 511)] + fVec26[((IOTA - 254) & 511)]) + fVec26[((IOTA - 269) & 511)])) + ((0.00180059206f * fVec26[((IOTA - 265) & 511)]) + ((0.00149540696f * (fVec26[((IOTA - 259) & 511)] + fVec26[((IOTA - 260) & 511)])) + ((0.00186162908f * ((((fVec26[((IOTA - 166) & 511)] + fVec26[((IOTA - 238) & 511)]) + fVec26[((IOTA - 240) & 511)]) + fVec26[((IOTA - 256) & 511)]) + fVec26[((IOTA - 257) & 511)])) + ((0.00155644398f * fVec26[((IOTA - 255) & 511)]) + ((0.00198370311f * fVec26[((IOTA - 251) & 511)]) + ((0.00305185094f * fVec26[((IOTA - 247) & 511)]) + ((0.00329599902f * (((fVec26[((IOTA - 230) & 511)] + fVec26[((IOTA - 233) & 511)]) + fVec26[((IOTA - 234) & 511)]) + fVec26[((IOTA - 246) & 511)])) + ((0.00350962859f * (fVec26[((IOTA - 158) & 511)] + fVec26[((IOTA - 245) & 511)])) + ((0.00338755455f * fVec26[((IOTA - 244) & 511)]) + ((0.00314340647f * fVec26[((IOTA - 243) & 511)]) + ((0.00274666585f * fVec26[((IOTA - 242) & 511)]) + ((0.00332651753f * fVec26[((IOTA - 232) & 511)]) + ((0.00170903653f * fVec26[((IOTA - 228) & 511)]) + ((0.00320444349f * (fVec26[((IOTA - 191) & 511)] + fVec26[((IOTA - 224) & 511)])) + ((0.00411999878f * (fVec26[((IOTA - 194) & 511)] + fVec26[((IOTA - 222) & 511)])) + ((0.00335703604f * fVec26[((IOTA - 221) & 511)]) + ((0.00534073915f * (fVec26[((IOTA - 168) & 511)] + fVec26[((IOTA - 210) & 511)])) + ((0.00628681295f * fVec26[((IOTA - 209) & 511)]) + ((0.0061342204f * fVec26[((IOTA - 208) & 511)]) + ((0.00518814661f * fVec26[((IOTA - 207) & 511)]) + ((0.00372325815f * (fVec26[((IOTA - 193) & 511)] + fVec26[((IOTA - 206) & 511)])) + ((0.00384533219f * fVec26[((IOTA - 195) & 511)]) + ((0.00311288796f * (fVec26[((IOTA - 173) & 511)] + fVec26[((IOTA - 192) & 511)])) + ((0.00381481368f * (fVec26[((IOTA - 172) & 511)] + fVec26[((IOTA - 190) & 511)])) + ((0.00552385021f * fVec26[((IOTA - 188) & 511)]) + ((0.00607318338f * fVec26[((IOTA - 187) & 511)]) + ((0.00650044251f * fVec26[((IOTA - 186) & 511)]) + ((0.00653096102f * fVec26[((IOTA - 185) & 511)]) + ((0.0067751091f * (fVec26[((IOTA - 182) & 511)] + fVec26[((IOTA - 184) & 511)])) + ((0.00689718314f * fVec26[((IOTA - 183) & 511)]) + ((0.00598162785f * (fVec26[((IOTA - 153) & 511)] + fVec26[((IOTA - 181) & 511)])) + ((0.00506607257f * fVec26[((IOTA - 180) & 511)]) + ((0.00393688772f * fVec26[((IOTA - 179) & 511)]) + ((0.00415051728f * (fVec26[((IOTA - 135) & 511)] + fVec26[((IOTA - 178) & 511)])) + ((0.00531022064f * fVec26[((IOTA - 177) & 511)]) + ((0.00610370189f * fVec26[((IOTA - 176) & 511)]) + ((0.00527970213f * fVec26[((IOTA - 175) & 511)]) + ((0.00360118411f * fVec26[((IOTA - 174) & 511)]) + ((0.00589007232f * fVec26[((IOTA - 171) & 511)]) + ((0.00747703481f * fVec26[((IOTA - 170) & 511)]) + ((0.00738547929f * fVec26[((IOTA - 169) & 511)]) + ((0.0180059206f * fVec26[((IOTA - 156) & 511)]) + ((0.0181585141f * fVec26[((IOTA - 155) & 511)]) + ((0.00570696127f * fVec26[((IOTA - 149) & 511)]) + ((0.0104373302f * fVec26[((IOTA - 148) & 511)]) + ((0.0115970336f * fVec26[((IOTA - 147) & 511)]) + ((0.0108951079f * fVec26[((IOTA - 146) & 511)]) + ((0.00885036774f * fVec26[((IOTA - 145) & 511)]) + ((0.0071108127f * fVec26[((IOTA - 144) & 511)]) + ((0.00396740623f * fVec26[((IOTA - 143) & 511)]) + ((0.0121768853f * fVec26[((IOTA - 134) & 511)]) + ((0.0197149571f * fVec26[((IOTA - 133) & 511)]) + ((0.0272225104f * fVec26[((IOTA - 132) & 511)]) + ((0.0313425101f * fVec26[((IOTA - 131) & 511)]) + ((0.0300607327f * fVec26[((IOTA - 130) & 511)]) + ((0.0186773278f * fVec26[((IOTA - 129) & 511)]) + ((0.0171514023f * fVec26[((IOTA - 123) & 511)]) + ((0.0259102155f * fVec26[((IOTA - 122) & 511)]) + ((0.0270088818f * (fVec26[((IOTA - 118) & 511)] + fVec26[((IOTA - 121) & 511)])) + ((0.0273445845f * fVec26[((IOTA - 120) & 511)]) + ((0.0279549547f * fVec26[((IOTA - 119) & 511)]) + ((0.0206915494f * fVec26[((IOTA - 117) & 511)]) + ((0.0115665151f * fVec26[((IOTA - 116) & 511)]) + ((0.00900296029f * fVec26[((IOTA - 105) & 511)]) + ((0.0223090313f * fVec26[((IOTA - 104) & 511)]) + ((0.0306405835f * fVec26[((IOTA - 103) & 511)]) + ((0.030976288f * fVec26[((IOTA - 102) & 511)]) + ((0.0116885891f * fVec26[((IOTA - 101) & 511)]) + ((0.0226752535f * fVec26[((IOTA - 96) & 511)]) + ((0.0446790978f * fVec26[((IOTA - 95) & 511)]) + ((0.0398876928f * fVec26[((IOTA - 94) & 511)]) + ((0.0189519953f * fVec26[((IOTA - 90) & 511)]) + ((0.0257881414f * fVec26[((IOTA - 89) & 511)]) + ((0.0275887325f * fVec26[((IOTA - 88) & 511)]) + ((0.0139164403f * fVec26[((IOTA - 87) & 511)]) + ((0.0232245866f * fVec26[((IOTA - 79) & 511)]) + ((0.132450327f * fVec26[((IOTA - 78) & 511)]) + ((0.203802601f * fVec26[((IOTA - 77) & 511)]) + ((0.136814475f * fVec26[((IOTA - 76) & 511)]) + ((0.00668355357f * fVec26[((IOTA - 67) & 511)]) + ((0.0106509598f * fVec26[((IOTA - 66) & 511)]) + ((0.0106814783f * fVec26[((IOTA - 65) & 511)]) + ((0.0042115543f * fVec26[((IOTA - 63) & 511)]) + (0.00793481246f * fVec26[((IOTA - 64) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000335703604f * (((fVec26[((IOTA - 336) & 511)] - fVec26[((IOTA - 395) & 511)]) - fVec26[((IOTA - 441) & 511)]) - fVec26[((IOTA - 511) & 511)]))))) : (iSlow61 ? (((0.0051576281f * ((fVec25[((IOTA - 444) & 511)] + fVec25[((IOTA - 452) & 511)]) + fVec25[((IOTA - 510) & 511)])) + ((0.00564592425f * (fVec25[((IOTA - 233) & 511)] + fVec25[((IOTA - 509) & 511)])) + ((0.00604266487f * fVec25[((IOTA - 508) & 511)]) + ((0.00625629444f * (fVec25[((IOTA - 504) & 511)] + fVec25[((IOTA - 506) & 511)])) + ((0.00619525742f * (fVec25[((IOTA - 234) & 511)] + fVec25[((IOTA - 505) & 511)])) + ((0.00643940549f * fVec25[((IOTA - 503) & 511)]) + ((0.00720236823f * fVec25[((IOTA - 500) & 511)]) + ((0.00781273842f * fVec25[((IOTA - 498) & 511)]) + ((0.00811792351f * fVec25[((IOTA - 495) & 511)]) + ((0.00799584948f * ((fVec25[((IOTA - 468) & 511)] + fVec25[((IOTA - 469) & 511)]) + fVec25[((IOTA - 494) & 511)])) + ((0.00793481246f * (fVec25[((IOTA - 279) & 511)] + fVec25[((IOTA - 493) & 511)])) + ((0.00787377544f * ((fVec25[((IOTA - 467) & 511)] + fVec25[((IOTA - 470) & 511)]) + fVec25[((IOTA - 492) & 511)])) + ((0.00778221991f * (fVec25[((IOTA - 277) & 511)] + fVec25[((IOTA - 491) & 511)])) + ((0.00769066438f * (fVec25[((IOTA - 488) & 511)] + fVec25[((IOTA - 490) & 511)])) + ((0.00766014587f * fVec25[((IOTA - 489) & 511)]) + ((0.00759910885f * ((fVec25[((IOTA - 278) & 511)] + fVec25[((IOTA - 294) & 511)]) + fVec25[((IOTA - 487) & 511)])) + ((0.00704977568f * (fVec25[((IOTA - 455) & 511)] + fVec25[((IOTA - 485) & 511)])) + ((0.00680562761f * fVec25[((IOTA - 484) & 511)]) + ((0.00717184972f * fVec25[((IOTA - 477) & 511)]) + ((0.00726340525f * ((fVec25[((IOTA - 137) & 511)] + fVec25[((IOTA - 458) & 511)]) + fVec25[((IOTA - 476) & 511)])) + ((0.00756859034f * (fVec25[((IOTA - 256) & 511)] + fVec25[((IOTA - 472) & 511)])) + ((0.008087405f * fVec25[((IOTA - 497) & 511)]) + ((0.00762962736f * fVec25[((IOTA - 466) & 511)]) + ((0.0067751091f * (((fVec25[((IOTA - 199) & 511)] - fVec25[((IOTA - 206) & 511)]) + fVec25[((IOTA - 257) & 511)]) + fVec25[((IOTA - 462) & 511)])) + ((0.0071108127f * fVec25[((IOTA - 459) & 511)]) + ((0.00729392376f * (fVec25[((IOTA - 259) & 511)] + fVec25[((IOTA - 456) & 511)])) + ((0.00653096102f * (((fVec25[((IOTA - 258) & 511)] - fVec25[((IOTA - 344) & 511)]) - fVec25[((IOTA - 347) & 511)]) + fVec25[((IOTA - 454) & 511)])) + ((0.00585955381f * fVec25[((IOTA - 453) & 511)]) + ((0.00454725791f * fVec25[((IOTA - 451) & 511)]) + ((0.00405896176f * (fVec25[((IOTA - 298) & 511)] + fVec25[((IOTA - 450) & 511)])) + ((0.00375377666f * (fVec25[((IOTA - 433) & 511)] + fVec25[((IOTA - 448) & 511)])) + ((0.00399792474f * (fVec25[((IOTA - 435) & 511)] + fVec25[((IOTA - 447) & 511)])) + ((0.00442518387f * (fVec25[((IOTA - 439) & 511)] + fVec25[((IOTA - 446) & 511)])) + ((0.004852443f * fVec25[((IOTA - 445) & 511)]) + ((0.00521866512f * fVec25[((IOTA - 443) & 511)]) + ((0.00503555406f * fVec25[((IOTA - 442) & 511)]) + ((0.00479140598f * fVec25[((IOTA - 441) & 511)]) + ((0.00457777642f * fVec25[((IOTA - 440) & 511)]) + ((0.00433362834f * fVec25[((IOTA - 438) & 511)]) + ((0.0042115543f * fVec25[((IOTA - 437) & 511)]) + ((0.00408948027f * fVec25[((IOTA - 436) & 511)]) + ((0.00390636921f * (fVec25[((IOTA - 434) & 511)] - fVec25[((IOTA - 407) & 511)])) + ((0.00299081393f * (fVec25[((IOTA - 203) & 511)] + fVec25[((IOTA - 431) & 511)])) + ((0.00253303628f * fVec25[((IOTA - 430) & 511)]) + ((0.00207525864f * fVec25[((IOTA - 429) & 511)]) + ((0.00119022187f * fVec25[((IOTA - 427) & 511)]) + ((0.000640888698f * ((fVec25[((IOTA - 214) & 511)] - fVec25[((IOTA - 314) & 511)]) - fVec25[((IOTA - 423) & 511)])) + ((0.00244148076f * (fVec25[((IOTA - 216) & 511)] - fVec25[((IOTA - 419) & 511)])) + ((0.00357066561f * ((fVec25[((IOTA - 166) & 511)] - fVec25[((IOTA - 328) & 511)]) - fVec25[((IOTA - 416) & 511)])) + ((0.00393688772f * (fVec25[((IOTA - 109) & 511)] - fVec25[((IOTA - 412) & 511)])) + ((0.00723288674f * ((fVec25[((IOTA - 202) & 511)] - fVec25[((IOTA - 333) & 511)]) - fVec25[((IOTA - 399) & 511)])) + ((0.00341807306f * fVec25[((IOTA - 432) & 511)]) + ((0.0101016266f * (fVec25[((IOTA - 253) & 511)] - fVec25[((IOTA - 396) & 511)])) + ((0.0100711081f * (fVec25[((IOTA - 284) & 511)] - fVec25[((IOTA - 395) & 511)])) + ((0.00881984923f * (fVec25[((IOTA - 136) & 511)] - fVec25[((IOTA - 393) & 511)])) + ((0.0090334788f * (fVec25[((IOTA - 125) & 511)] - fVec25[((IOTA - 364) & 511)])) + ((0.00939970091f * (fVec25[((IOTA - 281) & 511)] - fVec25[((IOTA - 363) & 511)])) + ((0.00991851557f * (fVec25[((IOTA - 285) & 511)] - fVec25[((IOTA - 362) & 511)])) + ((0.011322367f * (fVec25[((IOTA - 230) & 511)] - fVec25[((IOTA - 359) & 511)])) + ((0.000518814661f * (fVec25[((IOTA - 317) & 511)] - fVec25[((IOTA - 324) & 511)])) + ((3.05185094e-05f * (((fVec25[((IOTA - 77) & 511)] + fVec25[((IOTA - 78) & 511)]) + fVec25[((IOTA - 80) & 511)]) - fVec25[((IOTA - 320) & 511)])) + ((0.000427259132f * (fVec25[((IOTA - 196) & 511)] + fVec25[((IOTA - 318) & 511)])) + ((0.000366222113f * fVec25[((IOTA - 316) & 511)]) + ((0.000823999755f * (fVec25[((IOTA - 303) & 511)] - fVec25[((IOTA - 305) & 511)])) + ((0.00231940672f * fVec25[((IOTA - 301) & 511)]) + ((0.00296029542f * fVec25[((IOTA - 300) & 511)]) + ((0.00350962859f * fVec25[((IOTA - 299) & 511)]) + ((0.0054933317f * fVec25[((IOTA - 296) & 511)]) + ((0.006469924f * fVec25[((IOTA - 295) & 511)]) + ((0.00875881221f * (fVec25[((IOTA - 231) & 511)] + fVec25[((IOTA - 293) & 511)])) + ((0.00982696004f * fVec25[((IOTA - 292) & 511)]) + ((0.0105899228f * fVec25[((IOTA - 291) & 511)]) + ((0.0108951079f * fVec25[((IOTA - 290) & 511)]) + ((0.0108035523f * fVec25[((IOTA - 289) & 511)]) + ((0.0101626636f * fVec25[((IOTA - 287) & 511)]) + ((0.00994903408f * (fVec25[((IOTA - 282) & 511)] + fVec25[((IOTA - 286) & 511)])) + ((0.0101321451f * fVec25[((IOTA - 283) & 511)]) + ((0.00863673817f * fVec25[((IOTA - 280) & 511)]) + ((0.00927762687f * fVec25[((IOTA - 275) & 511)]) + ((0.0104373302f * fVec25[((IOTA - 274) & 511)]) + ((0.0118411817f * fVec25[((IOTA - 273) & 511)]) + ((0.0132450331f * fVec25[((IOTA - 272) & 511)]) + ((0.0144657735f * fVec25[((IOTA - 271) & 511)]) + ((0.015991699f * (fVec25[((IOTA - 228) & 511)] + fVec25[((IOTA - 269) & 511)])) + ((0.0164494775f * fVec25[((IOTA - 268) & 511)]) + ((0.0168462172f * fVec25[((IOTA - 267) & 511)]) + ((0.0170903653f * fVec25[((IOTA - 266) & 511)]) + ((0.0171208847f * fVec25[((IOTA - 265) & 511)]) + ((0.0166020691f * fVec25[((IOTA - 264) & 511)]) + ((0.0134891812f * fVec25[((IOTA - 262) & 511)]) + ((0.0112308115f * (fVec25[((IOTA - 187) & 511)] + fVec25[((IOTA - 261) & 511)])) + ((0.00900296029f * fVec25[((IOTA - 260) & 511)]) + ((0.00860621966f * fVec25[((IOTA - 255) & 511)]) + ((0.0109256264f * fVec25[((IOTA - 252) & 511)]) + ((0.0121463668f * fVec25[((IOTA - 251) & 511)]) + ((0.0137333293f * fVec25[((IOTA - 250) & 511)]) + ((0.0149845881f * fVec25[((IOTA - 249) & 511)]) + ((0.0151982177f * fVec25[((IOTA - 248) & 511)]) + ((0.0141911069f * fVec25[((IOTA - 247) & 511)]) + ((0.0126651814f * fVec25[((IOTA - 246) & 511)]) + ((0.0115665151f * fVec25[((IOTA - 245) & 511)]) + ((0.0116580706f * fVec25[((IOTA - 244) & 511)]) + ((0.0129703665f * fVec25[((IOTA - 243) & 511)]) + ((0.014679403f * fVec25[((IOTA - 242) & 511)]) + ((0.0159306619f * fVec25[((IOTA - 241) & 511)]) + ((0.0163579211f * fVec25[((IOTA - 240) & 511)]) + ((0.016235847f * fVec25[((IOTA - 239) & 511)]) + ((0.0155644398f * fVec25[((IOTA - 238) & 511)]) + ((0.0138554033f * fVec25[((IOTA - 237) & 511)]) + ((0.0111087374f * fVec25[((IOTA - 236) & 511)]) + ((0.0153813288f * (fVec25[((IOTA - 263) & 511)] + fVec25[((IOTA - 270) & 511)])) + ((0.00662251655f * fVec25[((IOTA - 232) & 511)]) + ((0.0181279946f * fVec25[((IOTA - 226) & 511)]) + ((0.0174871068f * (fVec25[((IOTA - 160) & 511)] + fVec25[((IOTA - 225) & 511)])) + ((0.01617481f * fVec25[((IOTA - 224) & 511)]) + ((0.0148014771f * fVec25[((IOTA - 223) & 511)]) + ((0.0135502182f * fVec25[((IOTA - 222) & 511)]) + ((0.0109866634f * fVec25[((IOTA - 220) & 511)]) + ((0.00906399731f * (fVec25[((IOTA - 200) & 511)] + fVec25[((IOTA - 219) & 511)])) + ((0.0137943663f * fVec25[((IOTA - 229) & 511)]) + ((0.00650044251f * fVec25[((IOTA - 218) & 511)]) + ((0.00402844325f * fVec25[((IOTA - 217) & 511)]) + ((0.00152592547f * fVec25[((IOTA - 215) & 511)]) + ((0.00439466536f * fVec25[((IOTA - 198) & 511)]) + ((0.00262459181f * fVec25[((IOTA - 197) & 511)]) + ((0.00277718436f * fVec25[((IOTA - 188) & 511)]) + ((0.0142216254f * fVec25[((IOTA - 186) & 511)]) + ((0.0188604388f * fVec25[((IOTA - 165) & 511)]) + ((0.0325327329f * fVec25[((IOTA - 164) & 511)]) + ((0.0407116935f * fVec25[((IOTA - 163) & 511)]) + ((0.0409253202f * fVec25[((IOTA - 162) & 511)]) + ((0.0325937681f * fVec25[((IOTA - 161) & 511)]) + ((0.00219733268f * fVec25[((IOTA - 138) & 511)]) + ((0.00598162785f * fVec25[((IOTA - 134) & 511)]) + ((0.0175786614f * fVec25[((IOTA - 227) & 511)]) + ((0.0269478448f * fVec25[((IOTA - 124) & 511)]) + ((0.0426953956f * fVec25[((IOTA - 123) & 511)]) + ((0.0415051728f * fVec25[((IOTA - 122) & 511)]) + ((0.0199591052f * fVec25[((IOTA - 121) & 511)]) + ((0.00610370189f * fVec25[((IOTA - 110) & 511)]) + ((0.0318002887f * fVec25[((IOTA - 100) & 511)]) + ((0.12707907f * fVec25[((IOTA - 99) & 511)]) + ((0.224585712f * fVec25[((IOTA - 98) & 511)]) + ((0.261574149f * fVec25[((IOTA - 97) & 511)]) + ((0.21512498f * fVec25[((IOTA - 96) & 511)]) + ((0.129612103f * fVec25[((IOTA - 95) & 511)]) + ((0.0647907928f * fVec25[((IOTA - 94) & 511)]) + ((0.0137638478f * fVec25[((IOTA - 92) & 511)]) + (0.0332041383f * fVec25[((IOTA - 93) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00622577593f * (fVec25[((IOTA - 331) & 511)] - fVec25[((IOTA - 507) & 511)])) + ((0.00674459059f * (((fVec25[((IOTA - 127) & 511)] + fVec25[((IOTA - 339) & 511)]) - fVec25[((IOTA - 481) & 511)]) - fVec25[((IOTA - 502) & 511)])) + ((0.00698873866f * ((fVec25[((IOTA - 390) & 511)] - fVec25[((IOTA - 479) & 511)]) - fVec25[((IOTA - 501) & 511)])) + ((0.00747703481f * ((fVec25[((IOTA - 387) & 511)] - fVec25[((IOTA - 473) & 511)]) - fVec25[((IOTA - 499) & 511)])) + ((0.00820947904f * ((fVec25[((IOTA - 207) & 511)] - fVec25[((IOTA - 235) & 511)]) - fVec25[((IOTA - 496) & 511)])) + ((0.00735496078f * (fVec25[((IOTA - 334) & 511)] - fVec25[((IOTA - 486) & 511)])) + ((0.00668355357f * (((fVec25[((IOTA - 341) & 511)] + fVec25[((IOTA - 342) & 511)]) - fVec25[((IOTA - 482) & 511)]) - fVec25[((IOTA - 483) & 511)])) + ((0.00686666463f * (fVec25[((IOTA - 332) & 511)] - fVec25[((IOTA - 480) & 511)])) + ((0.00708029419f * (fVec25[((IOTA - 388) & 511)] - fVec25[((IOTA - 478) & 511)])) + ((0.00732444227f * (((fVec25[((IOTA - 335) & 511)] - fVec25[((IOTA - 457) & 511)]) - fVec25[((IOTA - 465) & 511)]) - fVec25[((IOTA - 475) & 511)])) + ((0.00738547929f * (fVec25[((IOTA - 391) & 511)] - fVec25[((IOTA - 474) & 511)])) + ((0.00772118289f * (fVec25[((IOTA - 349) & 511)] - fVec25[((IOTA - 471) & 511)])) + ((0.00701925717f * (fVec25[((IOTA - 348) & 511)] - fVec25[((IOTA - 464) & 511)])) + ((0.00683614612f * ((fVec25[((IOTA - 338) & 511)] - fVec25[((IOTA - 461) & 511)]) - fVec25[((IOTA - 463) & 511)])) + ((0.00695822015f * (fVec25[((IOTA - 337) & 511)] - fVec25[((IOTA - 460) & 511)])) + ((0.00378429517f * ((fVec25[((IOTA - 402) & 511)] + fVec25[((IOTA - 413) & 511)]) - fVec25[((IOTA - 449) & 511)])) + ((0.00164799951f * ((fVec25[((IOTA - 306) & 511)] + fVec25[((IOTA - 421) & 511)]) - fVec25[((IOTA - 428) & 511)])) + ((0.000732444227f * (fVec25[((IOTA - 159) & 511)] - fVec25[((IOTA - 426) & 511)])) + ((0.000274666585f * ((((((((((fVec25[((IOTA - 3) & 511)] + fVec25[((IOTA - 4) & 511)]) + fVec25[((IOTA - 5) & 511)]) + fVec25[((IOTA - 6) & 511)]) + fVec25[((IOTA - 7) & 511)]) + fVec25[((IOTA - 36) & 511)]) + fVec25[((IOTA - 39) & 511)]) + fVec25[((IOTA - 64) & 511)]) + fVec25[((IOTA - 65) & 511)]) + fVec25[((IOTA - 323) & 511)]) - fVec25[((IOTA - 425) & 511)])) + ((0.000152592547f * (((((((((fTemp26 + fVec25[((IOTA - 12) & 511)]) + fVec25[((IOTA - 13) & 511)]) + fVec25[((IOTA - 21) & 511)]) + fVec25[((IOTA - 43) & 511)]) + fVec25[((IOTA - 49) & 511)]) + fVec25[((IOTA - 54) & 511)]) + fVec25[((IOTA - 59) & 511)]) + fVec25[((IOTA - 67) & 511)]) + fVec25[((IOTA - 424) & 511)])) + ((0.00204474013f * fVec25[((IOTA - 420) & 511)]) + ((0.00280770287f * fVec25[((IOTA - 418) & 511)]) + ((0.003234962f * (fVec25[((IOTA - 86) & 511)] + fVec25[((IOTA - 417) & 511)])) + ((0.00369273964f * (fVec25[((IOTA - 195) & 511)] + fVec25[((IOTA - 415) & 511)])) + ((0.00372325815f * fVec25[((IOTA - 414) & 511)]) + ((0.00115970336f * fVec25[((IOTA - 422) & 511)]) + ((0.00424207281f * fVec25[((IOTA - 411) & 511)]) + ((0.00445570238f * (fVec25[((IOTA - 329) & 511)] + fVec25[((IOTA - 410) & 511)])) + ((0.0045167394f * fVec25[((IOTA - 409) & 511)]) + ((0.00430310983f * fVec25[((IOTA - 408) & 511)]) + ((0.00347911008f * (fVec25[((IOTA - 309) & 511)] + fVec25[((IOTA - 406) & 511)])) + ((0.00320444349f * fVec25[((IOTA - 405) & 511)]) + ((0.00314340647f * (fVec25[((IOTA - 308) & 511)] + fVec25[((IOTA - 404) & 511)])) + ((0.00329599902f * fVec25[((IOTA - 403) & 511)]) + ((0.0058290353f * fVec25[((IOTA - 400) & 511)]) + ((0.00857570115f * fVec25[((IOTA - 398) & 511)]) + ((0.00952177495f * ((fVec25[((IOTA - 194) & 511)] - fVec25[((IOTA - 201) & 511)]) + fVec25[((IOTA - 394) & 511)])) + ((0.00805688649f * fVec25[((IOTA - 392) & 511)]) + ((0.00689718314f * fVec25[((IOTA - 389) & 511)]) + ((0.00802636798f * fVec25[((IOTA - 386) & 511)]) + ((0.00869777519f * fVec25[((IOTA - 385) & 511)]) + ((0.0093691824f * fVec25[((IOTA - 384) & 511)]) + ((0.00997955259f * fVec25[((IOTA - 383) & 511)]) + ((0.0105594043f * (fVec25[((IOTA - 352) & 511)] + fVec25[((IOTA - 382) & 511)])) + ((0.0110171819f * fVec25[((IOTA - 381) & 511)]) + ((0.0114749596f * fVec25[((IOTA - 380) & 511)]) + ((0.0120242927f * fVec25[((IOTA - 379) & 511)]) + ((0.013000885f * (fVec25[((IOTA - 150) & 511)] + fVec25[((IOTA - 376) & 511)])) + ((0.0130314035f * fVec25[((IOTA - 375) & 511)]) + ((0.012939848f * fVec25[((IOTA - 374) & 511)]) + ((0.0127262184f * fVec25[((IOTA - 373) & 511)]) + ((0.0123294778f * fVec25[((IOTA - 372) & 511)]) + ((0.0117801446f * fVec25[((IOTA - 371) & 511)]) + ((0.0110477004f * fVec25[((IOTA - 370) & 511)]) + ((0.0102542192f * (fVec25[((IOTA - 178) & 511)] + fVec25[((IOTA - 369) & 511)])) + ((0.00955229346f * fVec25[((IOTA - 368) & 511)]) + ((0.00909451582f * fVec25[((IOTA - 367) & 511)]) + ((0.00888088625f * (fVec25[((IOTA - 365) & 511)] + fVec25[((IOTA - 366) & 511)])) + ((0.0104678487f * fVec25[((IOTA - 361) & 511)]) + ((0.0109561449f * fVec25[((IOTA - 360) & 511)]) + ((0.0115970336f * fVec25[((IOTA - 358) & 511)]) + ((0.0117496261f * fVec25[((IOTA - 357) & 511)]) + ((0.0118717002f * (fVec25[((IOTA - 356) & 511)] - (fVec25[((IOTA - 185) & 511)] - fVec25[((IOTA - 355) & 511)]))) + ((0.0116885891f * fVec25[((IOTA - 354) & 511)]) + ((0.01126133f * fVec25[((IOTA - 353) & 511)]) + ((0.00964384899f * fVec25[((IOTA - 351) & 511)]) + ((0.00866725668f * fVec25[((IOTA - 350) & 511)]) + ((0.00637836847f * ((fVec25[((IOTA - 182) & 511)] - fVec25[((IOTA - 184) & 511)]) + fVec25[((IOTA - 346) & 511)])) + ((0.00640888698f * fVec25[((IOTA - 345) & 511)]) + ((0.00665303506f * fVec25[((IOTA - 343) & 511)]) + ((0.00671407208f * fVec25[((IOTA - 340) & 511)]) + ((0.0128482925f * fVec25[((IOTA - 377) & 511)]) + ((0.0124820704f * fVec25[((IOTA - 378) & 511)]) + ((0.00537125766f * fVec25[((IOTA - 330) & 511)]) + ((0.00265511032f * fVec25[((IOTA - 327) & 511)]) + ((0.00177007355f * fVec25[((IOTA - 326) & 511)]) + ((0.00100711081f * fVec25[((IOTA - 325) & 511)]) + ((0.000244148076f * ((((((((((fVec25[((IOTA - 2) & 511)] + fVec25[((IOTA - 8) & 511)]) + fVec25[((IOTA - 25) & 511)]) + fVec25[((IOTA - 26) & 511)]) + fVec25[((IOTA - 27) & 511)]) + fVec25[((IOTA - 28) & 511)]) + fVec25[((IOTA - 35) & 511)]) + fVec25[((IOTA - 40) & 511)]) + fVec25[((IOTA - 52) & 511)]) + fVec25[((IOTA - 61) & 511)]) + fVec25[((IOTA - 322) & 511)])) + ((0.00146488845f * fVec25[((IOTA - 313) & 511)]) + ((0.00234992523f * fVec25[((IOTA - 312) & 511)]) + ((0.00305185094f * fVec25[((IOTA - 311) & 511)]) + ((0.00344859157f * fVec25[((IOTA - 310) & 511)]) + ((0.00247199927f * fVec25[((IOTA - 307) & 511)]) + ((0.00961333048f * fVec25[((IOTA - 397) & 511)]) + ((0.00714133121f * fVec25[((IOTA - 336) & 511)]) + ((0.001617481f * (fVec25[((IOTA - 85) & 511)] - fVec25[((IOTA - 302) & 511)])) + ((0.00469985045f * (fVec25[((IOTA - 205) & 511)] - fVec25[((IOTA - 297) & 511)])) + ((0.0105288858f * (fVec25[((IOTA - 149) & 511)] - fVec25[((IOTA - 288) & 511)])) + ((0.00836207159f * ((fVec25[((IOTA - 88) & 511)] - fVec25[((IOTA - 135) & 511)]) - fVec25[((IOTA - 276) & 511)])) + ((0.000183111057f * ((((((fVec25[((IOTA - 11) & 511)] + fVec25[((IOTA - 22) & 511)]) + fVec25[((IOTA - 31) & 511)]) + fVec25[((IOTA - 42) & 511)]) - fVec25[((IOTA - 133) & 511)]) - fVec25[((IOTA - 319) & 511)]) + fVec25[((IOTA - 321) & 511)])) + ((0.00943021942f * (fVec25[((IOTA - 208) & 511)] - fVec25[((IOTA - 254) & 511)])) + ((0.0123599963f * (fVec25[((IOTA - 180) & 511)] - fVec25[((IOTA - 221) & 511)])) + ((0.00057985168f * fVec25[((IOTA - 213) & 511)]) + ((0.00256355479f * fVec25[((IOTA - 212) & 511)]) + ((0.00552385021f * fVec25[((IOTA - 211) & 511)]) + ((0.00848414563f * fVec25[((IOTA - 210) & 511)]) + ((0.00985747855f * (fVec25[((IOTA - 167) & 511)] + fVec25[((IOTA - 209) & 511)])) + ((0.00143436994f * fVec25[((IOTA - 204) & 511)]) + ((0.0153508103f * fVec25[((IOTA - 193) & 511)]) + ((0.0196844395f * fVec25[((IOTA - 192) & 511)]) + ((0.0209356975f * fVec25[((IOTA - 191) & 511)]) + ((0.0172429588f * fVec25[((IOTA - 190) & 511)]) + ((0.00830103457f * fVec25[((IOTA - 189) & 511)]) + ((0.000213629566f * (((((((((((((((((fVec25[((IOTA - 1) & 511)] + fVec25[((IOTA - 9) & 511)]) + fVec25[((IOTA - 10) & 511)]) + fVec25[((IOTA - 23) & 511)]) + fVec25[((IOTA - 24) & 511)]) + fVec25[((IOTA - 29) & 511)]) + fVec25[((IOTA - 30) & 511)]) + fVec25[((IOTA - 32) & 511)]) + fVec25[((IOTA - 33) & 511)]) + fVec25[((IOTA - 34) & 511)]) + fVec25[((IOTA - 41) & 511)]) + fVec25[((IOTA - 50) & 511)]) + fVec25[((IOTA - 51) & 511)]) + fVec25[((IOTA - 53) & 511)]) + fVec25[((IOTA - 60) & 511)]) + fVec25[((IOTA - 66) & 511)]) + fVec25[((IOTA - 83) & 511)]) + fVec25[((IOTA - 183) & 511)])) + ((0.0107730338f * fVec25[((IOTA - 181) & 511)]) + ((0.0115359966f * fVec25[((IOTA - 179) & 511)]) + ((0.0103152562f * fVec25[((IOTA - 177) & 511)]) + ((0.0119327372f * fVec25[((IOTA - 176) & 511)]) + ((0.0145268105f * fVec25[((IOTA - 175) & 511)]) + ((0.0183721427f * fVec25[((IOTA - 174) & 511)]) + ((0.0238349568f * fVec25[((IOTA - 173) & 511)]) + ((0.0295113996f * fVec25[((IOTA - 172) & 511)]) + ((0.0326242857f * fVec25[((IOTA - 171) & 511)]) + ((0.0316171758f * fVec25[((IOTA - 170) & 511)]) + ((0.0270699188f * fVec25[((IOTA - 169) & 511)]) + ((0.0199285876f * fVec25[((IOTA - 168) & 511)]) + ((0.017853329f * fVec25[((IOTA - 158) & 511)]) + ((0.0324716941f * fVec25[((IOTA - 157) & 511)]) + ((0.0450758375f * fVec25[((IOTA - 156) & 511)]) + ((0.0545670949f * fVec25[((IOTA - 155) & 511)]) + ((0.0574358366f * fVec25[((IOTA - 154) & 511)]) + ((0.0517288744f * fVec25[((IOTA - 153) & 511)]) + ((0.0390636921f * fVec25[((IOTA - 152) & 511)]) + ((0.0241401419f * fVec25[((IOTA - 151) & 511)]) + ((0.0172124393f * fVec25[((IOTA - 148) & 511)]) + ((0.0275887325f * fVec25[((IOTA - 147) & 511)]) + ((0.0347911008f * fVec25[((IOTA - 146) & 511)]) + ((0.0357066579f * fVec25[((IOTA - 145) & 511)]) + ((0.0323801376f * fVec25[((IOTA - 144) & 511)]) + ((0.0292062145f * (fVec25[((IOTA - 108) & 511)] + fVec25[((IOTA - 143) & 511)])) + ((0.0270393994f * fVec25[((IOTA - 142) & 511)]) + ((0.0234382153f * fVec25[((IOTA - 141) & 511)]) + ((0.0160222184f * fVec25[((IOTA - 140) & 511)]) + ((0.00631733146f * fVec25[((IOTA - 139) & 511)]) + ((0.00973540451f * fVec25[((IOTA - 132) & 511)]) + ((0.0195928831f * fVec25[((IOTA - 131) & 511)]) + ((0.0240180679f * fVec25[((IOTA - 130) & 511)]) + ((0.0211188085f * fVec25[((IOTA - 129) & 511)]) + ((0.0137028107f * fVec25[((IOTA - 128) & 511)]) + ((0.00103762932f * fVec25[((IOTA - 126) & 511)]) + ((0.0122379223f * fVec25[((IOTA - 120) & 511)]) + ((0.0397045799f * fVec25[((IOTA - 119) & 511)]) + ((0.0512100607f * fVec25[((IOTA - 118) & 511)]) + ((0.0451368764f * fVec25[((IOTA - 117) & 511)]) + ((0.0341807306f * fVec25[((IOTA - 116) & 511)]) + ((0.0321054719f * fVec25[((IOTA - 115) & 511)]) + ((0.0417798385f * fVec25[((IOTA - 114) & 511)]) + ((0.0505081341f * fVec25[((IOTA - 113) & 511)]) + ((0.0425122827f * fVec25[((IOTA - 112) & 511)]) + ((0.0174565874f * fVec25[((IOTA - 111) & 511)]) + ((0.0746177584f * fVec25[((IOTA - 107) & 511)]) + ((0.103122041f * fVec25[((IOTA - 106) & 511)]) + ((0.102420121f * fVec25[((IOTA - 105) & 511)]) + ((0.0848719776f * fVec25[((IOTA - 104) & 511)]) + ((0.0662251636f * fVec25[((IOTA - 103) & 511)]) + ((0.0501113944f * fVec25[((IOTA - 102) & 511)]) + ((0.0245979186f * fVec25[((IOTA - 101) & 511)]) + ((0.00317392498f * fVec25[((IOTA - 91) & 511)]) + ((0.0122684408f * fVec25[((IOTA - 90) & 511)]) + ((0.0120548112f * fVec25[((IOTA - 89) & 511)]) + ((0.00543229468f * fVec25[((IOTA - 87) & 511)]) + ((0.000671407208f * fVec25[((IOTA - 84) & 511)]) + ((9.15555283e-05f * ((((((((((fVec25[((IOTA - 16) & 511)] + fVec25[((IOTA - 17) & 511)]) + fVec25[((IOTA - 18) & 511)]) + fVec25[((IOTA - 45) & 511)]) + fVec25[((IOTA - 46) & 511)]) + fVec25[((IOTA - 47) & 511)]) + fVec25[((IOTA - 56) & 511)]) + fVec25[((IOTA - 57) & 511)]) + fVec25[((IOTA - 58) & 511)]) - fVec25[((IOTA - 75) & 511)]) - fVec25[((IOTA - 81) & 511)])) + ((6.10370189e-05f * ((fVec25[((IOTA - 69) & 511)] - fVec25[((IOTA - 71) & 511)]) - fVec25[((IOTA - 76) & 511)])) + ((0.000305185094f * (((fVec25[((IOTA - 37) & 511)] + fVec25[((IOTA - 38) & 511)]) + fVec25[((IOTA - 62) & 511)]) + fVec25[((IOTA - 63) & 511)])) + (0.000122074038f * ((((((((((fVec25[((IOTA - 14) & 511)] + fVec25[((IOTA - 15) & 511)]) + fVec25[((IOTA - 19) & 511)]) + fVec25[((IOTA - 20) & 511)]) + fVec25[((IOTA - 44) & 511)]) + fVec25[((IOTA - 48) & 511)]) + fVec25[((IOTA - 55) & 511)]) + fVec25[((IOTA - 68) & 511)]) - fVec25[((IOTA - 72) & 511)]) - fVec25[((IOTA - 73) & 511)]) - fVec25[((IOTA - 74) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00460829493f * (fVec25[((IOTA - 401) & 511)] - fVec25[((IOTA - 511) & 511)])))) : (((0.00119022187f * ((fVec24[((IOTA - 498) & 511)] - (((fVec24[((IOTA - 210) & 511)] + fVec24[((IOTA - 324) & 511)]) - fVec24[((IOTA - 383) & 511)]) - fVec24[((IOTA - 495) & 511)])) + fVec24[((IOTA - 511) & 511)])) + ((0.000946073793f * (((fVec24[((IOTA - 165) & 511)] - fVec24[((IOTA - 322) & 511)]) + fVec24[((IOTA - 494) & 511)]) + fVec24[((IOTA - 510) & 511)])) + ((9.15555283e-05f * ((((((((((((((((fVec24[((IOTA - 6) & 511)] + fVec24[((IOTA - 8) & 511)]) + fVec24[((IOTA - 9) & 511)]) + fVec24[((IOTA - 10) & 511)]) + fVec24[((IOTA - 11) & 511)]) + fVec24[((IOTA - 12) & 511)]) - fVec24[((IOTA - 31) & 511)]) + fVec24[((IOTA - 50) & 511)]) + fVec24[((IOTA - 51) & 511)]) - fVec24[((IOTA - 60) & 511)]) + fVec24[((IOTA - 330) & 511)]) - fVec24[((IOTA - 399) & 511)]) - fVec24[((IOTA - 400) & 511)]) + fVec24[((IOTA - 503) & 511)]) - fVec24[((IOTA - 504) & 511)]) - fVec24[((IOTA - 506) & 511)]) + fVec24[((IOTA - 507) & 511)])) + ((0.000274666585f * (((fVec24[((IOTA - 57) & 511)] + fVec24[((IOTA - 460) & 511)]) + fVec24[((IOTA - 461) & 511)]) + fVec24[((IOTA - 502) & 511)])) + ((0.00131229591f * ((fVec24[((IOTA - 167) & 511)] + fVec24[((IOTA - 478) & 511)]) + fVec24[((IOTA - 496) & 511)])) + ((0.000915555283f * (((fVec24[((IOTA - 451) & 511)] + fVec24[((IOTA - 458) & 511)]) + fVec24[((IOTA - 476) & 511)]) + fVec24[((IOTA - 485) & 511)])) + ((0.00292977691f * (fVec24[((IOTA - 429) & 511)] + fVec24[((IOTA - 469) & 511)])) + ((0.000427259132f * fVec24[((IOTA - 462) & 511)]) + ((0.00228888821f * (((fVec24[((IOTA - 159) & 511)] - fVec24[((IOTA - 293) & 511)]) - fVec24[((IOTA - 306) & 511)]) + fVec24[((IOTA - 455) & 511)])) + ((0.00219733268f * fVec24[((IOTA - 453) & 511)]) + ((0.00164799951f * fVec24[((IOTA - 452) & 511)]) + ((0.00384533219f * fVec24[((IOTA - 441) & 511)]) + ((0.00122074038f * (((((fVec24[((IOTA - 68) & 511)] + fVec24[((IOTA - 168) & 511)]) - fVec24[((IOTA - 172) & 511)]) - fVec24[((IOTA - 317) & 511)]) - fVec24[((IOTA - 340) & 511)]) + fVec24[((IOTA - 438) & 511)])) + ((6.10370189e-05f * (((((((((((((((fVec24[((IOTA - 4) & 511)] + fVec24[((IOTA - 5) & 511)]) + fVec24[((IOTA - 7) & 511)]) + fVec24[((IOTA - 13) & 511)]) + fVec24[((IOTA - 14) & 511)]) + fVec24[((IOTA - 15) & 511)]) + fVec24[((IOTA - 18) & 511)]) + fVec24[((IOTA - 20) & 511)]) - fVec24[((IOTA - 33) & 511)]) + fVec24[((IOTA - 48) & 511)]) + fVec24[((IOTA - 49) & 511)]) - fVec24[((IOTA - 93) & 511)]) + fVec24[((IOTA - 212) & 511)]) + fVec24[((IOTA - 331) & 511)]) + fVec24[((IOTA - 435) & 511)]) + fVec24[((IOTA - 436) & 511)])) + ((0.00302133244f * fVec24[((IOTA - 426) & 511)]) + ((0.0025940733f * fVec24[((IOTA - 425) & 511)]) + ((0.00112918485f * fVec24[((IOTA - 421) & 511)]) + ((0.000823999755f * (((fVec24[((IOTA - 145) & 511)] - fVec24[((IOTA - 327) & 511)]) - fVec24[((IOTA - 382) & 511)]) + fVec24[((IOTA - 420) & 511)])) + ((0.00250251777f * fVec24[((IOTA - 430) & 511)]) + ((0.000183111057f * ((((fVec24[((IOTA - 55) & 511)] - fVec24[((IOTA - 117) & 511)]) - fVec24[((IOTA - 211) & 511)]) - fVec24[((IOTA - 403) & 511)]) + fVec24[((IOTA - 409) & 511)])) + ((0.00173955504f * fVec24[((IOTA - 414) & 511)]) + ((0.000152592547f * (((fVec24[((IOTA - 53) & 511)] + fVec24[((IOTA - 54) & 511)]) - fVec24[((IOTA - 127) & 511)]) + fVec24[((IOTA - 398) & 511)])) + ((0.00201422162f * (fVec24[((IOTA - 431) & 511)] - (((fVec24[((IOTA - 263) & 511)] + fVec24[((IOTA - 282) & 511)]) + fVec24[((IOTA - 308) & 511)]) + fVec24[((IOTA - 375) & 511)]))) + ((0.00308236945f * ((fVec24[((IOTA - 82) & 511)] - fVec24[((IOTA - 235) & 511)]) + fVec24[((IOTA - 387) & 511)])) + ((0.00393688772f * fVec24[((IOTA - 385) & 511)]) + ((0.00350962859f * (fVec24[((IOTA - 131) & 511)] - fVec24[((IOTA - 380) & 511)])) + ((0.00149540696f * (fVec24[((IOTA - 166) & 511)] - fVec24[((IOTA - 287) & 511)])) + ((0.00375377666f * (((fVec24[((IOTA - 170) & 511)] - fVec24[((IOTA - 184) & 511)]) - fVec24[((IOTA - 239) & 511)]) - fVec24[((IOTA - 249) & 511)])) + ((0.00320444349f * fVec24[((IOTA - 171) & 511)]) + ((0.00338755455f * fVec24[((IOTA - 169) & 511)]) + ((0.00848414563f * (fVec24[((IOTA - 130) & 511)] - fVec24[((IOTA - 161) & 511)])) + ((0.0116275521f * fVec24[((IOTA - 157) & 511)]) + ((0.00570696127f * fVec24[((IOTA - 156) & 511)]) + ((0.00512710959f * fVec24[((IOTA - 144) & 511)]) + ((0.00717184972f * fVec24[((IOTA - 143) & 511)]) + ((0.00833155308f * fVec24[((IOTA - 142) & 511)]) + ((0.00747703481f * fVec24[((IOTA - 141) & 511)]) + ((0.00442518387f * fVec24[((IOTA - 140) & 511)]) + ((0.00851466414f * fVec24[((IOTA - 129) & 511)]) + ((0.00637836847f * fVec24[((IOTA - 128) & 511)]) + ((0.0123294778f * fVec24[((IOTA - 116) & 511)]) + ((0.0206610318f * fVec24[((IOTA - 115) & 511)]) + ((0.0213629566f * fVec24[((IOTA - 114) & 511)]) + ((0.024323253f * fVec24[((IOTA - 113) & 511)]) + ((0.0175786614f * fVec24[((IOTA - 112) & 511)]) + ((0.0214850307f * fVec24[((IOTA - 111) & 511)]) + ((0.0149540696f * fVec24[((IOTA - 110) & 511)]) + ((0.0142826624f * fVec24[((IOTA - 109) & 511)]) + ((0.00109866634f * fVec24[((IOTA - 108) & 511)]) + ((0.00650044251f * fVec24[((IOTA - 101) & 511)]) + ((0.0249336231f * fVec24[((IOTA - 100) & 511)]) + ((0.0491653197f * fVec24[((IOTA - 99) & 511)]) + ((0.0226752535f * fVec24[((IOTA - 98) & 511)]) + ((0.00924710836f * fVec24[((IOTA - 97) & 511)]) + ((0.00567644276f * fVec24[((IOTA - 92) & 511)]) + ((0.0134891812f * fVec24[((IOTA - 86) & 511)]) + ((0.0214239936f * fVec24[((IOTA - 81) & 511)]) + ((0.049958799f * fVec24[((IOTA - 80) & 511)]) + ((0.00720236823f * fVec24[((IOTA - 79) & 511)]) + ((0.196234018f * fVec24[((IOTA - 74) & 511)]) + ((0.323679298f * fVec24[((IOTA - 73) & 511)]) + ((0.291390717f * fVec24[((IOTA - 72) & 511)]) + ((0.138981298f * fVec24[((IOTA - 71) & 511)]) + ((0.0311288796f * fVec24[((IOTA - 70) & 511)]) + ((0.000244148076f * fVec24[((IOTA - 58) & 511)]) + (0.00564592425f * fVec24[((IOTA - 69) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000335703604f * (fVec24[((IOTA - 390) & 511)] - fVec24[((IOTA - 508) & 511)])) + ((0.000122074038f * ((((((fVec24[((IOTA - 29) & 511)] - fVec24[((IOTA - 52) & 511)]) - fVec24[((IOTA - 59) & 511)]) + fVec24[((IOTA - 366) & 511)]) - fVec24[((IOTA - 488) & 511)]) - fVec24[((IOTA - 491) & 511)]) + fVec24[((IOTA - 505) & 511)])) + ((0.00054933317f * (((((((fVec24[((IOTA - 61) & 511)] + fVec24[((IOTA - 227) & 511)]) + fVec24[((IOTA - 328) & 511)]) - fVec24[((IOTA - 389) & 511)]) + fVec24[((IOTA - 393) & 511)]) - fVec24[((IOTA - 397) & 511)]) + fVec24[((IOTA - 405) & 511)]) - fVec24[((IOTA - 501) & 511)])) + ((0.000793481246f * ((fVec24[((IOTA - 216) & 511)] - fVec24[((IOTA - 395) & 511)]) - fVec24[((IOTA - 500) & 511)])) + ((0.00100711081f * (((fVec24[((IOTA - 325) & 511)] + fVec24[((IOTA - 392) & 511)]) - fVec24[((IOTA - 464) & 511)]) - fVec24[((IOTA - 499) & 511)])) + ((0.0012817774f * (fVec24[((IOTA - 225) & 511)] - fVec24[((IOTA - 497) & 511)])) + ((0.000366222113f * ((((((fVec24[((IOTA - 353) & 511)] + fVec24[((IOTA - 404) & 511)]) + fVec24[((IOTA - 408) & 511)]) - fVec24[((IOTA - 418) & 511)]) - fVec24[((IOTA - 434) & 511)]) + fVec24[((IOTA - 449) & 511)]) - fVec24[((IOTA - 492) & 511)])) + ((3.05185094e-05f * (((((((((((((((((fVec24[((IOTA - 28) & 511)] - (((((((fVec24[((IOTA - 16) & 511)] - ((fTemp25 + fVec24[((IOTA - 1) & 511)]) - fVec24[((IOTA - 3) & 511)])) + fVec24[((IOTA - 17) & 511)]) + fVec24[((IOTA - 19) & 511)]) + fVec24[((IOTA - 21) & 511)]) + fVec24[((IOTA - 22) & 511)]) + fVec24[((IOTA - 23) & 511)]) + fVec24[((IOTA - 24) & 511)])) + fVec24[((IOTA - 30) & 511)]) - fVec24[((IOTA - 34) & 511)]) + fVec24[((IOTA - 35) & 511)]) + fVec24[((IOTA - 37) & 511)]) + fVec24[((IOTA - 39) & 511)]) + fVec24[((IOTA - 40) & 511)]) + fVec24[((IOTA - 41) & 511)]) + fVec24[((IOTA - 42) & 511)]) + fVec24[((IOTA - 43) & 511)]) + fVec24[((IOTA - 44) & 511)]) + fVec24[((IOTA - 45) & 511)]) - fVec24[((IOTA - 47) & 511)]) + fVec24[((IOTA - 401) & 511)]) + fVec24[((IOTA - 402) & 511)]) + fVec24[((IOTA - 489) & 511)]) + fVec24[((IOTA - 490) & 511)])) + ((0.000396740623f * (fVec24[((IOTA - 26) & 511)] - fVec24[((IOTA - 487) & 511)])) + ((0.000671407208f * ((fVec24[((IOTA - 229) & 511)] + fVec24[((IOTA - 407) & 511)]) - fVec24[((IOTA - 486) & 511)])) + ((0.00115970336f * (((((fVec24[((IOTA - 139) & 511)] + fVec24[((IOTA - 323) & 511)]) + fVec24[((IOTA - 337) & 511)]) + fVec24[((IOTA - 344) & 511)]) - fVec24[((IOTA - 444) & 511)]) - fVec24[((IOTA - 484) & 511)])) + ((0.00134281442f * ((fVec24[((IOTA - 276) & 511)] + fVec24[((IOTA - 338) & 511)]) - fVec24[((IOTA - 483) & 511)])) + ((0.00152592547f * ((((fVec24[((IOTA - 278) & 511)] + fVec24[((IOTA - 312) & 511)]) - fVec24[((IOTA - 465) & 511)]) - fVec24[((IOTA - 479) & 511)]) - fVec24[((IOTA - 482) & 511)])) + ((0.00167851802f * ((((fVec24[((IOTA - 199) & 511)] + fVec24[((IOTA - 272) & 511)]) - fVec24[((IOTA - 423) & 511)]) - fVec24[((IOTA - 480) & 511)]) - fVec24[((IOTA - 481) & 511)])) + ((0.00106814783f * ((fVec24[((IOTA - 341) & 511)] - fVec24[((IOTA - 474) & 511)]) - fVec24[((IOTA - 477) & 511)])) + ((0.000885036774f * ((((fVec24[((IOTA - 226) & 511)] - fVec24[((IOTA - 396) & 511)]) - fVec24[((IOTA - 416) & 511)]) - fVec24[((IOTA - 433) & 511)]) - fVec24[((IOTA - 475) & 511)])) + ((0.00143436994f * ((((((fVec24[((IOTA - 231) & 511)] + fVec24[((IOTA - 274) & 511)]) + fVec24[((IOTA - 345) & 511)]) - fVec24[((IOTA - 432) & 511)]) + fVec24[((IOTA - 447) & 511)]) - fVec24[((IOTA - 457) & 511)]) - fVec24[((IOTA - 473) & 511)])) + ((0.0019226661f * (((fVec24[((IOTA - 200) & 511)] + fVec24[((IOTA - 262) & 511)]) - fVec24[((IOTA - 456) & 511)]) - fVec24[((IOTA - 472) & 511)])) + ((0.00238044374f * ((((fVec24[((IOTA - 290) & 511)] + fVec24[((IOTA - 291) & 511)]) + fVec24[((IOTA - 295) & 511)]) + fVec24[((IOTA - 297) & 511)]) - fVec24[((IOTA - 471) & 511)])) + ((0.00271614734f * (fVec24[((IOTA - 223) & 511)] - fVec24[((IOTA - 470) & 511)])) + ((0.00296029542f * (fVec24[((IOTA - 259) & 511)] - fVec24[((IOTA - 468) & 511)])) + ((0.00268562883f * ((fVec24[((IOTA - 198) & 511)] + fVec24[((IOTA - 234) & 511)]) - fVec24[((IOTA - 467) & 511)])) + ((0.00213629566f * (fVec24[((IOTA - 349) & 511)] - fVec24[((IOTA - 466) & 511)])) + ((0.000518814661f * (((fVec24[((IOTA - 228) & 511)] - fVec24[((IOTA - 417) & 511)]) - fVec24[((IOTA - 419) & 511)]) - fVec24[((IOTA - 459) & 511)])) + ((0.00244148076f * (fVec24[((IOTA - 360) & 511)] - fVec24[((IOTA - 454) & 511)])) + ((0.000213629566f * (((((((fVec24[((IOTA - 27) & 511)] - fVec24[((IOTA - 56) & 511)]) + fVec24[((IOTA - 213) & 511)]) + fVec24[((IOTA - 329) & 511)]) + fVec24[((IOTA - 332) & 511)]) - fVec24[((IOTA - 371) & 511)]) - fVec24[((IOTA - 394) & 511)]) - fVec24[((IOTA - 450) & 511)])) + ((0.000976592302f * ((((((fVec24[((IOTA - 217) & 511)] + fVec24[((IOTA - 230) & 511)]) + fVec24[((IOTA - 318) & 511)]) + fVec24[((IOTA - 342) & 511)]) + fVec24[((IOTA - 372) & 511)]) + fVec24[((IOTA - 391) & 511)]) + fVec24[((IOTA - 448) & 511)])) + ((0.00140385143f * ((((fVec24[((IOTA - 275) & 511)] + fVec24[((IOTA - 285) & 511)]) - fVec24[((IOTA - 411) & 511)]) - fVec24[((IOTA - 422) & 511)]) + fVec24[((IOTA - 446) & 511)])) + ((0.000457777642f * (fVec24[((IOTA - 359) & 511)] + fVec24[((IOTA - 445) & 511)])) + ((0.00274666585f * (fVec24[((IOTA - 245) & 511)] - fVec24[((IOTA - 443) & 511)])) + ((0.00372325815f * (fVec24[((IOTA - 221) & 511)] - fVec24[((IOTA - 442) & 511)])) + ((0.003234962f * ((((fVec24[((IOTA - 132) & 511)] + fVec24[((IOTA - 248) & 511)]) + fVec24[((IOTA - 254) & 511)]) - fVec24[((IOTA - 428) & 511)]) - fVec24[((IOTA - 440) & 511)])) + ((0.00222785119f * (((fVec24[((IOTA - 264) & 511)] + fVec24[((IOTA - 265) & 511)]) + fVec24[((IOTA - 266) & 511)]) - fVec24[((IOTA - 439) & 511)])) + ((0.000488296151f * (fVec24[((IOTA - 333) & 511)] - fVec24[((IOTA - 437) & 511)])) + ((0.00329599902f * ((fVec24[((IOTA - 84) & 511)] + fVec24[((IOTA - 240) & 511)]) - fVec24[((IOTA - 427) & 511)])) + ((0.00207525864f * ((fVec24[((IOTA - 261) & 511)] + fVec24[((IOTA - 304) & 511)]) - fVec24[((IOTA - 424) & 511)])) + ((0.00137333293f * (((((fVec24[((IOTA - 91) & 511)] + fVec24[((IOTA - 277) & 511)]) + fVec24[((IOTA - 286) & 511)]) + fVec24[((IOTA - 339) & 511)]) - fVec24[((IOTA - 355) & 511)]) - fVec24[((IOTA - 415) & 511)])) + ((0.00189214759f * (fVec24[((IOTA - 270) & 511)] - fVec24[((IOTA - 413) & 511)])) + ((0.00177007355f * (((((fVec24[((IOTA - 283) & 511)] + fVec24[((IOTA - 303) & 511)]) - fVec24[((IOTA - 356) & 511)]) - fVec24[((IOTA - 367) & 511)]) + fVec24[((IOTA - 373) & 511)]) - fVec24[((IOTA - 412) & 511)])) + ((0.000854518265f * ((((fVec24[((IOTA - 215) & 511)] + fVec24[((IOTA - 326) & 511)]) + fVec24[((IOTA - 336) & 511)]) - fVec24[((IOTA - 358) & 511)]) - fVec24[((IOTA - 410) & 511)])) + ((0.00186162908f * (((((fVec24[((IOTA - 218) & 511)] + fVec24[((IOTA - 232) & 511)]) + fVec24[((IOTA - 280) & 511)]) + fVec24[((IOTA - 288) & 511)]) + fVec24[((IOTA - 315) & 511)]) - fVec24[((IOTA - 388) & 511)])) + ((0.00396740623f * (((fVec24[((IOTA - 206) & 511)] + fVec24[((IOTA - 208) & 511)]) + fVec24[((IOTA - 238) & 511)]) - fVec24[((IOTA - 386) & 511)])) + ((0.00299081393f * ((fVec24[((IOTA - 241) & 511)] + fVec24[((IOTA - 255) & 511)]) - fVec24[((IOTA - 384) & 511)])) + ((0.00247199927f * (fVec24[((IOTA - 296) & 511)] + fVec24[((IOTA - 381) & 511)])) + ((0.00381481368f * (fVec24[((IOTA - 237) & 511)] + fVec24[((IOTA - 379) & 511)])) + ((0.0028992584f * fVec24[((IOTA - 377) & 511)]) + ((0.00234992523f * fVec24[((IOTA - 376) & 511)]) + ((0.00198370311f * ((fVec24[((IOTA - 268) & 511)] + fVec24[((IOTA - 314) & 511)]) + fVec24[((IOTA - 374) & 511)])) + ((0.00155644398f * (((fVec24[((IOTA - 273) & 511)] + fVec24[((IOTA - 284) & 511)]) + fVec24[((IOTA - 311) & 511)]) - fVec24[((IOTA - 370) & 511)])) + ((0.00256355479f * ((((fVec24[((IOTA - 62) & 511)] + fVec24[((IOTA - 203) & 511)]) + fVec24[((IOTA - 209) & 511)]) + fVec24[((IOTA - 260) & 511)]) - fVec24[((IOTA - 369) & 511)])) + ((0.00277718436f * (fVec24[((IOTA - 243) & 511)] - fVec24[((IOTA - 368) & 511)])) + ((0.00265511032f * (fVec24[((IOTA - 201) & 511)] + fVec24[((IOTA - 365) & 511)])) + ((0.00509659108f * fVec24[((IOTA - 364) & 511)]) + ((0.00668355357f * fVec24[((IOTA - 363) & 511)]) + ((0.00653096102f * fVec24[((IOTA - 362) & 511)]) + ((0.00476088747f * fVec24[((IOTA - 361) & 511)]) + ((0.00158696249f * ((fVec24[((IOTA - 302) & 511)] + fVec24[((IOTA - 310) & 511)]) - fVec24[((IOTA - 357) & 511)])) + ((0.00057985168f * ((fVec24[((IOTA - 214) & 511)] + fVec24[((IOTA - 320) & 511)]) - fVec24[((IOTA - 354) & 511)])) + ((0.00125125889f * fVec24[((IOTA - 352) & 511)]) + ((0.00180059206f * (((fVec24[((IOTA - 271) & 511)] + fVec24[((IOTA - 301) & 511)]) + fVec24[((IOTA - 309) & 511)]) + fVec24[((IOTA - 351) & 511)])) + ((0.00204474013f * (fVec24[((IOTA - 267) & 511)] + fVec24[((IOTA - 350) & 511)])) + ((0.0019531846f * ((fVec24[((IOTA - 269) & 511)] + fVec24[((IOTA - 281) & 511)]) + fVec24[((IOTA - 347) & 511)])) + ((0.00170903653f * (fVec24[((IOTA - 313) & 511)] + fVec24[((IOTA - 346) & 511)])) + ((0.00103762932f * fVec24[((IOTA - 343) & 511)]) + ((0.000701925717f * fVec24[((IOTA - 335) & 511)]) + ((0.000610370189f * fVec24[((IOTA - 321) & 511)]) + ((0.00210577715f * (fVec24[((IOTA - 224) & 511)] + fVec24[((IOTA - 348) & 511)])) + ((0.001617481f * (fVec24[((IOTA - 279) & 511)] + fVec24[((IOTA - 316) & 511)])) + ((0.00231940672f * ((fVec24[((IOTA - 233) & 511)] + fVec24[((IOTA - 294) & 511)]) + fVec24[((IOTA - 307) & 511)])) + ((0.0022583697f * (((fVec24[((IOTA - 289) & 511)] + fVec24[((IOTA - 292) & 511)]) + fVec24[((IOTA - 298) & 511)]) + fVec24[((IOTA - 305) & 511)])) + ((0.00216681417f * (fVec24[((IOTA - 299) & 511)] + fVec24[((IOTA - 300) & 511)])) + ((0.00360118411f * (fVec24[((IOTA - 220) & 511)] + fVec24[((IOTA - 378) & 511)])) + ((0.00335703604f * (fVec24[((IOTA - 222) & 511)] + fVec24[((IOTA - 258) & 511)])) + ((0.00341807306f * fVec24[((IOTA - 257) & 511)]) + ((0.00311288796f * fVec24[((IOTA - 256) & 511)]) + ((0.00390636921f * fVec24[((IOTA - 253) & 511)]) + ((0.00433362834f * fVec24[((IOTA - 252) & 511)]) + ((0.00436414685f * fVec24[((IOTA - 251) & 511)]) + ((0.00411999878f * (fVec24[((IOTA - 75) & 511)] + fVec24[((IOTA - 250) & 511)])) + ((0.00280770287f * (fVec24[((IOTA - 244) & 511)] + fVec24[((IOTA - 246) & 511)])) + ((0.00286873989f * fVec24[((IOTA - 242) & 511)]) + ((0.00344859157f * fVec24[((IOTA - 236) & 511)]) + ((0.00460829493f * fVec24[((IOTA - 207) & 511)]) + ((0.00305185094f * fVec24[((IOTA - 205) & 511)]) + ((0.00253303628f * fVec24[((IOTA - 204) & 511)]) + ((0.00262459181f * fVec24[((IOTA - 202) & 511)]) + ((0.00430310983f * fVec24[((IOTA - 197) & 511)]) + ((0.00540177617f * fVec24[((IOTA - 196) & 511)]) + ((0.00659199804f * fVec24[((IOTA - 195) & 511)]) + ((0.00738547929f * (fVec24[((IOTA - 181) & 511)] + fVec24[((IOTA - 194) & 511)])) + ((0.00836207159f * ((fVec24[((IOTA - 138) & 511)] + fVec24[((IOTA - 174) & 511)]) + fVec24[((IOTA - 193) & 511)])) + ((0.00854518265f * fVec24[((IOTA - 192) & 511)]) + ((0.00842310861f * fVec24[((IOTA - 191) & 511)]) + ((0.00683614612f * fVec24[((IOTA - 190) & 511)]) + ((0.00595110934f * fVec24[((IOTA - 189) & 511)]) + ((0.00610370189f * fVec24[((IOTA - 188) & 511)]) + ((0.0061342204f * fVec24[((IOTA - 187) & 511)]) + ((0.00561540574f * (fVec24[((IOTA - 173) & 511)] + fVec24[((IOTA - 186) & 511)])) + ((0.00402844325f * fVec24[((IOTA - 185) & 511)]) + ((0.00439466536f * fVec24[((IOTA - 183) & 511)]) + ((0.00573747978f * fVec24[((IOTA - 182) & 511)]) + ((0.00820947904f * fVec24[((IOTA - 180) & 511)]) + ((0.0093691824f * fVec24[((IOTA - 179) & 511)]) + ((0.00897244178f * fVec24[((IOTA - 178) & 511)]) + ((0.00766014587f * fVec24[((IOTA - 177) & 511)]) + ((0.00735496078f * fVec24[((IOTA - 176) & 511)]) + ((0.00912503432f * fVec24[((IOTA - 175) & 511)]) + ((0.00241096225f * fVec24[((IOTA - 164) & 511)]) + ((0.0051576281f * fVec24[((IOTA - 163) & 511)]) + ((0.00689718314f * fVec24[((IOTA - 162) & 511)]) + ((0.00283822138f * (fVec24[((IOTA - 219) & 511)] + fVec24[((IOTA - 247) & 511)])) + ((0.00473036896f * fVec24[((IOTA - 160) & 511)]) + ((0.0104678487f * (fVec24[((IOTA - 154) & 511)] - fVec24[((IOTA - 158) & 511)])) + ((0.00326548051f * fVec24[((IOTA - 155) & 511)]) + ((0.0130924406f * fVec24[((IOTA - 152) & 511)]) + ((0.0122379223f * fVec24[((IOTA - 151) & 511)]) + ((0.0155034028f * fVec24[((IOTA - 150) & 511)]) + ((0.0186468102f * fVec24[((IOTA - 149) & 511)]) + ((0.0174871068f * fVec24[((IOTA - 148) & 511)]) + ((0.0118106632f * fVec24[((IOTA - 147) & 511)]) + ((0.00503555406f * fVec24[((IOTA - 146) & 511)]) + ((0.0150761437f * fVec24[((IOTA - 137) & 511)]) + ((0.0205389578f * fVec24[((IOTA - 136) & 511)]) + ((0.0204474013f * fVec24[((IOTA - 135) & 511)]) + ((0.016296884f * fVec24[((IOTA - 134) & 511)]) + ((0.0103152562f * fVec24[((IOTA - 133) & 511)]) + ((0.008087405f * fVec24[((IOTA - 126) & 511)]) + ((0.01803644f * fVec24[((IOTA - 125) & 511)]) + ((0.0248420667f * fVec24[((IOTA - 124) & 511)]) + ((0.029175695f * fVec24[((IOTA - 123) & 511)]) + ((0.0307016205f * fVec24[((IOTA - 122) & 511)]) + ((0.0323801376f * fVec24[((IOTA - 121) & 511)]) + ((0.0293893255f * fVec24[((IOTA - 120) & 511)]) + ((0.0272225104f * fVec24[((IOTA - 119) & 511)]) + ((0.0151066622f * fVec24[((IOTA - 118) & 511)]) + ((0.0138248848f * fVec24[((IOTA - 153) & 511)]) + ((0.00491348002f * fVec24[((IOTA - 107) & 511)]) + ((0.00921658985f * fVec24[((IOTA - 106) & 511)]) + ((0.0124820704f * fVec24[((IOTA - 105) & 511)]) + ((0.0143131809f * fVec24[((IOTA - 104) & 511)]) + ((0.0127567369f * fVec24[((IOTA - 103) & 511)]) + ((0.0124515519f * fVec24[((IOTA - 102) & 511)]) + ((0.0381481387f * fVec24[((IOTA - 95) & 511)]) + ((0.0393383577f * fVec24[((IOTA - 94) & 511)]) + ((0.0222479943f * fVec24[((IOTA - 90) & 511)]) + ((0.0437635444f * fVec24[((IOTA - 89) & 511)]) + ((0.0233466607f * fVec24[((IOTA - 88) & 511)]) + ((0.0157475509f * fVec24[((IOTA - 87) & 511)]) + ((0.0163579211f * fVec24[((IOTA - 85) & 511)]) + ((0.0362254716f * fVec24[((IOTA - 96) & 511)]) + ((0.0255134739f * fVec24[((IOTA - 83) & 511)]) + ((0.0925931558f * fVec24[((IOTA - 78) & 511)]) + ((0.148228407f * fVec24[((IOTA - 77) & 511)]) + ((0.152989283f * fVec24[((IOTA - 76) & 511)]) + ((0.00524918362f * fVec24[((IOTA - 67) & 511)]) + ((0.0104983672f * fVec24[((IOTA - 66) & 511)]) + ((0.0117801446f * fVec24[((IOTA - 65) & 511)]) + ((0.00625629444f * fVec24[((IOTA - 63) & 511)]) + (0.009704886f * fVec24[((IOTA - 64) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000640888698f * (((((fVec24[((IOTA - 319) & 511)] + fVec24[((IOTA - 334) & 511)]) + fVec24[((IOTA - 406) & 511)]) - fVec24[((IOTA - 463) & 511)]) - fVec24[((IOTA - 493) & 511)]) - fVec24[((IOTA - 509) & 511)]))))))) : (iSlow41 ? (iSlow49 ? (iSlow54 ? (((0.00158696249f * (((((((((fVec23[((IOTA - 108) & 511)] + fVec23[((IOTA - 230) & 511)]) + fVec23[((IOTA - 231) & 511)]) - fVec23[((IOTA - 292) & 511)]) - fVec23[((IOTA - 304) & 511)]) + fVec23[((IOTA - 317) & 511)]) - fVec23[((IOTA - 401) & 511)]) - fVec23[((IOTA - 430) & 511)]) - fVec23[((IOTA - 485) & 511)]) - fVec23[((IOTA - 511) & 511)])) + ((0.001617481f * ((((((((((fVec23[((IOTA - 218) & 511)] + fVec23[((IOTA - 221) & 511)]) + fVec23[((IOTA - 222) & 511)]) + fVec23[((IOTA - 312) & 511)]) - fVec23[((IOTA - 421) & 511)]) - fVec23[((IOTA - 453) & 511)]) - fVec23[((IOTA - 486) & 511)]) - fVec23[((IOTA - 487) & 511)]) - fVec23[((IOTA - 493) & 511)]) - fVec23[((IOTA - 494) & 511)]) - fVec23[((IOTA - 510) & 511)])) + ((0.00155644398f * ((((fVec23[((IOTA - 229) & 511)] - fVec23[((IOTA - 328) & 511)]) - fVec23[((IOTA - 443) & 511)]) - fVec23[((IOTA - 505) & 511)]) - fVec23[((IOTA - 509) & 511)])) + ((0.00152592547f * (((((((fVec23[((IOTA - 123) & 511)] + fVec23[((IOTA - 228) & 511)]) + fVec23[((IOTA - 232) & 511)]) - fVec23[((IOTA - 390) & 511)]) - fVec23[((IOTA - 429) & 511)]) - fVec23[((IOTA - 461) & 511)]) - fVec23[((IOTA - 506) & 511)]) - fVec23[((IOTA - 508) & 511)])) + ((0.00149540696f * ((((((((fVec23[((IOTA - 109) & 511)] + fVec23[((IOTA - 130) & 511)]) + fVec23[((IOTA - 144) & 511)]) + fVec23[((IOTA - 219) & 511)]) + fVec23[((IOTA - 220) & 511)]) - fVec23[((IOTA - 345) & 511)]) - fVec23[((IOTA - 393) & 511)]) - fVec23[((IOTA - 484) & 511)]) - fVec23[((IOTA - 507) & 511)])) + ((0.00167851802f * (((((((fVec23[((IOTA - 204) & 511)] - fVec23[((IOTA - 307) & 511)]) - fVec23[((IOTA - 348) & 511)]) - fVec23[((IOTA - 386) & 511)]) - fVec23[((IOTA - 490) & 511)]) - fVec23[((IOTA - 496) & 511)]) - fVec23[((IOTA - 502) & 511)]) - fVec23[((IOTA - 503) & 511)])) + ((0.00173955504f * (((((fVec23[((IOTA - 124) & 511)] + fVec23[((IOTA - 314) & 511)]) - fVec23[((IOTA - 366) & 511)]) - fVec23[((IOTA - 444) & 511)]) - fVec23[((IOTA - 498) & 511)]) - fVec23[((IOTA - 499) & 511)])) + ((0.00125125889f * (((fVec23[((IOTA - 226) & 511)] - fVec23[((IOTA - 321) & 511)]) - fVec23[((IOTA - 432) & 511)]) - fVec23[((IOTA - 482) & 511)])) + ((0.00112918485f * (((fVec23[((IOTA - 234) & 511)] - fVec23[((IOTA - 469) & 511)]) - fVec23[((IOTA - 470) & 511)]) - fVec23[((IOTA - 481) & 511)])) + ((0.00106814783f * ((((fVec23[((IOTA - 136) & 511)] + fVec23[((IOTA - 182) & 511)]) + fVec23[((IOTA - 238) & 511)]) - fVec23[((IOTA - 257) & 511)]) - fVec23[((IOTA - 480) & 511)])) + ((0.000976592302f * ((((fVec23[((IOTA - 147) & 511)] + fVec23[((IOTA - 202) & 511)]) + fVec23[((IOTA - 246) & 511)]) - fVec23[((IOTA - 433) & 511)]) - fVec23[((IOTA - 479) & 511)])) + ((0.000885036774f * ((((((((fVec23[((IOTA - 143) & 511)] + fVec23[((IOTA - 235) & 511)]) + fVec23[((IOTA - 245) & 511)]) - fVec23[((IOTA - 259) & 511)]) - fVec23[((IOTA - 269) & 511)]) - fVec23[((IOTA - 343) & 511)]) - fVec23[((IOTA - 438) & 511)]) - fVec23[((IOTA - 464) & 511)]) - fVec23[((IOTA - 478) & 511)])) + ((0.000915555283f * ((((((fVec23[((IOTA - 138) & 511)] - fVec23[((IOTA - 264) & 511)]) - fVec23[((IOTA - 270) & 511)]) - fVec23[((IOTA - 352) & 511)]) - fVec23[((IOTA - 368) & 511)]) - fVec23[((IOTA - 466) & 511)]) - fVec23[((IOTA - 477) & 511)])) + ((0.00103762932f * ((((((fVec23[((IOTA - 240) & 511)] - fVec23[((IOTA - 331) & 511)]) - fVec23[((IOTA - 394) & 511)]) - fVec23[((IOTA - 399) & 511)]) - fVec23[((IOTA - 463) & 511)]) - fVec23[((IOTA - 467) & 511)]) - fVec23[((IOTA - 476) & 511)])) + ((0.00115970336f * (((fVec23[((IOTA - 225) & 511)] - fVec23[((IOTA - 330) & 511)]) - fVec23[((IOTA - 373) & 511)]) - fVec23[((IOTA - 473) & 511)])) + ((0.00109866634f * ((((((((fVec23[((IOTA - 131) & 511)] + fVec23[((IOTA - 132) & 511)]) + fVec23[((IOTA - 239) & 511)]) - fVec23[((IOTA - 311) & 511)]) - fVec23[((IOTA - 423) & 511)]) - fVec23[((IOTA - 439) & 511)]) - fVec23[((IOTA - 468) & 511)]) - fVec23[((IOTA - 471) & 511)]) - fVec23[((IOTA - 472) & 511)])) + ((0.000854518265f * (fVec23[((IOTA - 236) & 511)] - fVec23[((IOTA - 465) & 511)])) + ((0.00183111057f * ((fVec23[((IOTA - 205) & 511)] - fVec23[((IOTA - 447) & 511)]) - fVec23[((IOTA - 459) & 511)])) + ((0.00222785119f * (((fVec23[((IOTA - 318) & 511)] - fVec23[((IOTA - 387) & 511)]) - fVec23[((IOTA - 456) & 511)]) - fVec23[((IOTA - 457) & 511)])) + ((0.00198370311f * ((fVec23[((IOTA - 208) & 511)] + fVec23[((IOTA - 209) & 511)]) - fVec23[((IOTA - 455) & 511)])) + ((0.00189214759f * ((fVec23[((IOTA - 211) & 511)] - fVec23[((IOTA - 402) & 511)]) - fVec23[((IOTA - 445) & 511)])) + ((0.00146488845f * ((((fVec23[((IOTA - 72) & 511)] + fVec23[((IOTA - 181) & 511)]) + fVec23[((IOTA - 223) & 511)]) - fVec23[((IOTA - 431) & 511)]) - fVec23[((IOTA - 442) & 511)])) + ((0.00140385143f * ((((fVec23[((IOTA - 129) & 511)] - fVec23[((IOTA - 346) & 511)]) - fVec23[((IOTA - 347) & 511)]) - fVec23[((IOTA - 422) & 511)]) - fVec23[((IOTA - 441) & 511)])) + ((0.000762962736f * (((fVec23[((IOTA - 93) & 511)] - fVec23[((IOTA - 262) & 511)]) - fVec23[((IOTA - 276) & 511)]) - fVec23[((IOTA - 437) & 511)])) + ((0.000946073793f * ((fVec23[((IOTA - 237) & 511)] - fVec23[((IOTA - 263) & 511)]) - fVec23[((IOTA - 427) & 511)])) + ((0.000640888698f * (((((fVec23[((IOTA - 192) & 511)] + fVec23[((IOTA - 201) & 511)]) - fVec23[((IOTA - 268) & 511)]) + fVec23[((IOTA - 299) & 511)]) - fVec23[((IOTA - 398) & 511)]) - fVec23[((IOTA - 425) & 511)])) + ((0.00186162908f * (((fVec23[((IOTA - 133) & 511)] + fVec23[((IOTA - 206) & 511)]) - fVec23[((IOTA - 407) & 511)]) - fVec23[((IOTA - 419) & 511)])) + ((0.00219733268f * ((fVec23[((IOTA - 45) & 511)] - fVec23[((IOTA - 365) & 511)]) - fVec23[((IOTA - 418) & 511)])) + ((0.0025940733f * ((fVec23[((IOTA - 127) & 511)] + fVec23[((IOTA - 313) & 511)]) - fVec23[((IOTA - 417) & 511)])) + ((0.00286873989f * ((fVec23[((IOTA - 178) & 511)] - fVec23[((IOTA - 358) & 511)]) - fVec23[((IOTA - 416) & 511)])) + ((0.0028992584f * (fVec23[((IOTA - 134) & 511)] - fVec23[((IOTA - 415) & 511)])) + ((0.00271614734f * (fVec23[((IOTA - 179) & 511)] - fVec23[((IOTA - 414) & 511)])) + ((0.0022583697f * ((((fVec23[((IOTA - 155) & 511)] - fVec23[((IOTA - 327) & 511)]) - fVec23[((IOTA - 403) & 511)]) - fVec23[((IOTA - 405) & 511)]) - fVec23[((IOTA - 412) & 511)])) + ((0.00213629566f * ((fVec23[((IOTA - 142) & 511)] - fVec23[((IOTA - 374) & 511)]) - fVec23[((IOTA - 410) & 511)])) + ((0.00201422162f * (((fVec23[((IOTA - 22) & 511)] + fVec23[((IOTA - 150) & 511)]) + fVec23[((IOTA - 212) & 511)]) - fVec23[((IOTA - 406) & 511)])) + ((0.00241096225f * (fVec23[((IOTA - 164) & 511)] - fVec23[((IOTA - 404) & 511)])) + ((0.00134281442f * (((fVec23[((IOTA - 203) & 511)] + fVec23[((IOTA - 233) & 511)]) - fVec23[((IOTA - 367) & 511)]) - fVec23[((IOTA - 400) & 511)])) + ((0.000335703604f * ((((((fVec23[((IOTA - 149) & 511)] + fVec23[((IOTA - 199) & 511)]) - fVec23[((IOTA - 254) & 511)]) - fVec23[((IOTA - 333) & 511)]) + fVec23[((IOTA - 384) & 511)]) - fVec23[((IOTA - 396) & 511)]) - fVec23[((IOTA - 397) & 511)])) + ((0.00207525864f * ((fVec23[((IOTA - 180) & 511)] + fVec23[((IOTA - 215) & 511)]) - fVec23[((IOTA - 388) & 511)])) + ((0.000366222113f * (((((fVec23[((IOTA - 197) & 511)] + fVec23[((IOTA - 244) & 511)]) + fVec23[((IOTA - 247) & 511)]) - fVec23[((IOTA - 248) & 511)]) + fVec23[((IOTA - 337) & 511)]) - fVec23[((IOTA - 381) & 511)])) + ((0.00100711081f * (fVec23[((IOTA - 183) & 511)] - fVec23[((IOTA - 380) & 511)])) + ((0.00299081393f * ((fVec23[((IOTA - 161) & 511)] + fVec23[((IOTA - 171) & 511)]) - fVec23[((IOTA - 378) & 511)])) + ((0.00402844325f * (fVec23[((IOTA - 167) & 511)] - fVec23[((IOTA - 376) & 511)])) + ((0.00274666585f * (fVec23[((IOTA - 162) & 511)] - fVec23[((IOTA - 364) & 511)])) + ((0.003234962f * ((fVec23[((IOTA - 125) & 511)] - fVec23[((IOTA - 294) & 511)]) - fVec23[((IOTA - 363) & 511)])) + ((0.00341807306f * (((((fVec23[((IOTA - 83) & 511)] + fVec23[((IOTA - 110) & 511)]) + fVec23[((IOTA - 157) & 511)]) + fVec23[((IOTA - 175) & 511)]) - fVec23[((IOTA - 326) & 511)]) - fVec23[((IOTA - 361) & 511)])) + ((0.00320444349f * (fVec23[((IOTA - 166) & 511)] - fVec23[((IOTA - 360) & 511)])) + ((0.00302133244f * (fVec23[((IOTA - 153) & 511)] - fVec23[((IOTA - 359) & 511)])) + ((0.00253303628f * (fVec23[((IOTA - 146) & 511)] - fVec23[((IOTA - 357) & 511)])) + ((0.00177007355f * ((fVec23[((IOTA - 217) & 511)] + fVec23[((IOTA - 303) & 511)]) - fVec23[((IOTA - 356) & 511)])) + ((9.15555283e-05f * ((fVec23[((IOTA - 187) & 511)] + fVec23[((IOTA - 287) & 511)]) - fVec23[((IOTA - 353) & 511)])) + ((0.000305185094f * (((fVec23[((IOTA - 190) & 511)] - fVec23[((IOTA - 274) & 511)]) + fVec23[((IOTA - 320) & 511)]) - fVec23[((IOTA - 341) & 511)])) + ((0.000518814661f * fVec23[((IOTA - 338) & 511)]) + ((0.00216681417f * (((fVec23[((IOTA - 213) & 511)] + fVec23[((IOTA - 214) & 511)]) - fVec23[((IOTA - 349) & 511)]) - fVec23[((IOTA - 411) & 511)])) + ((0.00268562883f * ((fVec23[((IOTA - 82) & 511)] + fVec23[((IOTA - 177) & 511)]) - fVec23[((IOTA - 306) & 511)])) + ((0.00448622089f * fVec23[((IOTA - 302) & 511)]) + ((0.00497451704f * fVec23[((IOTA - 301) & 511)]) + ((0.00326548051f * (fVec23[((IOTA - 160) & 511)] + fVec23[((IOTA - 300) & 511)])) + ((0.000183111057f * ((fVec23[((IOTA - 242) & 511)] + fVec23[((IOTA - 288) & 511)]) + fVec23[((IOTA - 289) & 511)])) + ((0.000152592547f * (fVec23[((IOTA - 188) & 511)] + fVec23[((IOTA - 283) & 511)])) + ((0.000671407208f * ((fVec23[((IOTA - 195) & 511)] - fVec23[((IOTA - 265) & 511)]) - fVec23[((IOTA - 277) & 511)])) + ((0.00143436994f * fVec23[((IOTA - 227) & 511)]) + ((0.000274666585f * fVec23[((IOTA - 198) & 511)]) + ((0.00283822138f * fVec23[((IOTA - 176) & 511)]) + ((0.00411999878f * fVec23[((IOTA - 174) & 511)]) + ((0.00418103579f * (fVec23[((IOTA - 81) & 511)] + fVec23[((IOTA - 173) & 511)])) + ((0.00360118411f * fVec23[((IOTA - 172) & 511)]) + ((0.00308236945f * (fVec23[((IOTA - 33) & 511)] + fVec23[((IOTA - 170) & 511)])) + ((0.0042115543f * fVec23[((IOTA - 168) & 511)]) + ((0.00262459181f * fVec23[((IOTA - 165) & 511)]) + ((0.00265511032f * ((fVec23[((IOTA - 135) & 511)] + fVec23[((IOTA - 145) & 511)]) + fVec23[((IOTA - 163) & 511)])) + ((0.00363170262f * (fVec23[((IOTA - 152) & 511)] + fVec23[((IOTA - 159) & 511)])) + ((0.00375377666f * fVec23[((IOTA - 158) & 511)]) + ((0.00280770287f * fVec23[((IOTA - 156) & 511)]) + ((0.00244148076f * fVec23[((IOTA - 154) & 511)]) + ((0.00332651753f * fVec23[((IOTA - 151) & 511)]) + ((0.00445570238f * (fVec23[((IOTA - 107) & 511)] + fVec23[((IOTA - 141) & 511)])) + ((0.00518814661f * fVec23[((IOTA - 140) & 511)]) + ((0.0035401471f * fVec23[((IOTA - 139) & 511)]) + ((0.00357066561f * fVec23[((IOTA - 126) & 511)]) + ((0.00338755455f * fVec23[((IOTA - 122) & 511)]) + ((0.00561540574f * fVec23[((IOTA - 121) & 511)]) + ((0.00643940549f * fVec23[((IOTA - 120) & 511)]) + ((0.00637836847f * fVec23[((IOTA - 119) & 511)]) + ((0.00766014587f * fVec23[((IOTA - 118) & 511)]) + ((0.00979644153f * fVec23[((IOTA - 117) & 511)]) + ((0.0108645894f * fVec23[((IOTA - 116) & 511)]) + ((0.00943021942f * fVec23[((IOTA - 115) & 511)]) + ((0.00747703481f * fVec23[((IOTA - 114) & 511)]) + ((0.00698873866f * fVec23[((IOTA - 113) & 511)]) + ((0.00625629444f * (fVec23[((IOTA - 80) & 511)] + fVec23[((IOTA - 111) & 511)])) + ((0.00732444227f * fVec23[((IOTA - 106) & 511)]) + ((0.0101016266f * fVec23[((IOTA - 105) & 511)]) + ((0.0108340709f * fVec23[((IOTA - 104) & 511)]) + ((0.00933866389f * fVec23[((IOTA - 103) & 511)]) + ((0.00631733146f * fVec23[((IOTA - 102) & 511)]) + ((0.00567644276f * fVec23[((IOTA - 101) & 511)]) + ((0.00845362712f * fVec23[((IOTA - 100) & 511)]) + ((0.0103457747f * fVec23[((IOTA - 99) & 511)]) + ((0.00753807183f * fVec23[((IOTA - 98) & 511)]) + ((0.00491348002f * (fVec23[((IOTA - 36) & 511)] - fVec23[((IOTA - 96) & 511)])) + ((0.00415051728f * fVec23[((IOTA - 89) & 511)]) + ((0.00906399731f * fVec23[((IOTA - 88) & 511)]) + ((0.0111697745f * fVec23[((IOTA - 87) & 511)]) + ((0.0100711081f * fVec23[((IOTA - 86) & 511)]) + ((0.00759910885f * fVec23[((IOTA - 85) & 511)]) + ((0.00457777642f * fVec23[((IOTA - 84) & 511)]) + ((0.0152897732f * fVec23[((IOTA - 78) & 511)]) + ((0.0149540696f * fVec23[((IOTA - 77) & 511)]) + ((0.011383404f * fVec23[((IOTA - 76) & 511)]) + ((0.0093691824f * fVec23[((IOTA - 75) & 511)]) + ((0.00659199804f * fVec23[((IOTA - 73) & 511)]) + ((0.0071108127f * fVec23[((IOTA - 65) & 511)]) + ((0.0190130323f * fVec23[((IOTA - 63) & 511)]) + ((0.0189519953f * fVec23[((IOTA - 62) & 511)]) + ((0.0190435499f * fVec23[((IOTA - 61) & 511)]) + ((0.0241706595f * fVec23[((IOTA - 60) & 511)]) + ((0.0263069551f * fVec23[((IOTA - 59) & 511)]) + ((0.0195013285f * (fVec23[((IOTA - 30) & 511)] + fVec23[((IOTA - 58) & 511)])) + ((0.0143742179f * fVec23[((IOTA - 53) & 511)]) + ((0.0316782147f * fVec23[((IOTA - 52) & 511)]) + ((0.0325632505f * fVec23[((IOTA - 51) & 511)]) + ((0.027680289f * fVec23[((IOTA - 50) & 511)]) + ((0.0224921424f * fVec23[((IOTA - 49) & 511)]) + ((0.0252693258f * fVec23[((IOTA - 48) & 511)]) + ((0.0229194015f * (fVec23[((IOTA - 19) & 511)] + fVec23[((IOTA - 47) & 511)])) + ((0.0168156996f * fVec23[((IOTA - 46) & 511)]) + ((0.00708029419f * fVec23[((IOTA - 35) & 511)]) + ((0.012878811f * fVec23[((IOTA - 32) & 511)]) + ((0.0283822138f * fVec23[((IOTA - 31) & 511)]) + ((0.0617999807f * fVec23[((IOTA - 18) & 511)]) + ((0.0694296062f * fVec23[((IOTA - 17) & 511)]) + ((0.0915860459f * fVec23[((IOTA - 12) & 511)]) + ((0.0910367146f * fVec23[((IOTA - 11) & 511)]) + ((0.127628401f * fVec23[((IOTA - 7) & 511)]) + ((0.256843776f * fVec23[((IOTA - 6) & 511)]) + ((0.127231672f * fVec23[((IOTA - 5) & 511)]) + ((0.0664998293f * fVec23[((IOTA - 24) & 511)]) + ((0.0555742048f * fVec23[((IOTA - 23) & 511)]) + (0.0362254716f * fVec23[((IOTA - 25) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.00137333293f * fVec23[((IOTA - 483) & 511)]) + ((0.00119022187f * (fVec23[((IOTA - 258) & 511)] + fVec23[((IOTA - 475) & 511)])) + ((0.00122074038f * ((fVec23[((IOTA - 329) & 511)] - fVec23[((IOTA - 224) & 511)]) + fVec23[((IOTA - 474) & 511)])) + ((0.00131229591f * fVec23[((IOTA - 462) & 511)]) + ((0.00204474013f * ((fVec23[((IOTA - 308) & 511)] + fVec23[((IOTA - 409) & 511)]) + fVec23[((IOTA - 458) & 511)])) + ((0.0019226661f * (((((((fVec23[((IOTA - 66) & 511)] - fVec23[((IOTA - 207) & 511)]) - fVec23[((IOTA - 210) & 511)]) - fVec23[((IOTA - 216) & 511)]) + fVec23[((IOTA - 351) & 511)]) + fVec23[((IOTA - 379) & 511)]) + fVec23[((IOTA - 408) & 511)]) + fVec23[((IOTA - 446) & 511)])) + ((0.0012817774f * ((fVec23[((IOTA - 344) & 511)] + fVec23[((IOTA - 428) & 511)]) + fVec23[((IOTA - 440) & 511)])) + ((0.000701925717f * (fVec23[((IOTA - 436) & 511)] - (fVec23[((IOTA - 241) & 511)] - fVec23[((IOTA - 426) & 511)]))) + ((0.000732444227f * (((fVec23[((IOTA - 249) & 511)] + fVec23[((IOTA - 256) & 511)]) + fVec23[((IOTA - 291) & 511)]) + fVec23[((IOTA - 435) & 511)])) + ((0.000793481246f * (((fVec23[((IOTA - 332) & 511)] + fVec23[((IOTA - 355) & 511)]) + fVec23[((IOTA - 424) & 511)]) + fVec23[((IOTA - 434) & 511)])) + ((0.00247199927f * (fVec23[((IOTA - 293) & 511)] + fVec23[((IOTA - 413) & 511)])) + ((0.00057985168f * ((((((fVec23[((IOTA - 34) & 511)] - fVec23[((IOTA - 185) & 511)]) - fVec23[((IOTA - 315) & 511)]) - fVec23[((IOTA - 316) & 511)]) + fVec23[((IOTA - 342) & 511)]) + fVec23[((IOTA - 369) & 511)]) + fVec23[((IOTA - 395) & 511)])) + ((0.000610370189f * ((((fVec23[((IOTA - 271) & 511)] + fVec23[((IOTA - 275) & 511)]) + fVec23[((IOTA - 372) & 511)]) - fVec23[((IOTA - 383) & 511)]) + fVec23[((IOTA - 385) & 511)])) + ((0.000244148076f * ((((fVec23[((IOTA - 57) & 511)] - fVec23[((IOTA - 186) & 511)]) - fVec23[((IOTA - 189) & 511)]) + fVec23[((IOTA - 272) & 511)]) - fVec23[((IOTA - 382) & 511)])) + ((0.0038758507f * (fVec23[((IOTA - 37) & 511)] + fVec23[((IOTA - 377) & 511)])) + ((0.00329599902f * ((fVec23[((IOTA - 305) & 511)] + fVec23[((IOTA - 310) & 511)]) + fVec23[((IOTA - 375) & 511)])) + ((0.000396740623f * (fVec23[((IOTA - 371) & 511)] - ((((fVec23[((IOTA - 191) & 511)] - fVec23[((IOTA - 267) & 511)]) - fVec23[((IOTA - 281) & 511)]) + fVec23[((IOTA - 339) & 511)]) - fVec23[((IOTA - 370) & 511)]))) + ((0.00347911008f * fVec23[((IOTA - 362) & 511)]) + ((3.05185094e-05f * ((fVec23[((IOTA - 335) & 511)] - fVec23[((IOTA - 340) & 511)]) + fVec23[((IOTA - 354) & 511)])) + ((0.00234992523f * fVec23[((IOTA - 350) & 511)]) + ((6.10370189e-05f * ((((((fVec23[((IOTA - 137) & 511)] + fVec23[((IOTA - 148) & 511)]) + fVec23[((IOTA - 243) & 511)]) + fVec23[((IOTA - 251) & 511)]) - fVec23[((IOTA - 252) & 511)]) - fVec23[((IOTA - 286) & 511)]) - fVec23[((IOTA - 336) & 511)])) + ((0.000122074038f * ((((((fVec23[((IOTA - 97) & 511)] + fVec23[((IOTA - 253) & 511)]) + fVec23[((IOTA - 273) & 511)]) + fVec23[((IOTA - 282) & 511)]) - fVec23[((IOTA - 285) & 511)]) + fVec23[((IOTA - 290) & 511)]) + fVec23[((IOTA - 334) & 511)])) + ((0.00442518387f * fVec23[((IOTA - 325) & 511)]) + ((0.00473036896f * fVec23[((IOTA - 324) & 511)]) + ((0.00408948027f * fVec23[((IOTA - 323) & 511)]) + ((0.00277718436f * fVec23[((IOTA - 322) & 511)]) + ((0.00344859157f * fVec23[((IOTA - 309) & 511)]) + ((0.00314340647f * fVec23[((IOTA - 297) & 511)]) + ((0.00372325815f * ((fVec23[((IOTA - 71) & 511)] - fVec23[((IOTA - 169) & 511)]) + fVec23[((IOTA - 296) & 511)])) + ((0.00369273964f * fVec23[((IOTA - 295) & 511)]) + ((0.000213629566f * (fVec23[((IOTA - 94) & 511)] - fVec23[((IOTA - 284) & 511)])) + ((0.000488296151f * (((fVec23[((IOTA - 255) & 511)] + fVec23[((IOTA - 261) & 511)]) + fVec23[((IOTA - 279) & 511)]) + fVec23[((IOTA - 280) & 511)])) + ((0.00054933317f * (fVec23[((IOTA - 260) & 511)] + fVec23[((IOTA - 278) & 511)])) + ((0.000457777642f * ((((fVec23[((IOTA - 90) & 511)] - fVec23[((IOTA - 196) & 511)]) - fVec23[((IOTA - 200) & 511)]) + fVec23[((IOTA - 250) & 511)]) + fVec23[((IOTA - 266) & 511)])) + ((0.000823999755f * (((fVec23[((IOTA - 92) & 511)] - fVec23[((IOTA - 184) & 511)]) - fVec23[((IOTA - 193) & 511)]) - fVec23[((IOTA - 194) & 511)])) + ((0.00714133121f * (fVec23[((IOTA - 54) & 511)] - fVec23[((IOTA - 112) & 511)])) + ((0.00433362834f * fVec23[((IOTA - 95) & 511)]) + ((0.00231940672f * fVec23[((IOTA - 91) & 511)]) + ((0.0117496261f * (fVec23[((IOTA - 42) & 511)] - fVec23[((IOTA - 79) & 511)])) + ((0.00848414563f * (fVec23[((IOTA - 68) & 511)] - fVec23[((IOTA - 74) & 511)])) + ((0.00744651631f * fVec23[((IOTA - 70) & 511)]) + ((0.00820947904f * fVec23[((IOTA - 69) & 511)]) + ((0.00665303506f * fVec23[((IOTA - 67) & 511)]) + ((0.0156254768f * (fVec23[((IOTA - 38) & 511)] - fVec23[((IOTA - 64) & 511)])) + ((0.0177922919f * fVec23[((IOTA - 56) & 511)]) + ((0.022644734f * fVec23[((IOTA - 55) & 511)]) + ((0.00653096102f * fVec23[((IOTA - 44) & 511)]) + ((0.0122074038f * fVec23[((IOTA - 43) & 511)]) + ((0.0166020691f * fVec23[((IOTA - 41) & 511)]) + ((0.0214239936f * fVec23[((IOTA - 40) & 511)]) + ((((((0.0216071047f * fVec23[((IOTA - 20) & 511)]) + ((0.0129093295f * (fVec23[((IOTA - 10) & 511)] - fVec23[((IOTA - 16) & 511)])) + ((0.0590533167f * fVec23[((IOTA - 15) & 511)]) + ((0.0744651631f * fVec23[((IOTA - 14) & 511)]) + ((0.0116275521f * fVec23[((IOTA - 13) & 511)]) + ((0.131229594f * fVec23[((IOTA - 9) & 511)]) + ((0.0580767244f * fVec23[((IOTA - 8) & 511)]) + ((0.148472548f * fVec23[((IOTA - 4) & 511)]) + ((0.334055603f * fVec23[((IOTA - 3) & 511)]) + ((0.305276662f * fVec23[((IOTA - 2) & 511)]) + ((0.157872245f * fVec23[((IOTA - 1) & 511)]) + ((fSlow58 * fTemp0) + ((0.0234382153f * fVec23[((IOTA - 21) & 511)]) + (0.0246894751f * fVec23[((IOTA - 26) & 511)])))))))))))))) + (0.0477309488f * fVec23[((IOTA - 27) & 511)])) + (0.0396130271f * fVec23[((IOTA - 28) & 511)])) + (0.00436414685f * fVec23[((IOTA - 29) & 511)])) + (0.0232245866f * fVec23[((IOTA - 39) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00170903653f * (((((((((((fVec23[((IOTA - 298) & 511)] - fVec23[((IOTA - 319) & 511)]) + fVec23[((IOTA - 392) & 511)]) + fVec23[((IOTA - 420) & 511)]) + fVec23[((IOTA - 448) & 511)]) + fVec23[((IOTA - 450) & 511)]) + fVec23[((IOTA - 451) & 511)]) + fVec23[((IOTA - 454) & 511)]) + fVec23[((IOTA - 460) & 511)]) + fVec23[((IOTA - 497) & 511)]) + fVec23[((IOTA - 500) & 511)]) + fVec23[((IOTA - 501) & 511)]))) + (0.00164799951f * (((((fVec23[((IOTA - 489) & 511)] - (((((fVec23[((IOTA - 128) & 511)] - fVec23[((IOTA - 389) & 511)]) - fVec23[((IOTA - 391) & 511)]) - fVec23[((IOTA - 449) & 511)]) - fVec23[((IOTA - 452) & 511)]) - fVec23[((IOTA - 488) & 511)])) + fVec23[((IOTA - 491) & 511)]) + fVec23[((IOTA - 492) & 511)]) + fVec23[((IOTA - 495) & 511)]) + fVec23[((IOTA - 504) & 511)])))) : (((0.000152592547f * ((((((((((fVec22[((IOTA - 330) & 511)] + fVec22[((IOTA - 415) & 511)]) + fVec22[((IOTA - 449) & 511)]) + fVec22[((IOTA - 450) & 511)]) + fVec22[((IOTA - 465) & 511)]) + fVec22[((IOTA - 466) & 511)]) + fVec22[((IOTA - 480) & 511)]) + fVec22[((IOTA - 483) & 511)]) - fVec22[((IOTA - 486) & 511)]) + fVec22[((IOTA - 498) & 511)]) - fVec22[((IOTA - 511) & 511)])) + ((0.000244148076f * ((((((((fVec22[((IOTA - 199) & 511)] - fVec22[((IOTA - 264) & 511)]) + fVec22[((IOTA - 339) & 511)]) - fVec22[((IOTA - 434) & 511)]) + fVec22[((IOTA - 438) & 511)]) + fVec22[((IOTA - 447) & 511)]) + fVec22[((IOTA - 457) & 511)]) - fVec22[((IOTA - 461) & 511)]) + fVec22[((IOTA - 499) & 511)])) + ((3.05185094e-05f * (((((((fVec22[((IOTA - 202) & 511)] + fVec22[((IOTA - 273) & 511)]) + fVec22[((IOTA - 374) & 511)]) - fVec22[((IOTA - 393) & 511)]) - fVec22[((IOTA - 459) & 511)]) + fVec22[((IOTA - 484) & 511)]) - fVec22[((IOTA - 492) & 511)]) + fVec22[((IOTA - 495) & 511)])) + ((0.000183111057f * (((((((((fVec22[((IOTA - 269) & 511)] + fVec22[((IOTA - 375) & 511)]) - fVec22[((IOTA - 428) & 511)]) - fVec22[((IOTA - 436) & 511)]) + fVec22[((IOTA - 448) & 511)]) + fVec22[((IOTA - 451) & 511)]) - fVec22[((IOTA - 460) & 511)]) - fVec22[((IOTA - 462) & 511)]) + fVec22[((IOTA - 481) & 511)]) - fVec22[((IOTA - 489) & 511)])) + ((0.000671407208f * ((((fVec22[((IOTA - 156) & 511)] - fVec22[((IOTA - 194) & 511)]) - fVec22[((IOTA - 398) & 511)]) + fVec22[((IOTA - 441) & 511)]) - fVec22[((IOTA - 474) & 511)])) + ((0.000701925717f * ((fVec22[((IOTA - 250) & 511)] + fVec22[((IOTA - 403) & 511)]) - fVec22[((IOTA - 473) & 511)])) + ((9.15555283e-05f * (((((fVec22[((IOTA - 190) & 511)] + fVec22[((IOTA - 201) & 511)]) + fVec22[((IOTA - 230) & 511)]) - fVec22[((IOTA - 406) & 511)]) - fVec22[((IOTA - 433) & 511)]) + fVec22[((IOTA - 464) & 511)])) + ((0.000488296151f * (((((((fVec22[((IOTA - 108) & 511)] + fVec22[((IOTA - 189) & 511)]) - fVec22[((IOTA - 208) & 511)]) - fVec22[((IOTA - 226) & 511)]) + fVec22[((IOTA - 255) & 511)]) + fVec22[((IOTA - 331) & 511)]) - fVec22[((IOTA - 367) & 511)]) + fVec22[((IOTA - 444) & 511)])) + ((0.000457777642f * ((((fVec22[((IOTA - 198) & 511)] - fVec22[((IOTA - 222) & 511)]) - fVec22[((IOTA - 225) & 511)]) - fVec22[((IOTA - 284) & 511)]) + fVec22[((IOTA - 439) & 511)])) + ((0.00057985168f * ((((((((((fVec22[((IOTA - 197) & 511)] - fVec22[((IOTA - 206) & 511)]) - fVec22[((IOTA - 207) & 511)]) + fVec22[((IOTA - 249) & 511)]) + fVec22[((IOTA - 251) & 511)]) - fVec22[((IOTA - 265) & 511)]) + fVec22[((IOTA - 285) & 511)]) + fVec22[((IOTA - 332) & 511)]) + fVec22[((IOTA - 391) & 511)]) + fVec22[((IOTA - 413) & 511)]) - fVec22[((IOTA - 427) & 511)])) + ((0.000976592302f * (((fVec22[((IOTA - 188) & 511)] + fVec22[((IOTA - 233) & 511)]) + fVec22[((IOTA - 340) & 511)]) - fVec22[((IOTA - 426) & 511)])) + ((0.0012817774f * ((fVec22[((IOTA - 243) & 511)] + fVec22[((IOTA - 305) & 511)]) - fVec22[((IOTA - 425) & 511)])) + ((0.00164799951f * ((fVec22[((IOTA - 157) & 511)] - fVec22[((IOTA - 176) & 511)]) - fVec22[((IOTA - 423) & 511)])) + ((0.00177007355f * ((fVec22[((IOTA - 142) & 511)] - fVec22[((IOTA - 348) & 511)]) - fVec22[((IOTA - 422) & 511)])) + ((0.00106814783f * (fVec22[((IOTA - 234) & 511)] - fVec22[((IOTA - 418) & 511)])) + ((0.000427259132f * ((((fVec22[((IOTA - 271) & 511)] + fVec22[((IOTA - 333) & 511)]) + fVec22[((IOTA - 368) & 511)]) + fVec22[((IOTA - 376) & 511)]) + fVec22[((IOTA - 414) & 511)])) + ((0.000915555283f * fVec22[((IOTA - 390) & 511)]) + ((0.00119022187f * (((fVec22[((IOTA - 237) & 511)] - fVec22[((IOTA - 276) & 511)]) - fVec22[((IOTA - 351) & 511)]) + fVec22[((IOTA - 389) & 511)])) + ((0.000762962736f * ((((fVec22[((IOTA - 136) & 511)] - fVec22[((IOTA - 174) & 511)]) + fVec22[((IOTA - 256) & 511)]) - fVec22[((IOTA - 266) & 511)]) + fVec22[((IOTA - 387) & 511)])) + ((0.00100711081f * (((fVec22[((IOTA - 116) & 511)] - fVec22[((IOTA - 155) & 511)]) + fVec22[((IOTA - 173) & 511)]) - fVec22[((IOTA - 385) & 511)])) + ((0.00268562883f * ((fVec22[((IOTA - 71) & 511)] + fVec22[((IOTA - 287) & 511)]) - fVec22[((IOTA - 380) & 511)])) + ((0.00134281442f * fVec22[((IOTA - 371) & 511)]) + ((0.00112918485f * (fVec22[((IOTA - 236) & 511)] + fVec22[((IOTA - 369) & 511)])) + ((0.00222785119f * (fVec22[((IOTA - 185) & 511)] - fVec22[((IOTA - 365) & 511)])) + ((0.00256355479f * ((fVec22[((IOTA - 183) & 511)] + fVec22[((IOTA - 184) & 511)]) - fVec22[((IOTA - 364) & 511)])) + ((0.00131229591f * (fVec22[((IOTA - 170) & 511)] - fVec22[((IOTA - 362) & 511)])) + ((0.00158696249f * (fVec22[((IOTA - 321) & 511)] + fVec22[((IOTA - 360) & 511)])) + ((0.00302133244f * fVec22[((IOTA - 359) & 511)]) + ((0.004852443f * (fVec22[((IOTA - 43) & 511)] + fVec22[((IOTA - 357) & 511)])) + ((0.00497451704f * fVec22[((IOTA - 356) & 511)]) + ((0.00445570238f * fVec22[((IOTA - 355) & 511)]) + ((0.00170903653f * ((((fVec22[((IOTA - 158) & 511)] - fVec22[((IOTA - 175) & 511)]) + fVec22[((IOTA - 286) & 511)]) + fVec22[((IOTA - 341) & 511)]) + fVec22[((IOTA - 353) & 511)])) + ((0.00250251777f * fVec22[((IOTA - 343) & 511)]) + ((0.00228888821f * fVec22[((IOTA - 342) & 511)]) + ((0.000823999755f * ((((fVec22[((IOTA - 53) & 511)] - fVec22[((IOTA - 217) & 511)]) + fVec22[((IOTA - 258) & 511)]) + fVec22[((IOTA - 372) & 511)]) - fVec22[((IOTA - 396) & 511)])) + ((0.00396740623f * (fVec22[((IOTA - 64) & 511)] - fVec22[((IOTA - 325) & 511)])) + ((0.000793481246f * (fVec22[((IOTA - 239) & 511)] - fVec22[((IOTA - 322) & 511)])) + ((0.0067751091f * fVec22[((IOTA - 319) & 511)]) + ((0.00885036774f * fVec22[((IOTA - 317) & 511)]) + ((0.00756859034f * fVec22[((IOTA - 316) & 511)]) + ((0.00494399853f * fVec22[((IOTA - 315) & 511)]) + ((0.00167851802f * (fVec22[((IOTA - 181) & 511)] + fVec22[((IOTA - 314) & 511)])) + ((0.00448622089f * fVec22[((IOTA - 304) & 511)]) + ((0.00698873866f * fVec22[((IOTA - 303) & 511)]) + ((0.00735496078f * (fVec22[((IOTA - 89) & 511)] + fVec22[((IOTA - 301) & 511)])) + ((0.00546281319f * fVec22[((IOTA - 300) & 511)]) + ((0.00283822138f * fVec22[((IOTA - 299) & 511)]) + ((0.00311288796f * fVec22[((IOTA - 290) & 511)]) + ((0.0035401471f * fVec22[((IOTA - 289) & 511)]) + ((0.00335703604f * fVec22[((IOTA - 288) & 511)]) + ((0.00189214759f * (((fVec22[((IOTA - 107) & 511)] + fVec22[((IOTA - 128) & 511)]) - fVec22[((IOTA - 278) & 511)]) - fVec22[((IOTA - 280) & 511)])) + ((0.000732444227f * (fVec22[((IOTA - 232) & 511)] - fVec22[((IOTA - 275) & 511)])) + ((0.000946073793f * (((fVec22[((IOTA - 149) & 511)] + fVec22[((IOTA - 180) & 511)]) - fVec22[((IOTA - 216) & 511)]) + fVec22[((IOTA - 242) & 511)])) + ((0.00109866634f * (((fVec22[((IOTA - 159) & 511)] - fVec22[((IOTA - 161) & 511)]) + fVec22[((IOTA - 235) & 511)]) + fVec22[((IOTA - 238) & 511)])) + ((0.00180059206f * fVec22[((IOTA - 186) & 511)]) + ((0.00238044374f * fVec22[((IOTA - 172) & 511)]) + ((0.00247199927f * fVec22[((IOTA - 171) & 511)]) + ((0.00305185094f * (((fVec22[((IOTA - 105) & 511)] + fVec22[((IOTA - 148) & 511)]) - fVec22[((IOTA - 164) & 511)]) - fVec22[((IOTA - 165) & 511)])) + ((0.00491348002f * fVec22[((IOTA - 147) & 511)]) + ((0.00656147953f * fVec22[((IOTA - 146) & 511)]) + ((0.00759910885f * fVec22[((IOTA - 145) & 511)]) + ((0.00732444227f * fVec22[((IOTA - 144) & 511)]) + ((0.00531022064f * fVec22[((IOTA - 143) & 511)]) + ((0.00430310983f * (fVec22[((IOTA - 121) & 511)] - fVec22[((IOTA - 138) & 511)])) + ((0.00299081393f * fVec22[((IOTA - 135) & 511)]) + ((0.00476088747f * fVec22[((IOTA - 134) & 511)]) + ((0.00592059083f * fVec22[((IOTA - 133) & 511)]) + ((0.006469924f * fVec22[((IOTA - 131) & 511)]) + ((0.00573747978f * fVec22[((IOTA - 130) & 511)]) + ((0.00408948027f * (fVec22[((IOTA - 104) & 511)] + fVec22[((IOTA - 129) & 511)])) + ((0.00125125889f * fVec22[((IOTA - 122) & 511)]) + ((0.00927762687f * fVec22[((IOTA - 119) & 511)]) + ((0.00537125766f * fVec22[((IOTA - 117) & 511)]) + ((0.00799584948f * fVec22[((IOTA - 302) & 511)]) + ((0.00244148076f * fVec22[((IOTA - 106) & 511)]) + ((0.00350962859f * fVec22[((IOTA - 103) & 511)]) + ((0.0126651814f * fVec22[((IOTA - 95) & 511)]) + ((0.0216681417f * fVec22[((IOTA - 94) & 511)]) + ((0.0272225104f * fVec22[((IOTA - 93) & 511)]) + ((0.0296639912f * fVec22[((IOTA - 92) & 511)]) + ((0.0285958443f * fVec22[((IOTA - 91) & 511)]) + ((0.0219733268f * fVec22[((IOTA - 90) & 511)]) + ((0.00460829493f * fVec22[((IOTA - 83) & 511)]) + ((0.0115970336f * fVec22[((IOTA - 82) & 511)]) + ((0.0139164403f * fVec22[((IOTA - 81) & 511)]) + ((0.013000885f * fVec22[((IOTA - 80) & 511)]) + ((0.00930814538f * fVec22[((IOTA - 79) & 511)]) + ((0.00402844325f * fVec22[((IOTA - 78) & 511)]) + ((0.0140079958f * fVec22[((IOTA - 70) & 511)]) + ((0.0242927335f * fVec22[((IOTA - 69) & 511)]) + ((0.0318613239f * fVec22[((IOTA - 68) & 511)]) + ((0.0351268053f * fVec22[((IOTA - 67) & 511)]) + ((0.0315561406f * fVec22[((IOTA - 66) & 511)]) + ((0.0205084383f * fVec22[((IOTA - 65) & 511)]) + ((0.0188299213f * fVec22[((IOTA - 57) & 511)]) + ((0.0307321399f * fVec22[((IOTA - 56) & 511)]) + ((0.029053621f * fVec22[((IOTA - 55) & 511)]) + (((((((((((0.0229194015f * fVec22[((IOTA - 15) & 511)]) + ((0.0491348021f * fVec22[((IOTA - 14) & 511)]) + ((0.053132724f * fVec22[((IOTA - 13) & 511)]) + ((0.032898955f * fVec22[((IOTA - 12) & 511)]) + ((0.0541093163f * fVec22[((IOTA - 5) & 511)]) + ((0.23239845f * fVec22[((IOTA - 4) & 511)]) + ((0.298867762f * fVec22[((IOTA - 3) & 511)]) + ((0.2342906f * fVec22[((IOTA - 2) & 511)]) + ((0.118961148f * fVec22[((IOTA - 1) & 511)]) + ((fSlow56 * fTemp0) + (((0.0234382153f * fVec22[((IOTA - 26) & 511)]) + (0.0499893203f * fVec22[((IOTA - 27) & 511)])) + (0.0632343516f * fVec22[((IOTA - 28) & 511)])))))))))))) + (0.0563371703f * fVec22[((IOTA - 29) & 511)])) + (0.0267036967f * fVec22[((IOTA - 30) & 511)])) + (0.0222174749f * fVec22[((IOTA - 37) & 511)])) + (0.0440992452f * fVec22[((IOTA - 38) & 511)])) + (0.0523392446f * fVec22[((IOTA - 39) & 511)])) + (0.0467848741f * fVec22[((IOTA - 40) & 511)])) + (0.0335703604f * fVec22[((IOTA - 41) & 511)])) + (0.0196539201f * fVec22[((IOTA - 42) & 511)])) + (0.0168156996f * fVec22[((IOTA - 54) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000122074038f * ((((((((((((((fVec22[((IOTA - 195) & 511)] - fVec22[((IOTA - 200) & 511)]) + fVec22[((IOTA - 203) & 511)]) + fVec22[((IOTA - 229) & 511)]) - fVec22[((IOTA - 262) & 511)]) - fVec22[((IOTA - 334) & 511)]) - fVec22[((IOTA - 352) & 511)]) + fVec22[((IOTA - 409) & 511)]) - fVec22[((IOTA - 410) & 511)]) - fVec22[((IOTA - 429) & 511)]) - fVec22[((IOTA - 432) & 511)]) - fVec22[((IOTA - 458) & 511)]) + fVec22[((IOTA - 490) & 511)]) - fVec22[((IOTA - 497) & 511)]) - fVec22[((IOTA - 508) & 511)])) + ((0.000213629566f * (((((((((((((((fVec22[((IOTA - 169) & 511)] - fVec22[((IOTA - 179) & 511)]) + fVec22[((IOTA - 209) & 511)]) - fVec22[((IOTA - 247) & 511)]) - fVec22[((IOTA - 253) & 511)]) - fVec22[((IOTA - 261) & 511)]) + fVec22[((IOTA - 268) & 511)]) - fVec22[((IOTA - 405) & 511)]) + fVec22[((IOTA - 416) & 511)]) - fVec22[((IOTA - 452) & 511)]) + fVec22[((IOTA - 469) & 511)]) + fVec22[((IOTA - 477) & 511)]) - fVec22[((IOTA - 482) & 511)]) + fVec22[((IOTA - 487) & 511)]) + fVec22[((IOTA - 488) & 511)]) - fVec22[((IOTA - 507) & 511)])) + ((0.000274666585f * (((((fVec22[((IOTA - 191) & 511)] - fVec22[((IOTA - 254) & 511)]) - fVec22[((IOTA - 373) & 511)]) - fVec22[((IOTA - 392) & 511)]) - fVec22[((IOTA - 431) & 511)]) - fVec22[((IOTA - 506) & 511)])) + ((0.000305185094f * ((((((((((((((((((fVec22[((IOTA - 213) & 511)] + fVec22[((IOTA - 228) & 511)]) - fVec22[((IOTA - 248) & 511)]) - fVec22[((IOTA - 272) & 511)]) + fVec22[((IOTA - 274) & 511)]) + fVec22[((IOTA - 298) & 511)]) + fVec22[((IOTA - 335) & 511)]) - fVec22[((IOTA - 346) & 511)]) + fVec22[((IOTA - 394) & 511)]) + fVec22[((IOTA - 407) & 511)]) + fVec22[((IOTA - 408) & 511)]) - fVec22[((IOTA - 430) & 511)]) + fVec22[((IOTA - 435) & 511)]) - fVec22[((IOTA - 453) & 511)]) - fVec22[((IOTA - 500) & 511)]) - fVec22[((IOTA - 501) & 511)]) - fVec22[((IOTA - 503) & 511)]) - fVec22[((IOTA - 504) & 511)]) - fVec22[((IOTA - 505) & 511)])) + ((0.000335703604f * (((((fVec22[((IOTA - 338) & 511)] - fVec22[((IOTA - 377) & 511)]) - fVec22[((IOTA - 446) & 511)]) - fVec22[((IOTA - 454) & 511)]) - fVec22[((IOTA - 456) & 511)]) - fVec22[((IOTA - 502) & 511)])) + ((0.000396740623f * (((((((((((((fVec22[((IOTA - 102) & 511)] + fVec22[((IOTA - 178) & 511)]) - fVec22[((IOTA - 196) & 511)]) + fVec22[((IOTA - 223) & 511)]) + fVec22[((IOTA - 224) & 511)]) + fVec22[((IOTA - 227) & 511)]) - fVec22[((IOTA - 231) & 511)]) - fVec22[((IOTA - 260) & 511)]) - fVec22[((IOTA - 270) & 511)]) + fVec22[((IOTA - 292) & 511)]) + fVec22[((IOTA - 378) & 511)]) - fVec22[((IOTA - 445) & 511)]) - fVec22[((IOTA - 455) & 511)]) + fVec22[((IOTA - 476) & 511)])) + ((0.00054933317f * ((((((fVec22[((IOTA - 219) & 511)] + fVec22[((IOTA - 220) & 511)]) - fVec22[((IOTA - 240) & 511)]) - fVec22[((IOTA - 404) & 511)]) - fVec22[((IOTA - 412) & 511)]) - fVec22[((IOTA - 443) & 511)]) + fVec22[((IOTA - 475) & 511)])) + ((0.000640888698f * (((((fVec22[((IOTA - 192) & 511)] + fVec22[((IOTA - 337) & 511)]) - fVec22[((IOTA - 402) & 511)]) - fVec22[((IOTA - 440) & 511)]) - fVec22[((IOTA - 442) & 511)]) + fVec22[((IOTA - 472) & 511)])) + ((0.000518814661f * (((((fVec22[((IOTA - 123) & 511)] + fVec22[((IOTA - 205) & 511)]) + fVec22[((IOTA - 221) & 511)]) - fVec22[((IOTA - 246) & 511)]) + fVec22[((IOTA - 329) & 511)]) + fVec22[((IOTA - 471) & 511)])) + ((0.000366222113f * (((((fVec22[((IOTA - 204) & 511)] - fVec22[((IOTA - 252) & 511)]) + fVec22[((IOTA - 399) & 511)]) - fVec22[((IOTA - 401) & 511)]) - fVec22[((IOTA - 411) & 511)]) + fVec22[((IOTA - 470) & 511)])) + ((0.00152592547f * (fVec22[((IOTA - 313) & 511)] + fVec22[((IOTA - 424) & 511)])) + ((0.00183111057f * (((fVec22[((IOTA - 137) & 511)] + fVec22[((IOTA - 281) & 511)]) - fVec22[((IOTA - 291) & 511)]) + fVec22[((IOTA - 421) & 511)])) + ((0.00173955504f * (fVec22[((IOTA - 109) & 511)] + fVec22[((IOTA - 420) & 511)])) + ((0.00149540696f * (fVec22[((IOTA - 328) & 511)] + fVec22[((IOTA - 419) & 511)])) + ((0.000610370189f * (((((((fVec22[((IOTA - 214) & 511)] + fVec22[((IOTA - 218) & 511)]) - fVec22[((IOTA - 241) & 511)]) - fVec22[((IOTA - 259) & 511)]) + fVec22[((IOTA - 267) & 511)]) + fVec22[((IOTA - 336) & 511)]) + fVec22[((IOTA - 395) & 511)]) + fVec22[((IOTA - 417) & 511)])) + ((0.000854518265f * (fVec22[((IOTA - 193) & 511)] + fVec22[((IOTA - 397) & 511)])) + ((0.00122074038f * ((fVec22[((IOTA - 124) & 511)] + fVec22[((IOTA - 283) & 511)]) - fVec22[((IOTA - 388) & 511)])) + ((0.0019531846f * (((fVec22[((IOTA - 58) & 511)] - fVec22[((IOTA - 96) & 511)]) + fVec22[((IOTA - 279) & 511)]) + fVec22[((IOTA - 384) & 511)])) + ((0.00274666585f * (fVec22[((IOTA - 163) & 511)] + fVec22[((IOTA - 383) & 511)])) + ((0.00329599902f * (fVec22[((IOTA - 382) & 511)] - fVec22[((IOTA - 354) & 511)])) + ((0.00155644398f * fVec22[((IOTA - 379) & 511)]) + ((0.00146488845f * (((fVec22[((IOTA - 168) & 511)] - fVec22[((IOTA - 345) & 511)]) + fVec22[((IOTA - 366) & 511)]) - fVec22[((IOTA - 370) & 511)])) + ((0.0022583697f * (((fVec22[((IOTA - 167) & 511)] - fVec22[((IOTA - 182) & 511)]) - fVec22[((IOTA - 344) & 511)]) + fVec22[((IOTA - 363) & 511)])) + ((0.00415051728f * (fVec22[((IOTA - 312) & 511)] - fVec22[((IOTA - 358) & 511)])) + ((0.00198370311f * fVec22[((IOTA - 350) & 511)]) + ((0.00216681417f * fVec22[((IOTA - 349) & 511)]) + ((0.00332651753f * fVec22[((IOTA - 381) & 511)]) + ((0.00262459181f * fVec22[((IOTA - 327) & 511)]) + ((0.00357066561f * fVec22[((IOTA - 326) & 511)]) + ((0.00366222113f * fVec22[((IOTA - 324) & 511)]) + ((0.0025940733f * fVec22[((IOTA - 323) & 511)]) + ((0.00427259132f * (fVec22[((IOTA - 307) & 511)] - fVec22[((IOTA - 320) & 511)])) + ((0.00848414563f * (((fVec22[((IOTA - 76) & 511)] + fVec22[((IOTA - 84) & 511)]) - fVec22[((IOTA - 118) & 511)]) - fVec22[((IOTA - 318) & 511)])) + ((0.00595110934f * fVec22[((IOTA - 311) & 511)]) + ((0.00674459059f * fVec22[((IOTA - 310) & 511)]) + ((0.00665303506f * fVec22[((IOTA - 309) & 511)]) + ((0.0058290353f * fVec22[((IOTA - 308) & 511)]) + ((0.00186162908f * fVec22[((IOTA - 306) & 511)]) + ((0.00363170262f * fVec22[((IOTA - 297) & 511)]) + ((0.00622577593f * fVec22[((IOTA - 296) & 511)]) + ((0.00708029419f * fVec22[((IOTA - 295) & 511)]) + ((0.00585955381f * fVec22[((IOTA - 294) & 511)]) + ((0.003234962f * fVec22[((IOTA - 293) & 511)]) + ((0.001617481f * (fVec22[((IOTA - 277) & 511)] + fVec22[((IOTA - 282) & 511)])) + ((0.00103762932f * (fVec22[((IOTA - 177) & 511)] - fVec22[((IOTA - 245) & 511)])) + ((0.00137333293f * ((fVec22[((IOTA - 150) & 511)] - fVec22[((IOTA - 187) & 511)]) - fVec22[((IOTA - 244) & 511)])) + ((0.000885036774f * ((fVec22[((IOTA - 215) & 511)] - fVec22[((IOTA - 257) & 511)]) + fVec22[((IOTA - 347) & 511)])) + ((0.00277718436f * fVec22[((IOTA - 166) & 511)]) + ((0.00210577715f * (fVec22[((IOTA - 77) & 511)] + fVec22[((IOTA - 162) & 511)])) + ((0.00280770287f * fVec22[((IOTA - 154) & 511)]) + ((0.00405896176f * fVec22[((IOTA - 153) & 511)]) + ((0.00436414685f * fVec22[((IOTA - 152) & 511)]) + ((0.00338755455f * (fVec22[((IOTA - 25) & 511)] + fVec22[((IOTA - 151) & 511)])) + ((0.00219733268f * fVec22[((IOTA - 141) & 511)]) + ((0.00503555406f * (fVec22[((IOTA - 110) & 511)] + fVec22[((IOTA - 140) & 511)])) + ((0.00567644276f * fVec22[((IOTA - 139) & 511)]) + ((0.00650044251f * (fVec22[((IOTA - 101) & 511)] - fVec22[((IOTA - 132) & 511)])) + ((0.00115970336f * fVec22[((IOTA - 126) & 511)]) + ((0.00143436994f * fVec22[((IOTA - 125) & 511)]) + ((0.00753807183f * (fVec22[((IOTA - 97) & 511)] - fVec22[((IOTA - 120) & 511)])) + ((0.00399792474f * fVec22[((IOTA - 115) & 511)]) + ((0.00888088625f * fVec22[((IOTA - 114) & 511)]) + ((0.0120853297f * (fVec22[((IOTA - 112) & 511)] + fVec22[((IOTA - 113) & 511)])) + ((0.0090334788f * fVec22[((IOTA - 111) & 511)]) + ((0.0118411817f * fVec22[((IOTA - 100) & 511)]) + ((0.0133365886f * fVec22[((IOTA - 88) & 511)]) + ((0.030854214f * fVec22[((IOTA - 87) & 511)]) + ((0.0353099145f * fVec22[((IOTA - 86) & 511)]) + ((0.0248725861f * fVec22[((IOTA - 85) & 511)]) + ((0.0131534776f * fVec22[((IOTA - 98) & 511)]) + ((0.0143742179f * fVec22[((IOTA - 99) & 511)]) + ((0.0139774773f * fVec22[((IOTA - 75) & 511)]) + ((0.0164799951f * fVec22[((IOTA - 74) & 511)]) + ((0.0145268105f * fVec22[((IOTA - 73) & 511)]) + ((0.0077517014f * fVec22[((IOTA - 72) & 511)]) + ((0.0146488845f * fVec22[((IOTA - 63) & 511)]) + ((0.0306100659f * fVec22[((IOTA - 62) & 511)]) + ((0.039124731f * fVec22[((IOTA - 61) & 511)]) + ((0.0364391021f * fVec22[((IOTA - 60) & 511)]) + ((0.0229804385f * fVec22[((IOTA - 59) & 511)]) + ((0.0130924406f * fVec22[((IOTA - 52) & 511)]) + ((0.0219428092f * fVec22[((IOTA - 51) & 511)]) + ((0.0282906592f * fVec22[((IOTA - 50) & 511)]) + ((0.0347911008f * fVec22[((IOTA - 49) & 511)]) + ((0.0410473943f * fVec22[((IOTA - 48) & 511)]) + ((0.0423902087f * fVec22[((IOTA - 47) & 511)]) + ((0.0370494723f * fVec22[((IOTA - 46) & 511)]) + ((0.0256050304f * fVec22[((IOTA - 45) & 511)]) + ((0.0105594043f * fVec22[((IOTA - 44) & 511)]) + ((0.00610370189f * fVec22[((IOTA - 36) & 511)]) + ((0.0316782147f * fVec22[((IOTA - 35) & 511)]) + ((0.0479445793f * fVec22[((IOTA - 34) & 511)]) + ((0.0525223538f * fVec22[((IOTA - 33) & 511)]) + ((0.0420850255f * fVec22[((IOTA - 32) & 511)]) + (((0.0649128705f * fVec22[((IOTA - 21) & 511)]) + ((0.0862147883f * fVec22[((IOTA - 20) & 511)]) + ((0.0952482671f * fVec22[((IOTA - 19) & 511)]) + ((0.0852076784f * fVec22[((IOTA - 18) & 511)]) + ((0.0571001321f * fVec22[((IOTA - 17) & 511)]) + ((0.0169072542f * fVec22[((IOTA - 16) & 511)]) + ((0.00695822015f * fVec22[((IOTA - 11) & 511)]) + ((0.065523237f * fVec22[((IOTA - 10) & 511)]) + ((0.136051521f * fVec22[((IOTA - 9) & 511)]) + ((0.199591056f * fVec22[((IOTA - 8) & 511)]) + ((0.211066008f * fVec22[((IOTA - 7) & 511)]) + ((0.125217438f * fVec22[((IOTA - 6) & 511)]) + (((0.0411389507f * fVec22[((IOTA - 22) & 511)]) + (0.0269783624f * fVec22[((IOTA - 23) & 511)])) + (0.0185857732f * fVec22[((IOTA - 24) & 511)])))))))))))))) + (0.0124515519f * fVec22[((IOTA - 31) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (6.10370189e-05f * ((((((((((((((fVec22[((IOTA - 127) & 511)] - fVec22[((IOTA - 160) & 511)]) - fVec22[((IOTA - 211) & 511)]) + fVec22[((IOTA - 212) & 511)]) - fVec22[((IOTA - 361) & 511)]) + fVec22[((IOTA - 386) & 511)]) + fVec22[((IOTA - 463) & 511)]) - fVec22[((IOTA - 467) & 511)]) + fVec22[((IOTA - 468) & 511)]) + fVec22[((IOTA - 478) & 511)]) - fVec22[((IOTA - 479) & 511)]) + fVec22[((IOTA - 485) & 511)]) + fVec22[((IOTA - 491) & 511)]) - fVec22[((IOTA - 496) & 511)]) + fVec22[((IOTA - 510) & 511)]))))) : (iSlow50 ? (((0.000366222113f * ((((fVec21[((IOTA - 302) & 511)] + fVec21[((IOTA - 424) & 511)]) + fVec21[((IOTA - 473) & 511)]) + fVec21[((IOTA - 480) & 511)]) + fVec21[((IOTA - 511) & 511)])) + ((0.000244148076f * ((((((((((fVec21[((IOTA - 262) & 511)] + fVec21[((IOTA - 332) & 511)]) + fVec21[((IOTA - 333) & 511)]) + fVec21[((IOTA - 334) & 511)]) + fVec21[((IOTA - 341) & 511)]) - fVec21[((IOTA - 406) & 511)]) + fVec21[((IOTA - 460) & 511)]) + fVec21[((IOTA - 467) & 511)]) + fVec21[((IOTA - 472) & 511)]) + fVec21[((IOTA - 479) & 511)]) + fVec21[((IOTA - 510) & 511)])) + ((0.000457777642f * (((((((((fVec21[((IOTA - 208) & 511)] - fVec21[((IOTA - 234) & 511)]) + fVec21[((IOTA - 249) & 511)]) - fVec21[((IOTA - 355) & 511)]) - fVec21[((IOTA - 411) & 511)]) + fVec21[((IOTA - 441) & 511)]) + fVec21[((IOTA - 487) & 511)]) + fVec21[((IOTA - 489) & 511)]) + fVec21[((IOTA - 499) & 511)]) + fVec21[((IOTA - 506) & 511)])) + ((0.000518814661f * (((((((((((((fVec21[((IOTA - 203) & 511)] - fVec21[((IOTA - 214) & 511)]) - fVec21[((IOTA - 217) & 511)]) + fVec21[((IOTA - 233) & 511)]) - fVec21[((IOTA - 279) & 511)]) + fVec21[((IOTA - 281) & 511)]) + fVec21[((IOTA - 290) & 511)]) - fVec21[((IOTA - 359) & 511)]) + fVec21[((IOTA - 444) & 511)]) + fVec21[((IOTA - 457) & 511)]) + fVec21[((IOTA - 481) & 511)]) + fVec21[((IOTA - 498) & 511)]) + fVec21[((IOTA - 504) & 511)]) + fVec21[((IOTA - 505) & 511)])) + ((0.00054933317f * ((((((((fVec21[((IOTA - 143) & 511)] - fVec21[((IOTA - 273) & 511)]) - fVec21[((IOTA - 307) & 511)]) - fVec21[((IOTA - 316) & 511)]) + fVec21[((IOTA - 320) & 511)]) - fVec21[((IOTA - 370) & 511)]) + fVec21[((IOTA - 486) & 511)]) + fVec21[((IOTA - 501) & 511)]) + fVec21[((IOTA - 503) & 511)])) + ((0.000610370189f * (((((((fVec21[((IOTA - 193) & 511)] + fVec21[((IOTA - 239) & 511)]) + fVec21[((IOTA - 270) & 511)]) - fVec21[((IOTA - 284) & 511)]) - fVec21[((IOTA - 360) & 511)]) + fVec21[((IOTA - 443) & 511)]) + fVec21[((IOTA - 463) & 511)]) + fVec21[((IOTA - 497) & 511)])) + ((0.000793481246f * (((((((fVec21[((IOTA - 188) & 511)] - fVec21[((IOTA - 248) & 511)]) - fVec21[((IOTA - 264) & 511)]) - fVec21[((IOTA - 285) & 511)]) - fVec21[((IOTA - 300) & 511)]) + fVec21[((IOTA - 455) & 511)]) + fVec21[((IOTA - 492) & 511)]) + fVec21[((IOTA - 494) & 511)])) + ((0.000427259132f * (((((fVec21[((IOTA - 394) & 511)] - ((fVec21[((IOTA - 238) & 511)] - fVec21[((IOTA - 306) & 511)]) - fVec21[((IOTA - 373) & 511)])) - fVec21[((IOTA - 395) & 511)]) + fVec21[((IOTA - 423) & 511)]) + fVec21[((IOTA - 475) & 511)]) + fVec21[((IOTA - 488) & 511)])) + ((0.000213629566f * ((((fVec21[((IOTA - 259) & 511)] - fVec21[((IOTA - 318) & 511)]) - fVec21[((IOTA - 400) & 511)]) + fVec21[((IOTA - 425) & 511)]) + fVec21[((IOTA - 477) & 511)])) + ((0.000335703604f * (((((((((fVec21[((IOTA - 272) & 511)] + fVec21[((IOTA - 282) & 511)]) + fVec21[((IOTA - 342) & 511)]) - fVec21[((IOTA - 349) & 511)]) + fVec21[((IOTA - 350) & 511)]) + fVec21[((IOTA - 372) & 511)]) + fVec21[((IOTA - 422) & 511)]) + fVec21[((IOTA - 452) & 511)]) + fVec21[((IOTA - 461) & 511)]) + fVec21[((IOTA - 476) & 511)])) + ((6.10370189e-05f * ((((((fVec21[((IOTA - 385) & 511)] + fVec21[((IOTA - 386) & 511)]) + fVec21[((IOTA - 391) & 511)]) + fVec21[((IOTA - 433) & 511)]) + fVec21[((IOTA - 438) & 511)]) + fVec21[((IOTA - 468) & 511)]) + fVec21[((IOTA - 470) & 511)])) + ((3.05185094e-05f * (((((((((((fVec21[((IOTA - 243) & 511)] - fVec21[((IOTA - 263) & 511)]) - fVec21[((IOTA - 269) & 511)]) - fVec21[((IOTA - 319) & 511)]) + fVec21[((IOTA - 331) & 511)]) - fVec21[((IOTA - 354) & 511)]) + fVec21[((IOTA - 371) & 511)]) + fVec21[((IOTA - 434) & 511)]) + fVec21[((IOTA - 435) & 511)]) + fVec21[((IOTA - 436) & 511)]) + fVec21[((IOTA - 437) & 511)]) + fVec21[((IOTA - 469) & 511)])) + ((0.000122074038f * (((((((fVec21[((IOTA - 163) & 511)] - fVec21[((IOTA - 253) & 511)]) + fVec21[((IOTA - 260) & 511)]) + fVec21[((IOTA - 280) & 511)]) + fVec21[((IOTA - 405) & 511)]) + fVec21[((IOTA - 421) & 511)]) + fVec21[((IOTA - 447) & 511)]) - fVec21[((IOTA - 450) & 511)])) + ((0.000396740623f * (((fVec21[((IOTA - 289) & 511)] + fVec21[((IOTA - 353) & 511)]) + fVec21[((IOTA - 387) & 511)]) + fVec21[((IOTA - 445) & 511)])) + ((0.00119022187f * fVec21[((IOTA - 402) & 511)]) + ((0.00222785119f * ((fVec21[((IOTA - 88) & 511)] + fVec21[((IOTA - 102) & 511)]) - fVec21[((IOTA - 398) & 511)])) + ((0.00234992523f * (fVec21[((IOTA - 209) & 511)] - fVec21[((IOTA - 397) & 511)])) + ((0.00207525864f * (fVec21[((IOTA - 322) & 511)] - fVec21[((IOTA - 381) & 511)])) + ((0.00201422162f * ((fVec21[((IOTA - 222) & 511)] - fVec21[((IOTA - 310) & 511)]) - fVec21[((IOTA - 365) & 511)])) + ((0.00213629566f * ((fVec21[((IOTA - 231) & 511)] - fVec21[((IOTA - 297) & 511)]) - fVec21[((IOTA - 346) & 511)])) + ((0.00103762932f * ((((fVec21[((IOTA - 66) & 511)] + fVec21[((IOTA - 152) & 511)]) + fVec21[((IOTA - 218) & 511)]) - fVec21[((IOTA - 313) & 511)]) - fVec21[((IOTA - 344) & 511)])) + ((0.000976592302f * (fVec21[((IOTA - 303) & 511)] - fVec21[((IOTA - 338) & 511)])) + ((0.000762962736f * (((((fVec21[((IOTA - 57) & 511)] + fVec21[((IOTA - 198) & 511)]) + fVec21[((IOTA - 229) & 511)]) - fVec21[((IOTA - 268) & 511)]) - fVec21[((IOTA - 278) & 511)]) - fVec21[((IOTA - 330) & 511)])) + ((0.00238044374f * (fVec21[((IOTA - 221) & 511)] - fVec21[((IOTA - 329) & 511)])) + ((0.00405896176f * (fVec21[((IOTA - 98) & 511)] - fVec21[((IOTA - 328) & 511)])) + ((0.00479140598f * (fVec21[((IOTA - 118) & 511)] - fVec21[((IOTA - 327) & 511)])) + (((0.0038758507f * (fVec21[((IOTA - 172) & 511)] - fVec21[((IOTA - 326) & 511)])) + ((0.00170903653f * ((fVec21[((IOTA - 46) & 511)] - fVec21[((IOTA - 255) & 511)]) - fVec21[((IOTA - 325) & 511)])) + ((0.0019226661f * (fVec21[((IOTA - 219) & 511)] + fVec21[((IOTA - 323) & 511)])) + ((0.0022583697f * (fVec21[((IOTA - 220) & 511)] - fVec21[((IOTA - 309) & 511)])) + ((0.00106814783f * (fVec21[((IOTA - 213) & 511)] + fVec21[((IOTA - 305) & 511)])) + ((0.00149540696f * ((fVec21[((IOTA - 158) & 511)] - fVec21[((IOTA - 246) & 511)]) - fVec21[((IOTA - 247) & 511)])) + ((0.00134281442f * ((fVec21[((IOTA - 59) & 511)] + fVec21[((IOTA - 168) & 511)]) - fVec21[((IOTA - 226) & 511)])) + (((0.00210577715f * (fVec21[((IOTA - 202) & 511)] + fVec21[((IOTA - 212) & 511)])) + ((0.00308236945f * fVec21[((IOTA - 210) & 511)]) + ((0.00204474013f * (fVec21[((IOTA - 178) & 511)] - fVec21[((IOTA - 205) & 511)])) + ((0.00375377666f * fVec21[((IOTA - 201) & 511)]) + ((0.00430310983f * fVec21[((IOTA - 200) & 511)]) + ((0.00305185094f * fVec21[((IOTA - 199) & 511)]) + ((0.001617481f * (fVec21[((IOTA - 183) & 511)] - fVec21[((IOTA - 196) & 511)])) + ((0.00427259132f * (fVec21[((IOTA - 128) & 511)] + fVec21[((IOTA - 191) & 511)])) + ((0.00415051728f * fVec21[((IOTA - 190) & 511)]) + ((0.0025940733f * fVec21[((IOTA - 189) & 511)]) + ((0.00418103579f * fVec21[((IOTA - 182) & 511)]) + ((0.00567644276f * fVec21[((IOTA - 181) & 511)]) + ((0.00546281319f * fVec21[((IOTA - 180) & 511)]) + ((0.00402844325f * fVec21[((IOTA - 179) & 511)]) + ((0.004852443f * fVec21[((IOTA - 171) & 511)]) + ((0.00466933195f * fVec21[((IOTA - 170) & 511)]) + ((0.0035401471f * fVec21[((IOTA - 169) & 511)]) + ((0.00350962859f * (fVec21[((IOTA - 51) & 511)] + fVec21[((IOTA - 162) & 511)])) + ((0.00622577593f * fVec21[((IOTA - 161) & 511)]) + ((0.00506607257f * fVec21[((IOTA - 159) & 511)]) + ((0.00476088747f * fVec21[((IOTA - 151) & 511)]) + ((0.00723288674f * (fVec21[((IOTA - 129) & 511)] + fVec21[((IOTA - 150) & 511)])) + ((0.00659199804f * fVec21[((IOTA - 149) & 511)]) + ((0.003234962f * fVec21[((IOTA - 148) & 511)]) + ((0.00448622089f * fVec21[((IOTA - 142) & 511)]) + ((0.00726340525f * fVec21[((IOTA - 141) & 511)]) + ((0.00735496078f * fVec21[((IOTA - 140) & 511)]) + ((0.00540177617f * fVec21[((IOTA - 139) & 511)]) + ((0.0028992584f * fVec21[((IOTA - 138) & 511)]) + ((0.00527970213f * fVec21[((IOTA - 132) & 511)]) + ((0.00888088625f * fVec21[((IOTA - 131) & 511)]) + ((0.00909451582f * fVec21[((IOTA - 130) & 511)]) + ((0.0057985168f * fVec21[((IOTA - 122) & 511)]) + ((0.0101321451f * fVec21[((IOTA - 121) & 511)]) + ((0.00915555283f * fVec21[((IOTA - 119) & 511)]) + ((0.00552385021f * fVec21[((IOTA - 111) & 511)]) + ((0.0117496261f * fVec21[((IOTA - 110) & 511)]) + ((0.0135502182f * fVec21[((IOTA - 109) & 511)]) + ((0.0087282937f * fVec21[((IOTA - 108) & 511)]) + ((0.00674459059f * fVec21[((IOTA - 101) & 511)]) + ((0.00906399731f * fVec21[((IOTA - 100) & 511)]) + ((0.00833155308f * (fVec21[((IOTA - 68) & 511)] + fVec21[((IOTA - 99) & 511)])) + ((0.0192571804f * fVec21[((IOTA - 91) & 511)]) + ((0.0226142164f * fVec21[((IOTA - 90) & 511)]) + ((0.0162663665f * fVec21[((IOTA - 89) & 511)]) + ((0.00299081393f * fVec21[((IOTA - 82) & 511)]) + ((0.0127262184f * fVec21[((IOTA - 81) & 511)]) + ((0.0191351064f * (fVec21[((IOTA - 26) & 511)] + fVec21[((IOTA - 80) & 511)])) + ((0.0166020691f * (fVec21[((IOTA - 41) & 511)] + fVec21[((IOTA - 79) & 511)])) + ((0.00628681295f * fVec21[((IOTA - 78) & 511)]) + ((0.0108951079f * fVec21[((IOTA - 72) & 511)]) + ((0.0241706595f * fVec21[((IOTA - 71) & 511)]) + ((0.0250556972f * fVec21[((IOTA - 70) & 511)]) + ((0.0163579211f * fVec21[((IOTA - 69) & 511)]) + ((0.00537125766f * fVec21[((IOTA - 67) & 511)]) + ((0.00360118411f * fVec21[((IOTA - 58) & 511)]) + ((0.00384533219f * fVec21[((IOTA - 53) & 511)]) + ((0.0119327372f * fVec21[((IOTA - 52) & 511)]) + ((0.0083925901f * fVec21[((IOTA - 48) & 511)]) + ((0.0155034028f * fVec21[((IOTA - 47) & 511)]) + ((0.0664693117f * fVec21[((IOTA - 40) & 511)]) + ((0.063631095f * fVec21[((IOTA - 39) & 511)]) + ((0.0168156996f * fVec21[((IOTA - 38) & 511)]) + ((0.00836207159f * fVec21[((IOTA - 34) & 511)]) + ((0.0439466536f * fVec21[((IOTA - 29) & 511)]) + ((0.0997650102f * fVec21[((IOTA - 28) & 511)]) + (((((((((((((((fSlow53 * fTemp0) + (0.072969757f * fVec21[((IOTA - 1) & 511)])) + (0.180333868f * fVec21[((IOTA - 2) & 511)])) + (0.218726158f * fVec21[((IOTA - 3) & 511)])) + (0.0521561317f * fVec21[((IOTA - 4) & 511)])) + (0.107333601f * fVec21[((IOTA - 8) & 511)])) + (0.16647847f * fVec21[((IOTA - 9) & 511)])) + (0.0741294622f * fVec21[((IOTA - 10) & 511)])) + (0.0224311054f * fVec21[((IOTA - 15) & 511)])) + (0.0517899096f * fVec21[((IOTA - 16) & 511)])) + (0.0119022187f * fVec21[((IOTA - 17) & 511)])) + (0.0339976214f * fVec21[((IOTA - 20) & 511)])) + (0.114291817f * fVec21[((IOTA - 21) & 511)])) + (0.0498977639f * fVec21[((IOTA - 22) & 511)])) + (0.111331522f * fVec21[((IOTA - 27) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00140385143f * ((fVec21[((IOTA - 250) & 511)] + fVec21[((IOTA - 321) & 511)]) - fVec21[((IOTA - 409) & 511)])))))))))) + (0.000854518265f * (fVec21[((IOTA - 493) & 511)] - ((fVec21[((IOTA - 204) & 511)] + fVec21[((IOTA - 235) & 511)]) - fVec21[((IOTA - 484) & 511)])))))))))))))))))))))))))))))) - (((0.000183111057f * (((((((fVec21[((IOTA - 283) & 511)] - fVec21[((IOTA - 291) & 511)]) + fVec21[((IOTA - 420) & 511)]) - fVec21[((IOTA - 429) & 511)]) + fVec21[((IOTA - 449) & 511)]) - fVec21[((IOTA - 459) & 511)]) - fVec21[((IOTA - 478) & 511)]) - fVec21[((IOTA - 508) & 511)])) + ((0.000305185094f * (((((fVec21[((IOTA - 127) & 511)] + fVec21[((IOTA - 415) & 511)]) - fVec21[((IOTA - 430) & 511)]) - fVec21[((IOTA - 440) & 511)]) - fVec21[((IOTA - 458) & 511)]) - fVec21[((IOTA - 507) & 511)])) + ((0.00057985168f * (((((((((((fVec21[((IOTA - 147) & 511)] + fVec21[((IOTA - 184) & 511)]) + fVec21[((IOTA - 224) & 511)]) + fVec21[((IOTA - 287) & 511)]) - fVec21[((IOTA - 324) & 511)]) + fVec21[((IOTA - 358) & 511)]) - fVec21[((IOTA - 374) & 511)]) - fVec21[((IOTA - 393) & 511)]) + fVec21[((IOTA - 417) & 511)]) - fVec21[((IOTA - 442) & 511)]) - fVec21[((IOTA - 453) & 511)]) - fVec21[((IOTA - 502) & 511)])) + ((0.000488296151f * (((((((fVec21[((IOTA - 187) & 511)] + fVec21[((IOTA - 416) & 511)]) + fVec21[((IOTA - 419) & 511)]) - fVec21[((IOTA - 462) & 511)]) - fVec21[((IOTA - 466) & 511)]) - fVec21[((IOTA - 474) & 511)]) - fVec21[((IOTA - 490) & 511)]) - fVec21[((IOTA - 500) & 511)])) + ((0.000671407208f * (((((((fVec21[((IOTA - 277) & 511)] - fVec21[((IOTA - 352) & 511)]) + fVec21[((IOTA - 356) & 511)]) + fVec21[((IOTA - 357) & 511)]) - fVec21[((IOTA - 376) & 511)]) - fVec21[((IOTA - 389) & 511)]) - fVec21[((IOTA - 464) & 511)]) - fVec21[((IOTA - 496) & 511)])) + ((0.000732444227f * (((((((fVec21[((IOTA - 227) & 511)] + fVec21[((IOTA - 257) & 511)]) - fVec21[((IOTA - 388) & 511)]) - fVec21[((IOTA - 401) & 511)]) - fVec21[((IOTA - 454) & 511)]) - fVec21[((IOTA - 456) & 511)]) - fVec21[((IOTA - 482) & 511)]) - fVec21[((IOTA - 495) & 511)])) + ((0.000640888698f * (((((((fVec21[((IOTA - 244) & 511)] + fVec21[((IOTA - 336) & 511)]) + fVec21[((IOTA - 339) & 511)]) - fVec21[((IOTA - 404) & 511)]) + fVec21[((IOTA - 407) & 511)]) + fVec21[((IOTA - 418) & 511)]) - fVec21[((IOTA - 465) & 511)]) - fVec21[((IOTA - 491) & 511)])) + ((0.000701925717f * (((fVec21[((IOTA - 276) & 511)] - fVec21[((IOTA - 351) & 511)]) + fVec21[((IOTA - 361) & 511)]) - fVec21[((IOTA - 485) & 511)])) + ((0.000885036774f * (((fVec21[((IOTA - 107) & 511)] + fVec21[((IOTA - 194) & 511)]) - fVec21[((IOTA - 223) & 511)]) - fVec21[((IOTA - 483) & 511)])) + ((9.15555283e-05f * (((((fVec21[((IOTA - 288) & 511)] + fVec21[((IOTA - 292) & 511)]) + fVec21[((IOTA - 335) & 511)]) + fVec21[((IOTA - 427) & 511)]) + fVec21[((IOTA - 448) & 511)]) - fVec21[((IOTA - 451) & 511)])) + ((0.000274666585f * (((((((((fVec21[((IOTA - 137) & 511)] + fVec21[((IOTA - 294) & 511)]) + fVec21[((IOTA - 301) & 511)]) + fVec21[((IOTA - 317) & 511)]) + fVec21[((IOTA - 377) & 511)]) - fVec21[((IOTA - 390) & 511)]) - fVec21[((IOTA - 392) & 511)]) - fVec21[((IOTA - 413) & 511)]) - fVec21[((IOTA - 431) & 511)]) - fVec21[((IOTA - 446) & 511)])) + ((0.00112918485f * (((fVec21[((IOTA - 274) & 511)] + fVec21[((IOTA - 348) & 511)]) + fVec21[((IOTA - 408) & 511)]) + fVec21[((IOTA - 410) & 511)])) + ((0.00109866634f * (((fVec21[((IOTA - 245) & 511)] + fVec21[((IOTA - 254) & 511)]) + fVec21[((IOTA - 369) & 511)]) - fVec21[((IOTA - 403) & 511)])) + ((0.00137333293f * (fVec21[((IOTA - 117) & 511)] + fVec21[((IOTA - 399) & 511)])) + ((0.00158696249f * ((fVec21[((IOTA - 60) & 511)] + fVec21[((IOTA - 153) & 511)]) + fVec21[((IOTA - 396) & 511)])) + ((0.00100711081f * ((((fVec21[((IOTA - 197) & 511)] + fVec21[((IOTA - 275) & 511)]) + fVec21[((IOTA - 315) & 511)]) + fVec21[((IOTA - 337) & 511)]) + fVec21[((IOTA - 382) & 511)])) + ((0.00280770287f * fVec21[((IOTA - 380) & 511)]) + ((0.00268562883f * fVec21[((IOTA - 379) & 511)]) + ((0.00164799951f * (((fVec21[((IOTA - 207) & 511)] - fVec21[((IOTA - 230) & 511)]) + fVec21[((IOTA - 308) & 511)]) + fVec21[((IOTA - 378) & 511)])) + ((0.000823999755f * ((((fVec21[((IOTA - 133) & 511)] - fVec21[((IOTA - 252) & 511)]) - fVec21[((IOTA - 271) & 511)]) + fVec21[((IOTA - 286) & 511)]) - fVec21[((IOTA - 375) & 511)])) + ((0.00146488845f * (((fVec21[((IOTA - 123) & 511)] - fVec21[((IOTA - 251) & 511)]) + fVec21[((IOTA - 267) & 511)]) + fVec21[((IOTA - 368) & 511)])) + ((0.00173955504f * (fVec21[((IOTA - 364) & 511)] + fVec21[((IOTA - 367) & 511)])) + ((0.0019531846f * fVec21[((IOTA - 366) & 511)]) + ((0.00131229591f * (fVec21[((IOTA - 311) & 511)] + fVec21[((IOTA - 363) & 511)])) + ((0.000946073793f * (((fVec21[((IOTA - 236) & 511)] - fVec21[((IOTA - 242) & 511)]) + fVec21[((IOTA - 295) & 511)]) + fVec21[((IOTA - 362) & 511)])) + ((0.00180059206f * (fVec21[((IOTA - 266) & 511)] + fVec21[((IOTA - 347) & 511)])) + ((0.00186162908f * ((fVec21[((IOTA - 215) & 511)] + fVec21[((IOTA - 216) & 511)]) + fVec21[((IOTA - 345) & 511)])) + ((0.00122074038f * ((fVec21[((IOTA - 174) & 511)] + fVec21[((IOTA - 186) & 511)]) + fVec21[((IOTA - 314) & 511)])) + ((0.000915555283f * (fVec21[((IOTA - 237) & 511)] + fVec21[((IOTA - 312) & 511)])) + ((0.00125125889f * (fVec21[((IOTA - 299) & 511)] - fVec21[((IOTA - 304) & 511)])) + ((0.00183111057f * fVec21[((IOTA - 298) & 511)]) + ((0.00177007355f * fVec21[((IOTA - 296) & 511)]) + ((0.00155644398f * (((fVec21[((IOTA - 167) & 511)] - fVec21[((IOTA - 173) & 511)]) - fVec21[((IOTA - 240) & 511)]) + fVec21[((IOTA - 265) & 511)])) + ((0.00152592547f * (fVec21[((IOTA - 195) & 511)] + fVec21[((IOTA - 256) & 511)])) + ((0.00167851802f * (((fVec21[((IOTA - 112) & 511)] + fVec21[((IOTA - 157) & 511)]) - fVec21[((IOTA - 232) & 511)]) - fVec21[((IOTA - 241) & 511)])) + ((0.00143436994f * (fVec21[((IOTA - 185) & 511)] + fVec21[((IOTA - 225) & 511)])) + ((0.00277718436f * (fVec21[((IOTA - 97) & 511)] - fVec21[((IOTA - 211) & 511)])) + ((0.00262459181f * fVec21[((IOTA - 206) & 511)]) + ((0.00274666585f * (fVec21[((IOTA - 175) & 511)] - fVec21[((IOTA - 192) & 511)])) + ((0.00216681417f * fVec21[((IOTA - 176) & 511)]) + ((0.00390636921f * fVec21[((IOTA - 166) & 511)]) + ((0.00442518387f * fVec21[((IOTA - 165) & 511)]) + ((0.00286873989f * fVec21[((IOTA - 164) & 511)]) + ((0.00695822015f * (fVec21[((IOTA - 113) & 511)] - fVec21[((IOTA - 160) & 511)])) + ((0.00314340647f * (fVec21[((IOTA - 146) & 511)] + fVec21[((IOTA - 156) & 511)])) + ((0.00378429517f * fVec21[((IOTA - 145) & 511)]) + ((0.00253303628f * fVec21[((IOTA - 144) & 511)]) + ((0.00424207281f * (fVec21[((IOTA - 103) & 511)] + fVec21[((IOTA - 136) & 511)])) + ((0.00698873866f * fVec21[((IOTA - 135) & 511)]) + ((0.00585955381f * ((fVec21[((IOTA - 73) & 511)] + fVec21[((IOTA - 126) & 511)]) + fVec21[((IOTA - 134) & 511)])) + ((0.00952177495f * fVec21[((IOTA - 125) & 511)]) + ((0.00793481246f * fVec21[((IOTA - 124) & 511)]) + ((0.0110477004f * (fVec21[((IOTA - 104) & 511)] - fVec21[((IOTA - 120) & 511)])) + ((0.00704977568f * (fVec21[((IOTA - 49) & 511)] + fVec21[((IOTA - 116) & 511)])) + ((0.00283822138f * fVec21[((IOTA - 154) & 511)]) + ((0.0100711081f * fVec21[((IOTA - 115) & 511)]) + ((0.00982696004f * fVec21[((IOTA - 114) & 511)]) + ((0.0104068117f * fVec21[((IOTA - 106) & 511)]) + ((0.0141605884f * fVec21[((IOTA - 105) & 511)]) + ((0.00933866389f * fVec21[((IOTA - 96) & 511)]) + ((0.0126346629f * fVec21[((IOTA - 95) & 511)]) + ((0.0103457747f * fVec21[((IOTA - 94) & 511)]) + ((0.00241096225f * fVec21[((IOTA - 93) & 511)]) + ((0.0090334788f * (fVec21[((IOTA - 50) & 511)] - fVec21[((IOTA - 92) & 511)])) + (((0.011322367f * fVec21[((IOTA - 87) & 511)]) + ((0.0169988107f * fVec21[((IOTA - 86) & 511)]) + ((0.0147099216f * fVec21[((IOTA - 85) & 511)]) + ((0.00979644153f * fVec21[((IOTA - 84) & 511)]) + ((0.0045167394f * fVec21[((IOTA - 83) & 511)]) + ((0.00656147953f * fVec21[((IOTA - 77) & 511)]) + ((0.0165715516f * fVec21[((IOTA - 76) & 511)]) + ((0.0205084383f * fVec21[((IOTA - 75) & 511)]) + ((0.0172124393f * fVec21[((IOTA - 74) & 511)]) + ((0.00997955259f * fVec21[((IOTA - 65) & 511)]) + ((0.0216071047f * fVec21[((IOTA - 64) & 511)]) + ((0.0249641407f * fVec21[((IOTA - 63) & 511)]) + ((0.0172429588f * fVec21[((IOTA - 62) & 511)]) + ((0.00747703481f * fVec21[((IOTA - 61) & 511)]) + ((0.00842310861f * fVec21[((IOTA - 56) & 511)]) + (((0.0277108066f * fVec21[((IOTA - 45) & 511)]) + ((0.0544450209f * fVec21[((IOTA - 44) & 511)]) + ((0.0639973134f * fVec21[((IOTA - 43) & 511)]) + ((0.0397961363f * fVec21[((IOTA - 42) & 511)]) + ((0.0230414756f * fVec21[((IOTA - 37) & 511)]) + ((0.0292977691f * fVec21[((IOTA - 36) & 511)]) + ((0.00610370189f * fVec21[((IOTA - 35) & 511)]) + ((0.00433362834f * fVec21[((IOTA - 33) & 511)]) + ((0.0291451775f * fVec21[((IOTA - 32) & 511)]) + ((0.0294503625f * fVec21[((IOTA - 31) & 511)]) + ((0.00302133244f * fVec21[((IOTA - 30) & 511)]) + ((0.132511362f * fVec21[((IOTA - 25) & 511)]) + ((0.206030458f * fVec21[((IOTA - 24) & 511)]) + ((0.111728266f * fVec21[((IOTA - 23) & 511)]) + ((0.0592364259f * fVec21[((IOTA - 19) & 511)]) + ((0.0598467961f * fVec21[((IOTA - 18) & 511)]) + ((0.0199285876f * fVec21[((IOTA - 14) & 511)]) + ((0.0535294674f * fVec21[((IOTA - 13) & 511)]) + ((0.0618915372f * fVec21[((IOTA - 12) & 511)]) + ((0.0374156944f * fVec21[((IOTA - 11) & 511)]) + ((0.120853297f * fVec21[((IOTA - 7) & 511)]) + ((0.290932953f * fVec21[((IOTA - 6) & 511)]) + ((0.201971501f * fVec21[((IOTA - 5) & 511)]) + (0.0107425153f * fVec21[((IOTA - 54) & 511)])))))))))))))))))))))))) + (0.0159611814f * fVec21[((IOTA - 55) & 511)]))))))))))))))))) + (0.00329599902f * fVec21[((IOTA - 155) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000152592547f * (((((((((((fVec21[((IOTA - 177) & 511)] - fVec21[((IOTA - 261) & 511)]) + fVec21[((IOTA - 293) & 511)]) + fVec21[((IOTA - 340) & 511)]) + fVec21[((IOTA - 343) & 511)]) + fVec21[((IOTA - 383) & 511)]) - fVec21[((IOTA - 384) & 511)]) - fVec21[((IOTA - 412) & 511)]) - fVec21[((IOTA - 432) & 511)]) - fVec21[((IOTA - 439) & 511)]) - fVec21[((IOTA - 471) & 511)]) - fVec21[((IOTA - 509) & 511)])))) : (((0.000213629566f * ((((((((((((((((fVec20[((IOTA - 57) & 511)] - fVec20[((IOTA - 237) & 511)]) - fVec20[((IOTA - 241) & 511)]) - fVec20[((IOTA - 249) & 511)]) + fVec20[((IOTA - 282) & 511)]) + fVec20[((IOTA - 292) & 511)]) - fVec20[((IOTA - 301) & 511)]) + fVec20[((IOTA - 307) & 511)]) + fVec20[((IOTA - 309) & 511)]) + fVec20[((IOTA - 385) & 511)]) - fVec20[((IOTA - 398) & 511)]) + fVec20[((IOTA - 435) & 511)]) + fVec20[((IOTA - 436) & 511)]) - fVec20[((IOTA - 466) & 511)]) - fVec20[((IOTA - 507) & 511)]) + fVec20[((IOTA - 509) & 511)]) + fVec20[((IOTA - 511) & 511)])) + ((0.000274666585f * (((((((fVec20[((IOTA - 165) & 511)] - fVec20[((IOTA - 205) & 511)]) - fVec20[((IOTA - 262) & 511)]) + fVec20[((IOTA - 338) & 511)]) - fVec20[((IOTA - 396) & 511)]) - fVec20[((IOTA - 397) & 511)]) + fVec20[((IOTA - 437) & 511)]) + fVec20[((IOTA - 510) & 511)])) + ((0.000610370189f * ((((((((fVec20[((IOTA - 218) & 511)] + fVec20[((IOTA - 269) & 511)]) + fVec20[((IOTA - 304) & 511)]) + fVec20[((IOTA - 312) & 511)]) - fVec20[((IOTA - 352) & 511)]) - fVec20[((IOTA - 353) & 511)]) + fVec20[((IOTA - 356) & 511)]) + fVec20[((IOTA - 482) & 511)]) - fVec20[((IOTA - 503) & 511)])) + ((0.000183111057f * (((((fVec20[((IOTA - 271) & 511)] - fVec20[((IOTA - 283) & 511)]) + fVec20[((IOTA - 346) & 511)]) - fVec20[((IOTA - 376) & 511)]) - fVec20[((IOTA - 497) & 511)]) - fVec20[((IOTA - 501) & 511)])) + ((6.10370189e-05f * (((((((((((((((fVec20[((IOTA - 29) & 511)] + fVec20[((IOTA - 31) & 511)]) + fVec20[((IOTA - 33) & 511)]) + fVec20[((IOTA - 48) & 511)]) + fVec20[((IOTA - 49) & 511)]) + fVec20[((IOTA - 50) & 511)]) - fVec20[((IOTA - 60) & 511)]) + fVec20[((IOTA - 259) & 511)]) + fVec20[((IOTA - 294) & 511)]) - fVec20[((IOTA - 295) & 511)]) + fVec20[((IOTA - 302) & 511)]) + fVec20[((IOTA - 308) & 511)]) - fVec20[((IOTA - 355) & 511)]) + fVec20[((IOTA - 448) & 511)]) + fVec20[((IOTA - 468) & 511)]) + fVec20[((IOTA - 500) & 511)])) + ((0.000152592547f * (((((((fVec20[((IOTA - 59) & 511)] + fVec20[((IOTA - 204) & 511)]) + fVec20[((IOTA - 293) & 511)]) - fVec20[((IOTA - 347) & 511)]) - fVec20[((IOTA - 401) & 511)]) - fVec20[((IOTA - 465) & 511)]) - fVec20[((IOTA - 467) & 511)]) + fVec20[((IOTA - 499) & 511)])) + ((9.15555283e-05f * ((((((((fVec20[((IOTA - 26) & 511)] + fVec20[((IOTA - 27) & 511)]) + fVec20[((IOTA - 56) & 511)]) + fVec20[((IOTA - 166) & 511)]) - fVec20[((IOTA - 197) & 511)]) - fVec20[((IOTA - 272) & 511)]) - fVec20[((IOTA - 277) & 511)]) - fVec20[((IOTA - 395) & 511)]) + fVec20[((IOTA - 498) & 511)])) + ((0.00100711081f * ((((fVec20[((IOTA - 226) & 511)] + fVec20[((IOTA - 321) & 511)]) + fVec20[((IOTA - 417) & 511)]) - fVec20[((IOTA - 492) & 511)]) - fVec20[((IOTA - 494) & 511)])) + ((0.00103762932f * (((fVec20[((IOTA - 203) & 511)] + fVec20[((IOTA - 328) & 511)]) + fVec20[((IOTA - 473) & 511)]) - fVec20[((IOTA - 493) & 511)])) + ((0.000946073793f * ((((fVec20[((IOTA - 324) & 511)] + fVec20[((IOTA - 369) & 511)]) + fVec20[((IOTA - 441) & 511)]) + fVec20[((IOTA - 471) & 511)]) - fVec20[((IOTA - 491) & 511)])) + ((0.000885036774f * ((fVec20[((IOTA - 227) & 511)] - fVec20[((IOTA - 453) & 511)]) - fVec20[((IOTA - 490) & 511)])) + ((0.000793481246f * (((fVec20[((IOTA - 316) & 511)] + fVec20[((IOTA - 334) & 511)]) + fVec20[((IOTA - 474) & 511)]) - fVec20[((IOTA - 489) & 511)])) + ((0.000457777642f * (((((((fVec20[((IOTA - 270) & 511)] + fVec20[((IOTA - 289) & 511)]) + fVec20[((IOTA - 340) & 511)]) - fVec20[((IOTA - 354) & 511)]) + fVec20[((IOTA - 419) & 511)]) + fVec20[((IOTA - 420) & 511)]) + fVec20[((IOTA - 478) & 511)]) - fVec20[((IOTA - 487) & 511)])) + ((0.000244148076f * ((((((((fVec20[((IOTA - 58) & 511)] - fVec20[((IOTA - 190) & 511)]) + fVec20[((IOTA - 225) & 511)]) - fVec20[((IOTA - 260) & 511)]) - fVec20[((IOTA - 286) & 511)]) - fVec20[((IOTA - 296) & 511)]) - fVec20[((IOTA - 403) & 511)]) + fVec20[((IOTA - 460) & 511)]) - fVec20[((IOTA - 486) & 511)])) + ((0.000305185094f * ((((fVec20[((IOTA - 240) & 511)] + fVec20[((IOTA - 288) & 511)]) + fVec20[((IOTA - 291) & 511)]) - fVec20[((IOTA - 402) & 511)]) + fVec20[((IOTA - 484) & 511)])) + ((0.000518814661f * (((((((fVec20[((IOTA - 257) & 511)] - (fVec20[((IOTA - 247) & 511)] - fVec20[((IOTA - 256) & 511)])) - fVec20[((IOTA - 298) & 511)]) - fVec20[((IOTA - 299) & 511)]) + fVec20[((IOTA - 306) & 511)]) + fVec20[((IOTA - 311) & 511)]) - fVec20[((IOTA - 349) & 511)]) + fVec20[((IOTA - 483) & 511)])) + ((0.00131229591f * (((fVec20[((IOTA - 386) & 511)] + fVec20[((IOTA - 393) & 511)]) - fVec20[((IOTA - 449) & 511)]) + fVec20[((IOTA - 458) & 511)])) + ((0.00167851802f * ((((fVec20[((IOTA - 151) & 511)] - fVec20[((IOTA - 230) & 511)]) + fVec20[((IOTA - 413) & 511)]) + fVec20[((IOTA - 423) & 511)]) + fVec20[((IOTA - 457) & 511)])) + ((0.000915555283f * (((fVec20[((IOTA - 173) & 511)] + fVec20[((IOTA - 323) & 511)]) + fVec20[((IOTA - 329) & 511)]) + fVec20[((IOTA - 455) & 511)])) + ((0.00170903653f * (fVec20[((IOTA - 415) & 511)] - fVec20[((IOTA - 452) & 511)])) + ((0.00216681417f * (fVec20[((IOTA - 216) & 511)] - fVec20[((IOTA - 451) & 511)])) + ((0.00149540696f * fVec20[((IOTA - 447) & 511)]) + ((0.00265511032f * (fVec20[((IOTA - 199) & 511)] + fVec20[((IOTA - 445) & 511)])) + ((0.00164799951f * ((fVec20[((IOTA - 198) & 511)] - fVec20[((IOTA - 232) & 511)]) + fVec20[((IOTA - 443) & 511)])) + ((0.000762962736f * ((fVec20[((IOTA - 280) & 511)] + fVec20[((IOTA - 314) & 511)]) + fVec20[((IOTA - 440) & 511)])) + ((0.00158696249f * fVec20[((IOTA - 431) & 511)]) + ((0.00234992523f * (fVec20[((IOTA - 359) & 511)] + fVec20[((IOTA - 429) & 511)])) + ((0.00262459181f * (fVec20[((IOTA - 93) & 511)] + fVec20[((IOTA - 428) & 511)])) + ((0.00280770287f * fVec20[((IOTA - 427) & 511)]) + ((0.00283822138f * fVec20[((IOTA - 426) & 511)]) + ((0.00268562883f * fVec20[((IOTA - 425) & 511)]) + ((0.00228888821f * fVec20[((IOTA - 424) & 511)]) + ((0.00143436994f * (((fVec20[((IOTA - 253) & 511)] + fVec20[((IOTA - 362) & 511)]) + fVec20[((IOTA - 411) & 511)]) + fVec20[((IOTA - 416) & 511)])) + ((0.00177007355f * (fVec20[((IOTA - 212) & 511)] + fVec20[((IOTA - 414) & 511)])) + ((0.00155644398f * fVec20[((IOTA - 412) & 511)]) + ((0.0022583697f * (((fVec20[((IOTA - 112) & 511)] - fVec20[((IOTA - 146) & 511)]) - fVec20[((IOTA - 379) & 511)]) + fVec20[((IOTA - 392) & 511)])) + ((0.00317392498f * fVec20[((IOTA - 391) & 511)]) + ((0.00393688772f * fVec20[((IOTA - 390) & 511)]) + ((0.00424207281f * fVec20[((IOTA - 389) & 511)]) + ((0.00375377666f * fVec20[((IOTA - 388) & 511)]) + ((0.000671407208f * (((fVec20[((IOTA - 342) & 511)] - (((fVec20[((IOTA - 189) & 511)] - fVec20[((IOTA - 268) & 511)]) - fVec20[((IOTA - 305) & 511)]) - fVec20[((IOTA - 313) & 511)])) + fVec20[((IOTA - 344) & 511)]) - fVec20[((IOTA - 384) & 511)])) + ((0.00134281442f * (fVec20[((IOTA - 357) & 511)] - fVec20[((IOTA - 377) & 511)])) + ((0.00125125889f * fVec20[((IOTA - 375) & 511)]) + ((0.00250251777f * fVec20[((IOTA - 374) & 511)]) + ((0.00308236945f * fVec20[((IOTA - 373) & 511)]) + ((0.00311288796f * (fVec20[((IOTA - 201) & 511)] + fVec20[((IOTA - 372) & 511)])) + ((0.00292977691f * fVec20[((IOTA - 371) & 511)]) + ((0.00198370311f * fVec20[((IOTA - 358) & 511)]) + ((0.000366222113f * (((((fVec20[((IOTA - 238) & 511)] - fVec20[((IOTA - 261) & 511)]) + fVec20[((IOTA - 264) & 511)]) - fVec20[((IOTA - 273) & 511)]) + fVec20[((IOTA - 303) & 511)]) - fVec20[((IOTA - 348) & 511)])) + ((0.000488296151f * fVec20[((IOTA - 345) & 511)]) + ((0.000701925717f * ((((fVec20[((IOTA - 317) & 511)] - ((fVec20[((IOTA - 191) & 511)] - fVec20[((IOTA - 267) & 511)]) - fVec20[((IOTA - 279) & 511)])) + fVec20[((IOTA - 319) & 511)]) + fVec20[((IOTA - 335) & 511)]) + fVec20[((IOTA - 343) & 511)])) + ((0.000823999755f * ((fVec20[((IOTA - 315) & 511)] + fVec20[((IOTA - 330) & 511)]) + fVec20[((IOTA - 331) & 511)])) + ((0.00112918485f * fVec20[((IOTA - 325) & 511)]) + ((0.00122074038f * (fVec20[((IOTA - 327) & 511)] + fVec20[((IOTA - 409) & 511)])) + ((0.00106814783f * (((((fVec20[((IOTA - 113) & 511)] + fVec20[((IOTA - 139) & 511)]) - fVec20[((IOTA - 188) & 511)]) - fVec20[((IOTA - 229) & 511)]) + fVec20[((IOTA - 251) & 511)]) + fVec20[((IOTA - 254) & 511)])) + ((0.00115970336f * ((fVec20[((IOTA - 152) & 511)] - fVec20[((IOTA - 164) & 511)]) - fVec20[((IOTA - 224) & 511)])) + ((0.00302133244f * fVec20[((IOTA - 215) & 511)]) + ((0.00363170262f * fVec20[((IOTA - 214) & 511)]) + ((0.00326548051f * fVec20[((IOTA - 213) & 511)]) + ((0.00329599902f * fVec20[((IOTA - 200) & 511)]) + ((0.00555436872f * fVec20[((IOTA - 162) & 511)]) + ((0.0131534776f * fVec20[((IOTA - 161) & 511)]) + ((0.01617481f * fVec20[((IOTA - 160) & 511)]) + ((0.0108340709f * fVec20[((IOTA - 159) & 511)]) + ((0.00503555406f * fVec20[((IOTA - 138) & 511)]) + ((0.0109256264f * fVec20[((IOTA - 137) & 511)]) + ((0.0132755516f * fVec20[((IOTA - 136) & 511)]) + ((0.01126133f * fVec20[((IOTA - 135) & 511)]) + ((0.0038758507f * fVec20[((IOTA - 134) & 511)]) + ((0.0116885891f * fVec20[((IOTA - 127) & 511)]) + ((0.0203558467f * fVec20[((IOTA - 126) & 511)]) + ((0.0156559963f * fVec20[((IOTA - 125) & 511)]) + ((0.00213629566f * (fVec20[((IOTA - 68) & 511)] + fVec20[((IOTA - 124) & 511)])) + ((0.00726340525f * fVec20[((IOTA - 111) & 511)]) + ((0.0167851802f * fVec20[((IOTA - 110) & 511)]) + ((0.0239265114f * fVec20[((IOTA - 109) & 511)]) + ((0.0232856236f * fVec20[((IOTA - 108) & 511)]) + ((0.0214239936f * fVec20[((IOTA - 107) & 511)]) + ((0.00744651631f * fVec20[((IOTA - 106) & 511)]) + ((0.0195928831f * fVec20[((IOTA - 100) & 511)]) + ((0.0396435447f * fVec20[((IOTA - 99) & 511)]) + ((0.029053621f * fVec20[((IOTA - 98) & 511)]) + ((0.00643940549f * fVec20[((IOTA - 97) & 511)]) + ((0.0191045869f * fVec20[((IOTA - 92) & 511)]) + ((0.0169072542f * fVec20[((IOTA - 91) & 511)]) + ((0.00720236823f * (fVec20[((IOTA - 69) & 511)] - fVec20[((IOTA - 84) & 511)])) + ((0.0295113996f * fVec20[((IOTA - 83) & 511)]) + ((0.0787682757f * fVec20[((IOTA - 82) & 511)]) + ((0.100405894f * fVec20[((IOTA - 81) & 511)]) + ((0.0761131644f * fVec20[((IOTA - 80) & 511)]) + ((0.0172124393f * fVec20[((IOTA - 75) & 511)]) + ((0.210577711f * fVec20[((IOTA - 74) & 511)]) + ((0.275337994f * fVec20[((IOTA - 73) & 511)]) + ((0.190221876f * fVec20[((IOTA - 72) & 511)]) + ((0.0183721427f * fVec20[((IOTA - 70) & 511)]) + (0.0740379021f * fVec20[((IOTA - 71) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000427259132f * ((((((((((fVec20[((IOTA - 219) & 511)] - fVec20[((IOTA - 250) & 511)]) + fVec20[((IOTA - 276) & 511)]) + fVec20[((IOTA - 284) & 511)]) + fVec20[((IOTA - 285) & 511)]) - fVec20[((IOTA - 290) & 511)]) + fVec20[((IOTA - 300) & 511)]) - fVec20[((IOTA - 394) & 511)]) - fVec20[((IOTA - 407) & 511)]) + fVec20[((IOTA - 502) & 511)]) + fVec20[((IOTA - 506) & 511)])) + ((0.000640888698f * ((((((((((((fVec20[((IOTA - 242) & 511)] + fVec20[((IOTA - 244) & 511)]) - fVec20[((IOTA - 255) & 511)]) - fVec20[((IOTA - 265) & 511)]) - fVec20[((IOTA - 318) & 511)]) - fVec20[((IOTA - 418) & 511)]) - fVec20[((IOTA - 421) & 511)]) - fVec20[((IOTA - 433) & 511)]) - fVec20[((IOTA - 470) & 511)]) - fVec20[((IOTA - 480) & 511)]) - fVec20[((IOTA - 481) & 511)]) + fVec20[((IOTA - 488) & 511)]) + fVec20[((IOTA - 504) & 511)])) + ((0.00054933317f * ((((((((fVec20[((IOTA - 206) & 511)] - fVec20[((IOTA - 239) & 511)]) + fVec20[((IOTA - 274) & 511)]) - fVec20[((IOTA - 281) & 511)]) - fVec20[((IOTA - 336) & 511)]) - fVec20[((IOTA - 439) & 511)]) - fVec20[((IOTA - 475) & 511)]) - fVec20[((IOTA - 479) & 511)]) + fVec20[((IOTA - 496) & 511)])) + ((0.000854518265f * (((((fVec20[((IOTA - 243) & 511)] - fVec20[((IOTA - 320) & 511)]) - fVec20[((IOTA - 332) & 511)]) - fVec20[((IOTA - 333) & 511)]) - fVec20[((IOTA - 408) & 511)]) + fVec20[((IOTA - 495) & 511)])) + (((0.000396740623f * (((((((fVec20[((IOTA - 245) & 511)] - fVec20[((IOTA - 258) & 511)]) + fVec20[((IOTA - 297) & 511)]) - fVec20[((IOTA - 310) & 511)]) - fVec20[((IOTA - 337) & 511)]) - fVec20[((IOTA - 438) & 511)]) - fVec20[((IOTA - 476) & 511)]) - fVec20[((IOTA - 477) & 511)])) + ((0.00109866634f * (((fVec20[((IOTA - 235) & 511)] - fVec20[((IOTA - 422) & 511)]) - fVec20[((IOTA - 432) & 511)]) - fVec20[((IOTA - 472) & 511)])) + ((0.000335703604f * ((((((fVec20[((IOTA - 61) & 511)] + fVec20[((IOTA - 211) & 511)]) + fVec20[((IOTA - 246) & 511)]) - fVec20[((IOTA - 278) & 511)]) - fVec20[((IOTA - 339) & 511)]) - fVec20[((IOTA - 434) & 511)]) - fVec20[((IOTA - 469) & 511)])) + ((0.000732444227f * ((fVec20[((IOTA - 236) & 511)] - fVec20[((IOTA - 266) & 511)]) - fVec20[((IOTA - 459) & 511)])) + ((0.00152592547f * (fVec20[((IOTA - 368) & 511)] - fVec20[((IOTA - 456) & 511)])) + ((0.00210577715f * fVec20[((IOTA - 450) & 511)]) + ((0.00247199927f * ((fVec20[((IOTA - 147) & 511)] - fVec20[((IOTA - 370) & 511)]) - fVec20[((IOTA - 446) & 511)])) + ((0.00222785119f * (fVec20[((IOTA - 196) & 511)] - fVec20[((IOTA - 444) & 511)])) + ((0.00119022187f * (fVec20[((IOTA - 207) & 511)] - fVec20[((IOTA - 442) & 511)])) + ((0.00201422162f * (fVec20[((IOTA - 378) & 511)] - fVec20[((IOTA - 430) & 511)])) + ((0.00137333293f * ((fVec20[((IOTA - 62) & 511)] - fVec20[((IOTA - 217) & 511)]) - fVec20[((IOTA - 410) & 511)])) + ((0.000122074038f * ((fVec20[((IOTA - 150) & 511)] + fVec20[((IOTA - 404) & 511)]) - fVec20[((IOTA - 406) & 511)])) + ((0.0025940733f * (((fVec20[((IOTA - 186) & 511)] + fVec20[((IOTA - 209) & 511)]) + fVec20[((IOTA - 221) & 511)]) - fVec20[((IOTA - 387) & 511)])) + ((0.00146488845f * (((fVec20[((IOTA - 178) & 511)] + fVec20[((IOTA - 233) & 511)]) - fVec20[((IOTA - 252) & 511)]) + fVec20[((IOTA - 383) & 511)])) + ((0.0019531846f * (fVec20[((IOTA - 192) & 511)] + fVec20[((IOTA - 382) & 511)])) + ((0.00219733268f * ((((fVec20[((IOTA - 140) & 511)] + fVec20[((IOTA - 175) & 511)]) - fVec20[((IOTA - 202) & 511)]) - fVec20[((IOTA - 361) & 511)]) + fVec20[((IOTA - 381) & 511)])) + ((0.00231940672f * (fVec20[((IOTA - 149) & 511)] + fVec20[((IOTA - 380) & 511)])) + ((0.00378429517f * (fVec20[((IOTA - 184) & 511)] + fVec20[((IOTA - 367) & 511)])) + ((0.0045167394f * fVec20[((IOTA - 366) & 511)]) + ((0.00369273964f * fVec20[((IOTA - 365) & 511)]) + ((0.0019226661f * fVec20[((IOTA - 364) & 511)]) + ((0.00244148076f * (fVec20[((IOTA - 167) & 511)] - fVec20[((IOTA - 360) & 511)])) + ((0.0012817774f * (fVec20[((IOTA - 234) & 511)] - fVec20[((IOTA - 326) & 511)])) + ((0.000976592302f * (fVec20[((IOTA - 172) & 511)] - fVec20[((IOTA - 322) & 511)])) + ((0.00180059206f * (fVec20[((IOTA - 158) & 511)] + fVec20[((IOTA - 231) & 511)])) + ((0.00238044374f * (fVec20[((IOTA - 145) & 511)] + fVec20[((IOTA - 223) & 511)])) + ((0.00296029542f * fVec20[((IOTA - 222) & 511)]) + ((0.001617481f * fVec20[((IOTA - 220) & 511)]) + ((0.00204474013f * (fVec20[((IOTA - 208) & 511)] + fVec20[((IOTA - 210) & 511)])) + ((0.00384533219f * (fVec20[((IOTA - 63) & 511)] + fVec20[((IOTA - 195) & 511)])) + ((0.00442518387f * fVec20[((IOTA - 194) & 511)]) + ((0.00350962859f * fVec20[((IOTA - 193) & 511)]) + ((0.00186162908f * (fVec20[((IOTA - 114) & 511)] + fVec20[((IOTA - 187) & 511)])) + ((0.0028992584f * fVec20[((IOTA - 185) & 511)]) + ((0.00521866512f * fVec20[((IOTA - 183) & 511)]) + ((0.00622577593f * fVec20[((IOTA - 182) & 511)]) + ((0.00540177617f * fVec20[((IOTA - 181) & 511)]) + ((0.00366222113f * fVec20[((IOTA - 180) & 511)]) + ((0.00173955504f * fVec20[((IOTA - 179) & 511)]) + ((0.00271614734f * (fVec20[((IOTA - 153) & 511)] + fVec20[((IOTA - 177) & 511)])) + ((0.00347911008f * fVec20[((IOTA - 176) & 511)]) + ((0.00430310983f * (fVec20[((IOTA - 143) & 511)] + fVec20[((IOTA - 171) & 511)])) + ((0.00781273842f * (fVec20[((IOTA - 133) & 511)] + fVec20[((IOTA - 170) & 511)])) + ((0.00851466414f * fVec20[((IOTA - 169) & 511)]) + ((0.00640888698f * fVec20[((IOTA - 168) & 511)]) + ((0.0149845881f * fVec20[((IOTA - 157) & 511)]) + ((0.0218207352f * fVec20[((IOTA - 156) & 511)]) + ((0.0187688842f * fVec20[((IOTA - 155) & 511)]) + ((0.0108035523f * fVec20[((IOTA - 154) & 511)]) + ((0.00338755455f * fVec20[((IOTA - 148) & 511)]) + ((0.00372325815f * fVec20[((IOTA - 144) & 511)]) + ((0.00494399853f * fVec20[((IOTA - 142) & 511)]) + ((0.00357066561f * fVec20[((IOTA - 141) & 511)]) + ((0.02252266f * fVec20[((IOTA - 132) & 511)]) + ((0.0329294726f * fVec20[((IOTA - 131) & 511)]) + ((0.0352488793f * fVec20[((IOTA - 130) & 511)]) + ((0.025757622f * fVec20[((IOTA - 129) & 511)]) + ((0.00784325693f * fVec20[((IOTA - 128) & 511)]) + ((0.00930814538f * fVec20[((IOTA - 123) & 511)]) + ((0.0167241432f * fVec20[((IOTA - 122) & 511)]) + ((0.0177007355f * fVec20[((IOTA - 121) & 511)]) + ((0.0184636991f * fVec20[((IOTA - 120) & 511)]) + ((0.0203863643f * fVec20[((IOTA - 119) & 511)]) + ((0.0217596982f * fVec20[((IOTA - 118) & 511)]) + ((0.0188604388f * fVec20[((IOTA - 117) & 511)]) + ((0.0131839961f * fVec20[((IOTA - 116) & 511)]) + ((0.00680562761f * fVec20[((IOTA - 115) & 511)]) + ((0.00845362712f * fVec20[((IOTA - 105) & 511)]) + ((0.0270393994f * fVec20[((IOTA - 104) & 511)]) + ((0.0348216183f * fVec20[((IOTA - 103) & 511)]) + ((0.035523545f * fVec20[((IOTA - 102) & 511)]) + ((0.0139469588f * fVec20[((IOTA - 101) & 511)]) + ((0.0259712525f * fVec20[((IOTA - 96) & 511)]) + ((0.0403454714f * fVec20[((IOTA - 95) & 511)]) + ((0.0321054719f * fVec20[((IOTA - 94) & 511)]) + ((0.00637836847f * fVec20[((IOTA - 90) & 511)]) + ((0.0266121402f * fVec20[((IOTA - 89) & 511)]) + ((0.0480971709f * fVec20[((IOTA - 88) & 511)]) + ((0.0542924292f * fVec20[((IOTA - 87) & 511)]) + ((0.049714651f * fVec20[((IOTA - 86) & 511)]) + ((0.037446212f * fVec20[((IOTA - 85) & 511)]) + ((0.0304574724f * fVec20[((IOTA - 79) & 511)]) + ((0.161961734f * fVec20[((IOTA - 78) & 511)]) + ((0.239661857f * fVec20[((IOTA - 77) & 511)]) + ((0.177892387f * fVec20[((IOTA - 76) & 511)]) + ((0.00457777642f * fVec20[((IOTA - 67) & 511)]) + ((0.00854518265f * fVec20[((IOTA - 66) & 511)]) + ((0.00698873866f * fVec20[((IOTA - 64) & 511)]) + (0.00912503432f * fVec20[((IOTA - 65) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00057985168f * (((((fVec20[((IOTA - 248) & 511)] + fVec20[((IOTA - 275) & 511)]) - fVec20[((IOTA - 341) & 511)]) + fVec20[((IOTA - 350) & 511)]) + fVec20[((IOTA - 351) & 511)]) + fVec20[((IOTA - 505) & 511)]))))))) + (3.05185094e-05f * ((((fVec20[((IOTA - 462) & 511)] - ((((((((((((((((((((((((((((((((((((fTemp21 + fVec20[((IOTA - 8) & 511)]) + fVec20[((IOTA - 9) & 511)]) + fVec20[((IOTA - 10) & 511)]) + fVec20[((IOTA - 11) & 511)]) + fVec20[((IOTA - 12) & 511)]) + fVec20[((IOTA - 15) & 511)]) + fVec20[((IOTA - 16) & 511)]) + fVec20[((IOTA - 17) & 511)]) + fVec20[((IOTA - 19) & 511)]) + fVec20[((IOTA - 20) & 511)]) + fVec20[((IOTA - 21) & 511)]) + fVec20[((IOTA - 22) & 511)]) + fVec20[((IOTA - 23) & 511)]) + fVec20[((IOTA - 24) & 511)]) + fVec20[((IOTA - 28) & 511)]) + fVec20[((IOTA - 30) & 511)]) + fVec20[((IOTA - 32) & 511)]) + fVec20[((IOTA - 34) & 511)]) + fVec20[((IOTA - 35) & 511)]) + fVec20[((IOTA - 37) & 511)]) + fVec20[((IOTA - 39) & 511)]) + fVec20[((IOTA - 40) & 511)]) + fVec20[((IOTA - 41) & 511)]) + fVec20[((IOTA - 42) & 511)]) + fVec20[((IOTA - 43) & 511)]) + fVec20[((IOTA - 47) & 511)]) + fVec20[((IOTA - 51) & 511)]) - fVec20[((IOTA - 52) & 511)]) - fVec20[((IOTA - 53) & 511)]) - fVec20[((IOTA - 54) & 511)]) + fVec20[((IOTA - 55) & 511)]) + fVec20[((IOTA - 287) & 511)]) - fVec20[((IOTA - 363) & 511)]) - fVec20[((IOTA - 399) & 511)]) - fVec20[((IOTA - 400) & 511)]) + fVec20[((IOTA - 454) & 511)])) + fVec20[((IOTA - 464) & 511)]) - fVec20[((IOTA - 485) & 511)]) - fVec20[((IOTA - 508) & 511)])))))) : (iSlow42 ? (iSlow46 ? (((0.000946073793f * ((fVec19[((IOTA - 239) & 511)] - fVec19[((IOTA - 250) & 511)]) - fVec19[((IOTA - 511) & 511)])) + ((0.000640888698f * ((((((((fVec19[((IOTA - 162) & 511)] + fVec19[((IOTA - 201) & 511)]) - fVec19[((IOTA - 236) & 511)]) + fVec19[((IOTA - 296) & 511)]) + fVec19[((IOTA - 300) & 511)]) + fVec19[((IOTA - 343) & 511)]) - fVec19[((IOTA - 502) & 511)]) + fVec19[((IOTA - 508) & 511)]) - fVec19[((IOTA - 510) & 511)])) + ((0.00125125889f * (((fVec19[((IOTA - 277) & 511)] + fVec19[((IOTA - 287) & 511)]) + fVec19[((IOTA - 292) & 511)]) + fVec19[((IOTA - 507) & 511)])) + ((0.00149540696f * (((fVec19[((IOTA - 290) & 511)] + fVec19[((IOTA - 291) & 511)]) - fVec19[((IOTA - 500) & 511)]) + fVec19[((IOTA - 506) & 511)])) + ((0.00131229591f * ((((fVec19[((IOTA - 279) & 511)] + fVec19[((IOTA - 280) & 511)]) + fVec19[((IOTA - 288) & 511)]) - fVec19[((IOTA - 495) & 511)]) + fVec19[((IOTA - 505) & 511)])) + ((0.000793481246f * ((fVec19[((IOTA - 241) & 511)] + fVec19[((IOTA - 356) & 511)]) + fVec19[((IOTA - 504) & 511)])) + ((0.00112918485f * (fVec19[((IOTA - 153) & 511)] - fVec19[((IOTA - 501) & 511)])) + ((0.00210577715f * (fVec19[((IOTA - 233) & 511)] - fVec19[((IOTA - 497) & 511)])) + ((0.00186162908f * (fVec19[((IOTA - 258) & 511)] - fVec19[((IOTA - 496) & 511)])) + ((0.000305185094f * ((((((((((((fVec19[((IOTA - 27) & 511)] + fVec19[((IOTA - 194) & 511)]) + fVec19[((IOTA - 262) & 511)]) + fVec19[((IOTA - 332) & 511)]) + fVec19[((IOTA - 333) & 511)]) + fVec19[((IOTA - 371) & 511)]) + fVec19[((IOTA - 399) & 511)]) + fVec19[((IOTA - 416) & 511)]) + fVec19[((IOTA - 421) & 511)]) + fVec19[((IOTA - 437) & 511)]) + fVec19[((IOTA - 439) & 511)]) + fVec19[((IOTA - 461) & 511)]) - fVec19[((IOTA - 494) & 511)])) + ((0.00204474013f * fVec19[((IOTA - 491) & 511)]) + ((0.00106814783f * fVec19[((IOTA - 489) & 511)]) + ((0.000518814661f * ((((((((fVec19[((IOTA - 30) & 511)] + fVec19[((IOTA - 211) & 511)]) - fVec19[((IOTA - 252) & 511)]) + fVec19[((IOTA - 269) & 511)]) + fVec19[((IOTA - 316) & 511)]) + fVec19[((IOTA - 323) & 511)]) + fVec19[((IOTA - 401) & 511)]) - fVec19[((IOTA - 470) & 511)]) + fVec19[((IOTA - 488) & 511)])) + ((0.000213629566f * (((((((((fVec19[((IOTA - 25) & 511)] + fVec19[((IOTA - 235) & 511)]) + fVec19[((IOTA - 266) & 511)]) + fVec19[((IOTA - 320) & 511)]) + fVec19[((IOTA - 367) & 511)]) + fVec19[((IOTA - 394) & 511)]) + fVec19[((IOTA - 395) & 511)]) + fVec19[((IOTA - 427) & 511)]) + fVec19[((IOTA - 441) & 511)]) + fVec19[((IOTA - 487) & 511)])) + ((0.000732444227f * ((fVec19[((IOTA - 282) & 511)] + fVec19[((IOTA - 479) & 511)]) - fVec19[((IOTA - 485) & 511)])) + ((0.00213629566f * (fVec19[((IOTA - 477) & 511)] - fVec19[((IOTA - 481) & 511)])) + ((0.000762962736f * (((fVec19[((IOTA - 298) & 511)] + fVec19[((IOTA - 342) & 511)]) + fVec19[((IOTA - 357) & 511)]) - fVec19[((IOTA - 480) & 511)])) + ((0.00122074038f * (fVec19[((IOTA - 278) & 511)] + fVec19[((IOTA - 475) & 511)])) + ((0.000610370189f * ((((((((fVec19[((IOTA - 219) & 511)] + fVec19[((IOTA - 221) & 511)]) + fVec19[((IOTA - 243) & 511)]) + fVec19[((IOTA - 268) & 511)]) + fVec19[((IOTA - 295) & 511)]) + fVec19[((IOTA - 314) & 511)]) + fVec19[((IOTA - 345) & 511)]) + fVec19[((IOTA - 346) & 511)]) + fVec19[((IOTA - 474) & 511)])) + ((0.000152592547f * (((((((((((((((((fVec19[((IOTA - 23) & 511)] + fVec19[((IOTA - 32) & 511)]) - fVec19[((IOTA - 264) & 511)]) + fVec19[((IOTA - 325) & 511)]) + fVec19[((IOTA - 326) & 511)]) + fVec19[((IOTA - 361) & 511)]) + fVec19[((IOTA - 364) & 511)]) + fVec19[((IOTA - 365) & 511)]) + fVec19[((IOTA - 368) & 511)]) + fVec19[((IOTA - 369) & 511)]) + fVec19[((IOTA - 370) & 511)]) + fVec19[((IOTA - 375) & 511)]) - fVec19[((IOTA - 382) & 511)]) - fVec19[((IOTA - 406) & 511)]) - fVec19[((IOTA - 407) & 511)]) - fVec19[((IOTA - 408) & 511)]) + fVec19[((IOTA - 431) & 511)]) + fVec19[((IOTA - 473) & 511)])) + ((6.10370189e-05f * ((((((((((((((((fVec19[((IOTA - 13) & 511)] - fVec19[((IOTA - 33) & 511)]) + fVec19[((IOTA - 45) & 511)]) + fVec19[((IOTA - 47) & 511)]) + fVec19[((IOTA - 57) & 511)]) + fVec19[((IOTA - 63) & 511)]) - fVec19[((IOTA - 64) & 511)]) + fVec19[((IOTA - 65) & 511)]) + fVec19[((IOTA - 67) & 511)]) - fVec19[((IOTA - 68) & 511)]) + fVec19[((IOTA - 238) & 511)]) + fVec19[((IOTA - 311) & 511)]) + fVec19[((IOTA - 387) & 511)]) + fVec19[((IOTA - 412) & 511)]) + fVec19[((IOTA - 432) & 511)]) - fVec19[((IOTA - 444) & 511)]) - fVec19[((IOTA - 464) & 511)])) + ((0.000457777642f * (((((((fVec19[((IOTA - 304) & 511)] + fVec19[((IOTA - 313) & 511)]) + fVec19[((IOTA - 328) & 511)]) + fVec19[((IOTA - 348) & 511)]) + fVec19[((IOTA - 359) & 511)]) + fVec19[((IOTA - 400) & 511)]) + fVec19[((IOTA - 456) & 511)]) + fVec19[((IOTA - 459) & 511)])) + ((0.000396740623f * (((((fVec19[((IOTA - 283) & 511)] + fVec19[((IOTA - 321) & 511)]) + fVec19[((IOTA - 349) & 511)]) + fVec19[((IOTA - 374) & 511)]) + fVec19[((IOTA - 428) & 511)]) + fVec19[((IOTA - 458) & 511)])) + ((0.000488296151f * (((((((fVec19[((IOTA - 206) & 511)] + fVec19[((IOTA - 267) & 511)]) + fVec19[((IOTA - 336) & 511)]) + fVec19[((IOTA - 373) & 511)]) + fVec19[((IOTA - 417) & 511)]) + fVec19[((IOTA - 419) & 511)]) + fVec19[((IOTA - 429) & 511)]) + fVec19[((IOTA - 455) & 511)])) + ((0.000274666585f * ((((((((fVec19[((IOTA - 301) & 511)] + fVec19[((IOTA - 324) & 511)]) + fVec19[((IOTA - 331) & 511)]) + fVec19[((IOTA - 360) & 511)]) + fVec19[((IOTA - 403) & 511)]) + fVec19[((IOTA - 434) & 511)]) + fVec19[((IOTA - 438) & 511)]) + fVec19[((IOTA - 440) & 511)]) + fVec19[((IOTA - 453) & 511)])) + ((0.00183111057f * fVec19[((IOTA - 476) & 511)]) + ((0.000335703604f * (((((fVec19[((IOTA - 284) & 511)] + fVec19[((IOTA - 308) & 511)]) + fVec19[((IOTA - 330) & 511)]) + fVec19[((IOTA - 350) & 511)]) + fVec19[((IOTA - 435) & 511)]) + fVec19[((IOTA - 436) & 511)])) + ((0.000244148076f * ((((fVec19[((IOTA - 312) & 511)] - (((fVec19[((IOTA - 26) & 511)] - fVec19[((IOTA - 179) & 511)]) - fVec19[((IOTA - 254) & 511)]) - fVec19[((IOTA - 256) & 511)])) + fVec19[((IOTA - 318) & 511)]) - fVec19[((IOTA - 423) & 511)]) - fVec19[((IOTA - 425) & 511)])) + ((0.00054933317f * (((fVec19[((IOTA - 270) & 511)] + fVec19[((IOTA - 285) & 511)]) + fVec19[((IOTA - 354) & 511)]) + fVec19[((IOTA - 418) & 511)])) + ((0.000915555283f * (((fVec19[((IOTA - 193) & 511)] - fVec19[((IOTA - 210) & 511)]) + fVec19[((IOTA - 293) & 511)]) + fVec19[((IOTA - 341) & 511)])) + ((0.00100711081f * (((fVec19[((IOTA - 271) & 511)] + fVec19[((IOTA - 286) & 511)]) + fVec19[((IOTA - 339) & 511)]) + fVec19[((IOTA - 340) & 511)])) + ((0.000885036774f * ((fVec19[((IOTA - 225) & 511)] + fVec19[((IOTA - 306) & 511)]) + fVec19[((IOTA - 338) & 511)])) + ((0.000701925717f * ((fVec19[((IOTA - 208) & 511)] + fVec19[((IOTA - 294) & 511)]) + fVec19[((IOTA - 297) & 511)])) + ((0.00152592547f * fVec19[((IOTA - 276) & 511)]) + ((0.0019531846f * (fVec19[((IOTA - 81) & 511)] + fVec19[((IOTA - 275) & 511)])) + ((0.0022583697f * (fVec19[((IOTA - 217) & 511)] + fVec19[((IOTA - 274) & 511)])) + ((0.00167851802f * (fVec19[((IOTA - 111) & 511)] + fVec19[((IOTA - 272) & 511)])) + ((0.00207525864f * fVec19[((IOTA - 260) & 511)]) + ((0.000854518265f * fVec19[((IOTA - 257) & 511)]) + ((0.00119022187f * (fVec19[((IOTA - 244) & 511)] + fVec19[((IOTA - 246) & 511)])) + ((0.00146488845f * fVec19[((IOTA - 245) & 511)]) + ((0.00115970336f * ((fVec19[((IOTA - 69) & 511)] + fVec19[((IOTA - 218) & 511)]) + fVec19[((IOTA - 240) & 511)])) + ((0.00222785119f * fVec19[((IOTA - 231) & 511)]) + ((0.00198370311f * fVec19[((IOTA - 230) & 511)]) + ((0.00329599902f * fVec19[((IOTA - 228) & 511)]) + ((0.00369273964f * fVec19[((IOTA - 227) & 511)]) + ((0.00268562883f * fVec19[((IOTA - 226) & 511)]) + ((0.00292977691f * fVec19[((IOTA - 216) & 511)]) + ((0.00308236945f * fVec19[((IOTA - 215) & 511)]) + ((0.00320444349f * fVec19[((IOTA - 214) & 511)]) + ((0.00326548051f * (fVec19[((IOTA - 158) & 511)] + fVec19[((IOTA - 213) & 511)])) + ((0.00234992523f * fVec19[((IOTA - 212) & 511)]) + ((0.00140385143f * fVec19[((IOTA - 207) & 511)]) + ((0.00271614734f * (fVec19[((IOTA - 175) & 511)] - fVec19[((IOTA - 203) & 511)])) + ((0.00344859157f * fVec19[((IOTA - 200) & 511)]) + ((0.00332651753f * fVec19[((IOTA - 199) & 511)]) + ((0.00265511032f * (fVec19[((IOTA - 188) & 511)] - fVec19[((IOTA - 195) & 511)])) + ((0.00247199927f * (fVec19[((IOTA - 154) & 511)] + fVec19[((IOTA - 186) & 511)])) + ((0.00857570115f * fVec19[((IOTA - 174) & 511)]) + ((0.011200293f * fVec19[((IOTA - 173) & 511)]) + ((0.0101321451f * fVec19[((IOTA - 172) & 511)]) + ((0.00637836847f * fVec19[((IOTA - 171) & 511)]) + ((0.00375377666f * fVec19[((IOTA - 170) & 511)]) + ((0.00155644398f * fVec19[((IOTA - 169) & 511)]) + ((0.0019226661f * (fVec19[((IOTA - 84) & 511)] - fVec19[((IOTA - 167) & 511)])) + ((0.0112308115f * fVec19[((IOTA - 161) & 511)]) + ((0.015991699f * fVec19[((IOTA - 160) & 511)]) + ((0.0118411817f * fVec19[((IOTA - 159) & 511)]) + ((0.00918607134f * fVec19[((IOTA - 147) & 511)]) + ((0.0148625141f * fVec19[((IOTA - 146) & 511)]) + ((0.0181585141f * fVec19[((IOTA - 145) & 511)]) + ((0.0196844395f * fVec19[((IOTA - 144) & 511)]) + ((0.0166631062f * fVec19[((IOTA - 143) & 511)]) + ((0.00619525742f * fVec19[((IOTA - 142) & 511)]) + ((0.00939970091f * fVec19[((IOTA - 133) & 511)]) + ((0.0228278451f * fVec19[((IOTA - 132) & 511)]) + ((0.0246589556f * fVec19[((IOTA - 131) & 511)]) + ((0.0149845881f * fVec19[((IOTA - 130) & 511)]) + ((0.00439466536f * fVec19[((IOTA - 129) & 511)]) + ((0.00396740623f * fVec19[((IOTA - 118) & 511)]) + ((0.0104068117f * fVec19[((IOTA - 117) & 511)]) + ((0.0115970336f * fVec19[((IOTA - 116) & 511)]) + ((0.0131839961f * fVec19[((IOTA - 115) & 511)]) + ((0.0221564379f * fVec19[((IOTA - 114) & 511)]) + ((0.0308847316f * fVec19[((IOTA - 113) & 511)]) + ((0.0206305124f * fVec19[((IOTA - 112) & 511)]) + ((0.00415051728f * fVec19[((IOTA - 103) & 511)]) + ((0.0369579159f * fVec19[((IOTA - 102) & 511)]) + ((0.0541703552f * fVec19[((IOTA - 101) & 511)]) + ((0.0480666533f * fVec19[((IOTA - 100) & 511)]) + ((0.0150456252f * fVec19[((IOTA - 99) & 511)]) + ((0.00961333048f * fVec19[((IOTA - 88) & 511)]) + ((0.034028139f * fVec19[((IOTA - 87) & 511)]) + ((0.049836725f * fVec19[((IOTA - 86) & 511)]) + ((0.0441908017f * fVec19[((IOTA - 85) & 511)]) + ((0.0411694683f * fVec19[((IOTA - 80) & 511)]) + ((0.00924710836f * fVec19[((IOTA - 79) & 511)]) + ((0.183782458f * fVec19[((IOTA - 74) & 511)]) + ((0.287728518f * fVec19[((IOTA - 73) & 511)]) + ((0.220831931f * fVec19[((IOTA - 72) & 511)]) + ((0.091830194f * fVec19[((IOTA - 71) & 511)]) + ((0.00177007355f * fVec19[((IOTA - 28) & 511)]) + (0.0174871068f * fVec19[((IOTA - 70) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00180059206f * ((fVec19[((IOTA - 192) & 511)] - fVec19[((IOTA - 478) & 511)]) + fVec19[((IOTA - 499) & 511)])) + ((0.00201422162f * fVec19[((IOTA - 498) & 511)]) + ((0.000823999755f * (((fVec19[((IOTA - 185) & 511)] - fVec19[((IOTA - 299) & 511)]) - fVec19[((IOTA - 305) & 511)]) - fVec19[((IOTA - 493) & 511)])) + ((0.00170903653f * ((fVec19[((IOTA - 484) & 511)] - fVec19[((IOTA - 490) & 511)]) - fVec19[((IOTA - 492) & 511)])) + ((0.0025940733f * fVec19[((IOTA - 483) & 511)]) + ((0.00280770287f * fVec19[((IOTA - 482) & 511)]) + ((0.000183111057f * (((((((((((fVec19[((IOTA - 24) & 511)] + fVec19[((IOTA - 31) & 511)]) - fVec19[((IOTA - 222) & 511)]) - fVec19[((IOTA - 366) & 511)]) + fVec19[((IOTA - 381) & 511)]) - fVec19[((IOTA - 396) & 511)]) - fVec19[((IOTA - 398) & 511)]) - fVec19[((IOTA - 450) & 511)]) - fVec19[((IOTA - 451) & 511)]) - fVec19[((IOTA - 452) & 511)]) + fVec19[((IOTA - 468) & 511)]) + fVec19[((IOTA - 472) & 511)])) + ((0.000427259132f * (((((((((((fVec19[((IOTA - 223) & 511)] + fVec19[((IOTA - 249) & 511)]) - fVec19[((IOTA - 329) & 511)]) - fVec19[((IOTA - 353) & 511)]) - fVec19[((IOTA - 372) & 511)]) - fVec19[((IOTA - 402) & 511)]) - fVec19[((IOTA - 420) & 511)]) - fVec19[((IOTA - 454) & 511)]) - fVec19[((IOTA - 457) & 511)]) - fVec19[((IOTA - 460) & 511)]) + fVec19[((IOTA - 469) & 511)]) + fVec19[((IOTA - 471) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((((((((fVec19[((IOTA - 8) & 511)] - ((((fVec19[((IOTA - 1) & 511)] + fVec19[((IOTA - 3) & 511)]) + fVec19[((IOTA - 5) & 511)]) - fVec19[((IOTA - 6) & 511)]) + fVec19[((IOTA - 7) & 511)])) - fVec19[((IOTA - 9) & 511)]) + fVec19[((IOTA - 10) & 511)]) - fVec19[((IOTA - 11) & 511)]) + fVec19[((IOTA - 12) & 511)]) + fVec19[((IOTA - 14) & 511)]) + fVec19[((IOTA - 16) & 511)]) - fVec19[((IOTA - 34) & 511)]) + fVec19[((IOTA - 35) & 511)]) - fVec19[((IOTA - 39) & 511)]) + fVec19[((IOTA - 40) & 511)]) - fVec19[((IOTA - 41) & 511)]) - fVec19[((IOTA - 43) & 511)]) - fVec19[((IOTA - 44) & 511)]) - fVec19[((IOTA - 46) & 511)]) + fVec19[((IOTA - 50) & 511)]) - fVec19[((IOTA - 53) & 511)]) + fVec19[((IOTA - 54) & 511)]) - fVec19[((IOTA - 55) & 511)]) + fVec19[((IOTA - 56) & 511)]) - fVec19[((IOTA - 58) & 511)]) - fVec19[((IOTA - 60) & 511)]) + fVec19[((IOTA - 66) & 511)]) + fVec19[((IOTA - 198) & 511)]) - fVec19[((IOTA - 253) & 511)]) - fVec19[((IOTA - 310) & 511)]) - fVec19[((IOTA - 376) & 511)]) - fVec19[((IOTA - 377) & 511)]) + fVec19[((IOTA - 380) & 511)]) + fVec19[((IOTA - 383) & 511)]) - fVec19[((IOTA - 386) & 511)]) + fVec19[((IOTA - 405) & 511)]) - fVec19[((IOTA - 410) & 511)]) + fVec19[((IOTA - 413) & 511)]) - fVec19[((IOTA - 422) & 511)]) + fVec19[((IOTA - 426) & 511)]) - fVec19[((IOTA - 448) & 511)]) - fVec19[((IOTA - 465) & 511)]) - fVec19[((IOTA - 467) & 511)])) + ((0.000122074038f * ((((((((((((((((((((fVec19[((IOTA - 20) & 511)] - fVec19[((IOTA - 21) & 511)]) + fVec19[((IOTA - 22) & 511)]) - fVec19[((IOTA - 59) & 511)]) + fVec19[((IOTA - 148) & 511)]) + fVec19[((IOTA - 168) & 511)]) - fVec19[((IOTA - 248) & 511)]) - fVec19[((IOTA - 255) & 511)]) + fVec19[((IOTA - 263) & 511)]) - fVec19[((IOTA - 319) & 511)]) - fVec19[((IOTA - 363) & 511)]) - fVec19[((IOTA - 378) & 511)]) - fVec19[((IOTA - 388) & 511)]) - fVec19[((IOTA - 389) & 511)]) - fVec19[((IOTA - 393) & 511)]) - fVec19[((IOTA - 397) & 511)]) - fVec19[((IOTA - 433) & 511)]) + fVec19[((IOTA - 445) & 511)]) + fVec19[((IOTA - 446) & 511)]) - fVec19[((IOTA - 449) & 511)]) - fVec19[((IOTA - 466) & 511)])) + ((0.000366222113f * (((((((((fVec19[((IOTA - 224) & 511)] - fVec19[((IOTA - 242) & 511)]) - fVec19[((IOTA - 317) & 511)]) - fVec19[((IOTA - 327) & 511)]) - fVec19[((IOTA - 334) & 511)]) - fVec19[((IOTA - 335) & 511)]) - fVec19[((IOTA - 351) & 511)]) - fVec19[((IOTA - 352) & 511)]) + fVec19[((IOTA - 424) & 511)]) - fVec19[((IOTA - 430) & 511)])) + ((0.000671407208f * ((((((fVec19[((IOTA - 237) & 511)] - fVec19[((IOTA - 220) & 511)]) - fVec19[((IOTA - 247) & 511)]) - fVec19[((IOTA - 307) & 511)]) - fVec19[((IOTA - 337) & 511)]) - fVec19[((IOTA - 355) & 511)]) - fVec19[((IOTA - 358) & 511)])) + ((0.00057985168f * ((((fVec19[((IOTA - 209) & 511)] - fVec19[((IOTA - 315) & 511)]) - fVec19[((IOTA - 322) & 511)]) - fVec19[((IOTA - 344) & 511)]) - fVec19[((IOTA - 347) & 511)])) + ((0.00134281442f * ((fVec19[((IOTA - 189) & 511)] - fVec19[((IOTA - 234) & 511)]) - fVec19[((IOTA - 289) & 511)])) + ((0.00109866634f * ((fVec19[((IOTA - 205) & 511)] - fVec19[((IOTA - 261) & 511)]) - fVec19[((IOTA - 281) & 511)])) + ((0.00219733268f * (fVec19[((IOTA - 204) & 511)] - fVec19[((IOTA - 273) & 511)])) + ((0.00241096225f * ((fVec19[((IOTA - 155) & 511)] - fVec19[((IOTA - 232) & 511)]) - fVec19[((IOTA - 259) & 511)])) + ((0.000976592302f * fVec19[((IOTA - 251) & 511)]) + ((0.00231940672f * (fVec19[((IOTA - 29) & 511)] - fVec19[((IOTA - 229) & 511)])) + ((0.00173955504f * fVec19[((IOTA - 202) & 511)]) + ((0.00381481368f * fVec19[((IOTA - 197) & 511)]) + ((0.00488296151f * fVec19[((IOTA - 196) & 511)]) + ((0.00399792474f * (fVec19[((IOTA - 181) & 511)] - fVec19[((IOTA - 187) & 511)])) + ((0.00503555406f * fVec19[((IOTA - 184) & 511)]) + ((0.00811792351f * fVec19[((IOTA - 183) & 511)]) + ((0.00784325693f * fVec19[((IOTA - 182) & 511)]) + ((0.00479140598f * fVec19[((IOTA - 191) & 511)]) + ((0.00286873989f * fVec19[((IOTA - 178) & 511)]) + ((0.00473036896f * fVec19[((IOTA - 177) & 511)]) + ((0.00302133244f * fVec19[((IOTA - 176) & 511)]) + ((0.00469985045f * fVec19[((IOTA - 190) & 511)]) + ((0.00402844325f * fVec19[((IOTA - 166) & 511)]) + ((0.00738547929f * fVec19[((IOTA - 165) & 511)]) + ((0.0103457747f * fVec19[((IOTA - 164) & 511)]) + ((0.00820947904f * fVec19[((IOTA - 163) & 511)]) + ((0.00393688772f * fVec19[((IOTA - 157) & 511)]) + ((0.00610370189f * fVec19[((IOTA - 156) & 511)]) + ((0.00842310861f * fVec19[((IOTA - 152) & 511)]) + ((0.0177312549f * fVec19[((IOTA - 151) & 511)]) + ((0.0191656239f * fVec19[((IOTA - 150) & 511)]) + ((0.0117191076f * fVec19[((IOTA - 149) & 511)]) + ((0.00680562761f * fVec19[((IOTA - 141) & 511)]) + ((0.0177922919f * fVec19[((IOTA - 140) & 511)]) + ((0.0228583645f * fVec19[((IOTA - 139) & 511)]) + ((0.022705771f * fVec19[((IOTA - 138) & 511)]) + ((0.02252266f * fVec19[((IOTA - 137) & 511)]) + ((0.022766808f * fVec19[((IOTA - 136) & 511)]) + ((0.0191351064f * fVec19[((IOTA - 135) & 511)]) + ((0.00753807183f * fVec19[((IOTA - 134) & 511)]) + ((0.00527970213f * fVec19[((IOTA - 128) & 511)]) + ((0.0154728843f * fVec19[((IOTA - 127) & 511)]) + ((0.0222479943f * fVec19[((IOTA - 126) & 511)]) + ((0.0224921424f * fVec19[((IOTA - 125) & 511)]) + ((0.0238044374f * fVec19[((IOTA - 124) & 511)]) + ((0.0277718436f * fVec19[((IOTA - 123) & 511)]) + ((0.0321359895f * fVec19[((IOTA - 122) & 511)]) + ((0.0295419171f * fVec19[((IOTA - 121) & 511)]) + ((0.0198065136f * fVec19[((IOTA - 120) & 511)]) + ((0.0074159978f * fVec19[((IOTA - 119) & 511)]) + ((0.00671407208f * fVec19[((IOTA - 110) & 511)]) + ((0.00964384899f * fVec19[((IOTA - 109) & 511)]) + ((0.0119632557f * fVec19[((IOTA - 108) & 511)]) + ((0.021332439f * fVec19[((IOTA - 107) & 511)]) + ((0.0343028046f * fVec19[((IOTA - 106) & 511)]) + ((0.0444654673f * fVec19[((IOTA - 105) & 511)]) + ((0.0303353984f * fVec19[((IOTA - 104) & 511)]) + ((0.0260628071f * fVec19[((IOTA - 98) & 511)]) + ((0.0486770235f * fVec19[((IOTA - 97) & 511)]) + ((0.0453810245f * fVec19[((IOTA - 96) & 511)]) + ((0.0255745109f * fVec19[((IOTA - 95) & 511)]) + ((0.0121768853f * fVec19[((IOTA - 94) & 511)]) + ((0.0126041444f * fVec19[((IOTA - 93) & 511)]) + ((0.0292672515f * fVec19[((IOTA - 92) & 511)]) + ((0.0418103598f * fVec19[((IOTA - 91) & 511)]) + ((0.0422376171f * fVec19[((IOTA - 90) & 511)]) + ((0.0247505121f * fVec19[((IOTA - 89) & 511)]) + ((0.035828732f * fVec19[((IOTA - 83) & 511)]) + ((0.0433057658f * fVec19[((IOTA - 82) & 511)]) + ((0.103701897f * fVec19[((IOTA - 78) & 511)]) + ((0.23139134f * fVec19[((IOTA - 77) & 511)]) + ((0.0395519882f * fVec19[((IOTA - 75) & 511)]) + (0.214911342f * fVec19[((IOTA - 76) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (9.15555283e-05f * (((((((((((((((((((((((((fVec19[((IOTA - 18) & 511)] - (fVec19[((IOTA - 15) & 511)] + fVec19[((IOTA - 17) & 511)])) - fVec19[((IOTA - 19) & 511)]) - fVec19[((IOTA - 61) & 511)]) + fVec19[((IOTA - 180) & 511)]) + fVec19[((IOTA - 265) & 511)]) - fVec19[((IOTA - 303) & 511)]) - fVec19[((IOTA - 309) & 511)]) - fVec19[((IOTA - 362) & 511)]) - fVec19[((IOTA - 379) & 511)]) - fVec19[((IOTA - 384) & 511)]) - fVec19[((IOTA - 385) & 511)]) - fVec19[((IOTA - 390) & 511)]) - fVec19[((IOTA - 391) & 511)]) - fVec19[((IOTA - 392) & 511)]) - fVec19[((IOTA - 404) & 511)]) + fVec19[((IOTA - 409) & 511)]) - fVec19[((IOTA - 411) & 511)]) - fVec19[((IOTA - 415) & 511)]) - fVec19[((IOTA - 442) & 511)]) + fVec19[((IOTA - 447) & 511)]) - fVec19[((IOTA - 462) & 511)]) + fVec19[((IOTA - 463) & 511)]) + fVec19[((IOTA - 486) & 511)]) - fVec19[((IOTA - 503) & 511)]) + fVec19[((IOTA - 509) & 511)])))) : (((0.000915555283f * (((fVec18[((IOTA - 263) & 511)] + fVec18[((IOTA - 317) & 511)]) + fVec18[((IOTA - 436) & 511)]) + fVec18[((IOTA - 511) & 511)])) + ((0.00180059206f * (fVec18[((IOTA - 244) & 511)] + fVec18[((IOTA - 510) & 511)])) + ((0.00228888821f * (fVec18[((IOTA - 246) & 511)] + fVec18[((IOTA - 509) & 511)])) + ((0.00155644398f * fVec18[((IOTA - 507) & 511)]) + ((0.000976592302f * ((((((fVec18[((IOTA - 172) & 511)] + fVec18[((IOTA - 299) & 511)]) + fVec18[((IOTA - 304) & 511)]) + fVec18[((IOTA - 323) & 511)]) + fVec18[((IOTA - 363) & 511)]) + fVec18[((IOTA - 364) & 511)]) + fVec18[((IOTA - 506) & 511)])) + ((0.00057985168f * (((((fVec18[((IOTA - 407) & 511)] - (((((((((((((fVec18[((IOTA - 226) & 511)] - fVec18[((IOTA - 252) & 511)]) - fVec18[((IOTA - 264) & 511)]) + fVec18[((IOTA - 282) & 511)]) - fVec18[((IOTA - 335) & 511)]) - fVec18[((IOTA - 348) & 511)]) - fVec18[((IOTA - 350) & 511)]) - fVec18[((IOTA - 379) & 511)]) - fVec18[((IOTA - 380) & 511)]) - fVec18[((IOTA - 381) & 511)]) - fVec18[((IOTA - 382) & 511)]) - fVec18[((IOTA - 386) & 511)]) - fVec18[((IOTA - 387) & 511)]) - fVec18[((IOTA - 396) & 511)])) + fVec18[((IOTA - 411) & 511)]) + fVec18[((IOTA - 459) & 511)]) + fVec18[((IOTA - 470) & 511)]) + fVec18[((IOTA - 505) & 511)])) + ((0.000335703604f * (fVec18[((IOTA - 423) & 511)] - fVec18[((IOTA - 503) & 511)])) + ((0.00125125889f * (((fVec18[((IOTA - 206) & 511)] + fVec18[((IOTA - 294) & 511)]) + fVec18[((IOTA - 306) & 511)]) - fVec18[((IOTA - 502) & 511)])) + ((0.00244148076f * (fVec18[((IOTA - 495) & 511)] - fVec18[((IOTA - 500) & 511)])) + ((0.000671407208f * ((fVec18[((IOTA - 471) & 511)] - ((((((((((fVec18[((IOTA - 180) & 511)] - fVec18[((IOTA - 334) & 511)]) - fVec18[((IOTA - 339) & 511)]) - fVec18[((IOTA - 347) & 511)]) - fVec18[((IOTA - 352) & 511)]) - fVec18[((IOTA - 412) & 511)]) - fVec18[((IOTA - 413) & 511)]) - fVec18[((IOTA - 421) & 511)]) - fVec18[((IOTA - 455) & 511)]) - fVec18[((IOTA - 456) & 511)]) - fVec18[((IOTA - 458) & 511)])) - fVec18[((IOTA - 498) & 511)])) + ((0.00198370311f * (fVec18[((IOTA - 232) & 511)] + fVec18[((IOTA - 496) & 511)])) + ((0.0022583697f * fVec18[((IOTA - 494) & 511)]) + ((0.00167851802f * (((fVec18[((IOTA - 234) & 511)] + fVec18[((IOTA - 278) & 511)]) + fVec18[((IOTA - 293) & 511)]) + fVec18[((IOTA - 493) & 511)])) + ((6.10370189e-05f * (((((((((((fVec18[((IOTA - 29) & 511)] + fVec18[((IOTA - 31) & 511)]) - fVec18[((IOTA - 34) & 511)]) - fVec18[((IOTA - 51) & 511)]) + fVec18[((IOTA - 61) & 511)]) + fVec18[((IOTA - 65) & 511)]) + fVec18[((IOTA - 75) & 511)]) + fVec18[((IOTA - 81) & 511)]) - fVec18[((IOTA - 82) & 511)]) + fVec18[((IOTA - 83) & 511)]) + fVec18[((IOTA - 442) & 511)]) - fVec18[((IOTA - 489) & 511)])) + ((3.05185094e-05f * ((((((((((((((((((((((((((((fVec18[((IOTA - 7) & 511)] + fVec18[((IOTA - 17) & 511)]) + fVec18[((IOTA - 19) & 511)]) + fVec18[((IOTA - 21) & 511)]) + fVec18[((IOTA - 23) & 511)]) + fVec18[((IOTA - 25) & 511)]) - fVec18[((IOTA - 26) & 511)]) + fVec18[((IOTA - 27) & 511)]) - fVec18[((IOTA - 28) & 511)]) - fVec18[((IOTA - 30) & 511)]) - fVec18[((IOTA - 32) & 511)]) + fVec18[((IOTA - 52) & 511)]) - fVec18[((IOTA - 53) & 511)]) - fVec18[((IOTA - 58) & 511)]) + fVec18[((IOTA - 59) & 511)]) + fVec18[((IOTA - 62) & 511)]) + fVec18[((IOTA - 64) & 511)]) - fVec18[((IOTA - 68) & 511)]) - fVec18[((IOTA - 70) & 511)]) + fVec18[((IOTA - 71) & 511)]) + fVec18[((IOTA - 73) & 511)]) - fVec18[((IOTA - 74) & 511)]) + fVec18[((IOTA - 76) & 511)]) + fVec18[((IOTA - 78) & 511)]) - fVec18[((IOTA - 84) & 511)]) - fVec18[((IOTA - 86) & 511)]) - fVec18[((IOTA - 236) & 511)]) - fVec18[((IOTA - 243) & 511)]) - fVec18[((IOTA - 487) & 511)])) + ((0.000305185094f * ((((((((fVec18[((IOTA - 45) & 511)] + fVec18[((IOTA - 257) & 511)]) - fVec18[((IOTA - 260) & 511)]) + fVec18[((IOTA - 400) & 511)]) + fVec18[((IOTA - 425) & 511)]) + fVec18[((IOTA - 426) & 511)]) + fVec18[((IOTA - 462) & 511)]) + fVec18[((IOTA - 465) & 511)]) + fVec18[((IOTA - 482) & 511)])) + ((0.000274666585f * ((((((fVec18[((IOTA - 286) & 511)] + fVec18[((IOTA - 327) & 511)]) + fVec18[((IOTA - 329) & 511)]) + fVec18[((IOTA - 399) & 511)]) + fVec18[((IOTA - 463) & 511)]) + fVec18[((IOTA - 464) & 511)]) + fVec18[((IOTA - 481) & 511)])) + ((0.000610370189f * ((((((((((fVec18[((IOTA - 262) & 511)] + fVec18[((IOTA - 300) & 511)]) + fVec18[((IOTA - 322) & 511)]) + fVec18[((IOTA - 351) & 511)]) + fVec18[((IOTA - 383) & 511)]) + fVec18[((IOTA - 384) & 511)]) + fVec18[((IOTA - 388) & 511)]) + fVec18[((IOTA - 393) & 511)]) + fVec18[((IOTA - 414) & 511)]) + fVec18[((IOTA - 416) & 511)]) + fVec18[((IOTA - 479) & 511)])) + ((0.000823999755f * ((((((((fVec18[((IOTA - 332) & 511)] + fVec18[((IOTA - 340) & 511)]) + fVec18[((IOTA - 354) & 511)]) + fVec18[((IOTA - 371) & 511)]) + fVec18[((IOTA - 392) & 511)]) + fVec18[((IOTA - 420) & 511)]) + fVec18[((IOTA - 446) & 511)]) + fVec18[((IOTA - 475) & 511)]) + fVec18[((IOTA - 476) & 511)])) + ((0.000518814661f * ((((((((((((((fVec18[((IOTA - 48) & 511)] - fVec18[((IOTA - 253) & 511)]) - fVec18[((IOTA - 281) & 511)]) + fVec18[((IOTA - 326) & 511)]) + fVec18[((IOTA - 342) & 511)]) + fVec18[((IOTA - 349) & 511)]) + fVec18[((IOTA - 397) & 511)]) + fVec18[((IOTA - 402) & 511)]) + fVec18[((IOTA - 403) & 511)]) + fVec18[((IOTA - 408) & 511)]) + fVec18[((IOTA - 410) & 511)]) + fVec18[((IOTA - 429) & 511)]) + fVec18[((IOTA - 433) & 511)]) + fVec18[((IOTA - 468) & 511)]) + fVec18[((IOTA - 469) & 511)])) + ((0.000488296151f * ((((((((((((fVec18[((IOTA - 258) & 511)] - fVec18[((IOTA - 266) & 511)]) - fVec18[((IOTA - 283) & 511)]) + fVec18[((IOTA - 303) & 511)]) + fVec18[((IOTA - 330) & 511)]) + fVec18[((IOTA - 338) & 511)]) + fVec18[((IOTA - 394) & 511)]) + fVec18[((IOTA - 395) & 511)]) + fVec18[((IOTA - 405) & 511)]) + fVec18[((IOTA - 409) & 511)]) + fVec18[((IOTA - 428) & 511)]) + fVec18[((IOTA - 451) & 511)]) + fVec18[((IOTA - 467) & 511)])) + ((0.000640888698f * ((((fVec18[((IOTA - 345) & 511)] + fVec18[((IOTA - 385) & 511)]) + fVec18[((IOTA - 439) & 511)]) + fVec18[((IOTA - 445) & 511)]) + fVec18[((IOTA - 452) & 511)])) + ((0.000213629566f * ((fVec18[((IOTA - 43) & 511)] + fVec18[((IOTA - 302) & 511)]) + fVec18[((IOTA - 443) & 511)])) + ((0.000793481246f * (fVec18[((IOTA - 497) & 511)] - (((fVec18[((IOTA - 197) & 511)] - fVec18[((IOTA - 315) & 511)]) - fVec18[((IOTA - 472) & 511)]) - fVec18[((IOTA - 478) & 511)]))) + ((0.000946073793f * (((((fVec18[((IOTA - 311) & 511)] + fVec18[((IOTA - 362) & 511)]) + fVec18[((IOTA - 365) & 511)]) + fVec18[((IOTA - 372) & 511)]) + fVec18[((IOTA - 391) & 511)]) + fVec18[((IOTA - 419) & 511)])) + ((0.00119022187f * (((((fVec18[((IOTA - 87) & 511)] + fVec18[((IOTA - 298) & 511)]) + fVec18[((IOTA - 305) & 511)]) + fVec18[((IOTA - 356) & 511)]) + fVec18[((IOTA - 374) & 511)]) + fVec18[((IOTA - 375) & 511)])) + ((0.00106814783f * (fVec18[((IOTA - 324) & 511)] + fVec18[((IOTA - 373) & 511)])) + ((0.00100711081f * ((((((fVec18[((IOTA - 235) & 511)] + fVec18[((IOTA - 248) & 511)]) - fVec18[((IOTA - 270) & 511)]) + fVec18[((IOTA - 295) & 511)]) + fVec18[((IOTA - 296) & 511)]) + fVec18[((IOTA - 355) & 511)]) + fVec18[((IOTA - 361) & 511)])) + ((0.00122074038f * (fVec18[((IOTA - 310) & 511)] + fVec18[((IOTA - 359) & 511)])) + ((0.000152592547f * (((fVec18[((IOTA - 41) & 511)] + fVec18[((IOTA - 50) & 511)]) + fVec18[((IOTA - 285) & 511)]) + fVec18[((IOTA - 441) & 511)])) + ((9.15555283e-05f * (((((((((((((fVec18[((IOTA - 33) & 511)] + fVec18[((IOTA - 35) & 511)]) - fVec18[((IOTA - 36) & 511)]) + fVec18[((IOTA - 37) & 511)]) + fVec18[((IOTA - 63) & 511)]) + fVec18[((IOTA - 77) & 511)]) + fVec18[((IOTA - 79) & 511)]) + fVec18[((IOTA - 85) & 511)]) - fVec18[((IOTA - 171) & 511)]) - fVec18[((IOTA - 187) & 511)]) + fVec18[((IOTA - 259) & 511)]) + fVec18[((IOTA - 265) & 511)]) - fVec18[((IOTA - 280) & 511)]) + fVec18[((IOTA - 320) & 511)])) + ((0.0012817774f * (fVec18[((IOTA - 247) & 511)] + fVec18[((IOTA - 307) & 511)])) + ((0.00115970336f * fVec18[((IOTA - 297) & 511)]) + ((0.00201422162f * ((fVec18[((IOTA - 231) & 511)] + fVec18[((IOTA - 277) & 511)]) + fVec18[((IOTA - 292) & 511)])) + ((0.0019531846f * fVec18[((IOTA - 291) & 511)]) + ((0.00143436994f * (fVec18[((IOTA - 276) & 511)] + fVec18[((IOTA - 290) & 511)])) + ((0.001617481f * fVec18[((IOTA - 250) & 511)]) + ((0.00277718436f * fVec18[((IOTA - 245) & 511)]) + ((0.00183111057f * fVec18[((IOTA - 233) & 511)]) + ((0.00216681417f * fVec18[((IOTA - 218) & 511)]) + ((0.00286873989f * fVec18[((IOTA - 205) & 511)]) + ((0.00137333293f * fVec18[((IOTA - 204) & 511)]) + ((0.00158696249f * fVec18[((IOTA - 193) & 511)]) + ((0.00744651631f * fVec18[((IOTA - 192) & 511)]) + ((0.00982696004f * fVec18[((IOTA - 191) & 511)]) + ((0.00863673817f * fVec18[((IOTA - 190) & 511)]) + ((0.00469985045f * fVec18[((IOTA - 189) & 511)]) + ((0.00207525864f * fVec18[((IOTA - 188) & 511)]) + ((0.00973540451f * fVec18[((IOTA - 179) & 511)]) + ((0.014557329f * fVec18[((IOTA - 178) & 511)]) + ((0.0103762932f * fVec18[((IOTA - 177) & 511)]) + ((0.00173955504f * fVec18[((IOTA - 176) & 511)]) + ((0.00814844202f * fVec18[((IOTA - 165) & 511)]) + ((0.0136417737f * fVec18[((IOTA - 164) & 511)]) + ((0.0167546626f * fVec18[((IOTA - 163) & 511)]) + ((0.0181279946f * fVec18[((IOTA - 162) & 511)]) + ((0.0151066622f * fVec18[((IOTA - 161) & 511)]) + ((0.00463881344f * fVec18[((IOTA - 160) & 511)]) + ((0.00891140476f * fVec18[((IOTA - 151) & 511)]) + ((0.0221869573f * fVec18[((IOTA - 150) & 511)]) + ((0.0238959938f * fVec18[((IOTA - 149) & 511)]) + ((0.0140995514f * fVec18[((IOTA - 148) & 511)]) + ((0.00341807306f * fVec18[((IOTA - 147) & 511)]) + ((0.00476088747f * fVec18[((IOTA - 136) & 511)]) + ((0.0110782189f * fVec18[((IOTA - 135) & 511)]) + ((0.0121158483f * fVec18[((IOTA - 134) & 511)]) + ((0.0137333293f * fVec18[((IOTA - 133) & 511)]) + ((0.022705771f * fVec18[((IOTA - 132) & 511)]) + ((0.0312204361f * fVec18[((IOTA - 131) & 511)]) + ((0.00177007355f * (fVec18[((IOTA - 46) & 511)] + fVec18[((IOTA - 129) & 511)])) + ((0.00509659108f * fVec18[((IOTA - 121) & 511)]) + ((0.0384533219f * fVec18[((IOTA - 120) & 511)]) + ((0.0556657612f * fVec18[((IOTA - 119) & 511)]) + ((0.0493789501f * fVec18[((IOTA - 118) & 511)]) + ((0.0158696249f * fVec18[((IOTA - 117) & 511)]) + ((0.0126651814f * fVec18[((IOTA - 106) & 511)]) + ((0.036896877f * fVec18[((IOTA - 105) & 511)]) + ((0.0524918362f * fVec18[((IOTA - 104) & 511)]) + ((0.0470595434f * fVec18[((IOTA - 103) & 511)]) + ((0.00488296151f * fVec18[((IOTA - 102) & 511)]) + ((0.0045167394f * fVec18[((IOTA - 99) & 511)]) + ((0.0440382101f * fVec18[((IOTA - 98) & 511)]) + ((0.0122379223f * fVec18[((IOTA - 97) & 511)]) + ((0.188360244f * fVec18[((IOTA - 92) & 511)]) + ((0.290749848f * fVec18[((IOTA - 91) & 511)]) + ((0.222205266f * fVec18[((IOTA - 90) & 511)]) + ((0.0174565874f * fVec18[((IOTA - 88) & 511)]) + (0.0922269374f * fVec18[((IOTA - 89) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.0019226661f * fVec18[((IOTA - 499) & 511)]) + ((0.00103762932f * (fVec18[((IOTA - 267) & 511)] - fVec18[((IOTA - 492) & 511)])) + ((0.00054933317f * ((((fVec18[((IOTA - 256) & 511)] - fVec18[((IOTA - 406) & 511)]) - fVec18[((IOTA - 415) & 511)]) - fVec18[((IOTA - 449) & 511)]) - fVec18[((IOTA - 491) & 511)])) + ((0.000183111057f * ((((((((fVec18[((IOTA - 42) & 511)] + fVec18[((IOTA - 49) & 511)]) + fVec18[((IOTA - 211) & 511)]) - fVec18[((IOTA - 225) & 511)]) + fVec18[((IOTA - 284) & 511)]) - fVec18[((IOTA - 287) & 511)]) - fVec18[((IOTA - 328) & 511)]) - fVec18[((IOTA - 486) & 511)]) - fVec18[((IOTA - 490) & 511)])) + ((0.000122074038f * (((fVec18[((IOTA - 38) & 511)] - fVec18[((IOTA - 39) & 511)]) + fVec18[((IOTA - 40) & 511)]) + fVec18[((IOTA - 488) & 511)])) + ((0.000366222113f * (((fVec18[((IOTA - 238) & 511)] + fVec18[((IOTA - 273) & 511)]) - fVec18[((IOTA - 275) & 511)]) - fVec18[((IOTA - 485) & 511)])) + ((0.000457777642f * (((((((fVec18[((IOTA - 237) & 511)] - fVec18[((IOTA - 336) & 511)]) - fVec18[((IOTA - 344) & 511)]) - fVec18[((IOTA - 404) & 511)]) - fVec18[((IOTA - 422) & 511)]) - fVec18[((IOTA - 430) & 511)]) - fVec18[((IOTA - 460) & 511)]) - fVec18[((IOTA - 484) & 511)])) + ((0.000396740623f * (((((((((((fVec18[((IOTA - 239) & 511)] - fVec18[((IOTA - 319) & 511)]) - fVec18[((IOTA - 337) & 511)]) - fVec18[((IOTA - 343) & 511)]) - fVec18[((IOTA - 398) & 511)]) - fVec18[((IOTA - 427) & 511)]) - fVec18[((IOTA - 431) & 511)]) - fVec18[((IOTA - 440) & 511)]) - fVec18[((IOTA - 461) & 511)]) - fVec18[((IOTA - 466) & 511)]) - fVec18[((IOTA - 480) & 511)]) - fVec18[((IOTA - 483) & 511)])) + ((0.000854518265f * (((((((fVec18[((IOTA - 212) & 511)] - fVec18[((IOTA - 316) & 511)]) - fVec18[((IOTA - 325) & 511)]) - fVec18[((IOTA - 366) & 511)]) - fVec18[((IOTA - 437) & 511)]) - fVec18[((IOTA - 473) & 511)]) - fVec18[((IOTA - 474) & 511)]) - fVec18[((IOTA - 477) & 511)])) + ((0.000701925717f * (((((((((fVec18[((IOTA - 224) & 511)] - fVec18[((IOTA - 279) & 511)]) - fVec18[((IOTA - 313) & 511)]) - fVec18[((IOTA - 331) & 511)]) - fVec18[((IOTA - 353) & 511)]) - fVec18[((IOTA - 368) & 511)]) - fVec18[((IOTA - 378) & 511)]) - fVec18[((IOTA - 453) & 511)]) - fVec18[((IOTA - 454) & 511)]) - fVec18[((IOTA - 457) & 511)])) + ((0.000427259132f * ((((fVec18[((IOTA - 271) & 511)] - fVec18[((IOTA - 401) & 511)]) - fVec18[((IOTA - 432) & 511)]) - fVec18[((IOTA - 444) & 511)]) - fVec18[((IOTA - 450) & 511)])) + ((0.000762962736f * (((((((fVec18[((IOTA - 219) & 511)] - fVec18[((IOTA - 333) & 511)]) - fVec18[((IOTA - 341) & 511)]) - fVec18[((IOTA - 367) & 511)]) - fVec18[((IOTA - 370) & 511)]) - fVec18[((IOTA - 389) & 511)]) - fVec18[((IOTA - 438) & 511)]) - fVec18[((IOTA - 448) & 511)])) + ((0.000885036774f * (((((fVec18[((IOTA - 240) & 511)] - fVec18[((IOTA - 377) & 511)]) - fVec18[((IOTA - 390) & 511)]) - fVec18[((IOTA - 418) & 511)]) - fVec18[((IOTA - 435) & 511)]) - fVec18[((IOTA - 447) & 511)])) + ((0.000732444227f * ((((((((fVec18[((IOTA - 229) & 511)] - fVec18[((IOTA - 289) & 511)]) - fVec18[((IOTA - 312) & 511)]) - fVec18[((IOTA - 314) & 511)]) - fVec18[((IOTA - 318) & 511)]) - fVec18[((IOTA - 346) & 511)]) - fVec18[((IOTA - 369) & 511)]) - fVec18[((IOTA - 417) & 511)]) - fVec18[((IOTA - 434) & 511)])) + ((0.00109866634f * (((fVec18[((IOTA - 198) & 511)] - fVec18[((IOTA - 230) & 511)]) - fVec18[((IOTA - 360) & 511)]) - fVec18[((IOTA - 376) & 511)])) + ((0.00131229591f * (((fVec18[((IOTA - 166) & 511)] + fVec18[((IOTA - 216) & 511)]) - fVec18[((IOTA - 357) & 511)]) - fVec18[((IOTA - 358) & 511)])) + ((0.00146488845f * ((fVec18[((IOTA - 241) & 511)] - fVec18[((IOTA - 308) & 511)]) - fVec18[((IOTA - 309) & 511)])) + ((0.00149540696f * fVec18[((IOTA - 269) & 511)]) + ((0.00152592547f * fVec18[((IOTA - 268) & 511)]) + ((0.00134281442f * ((((fVec18[((IOTA - 242) & 511)] - fVec18[((IOTA - 249) & 511)]) - fVec18[((IOTA - 251) & 511)]) + fVec18[((IOTA - 254) & 511)]) + fVec18[((IOTA - 255) & 511)])) + ((0.00219733268f * fVec18[((IOTA - 228) & 511)]) + ((0.00186162908f * fVec18[((IOTA - 227) & 511)]) + ((0.00234992523f * fVec18[((IOTA - 223) & 511)]) + ((0.00360118411f * fVec18[((IOTA - 222) & 511)]) + ((0.00424207281f * fVec18[((IOTA - 221) & 511)]) + ((0.003234962f * fVec18[((IOTA - 220) & 511)]) + ((0.00512710959f * (fVec18[((IOTA - 199) & 511)] + fVec18[((IOTA - 215) & 511)])) + ((0.00625629444f * fVec18[((IOTA - 214) & 511)]) + ((0.00393688772f * fVec18[((IOTA - 213) & 511)]) + ((0.00296029542f * fVec18[((IOTA - 210) & 511)]) + ((0.00607318338f * fVec18[((IOTA - 209) & 511)]) + ((0.0061342204f * fVec18[((IOTA - 208) & 511)]) + ((0.006469924f * fVec18[((IOTA - 202) & 511)]) + ((0.00961333048f * fVec18[((IOTA - 201) & 511)]) + ((0.00915555283f * fVec18[((IOTA - 200) & 511)]) + ((0.00408948027f * fVec18[((IOTA - 196) & 511)]) + ((0.00598162785f * fVec18[((IOTA - 195) & 511)]) + ((0.0042115543f * fVec18[((IOTA - 194) & 511)]) + ((0.00280770287f * fVec18[((IOTA - 207) & 511)]) + ((0.00164799951f * fVec18[((IOTA - 186) & 511)]) + ((0.00338755455f * fVec18[((IOTA - 185) & 511)]) + ((0.00561540574f * fVec18[((IOTA - 184) & 511)]) + ((0.00881984923f * fVec18[((IOTA - 183) & 511)]) + ((0.0116275521f * fVec18[((IOTA - 182) & 511)]) + ((0.00943021942f * fVec18[((IOTA - 181) & 511)]) + ((0.00567644276f * fVec18[((IOTA - 175) & 511)]) + ((0.00796533097f * (fVec18[((IOTA - 152) & 511)] + fVec18[((IOTA - 174) & 511)])) + ((0.00415051728f * fVec18[((IOTA - 173) & 511)]) + ((0.00967436749f * fVec18[((IOTA - 170) & 511)]) + ((0.019226661f * fVec18[((IOTA - 169) & 511)]) + ((0.0207220688f * fVec18[((IOTA - 168) & 511)]) + ((0.013061922f * fVec18[((IOTA - 167) & 511)]) + ((0.00836207159f * fVec18[((IOTA - 159) & 511)]) + ((0.019348735f * fVec18[((IOTA - 158) & 511)]) + ((0.024323253f * fVec18[((IOTA - 157) & 511)]) + ((0.0238654744f * fVec18[((IOTA - 156) & 511)]) + ((0.0232856236f * fVec18[((IOTA - 155) & 511)]) + ((0.0232245866f * fVec18[((IOTA - 154) & 511)]) + ((0.00604266487f * fVec18[((IOTA - 146) & 511)]) + ((0.0160222184f * fVec18[((IOTA - 145) & 511)]) + ((0.0224921424f * fVec18[((IOTA - 144) & 511)]) + ((0.0226142164f * fVec18[((IOTA - 143) & 511)]) + ((0.0238044374f * fVec18[((IOTA - 142) & 511)]) + ((0.0275887325f * fVec18[((IOTA - 141) & 511)]) + ((0.0318308063f * fVec18[((IOTA - 140) & 511)]) + ((0.029114658f * fVec18[((IOTA - 139) & 511)]) + ((0.0193182174f * fVec18[((IOTA - 138) & 511)]) + ((0.00671407208f * fVec18[((IOTA - 137) & 511)]) + ((0.0207525864f * (fVec18[((IOTA - 125) & 511)] - fVec18[((IOTA - 130) & 511)])) + ((0.019470809f * fVec18[((IOTA - 153) & 511)]) + ((0.00643940549f * fVec18[((IOTA - 128) & 511)]) + ((0.0093691824f * fVec18[((IOTA - 127) & 511)]) + ((0.0116885891f * fVec18[((IOTA - 126) & 511)]) + ((0.0331431031f * fVec18[((IOTA - 124) & 511)]) + ((0.043244727f * fVec18[((IOTA - 123) & 511)]) + ((0.0293282885f * fVec18[((IOTA - 122) & 511)]) + ((0.0254219193f * fVec18[((IOTA - 116) & 511)]) + ((0.0477004312f * fVec18[((IOTA - 115) & 511)]) + ((0.0435193963f * fVec18[((IOTA - 114) & 511)]) + ((0.0231635496f * fVec18[((IOTA - 113) & 511)]) + ((0.0100100711f * fVec18[((IOTA - 112) & 511)]) + ((0.0108035523f * fVec18[((IOTA - 111) & 511)]) + ((0.0271919928f * fVec18[((IOTA - 110) & 511)]) + ((0.0394299142f * fVec18[((IOTA - 109) & 511)]) + ((0.0393688791f * fVec18[((IOTA - 108) & 511)]) + ((0.0216986611f * fVec18[((IOTA - 107) & 511)]) + ((0.0330210291f * fVec18[((IOTA - 101) & 511)]) + ((0.0408032462f * fVec18[((IOTA - 100) & 511)]) + ((0.10089419f * fVec18[((IOTA - 96) & 511)]) + ((0.228308976f * fVec18[((IOTA - 95) & 511)]) + ((0.210852385f * fVec18[((IOTA - 94) & 511)]) + ((0.00231940672f * fVec18[((IOTA - 47) & 511)]) + (0.0346079916f * fVec18[((IOTA - 93) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000244148076f * (((((((fVec18[((IOTA - 44) & 511)] + fVec18[((IOTA - 272) & 511)]) + fVec18[((IOTA - 274) & 511)]) - fVec18[((IOTA - 288) & 511)]) - fVec18[((IOTA - 301) & 511)]) - fVec18[((IOTA - 321) & 511)]) - fVec18[((IOTA - 424) & 511)]) - fVec18[((IOTA - 504) & 511)]))) + (0.00210577715f * (((fVec18[((IOTA - 203) & 511)] - fVec18[((IOTA - 217) & 511)]) + fVec18[((IOTA - 501) & 511)]) - fVec18[((IOTA - 508) & 511)]))))) : (iSlow43 ? (((0.00399792474f * ((fVec17[((IOTA - 67) & 511)] - fVec17[((IOTA - 245) & 511)]) + fVec17[((IOTA - 510) & 511)])) + ((0.00393688772f * (fVec17[((IOTA - 501) & 511)] + fVec17[((IOTA - 509) & 511)])) + ((0.00384533219f * ((((((((((fVec17[((IOTA - 148) & 511)] + fVec17[((IOTA - 161) & 511)]) - fVec17[((IOTA - 165) & 511)]) - fVec17[((IOTA - 210) & 511)]) - fVec17[((IOTA - 272) & 511)]) - fVec17[((IOTA - 381) & 511)]) + fVec17[((IOTA - 435) & 511)]) + fVec17[((IOTA - 463) & 511)]) + fVec17[((IOTA - 490) & 511)]) + fVec17[((IOTA - 494) & 511)]) + fVec17[((IOTA - 508) & 511)])) + ((0.00366222113f * ((fVec17[((IOTA - 377) & 511)] + fVec17[((IOTA - 504) & 511)]) + fVec17[((IOTA - 505) & 511)])) + ((0.00457777642f * (fVec17[((IOTA - 498) & 511)] - ((((fVec17[((IOTA - 166) & 511)] + fVec17[((IOTA - 227) & 511)]) + fVec17[((IOTA - 235) & 511)]) + fVec17[((IOTA - 239) & 511)]) - fVec17[((IOTA - 497) & 511)]))) + ((0.00418103579f * ((fVec17[((IOTA - 434) & 511)] + fVec17[((IOTA - 468) & 511)]) + fVec17[((IOTA - 489) & 511)])) + ((0.00576799829f * (fVec17[((IOTA - 446) & 511)] + fVec17[((IOTA - 485) & 511)])) + ((0.00628681295f * fVec17[((IOTA - 484) & 511)]) + ((0.00659199804f * (fVec17[((IOTA - 482) & 511)] + fVec17[((IOTA - 483) & 511)])) + ((0.00601214636f * (fVec17[((IOTA - 428) & 511)] + fVec17[((IOTA - 479) & 511)])) + ((0.00589007232f * fVec17[((IOTA - 478) & 511)]) + ((0.0058290353f * ((fVec17[((IOTA - 475) & 511)] + fVec17[((IOTA - 476) & 511)]) + fVec17[((IOTA - 477) & 511)])) + ((0.00585955381f * fVec17[((IOTA - 474) & 511)]) + ((0.00598162785f * fVec17[((IOTA - 473) & 511)]) + ((0.00610370189f * (fVec17[((IOTA - 430) & 511)] + fVec17[((IOTA - 471) & 511)])) + ((0.00570696127f * fVec17[((IOTA - 470) & 511)]) + ((0.00497451704f * (fVec17[((IOTA - 392) & 511)] + fVec17[((IOTA - 469) & 511)])) + ((0.00350962859f * (fVec17[((IOTA - 455) & 511)] + fVec17[((IOTA - 467) & 511)])) + ((0.00332651753f * (fVec17[((IOTA - 395) & 511)] + fVec17[((IOTA - 464) & 511)])) + ((0.00433362834f * fVec17[((IOTA - 462) & 511)]) + ((0.00479140598f * fVec17[((IOTA - 461) & 511)]) + ((0.0057985168f * fVec17[((IOTA - 458) & 511)]) + ((0.00540177617f * fVec17[((IOTA - 457) & 511)]) + ((0.00308236945f * (((((fVec17[((IOTA - 390) & 511)] + fVec17[((IOTA - 438) & 511)]) + fVec17[((IOTA - 439) & 511)]) + fVec17[((IOTA - 448) & 511)]) + fVec17[((IOTA - 453) & 511)]) + fVec17[((IOTA - 454) & 511)])) + ((0.00704977568f * fVec17[((IOTA - 444) & 511)]) + ((0.00631733146f * fVec17[((IOTA - 429) & 511)]) + ((0.00219733268f * (fVec17[((IOTA - 363) & 511)] + fVec17[((IOTA - 424) & 511)])) + ((0.00177007355f * (fVec17[((IOTA - 362) & 511)] + fVec17[((IOTA - 423) & 511)])) + ((0.00164799951f * fVec17[((IOTA - 422) & 511)]) + ((0.00338755455f * fVec17[((IOTA - 419) & 511)]) + ((0.00405896176f * fVec17[((IOTA - 418) & 511)]) + ((0.0042115543f * fVec17[((IOTA - 417) & 511)]) + ((0.00317392498f * fVec17[((IOTA - 415) & 511)]) + ((0.00106814783f * (fVec17[((IOTA - 399) & 511)] + fVec17[((IOTA - 411) & 511)])) + ((0.00155644398f * fVec17[((IOTA - 402) & 511)]) + ((0.00140385143f * fVec17[((IOTA - 401) & 511)]) + ((0.00280770287f * fVec17[((IOTA - 396) & 511)]) + ((0.00671407208f * fVec17[((IOTA - 445) & 511)]) + ((0.00460829493f * fVec17[((IOTA - 391) & 511)]) + ((0.004852443f * fVec17[((IOTA - 376) & 511)]) + ((9.15555283e-05f * ((((((((((((((((((fVec17[((IOTA - 32) & 511)] + fVec17[((IOTA - 33) & 511)]) + fVec17[((IOTA - 34) & 511)]) + fVec17[((IOTA - 35) & 511)]) + fVec17[((IOTA - 36) & 511)]) + fVec17[((IOTA - 37) & 511)]) + fVec17[((IOTA - 38) & 511)]) + fVec17[((IOTA - 39) & 511)]) + fVec17[((IOTA - 40) & 511)]) + fVec17[((IOTA - 43) & 511)]) + fVec17[((IOTA - 44) & 511)]) + fVec17[((IOTA - 49) & 511)]) + fVec17[((IOTA - 50) & 511)]) + fVec17[((IOTA - 51) & 511)]) + fVec17[((IOTA - 52) & 511)]) + fVec17[((IOTA - 158) & 511)]) + fVec17[((IOTA - 327) & 511)]) + fVec17[((IOTA - 360) & 511)]) - fVec17[((IOTA - 366) & 511)])) + ((0.00103762932f * fVec17[((IOTA - 361) & 511)]) + ((0.000335703604f * (fVec17[((IOTA - 317) & 511)] - fVec17[((IOTA - 331) & 511)])) + ((0.000213629566f * ((fVec17[((IOTA - 54) & 511)] + fVec17[((IOTA - 57) & 511)]) - fVec17[((IOTA - 328) & 511)])) + ((0.000152592547f * ((fVec17[((IOTA - 47) & 511)] + fVec17[((IOTA - 316) & 511)]) - fVec17[((IOTA - 319) & 511)])) + ((0.000183111057f * fVec17[((IOTA - 318) & 511)]) + ((0.000122074038f * ((((fVec17[((IOTA - 45) & 511)] + fVec17[((IOTA - 46) & 511)]) + fVec17[((IOTA - 48) & 511)]) + fVec17[((IOTA - 53) & 511)]) - fVec17[((IOTA - 315) & 511)])) + (((0.00292977691f * (fVec17[((IOTA - 134) & 511)] - fVec17[((IOTA - 211) & 511)])) + ((0.000976592302f * fVec17[((IOTA - 162) & 511)]) + ((0.00543229468f * fVec17[((IOTA - 160) & 511)]) + ((0.00552385021f * fVec17[((IOTA - 159) & 511)]) + ((0.00561540574f * fVec17[((IOTA - 138) & 511)]) + ((0.00891140476f * fVec17[((IOTA - 137) & 511)]) + ((0.0125125889f * fVec17[((IOTA - 136) & 511)]) + ((0.00814844202f * fVec17[((IOTA - 135) & 511)]) + ((0.00781273842f * fVec17[((IOTA - 124) & 511)]) + ((0.0140385143f * fVec17[((IOTA - 123) & 511)]) + ((0.00915555283f * fVec17[((IOTA - 122) & 511)]) + ((0.0141605884f * fVec17[((IOTA - 111) & 511)]) + ((0.0215155501f * fVec17[((IOTA - 110) & 511)]) + ((0.0257881414f * fVec17[((IOTA - 109) & 511)]) + ((0.0187688842f * fVec17[((IOTA - 108) & 511)]) + ((0.0270088818f * fVec17[((IOTA - 107) & 511)]) + ((0.0201116987f * fVec17[((IOTA - 106) & 511)]) + ((0.0183721427f * fVec17[((IOTA - 105) & 511)]) + ((0.0138859218f * fVec17[((IOTA - 104) & 511)]) + ((0.00729392376f * fVec17[((IOTA - 103) & 511)]) + ((0.0323191024f * fVec17[((IOTA - 97) & 511)]) + ((0.0465102084f * fVec17[((IOTA - 96) & 511)]) + ((0.0466628f * fVec17[((IOTA - 95) & 511)]) + ((0.00900296029f * fVec17[((IOTA - 94) & 511)]) + ((0.0419324338f * fVec17[((IOTA - 84) & 511)]) + ((0.0284432508f * fVec17[((IOTA - 83) & 511)]) + ((0.0375988036f * fVec17[((IOTA - 82) & 511)]) + ((0.0166631062f * fVec17[((IOTA - 73) & 511)]) + ((0.185430467f * fVec17[((IOTA - 72) & 511)]) + ((0.327249974f * fVec17[((IOTA - 71) & 511)]) + ((0.312387466f * fVec17[((IOTA - 70) & 511)]) + ((0.157628104f * fVec17[((IOTA - 69) & 511)]) + ((0.0379650258f * fVec17[((IOTA - 68) & 511)]) + ((3.05185094e-05f * ((((((((((((((((((((fVec17[((IOTA - 1) & 511)] + fVec17[((IOTA - 3) & 511)]) + fVec17[((IOTA - 4) & 511)]) + fVec17[((IOTA - 5) & 511)]) + fVec17[((IOTA - 6) & 511)]) + fVec17[((IOTA - 7) & 511)]) + fVec17[((IOTA - 8) & 511)]) + fVec17[((IOTA - 9) & 511)]) + fVec17[((IOTA - 10) & 511)]) + fVec17[((IOTA - 11) & 511)]) + fVec17[((IOTA - 12) & 511)]) + fVec17[((IOTA - 13) & 511)]) + fVec17[((IOTA - 14) & 511)]) + fVec17[((IOTA - 15) & 511)]) + fVec17[((IOTA - 16) & 511)]) + fVec17[((IOTA - 22) & 511)]) + fVec17[((IOTA - 24) & 511)]) + fVec17[((IOTA - 25) & 511)]) + fVec17[((IOTA - 26) & 511)]) + fVec17[((IOTA - 27) & 511)]) + fVec17[((IOTA - 58) & 511)])) + ((6.10370189e-05f * (((((((((((fVec17[((IOTA - 17) & 511)] + fVec17[((IOTA - 18) & 511)]) + fVec17[((IOTA - 19) & 511)]) + fVec17[((IOTA - 20) & 511)]) + fVec17[((IOTA - 21) & 511)]) + fVec17[((IOTA - 23) & 511)]) + fVec17[((IOTA - 28) & 511)]) + fVec17[((IOTA - 29) & 511)]) + fVec17[((IOTA - 30) & 511)]) + fVec17[((IOTA - 31) & 511)]) + fVec17[((IOTA - 41) & 511)]) + fVec17[((IOTA - 42) & 511)])) + (0.000305185094f * (fVec17[((IOTA - 55) & 511)] + fVec17[((IOTA - 56) & 511)]))))))))))))))))))))))))))))))))))))) + (0.000671407208f * fVec17[((IOTA - 389) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00381481368f * ((fVec17[((IOTA - 198) & 511)] - fVec17[((IOTA - 416) & 511)]) - fVec17[((IOTA - 507) & 511)])) + ((0.00372325815f * (((fVec17[((IOTA - 276) & 511)] + fVec17[((IOTA - 386) & 511)]) - fVec17[((IOTA - 503) & 511)]) - fVec17[((IOTA - 506) & 511)])) + ((0.00378429517f * (fVec17[((IOTA - 203) & 511)] - fVec17[((IOTA - 502) & 511)])) + ((0.00439466536f * (fVec17[((IOTA - 217) & 511)] - fVec17[((IOTA - 499) & 511)])) + ((0.00442518387f * ((((fVec17[((IOTA - 195) & 511)] + fVec17[((IOTA - 237) & 511)]) + fVec17[((IOTA - 238) & 511)]) - fVec17[((IOTA - 456) & 511)]) - fVec17[((IOTA - 496) & 511)])) + ((0.00411999878f * (fVec17[((IOTA - 241) & 511)] - fVec17[((IOTA - 495) & 511)])) + ((0.00363170262f * ((fVec17[((IOTA - 257) & 511)] - fVec17[((IOTA - 491) & 511)]) - fVec17[((IOTA - 493) & 511)])) + ((0.00357066561f * (((fVec17[((IOTA - 382) & 511)] - fVec17[((IOTA - 436) & 511)]) - fVec17[((IOTA - 440) & 511)]) - fVec17[((IOTA - 492) & 511)])) + ((0.0045167394f * (((fVec17[((IOTA - 275) & 511)] - fVec17[((IOTA - 393) & 511)]) - fVec17[((IOTA - 433) & 511)]) - fVec17[((IOTA - 488) & 511)])) + ((0.00482192449f * (fVec17[((IOTA - 234) & 511)] - fVec17[((IOTA - 487) & 511)])) + ((0.00521866512f * (fVec17[((IOTA - 177) & 511)] - fVec17[((IOTA - 486) & 511)])) + ((0.00640888698f * (((fVec17[((IOTA - 65) & 511)] + fVec17[((IOTA - 77) & 511)]) + fVec17[((IOTA - 174) & 511)]) - fVec17[((IOTA - 481) & 511)])) + ((0.00619525742f * ((fVec17[((IOTA - 219) & 511)] + fVec17[((IOTA - 223) & 511)]) - fVec17[((IOTA - 480) & 511)])) + ((0.0061342204f * (fVec17[((IOTA - 208) & 511)] - fVec17[((IOTA - 472) & 511)])) + ((0.00311288796f * ((fVec17[((IOTA - 215) & 511)] + fVec17[((IOTA - 281) & 511)]) - fVec17[((IOTA - 466) & 511)])) + ((0.00305185094f * (fVec17[((IOTA - 260) & 511)] - fVec17[((IOTA - 465) & 511)])) + ((0.0051576281f * (fVec17[((IOTA - 204) & 511)] - fVec17[((IOTA - 460) & 511)])) + ((0.00567644276f * ((fVec17[((IOTA - 371) & 511)] - fVec17[((IOTA - 442) & 511)]) - fVec17[((IOTA - 459) & 511)])) + ((0.00302133244f * ((fVec17[((IOTA - 250) & 511)] + fVec17[((IOTA - 285) & 511)]) - fVec17[((IOTA - 452) & 511)])) + ((0.00253303628f * (fVec17[((IOTA - 254) & 511)] - fVec17[((IOTA - 451) & 511)])) + ((0.00207525864f * (fVec17[((IOTA - 297) & 511)] - fVec17[((IOTA - 450) & 511)])) + ((0.00216681417f * (fVec17[((IOTA - 213) & 511)] - fVec17[((IOTA - 449) & 511)])) + ((0.00445570238f * ((((fVec17[((IOTA - 196) & 511)] + fVec17[((IOTA - 225) & 511)]) + fVec17[((IOTA - 226) & 511)]) + fVec17[((IOTA - 236) & 511)]) - fVec17[((IOTA - 447) & 511)])) + ((0.00665303506f * (fVec17[((IOTA - 61) & 511)] - fVec17[((IOTA - 443) & 511)])) + ((0.00448622089f * (fVec17[((IOTA - 244) & 511)] - fVec17[((IOTA - 441) & 511)])) + ((0.00329599902f * (((fVec17[((IOTA - 246) & 511)] + fVec17[((IOTA - 271) & 511)]) + fVec17[((IOTA - 380) & 511)]) - fVec17[((IOTA - 437) & 511)])) + ((0.00500503555f * (fVec17[((IOTA - 232) & 511)] - fVec17[((IOTA - 432) & 511)])) + ((0.00558488723f * (fVec17[((IOTA - 81) & 511)] - fVec17[((IOTA - 431) & 511)])) + ((0.00509659108f * (fVec17[((IOTA - 218) & 511)] - fVec17[((IOTA - 427) & 511)])) + ((0.00390636921f * ((fVec17[((IOTA - 216) & 511)] - fVec17[((IOTA - 394) & 511)]) - fVec17[((IOTA - 426) & 511)])) + ((0.0028992584f * ((fVec17[((IOTA - 249) & 511)] + fVec17[((IOTA - 387) & 511)]) - fVec17[((IOTA - 425) & 511)])) + ((0.0019226661f * (((fVec17[((IOTA - 268) & 511)] + fVec17[((IOTA - 358) & 511)]) - fVec17[((IOTA - 413) & 511)]) - fVec17[((IOTA - 421) & 511)])) + ((0.00250251777f * (fVec17[((IOTA - 214) & 511)] - fVec17[((IOTA - 420) & 511)])) + ((0.00244148076f * ((((fVec17[((IOTA - 212) & 511)] + fVec17[((IOTA - 264) & 511)]) + fVec17[((IOTA - 286) & 511)]) + fVec17[((IOTA - 353) & 511)]) - fVec17[((IOTA - 414) & 511)])) + ((0.00149540696f * ((((fVec17[((IOTA - 200) & 511)] + fVec17[((IOTA - 289) & 511)]) - fVec17[((IOTA - 365) & 511)]) + fVec17[((IOTA - 379) & 511)]) - fVec17[((IOTA - 412) & 511)])) + ((0.000793481246f * ((((((fVec17[((IOTA - 307) & 511)] + fVec17[((IOTA - 308) & 511)]) + fVec17[((IOTA - 321) & 511)]) - fVec17[((IOTA - 325) & 511)]) + fVec17[((IOTA - 334) & 511)]) - fVec17[((IOTA - 409) & 511)]) - fVec17[((IOTA - 410) & 511)])) + ((0.000885036774f * ((fVec17[((IOTA - 139) & 511)] + fVec17[((IOTA - 343) & 511)]) - fVec17[((IOTA - 408) & 511)])) + ((0.000915555283f * (fVec17[((IOTA - 342) & 511)] - fVec17[((IOTA - 407) & 511)])) + ((0.000701925717f * (fVec17[((IOTA - 300) & 511)] - fVec17[((IOTA - 406) & 511)])) + ((0.000640888698f * (((fVec17[((IOTA - 304) & 511)] + fVec17[((IOTA - 336) & 511)]) - fVec17[((IOTA - 373) & 511)]) - fVec17[((IOTA - 405) & 511)])) + ((0.000946073793f * (fVec17[((IOTA - 335) & 511)] - fVec17[((IOTA - 404) & 511)])) + ((0.00143436994f * (((fVec17[((IOTA - 293) & 511)] + fVec17[((IOTA - 350) & 511)]) - fVec17[((IOTA - 398) & 511)]) - fVec17[((IOTA - 403) & 511)])) + ((0.00109866634f * (fVec17[((IOTA - 348) & 511)] - fVec17[((IOTA - 400) & 511)])) + ((0.00213629566f * (((fVec17[((IOTA - 296) & 511)] + fVec17[((IOTA - 352) & 511)]) - fVec17[((IOTA - 364) & 511)]) - fVec17[((IOTA - 397) & 511)])) + ((0.00137333293f * ((fVec17[((IOTA - 291) & 511)] + fVec17[((IOTA - 292) & 511)]) + fVec17[((IOTA - 388) & 511)])) + ((0.00402844325f * fVec17[((IOTA - 385) & 511)]) + ((0.00369273964f * (fVec17[((IOTA - 283) & 511)] + fVec17[((IOTA - 384) & 511)])) + ((0.00344859157f * fVec17[((IOTA - 383) & 511)]) + ((0.00122074038f * ((fVec17[((IOTA - 345) & 511)] + fVec17[((IOTA - 349) & 511)]) - fVec17[((IOTA - 378) & 511)])) + ((0.00463881344f * (fVec17[((IOTA - 231) & 511)] - fVec17[((IOTA - 375) & 511)])) + ((0.0025940733f * (((fVec17[((IOTA - 142) & 511)] + fVec17[((IOTA - 253) & 511)]) + fVec17[((IOTA - 354) & 511)]) + fVec17[((IOTA - 372) & 511)])) + ((0.00772118289f * fVec17[((IOTA - 370) & 511)]) + ((0.00766014587f * fVec17[((IOTA - 369) & 511)]) + ((0.00564592425f * fVec17[((IOTA - 368) & 511)]) + ((0.00265511032f * (fVec17[((IOTA - 280) & 511)] + fVec17[((IOTA - 367) & 511)])) + ((0.00100711081f * (fVec17[((IOTA - 344) & 511)] + fVec17[((IOTA - 359) & 511)])) + ((0.00247199927f * ((fVec17[((IOTA - 199) & 511)] + fVec17[((IOTA - 278) & 511)]) + fVec17[((IOTA - 357) & 511)])) + ((0.00262459181f * fVec17[((IOTA - 356) & 511)]) + ((0.00268562883f * (fVec17[((IOTA - 263) & 511)] + fVec17[((IOTA - 355) & 511)])) + ((0.00180059206f * fVec17[((IOTA - 351) & 511)]) + ((0.00314340647f * (fVec17[((IOTA - 251) & 511)] - fVec17[((IOTA - 374) & 511)])) + ((0.00115970336f * (fVec17[((IOTA - 299) & 511)] + fVec17[((IOTA - 347) & 511)])) + ((0.00134281442f * (fVec17[((IOTA - 290) & 511)] + fVec17[((IOTA - 346) & 511)])) + ((0.000854518265f * (fVec17[((IOTA - 201) & 511)] + fVec17[((IOTA - 341) & 511)])) + ((0.000610370189f * ((fVec17[((IOTA - 303) & 511)] - fVec17[((IOTA - 326) & 511)]) + fVec17[((IOTA - 340) & 511)])) + ((0.000274666585f * (((fVec17[((IOTA - 147) & 511)] + fVec17[((IOTA - 313) & 511)]) - fVec17[((IOTA - 324) & 511)]) + fVec17[((IOTA - 339) & 511)])) + ((0.000244148076f * (((((fVec17[((IOTA - 311) & 511)] + fVec17[((IOTA - 312) & 511)]) + fVec17[((IOTA - 314) & 511)]) + fVec17[((IOTA - 329) & 511)]) + fVec17[((IOTA - 330) & 511)]) + fVec17[((IOTA - 337) & 511)])) + ((0.00057985168f * fVec17[((IOTA - 333) & 511)]) + ((0.000457777642f * ((fVec17[((IOTA - 310) & 511)] + fVec17[((IOTA - 323) & 511)]) + fVec17[((IOTA - 332) & 511)])) + ((0.000823999755f * (fVec17[((IOTA - 306) & 511)] + fVec17[((IOTA - 322) & 511)])) + ((0.00054933317f * (fVec17[((IOTA - 301) & 511)] + fVec17[((IOTA - 320) & 511)])) + ((0.000732444227f * fVec17[((IOTA - 309) & 511)]) + ((0.000762962736f * fVec17[((IOTA - 305) & 511)]) + ((0.000518814661f * (fVec17[((IOTA - 59) & 511)] + fVec17[((IOTA - 302) & 511)])) + ((0.00167851802f * ((fVec17[((IOTA - 112) & 511)] + fVec17[((IOTA - 141) & 511)]) + fVec17[((IOTA - 298) & 511)])) + ((0.00189214759f * fVec17[((IOTA - 295) & 511)]) + ((0.001617481f * fVec17[((IOTA - 294) & 511)]) + ((0.00173955504f * fVec17[((IOTA - 288) & 511)]) + ((0.00204474013f * (fVec17[((IOTA - 267) & 511)] + fVec17[((IOTA - 287) & 511)])) + ((0.00347911008f * (fVec17[((IOTA - 282) & 511)] + fVec17[((IOTA - 284) & 511)])) + ((0.00241096225f * (fVec17[((IOTA - 163) & 511)] + fVec17[((IOTA - 279) & 511)])) + ((0.00296029542f * (fVec17[((IOTA - 252) & 511)] + fVec17[((IOTA - 277) & 511)])) + ((0.00491348002f * fVec17[((IOTA - 274) & 511)]) + ((0.00454725791f * ((((fVec17[((IOTA - 197) & 511)] + fVec17[((IOTA - 229) & 511)]) + fVec17[((IOTA - 240) & 511)]) + fVec17[((IOTA - 243) & 511)]) + fVec17[((IOTA - 273) & 511)])) + ((0.00274666585f * ((fVec17[((IOTA - 60) & 511)] + fVec17[((IOTA - 255) & 511)]) + fVec17[((IOTA - 270) & 511)])) + ((0.00228888821f * ((fVec17[((IOTA - 265) & 511)] + fVec17[((IOTA - 266) & 511)]) + fVec17[((IOTA - 269) & 511)])) + ((0.00283822138f * (fVec17[((IOTA - 261) & 511)] + fVec17[((IOTA - 262) & 511)])) + ((0.00341807306f * fVec17[((IOTA - 259) & 511)]) + ((0.00375377666f * fVec17[((IOTA - 258) & 511)]) + ((0.00286873989f * (fVec17[((IOTA - 247) & 511)] + fVec17[((IOTA - 248) & 511)])) + ((0.00503555406f * fVec17[((IOTA - 233) & 511)]) + ((0.00436414685f * fVec17[((IOTA - 230) & 511)]) + ((0.003234962f * fVec17[((IOTA - 256) & 511)]) + ((0.00469985045f * (fVec17[((IOTA - 164) & 511)] + fVec17[((IOTA - 228) & 511)])) + ((0.00512710959f * fVec17[((IOTA - 224) & 511)]) + ((0.00738547929f * fVec17[((IOTA - 222) & 511)]) + ((0.00778221991f * (fVec17[((IOTA - 189) & 511)] + fVec17[((IOTA - 221) & 511)])) + ((0.00717184972f * fVec17[((IOTA - 220) & 511)]) + ((0.00494399853f * fVec17[((IOTA - 209) & 511)]) + ((0.00653096102f * fVec17[((IOTA - 207) & 511)]) + ((0.00592059083f * fVec17[((IOTA - 206) & 511)]) + ((0.00555436872f * fVec17[((IOTA - 205) & 511)]) + ((0.00524918362f * fVec17[((IOTA - 194) & 511)]) + ((0.00604266487f * fVec17[((IOTA - 193) & 511)]) + ((0.00650044251f * fVec17[((IOTA - 192) & 511)]) + ((0.00714133121f * fVec17[((IOTA - 191) & 511)]) + ((0.00753807183f * fVec17[((IOTA - 190) & 511)]) + ((0.00747703481f * fVec17[((IOTA - 188) & 511)]) + ((0.00750755332f * fVec17[((IOTA - 187) & 511)]) + ((0.00927762687f * fVec17[((IOTA - 186) & 511)]) + ((0.0108951079f * fVec17[((IOTA - 185) & 511)]) + ((0.0135807367f * fVec17[((IOTA - 184) & 511)]) + ((0.0159306619f * fVec17[((IOTA - 183) & 511)]) + ((0.016296884f * fVec17[((IOTA - 182) & 511)]) + ((0.014435255f * fVec17[((IOTA - 181) & 511)]) + ((0.0121768853f * fVec17[((IOTA - 180) & 511)]) + ((0.0100711081f * fVec17[((IOTA - 179) & 511)]) + ((0.00686666463f * fVec17[((IOTA - 178) & 511)]) + ((0.00674459059f * fVec17[((IOTA - 176) & 511)]) + ((0.00744651631f * fVec17[((IOTA - 175) & 511)]) + ((0.00732444227f * fVec17[((IOTA - 173) & 511)]) + ((0.00952177495f * fVec17[((IOTA - 172) & 511)]) + ((0.0122989593f * fVec17[((IOTA - 171) & 511)]) + ((0.0148014771f * fVec17[((IOTA - 170) & 511)]) + ((0.0156865139f * fVec17[((IOTA - 169) & 511)]) + ((0.0137638478f * fVec17[((IOTA - 168) & 511)]) + ((0.00918607134f * fVec17[((IOTA - 167) & 511)]) + ((0.00802636798f * fVec17[((IOTA - 157) & 511)]) + ((0.0138554033f * fVec17[((IOTA - 156) & 511)]) + ((0.0139164403f * fVec17[((IOTA - 153) & 511)]) + ((0.0155339213f * fVec17[((IOTA - 152) & 511)]) + ((0.0160222184f * fVec17[((IOTA - 151) & 511)]) + ((0.0119022187f * fVec17[((IOTA - 150) & 511)]) + ((0.00473036896f * fVec17[((IOTA - 149) & 511)]) + ((0.012817774f * fVec17[((IOTA - 146) & 511)]) + ((0.0229499191f * fVec17[((IOTA - 145) & 511)]) + ((0.0210577715f * fVec17[((IOTA - 144) & 511)]) + ((0.0107730338f * fVec17[((IOTA - 143) & 511)]) + ((0.0144047365f * fVec17[((IOTA - 155) & 511)]) + ((0.00183111057f * fVec17[((IOTA - 202) & 511)]) + ((0.0132450331f * fVec17[((IOTA - 154) & 511)]) + ((0.00238044374f * fVec17[((IOTA - 140) & 511)]) + ((0.00769066438f * fVec17[((IOTA - 133) & 511)]) + ((0.0153202917f * fVec17[((IOTA - 132) & 511)]) + ((0.0224311054f * fVec17[((IOTA - 131) & 511)]) + ((0.0292062145f * fVec17[((IOTA - 130) & 511)]) + ((0.0348216183f * fVec17[((IOTA - 129) & 511)]) + ((0.0377819166f * fVec17[((IOTA - 128) & 511)]) + ((0.0343638435f * fVec17[((IOTA - 127) & 511)]) + ((0.0250556972f * fVec17[((IOTA - 126) & 511)]) + ((0.00836207159f * fVec17[((IOTA - 125) & 511)]) + ((0.00823999755f * fVec17[((IOTA - 121) & 511)]) + ((0.0233161412f * fVec17[((IOTA - 120) & 511)]) + ((0.0372020639f * fVec17[((IOTA - 119) & 511)]) + ((0.0352793969f * fVec17[((IOTA - 118) & 511)]) + ((0.0331431031f * fVec17[((IOTA - 117) & 511)]) + ((0.0235297717f * fVec17[((IOTA - 116) & 511)]) + ((0.0229804385f * fVec17[((IOTA - 115) & 511)]) + ((0.0182500686f * fVec17[((IOTA - 114) & 511)]) + ((0.0115970336f * fVec17[((IOTA - 113) & 511)]) + ((0.0074159978f * fVec17[((IOTA - 102) & 511)]) + ((0.0301828068f * fVec17[((IOTA - 101) & 511)]) + ((0.0495925769f * fVec17[((IOTA - 100) & 511)]) + ((0.0471205786f * fVec17[((IOTA - 99) & 511)]) + ((0.0132755516f * fVec17[((IOTA - 98) & 511)]) + ((0.014496292f * fVec17[((IOTA - 93) & 511)]) + ((0.0445875414f * fVec17[((IOTA - 92) & 511)]) + ((0.0407116935f * fVec17[((IOTA - 91) & 511)]) + ((0.030793177f * fVec17[((IOTA - 90) & 511)]) + ((0.0229194015f * fVec17[((IOTA - 89) & 511)]) + ((0.0394604318f * fVec17[((IOTA - 88) & 511)]) + ((0.0626239851f * fVec17[((IOTA - 87) & 511)]) + ((0.0295724366f * fVec17[((IOTA - 86) & 511)]) + ((0.0130924406f * fVec17[((IOTA - 85) & 511)]) + ((0.0224921424f * fVec17[((IOTA - 80) & 511)]) + ((0.0216681417f * fVec17[((IOTA - 79) & 511)]) + ((0.0101321451f * fVec17[((IOTA - 78) & 511)]) + ((0.0385448784f * fVec17[((IOTA - 76) & 511)]) + ((0.0561540574f * fVec17[((IOTA - 75) & 511)]) + ((0.0762047172f * fVec17[((IOTA - 74) & 511)]) + ((0.000488296151f * fVec17[((IOTA - 66) & 511)]) + ((0.0109561449f * fVec17[((IOTA - 64) & 511)]) + ((0.0101626636f * fVec17[((IOTA - 62) & 511)]) + (0.0120853297f * fVec17[((IOTA - 63) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00415051728f * ((fVec17[((IOTA - 242) & 511)] - fVec17[((IOTA - 500) & 511)]) - fVec17[((IOTA - 511) & 511)])))) : (((0.000122074038f * (((fVec16[((IOTA - 288) & 511)] + fVec16[((IOTA - 492) & 511)]) + fVec16[((IOTA - 501) & 511)]) + fVec16[((IOTA - 508) & 511)])) + ((0.000213629566f * ((((fVec16[((IOTA - 214) & 511)] + fVec16[((IOTA - 231) & 511)]) - fVec16[((IOTA - 342) & 511)]) + fVec16[((IOTA - 433) & 511)]) - fVec16[((IOTA - 506) & 511)])) + ((0.000335703604f * (((((fVec16[((IOTA - 285) & 511)] + fVec16[((IOTA - 304) & 511)]) + fVec16[((IOTA - 383) & 511)]) - fVec16[((IOTA - 389) & 511)]) - fVec16[((IOTA - 503) & 511)]) - fVec16[((IOTA - 505) & 511)])) + ((0.000396740623f * (((fVec16[((IOTA - 366) & 511)] + fVec16[((IOTA - 379) & 511)]) + fVec16[((IOTA - 497) & 511)]) - fVec16[((IOTA - 504) & 511)])) + ((0.000366222113f * ((((((((fVec16[((IOTA - 9) & 511)] + fVec16[((IOTA - 286) & 511)]) - fVec16[((IOTA - 345) & 511)]) + fVec16[((IOTA - 354) & 511)]) - fVec16[((IOTA - 364) & 511)]) + fVec16[((IOTA - 417) & 511)]) + fVec16[((IOTA - 434) & 511)]) + fVec16[((IOTA - 491) & 511)]) + fVec16[((IOTA - 500) & 511)])) + ((6.10370189e-05f * (((((((((fVec16[((IOTA - 216) & 511)] + fVec16[((IOTA - 233) & 511)]) + fVec16[((IOTA - 267) & 511)]) - fVec16[((IOTA - 298) & 511)]) - fVec16[((IOTA - 371) & 511)]) - fVec16[((IOTA - 378) & 511)]) + fVec16[((IOTA - 407) & 511)]) + fVec16[((IOTA - 416) & 511)]) - fVec16[((IOTA - 493) & 511)]) - fVec16[((IOTA - 494) & 511)])) + ((0.000854518265f * (fVec16[((IOTA - 250) & 511)] + fVec16[((IOTA - 489) & 511)])) + ((0.00106814783f * ((((fVec16[((IOTA - 10) & 511)] + fVec16[((IOTA - 212) & 511)]) + fVec16[((IOTA - 318) & 511)]) - fVec16[((IOTA - 412) & 511)]) + fVec16[((IOTA - 487) & 511)])) + ((0.000976592302f * fVec16[((IOTA - 484) & 511)]) + ((0.00112918485f * ((((((fVec16[((IOTA - 16) & 511)] + fVec16[((IOTA - 144) & 511)]) + fVec16[((IOTA - 193) & 511)]) + fVec16[((IOTA - 395) & 511)]) + fVec16[((IOTA - 441) & 511)]) + fVec16[((IOTA - 474) & 511)]) + fVec16[((IOTA - 483) & 511)])) + ((0.00131229591f * (((((((((((fVec16[((IOTA - 211) & 511)] - fVec16[((IOTA - 243) & 511)]) - fVec16[((IOTA - 254) & 511)]) - fVec16[((IOTA - 262) & 511)]) - fVec16[((IOTA - 271) & 511)]) - fVec16[((IOTA - 308) & 511)]) + fVec16[((IOTA - 319) & 511)]) - fVec16[((IOTA - 410) & 511)]) + fVec16[((IOTA - 437) & 511)]) + fVec16[((IOTA - 462) & 511)]) - fVec16[((IOTA - 468) & 511)]) + fVec16[((IOTA - 482) & 511)])) + ((0.000640888698f * ((((((((((fVec16[((IOTA - 230) & 511)] + fVec16[((IOTA - 251) & 511)]) - fVec16[((IOTA - 281) & 511)]) + fVec16[((IOTA - 302) & 511)]) + fVec16[((IOTA - 322) & 511)]) + fVec16[((IOTA - 385) & 511)]) - fVec16[((IOTA - 414) & 511)]) + fVec16[((IOTA - 435) & 511)]) - fVec16[((IOTA - 466) & 511)]) + fVec16[((IOTA - 473) & 511)]) + fVec16[((IOTA - 490) & 511)])) + ((0.00054933317f * ((fVec16[((IOTA - 443) & 511)] - ((fVec16[((IOTA - 264) & 511)] + fVec16[((IOTA - 290) & 511)]) - fVec16[((IOTA - 429) & 511)])) + fVec16[((IOTA - 464) & 511)])) + ((0.0012817774f * (fVec16[((IOTA - 247) & 511)] + fVec16[((IOTA - 460) & 511)])) + ((0.000671407208f * ((((((fVec16[((IOTA - 301) & 511)] - fVec16[((IOTA - 270) & 511)]) - fVec16[((IOTA - 363) & 511)]) + fVec16[((IOTA - 367) & 511)]) + fVec16[((IOTA - 382) & 511)]) + fVec16[((IOTA - 444) & 511)]) + fVec16[((IOTA - 458) & 511)])) + ((0.00250251777f * (fVec16[((IOTA - 447) & 511)] + fVec16[((IOTA - 448) & 511)])) + ((0.00152592547f * ((fVec16[((IOTA - 165) & 511)] + fVec16[((IOTA - 335) & 511)]) + fVec16[((IOTA - 438) & 511)])) + ((0.00146488845f * (((((fVec16[((IOTA - 201) & 511)] - fVec16[((IOTA - 208) & 511)]) - fVec16[((IOTA - 292) & 511)]) - fVec16[((IOTA - 326) & 511)]) - fVec16[((IOTA - 327) & 511)]) + fVec16[((IOTA - 425) & 511)])) + ((0.00189214759f * ((((fVec16[((IOTA - 11) & 511)] + fVec16[((IOTA - 22) & 511)]) + fVec16[((IOTA - 202) & 511)]) - fVec16[((IOTA - 392) & 511)]) + fVec16[((IOTA - 423) & 511)])) + ((0.000610370189f * ((((fVec16[((IOTA - 145) & 511)] - fVec16[((IOTA - 324) & 511)]) + fVec16[((IOTA - 340) & 511)]) - fVec16[((IOTA - 360) & 511)]) + fVec16[((IOTA - 406) & 511)])) + ((0.0022583697f * fVec16[((IOTA - 400) & 511)]) + ((0.00265511032f * (fVec16[((IOTA - 194) & 511)] + fVec16[((IOTA - 398) & 511)])) + ((0.00134281442f * fVec16[((IOTA - 387) & 511)]) + ((0.000274666585f * ((((fVec16[((IOTA - 287) & 511)] + fVec16[((IOTA - 299) & 511)]) - fVec16[((IOTA - 313) & 511)]) + fVec16[((IOTA - 333) & 511)]) + fVec16[((IOTA - 384) & 511)])) + ((0.000793481246f * ((fVec16[((IOTA - 369) & 511)] - (((fVec16[((IOTA - 176) & 511)] - fVec16[((IOTA - 236) & 511)]) - fVec16[((IOTA - 246) & 511)]) - fVec16[((IOTA - 368) & 511)])) + fVec16[((IOTA - 380) & 511)])) + ((0.000823999755f * ((fVec16[((IOTA - 234) & 511)] - fVec16[((IOTA - 307) & 511)]) - fVec16[((IOTA - 362) & 511)])) + ((0.00186162908f * ((fVec16[((IOTA - 41) & 511)] + fVec16[((IOTA - 336) & 511)]) + fVec16[((IOTA - 337) & 511)])) + ((0.000244148076f * ((fVec16[((IOTA - 229) & 511)] + fVec16[((IOTA - 284) & 511)]) - fVec16[((IOTA - 332) & 511)])) + ((0.00280770287f * ((fVec16[((IOTA - 12) & 511)] - fVec16[((IOTA - 256) & 511)]) - fVec16[((IOTA - 276) & 511)])) + ((0.00256355479f * (fVec16[((IOTA - 143) & 511)] - fVec16[((IOTA - 241) & 511)])) + ((0.00231940672f * fVec16[((IOTA - 199) & 511)]) + ((0.00320444349f * fVec16[((IOTA - 198) & 511)]) + ((0.00402844325f * fVec16[((IOTA - 197) & 511)]) + ((0.00408948027f * fVec16[((IOTA - 196) & 511)]) + ((0.00341807306f * fVec16[((IOTA - 195) & 511)]) + ((0.00442518387f * (((fVec16[((IOTA - 53) & 511)] + fVec16[((IOTA - 142) & 511)]) - fVec16[((IOTA - 159) & 511)]) - fVec16[((IOTA - 174) & 511)])) + ((0.00167851802f * (fVec16[((IOTA - 95) & 511)] + fVec16[((IOTA - 153) & 511)])) + ((0.00350962859f * fVec16[((IOTA - 146) & 511)]) + ((0.00372325815f * fVec16[((IOTA - 154) & 511)]) + ((0.00543229468f * fVec16[((IOTA - 141) & 511)]) + ((0.00823999755f * fVec16[((IOTA - 140) & 511)]) + ((0.0114749596f * fVec16[((IOTA - 139) & 511)]) + ((0.0142826624f * fVec16[((IOTA - 138) & 511)]) + ((0.0148014771f * fVec16[((IOTA - 137) & 511)]) + ((0.0148930326f * fVec16[((IOTA - 136) & 511)]) + ((0.0125125889f * fVec16[((IOTA - 135) & 511)]) + ((0.0105899228f * fVec16[((IOTA - 134) & 511)]) + ((0.00802636798f * fVec16[((IOTA - 133) & 511)]) + ((0.006469924f * ((fVec16[((IOTA - 23) & 511)] - fVec16[((IOTA - 46) & 511)]) + fVec16[((IOTA - 123) & 511)])) + ((0.0120242927f * fVec16[((IOTA - 122) & 511)]) + ((0.00344859157f * fVec16[((IOTA - 121) & 511)]) + ((0.00650044251f * fVec16[((IOTA - 112) & 511)]) + ((0.0187078472f * fVec16[((IOTA - 111) & 511)]) + ((0.0264900662f * fVec16[((IOTA - 110) & 511)]) + ((0.0240180679f * fVec16[((IOTA - 109) & 511)]) + ((0.0198980682f * fVec16[((IOTA - 108) & 511)]) + ((0.0241096225f * fVec16[((IOTA - 107) & 511)]) + ((0.0282296222f * fVec16[((IOTA - 106) & 511)]) + ((0.0275276955f * fVec16[((IOTA - 105) & 511)]) + ((0.0244758446f * fVec16[((IOTA - 104) & 511)]) + ((0.0122074038f * (fVec16[((IOTA - 50) & 511)] + fVec16[((IOTA - 103) & 511)])) + ((0.0107730338f * fVec16[((IOTA - 98) & 511)]) + ((0.0260628071f * fVec16[((IOTA - 97) & 511)]) + ((0.01803644f * fVec16[((IOTA - 96) & 511)]) + ((0.00527970213f * (fVec16[((IOTA - 65) & 511)] - fVec16[((IOTA - 88) & 511)])) + ((0.0119022187f * fVec16[((IOTA - 82) & 511)]) + ((0.0429090261f * fVec16[((IOTA - 73) & 511)]) + ((0.218115792f * fVec16[((IOTA - 72) & 511)]) + ((0.303842276f * fVec16[((IOTA - 71) & 511)]) + ((0.255348355f * fVec16[((IOTA - 70) & 511)]) + ((0.12494278f * fVec16[((IOTA - 69) & 511)]) + ((0.0329294726f * fVec16[((IOTA - 68) & 511)]) + ((0.00817896053f * fVec16[((IOTA - 67) & 511)]) + ((0.00738547929f * fVec16[((IOTA - 66) & 511)]) + ((0.00164799951f * fVec16[((IOTA - 64) & 511)]) + ((0.00311288796f * (fVec16[((IOTA - 37) & 511)] - fVec16[((IOTA - 61) & 511)])) + ((0.00564592425f * fVec16[((IOTA - 81) & 511)]) + ((0.00933866389f * fVec16[((IOTA - 52) & 511)]) + ((0.0122379223f * fVec16[((IOTA - 51) & 511)]) + ((0.0090334788f * fVec16[((IOTA - 49) & 511)]) + ((0.00378429517f * (fVec16[((IOTA - 27) & 511)] + fVec16[((IOTA - 48) & 511)])) + ((0.00396740623f * fVec16[((IOTA - 40) & 511)]) + ((0.00463881344f * fVec16[((IOTA - 39) & 511)]) + ((0.00299081393f * (fVec16[((IOTA - 15) & 511)] - fVec16[((IOTA - 34) & 511)])) + ((0.008087405f * fVec16[((IOTA - 26) & 511)]) + ((0.0104068117f * fVec16[((IOTA - 25) & 511)]) + ((0.00973540451f * fVec16[((IOTA - 24) & 511)]) + ((0.00357066561f * fVec16[((IOTA - 13) & 511)]) + (0.00375377666f * fVec16[((IOTA - 14) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000457777642f * ((((((((fVec16[((IOTA - 131) & 511)] - fVec16[((IOTA - 178) & 511)]) - fVec16[((IOTA - 213) & 511)]) + fVec16[((IOTA - 253) & 511)]) - fVec16[((IOTA - 316) & 511)]) - fVec16[((IOTA - 351) & 511)]) + fVec16[((IOTA - 359) & 511)]) - fVec16[((IOTA - 457) & 511)]) - fVec16[((IOTA - 510) & 511)])) + ((0.000305185094f * (((((((((((((((fVec16[((IOTA - 8) & 511)] + fVec16[((IOTA - 80) & 511)]) - fVec16[((IOTA - 204) & 511)]) + fVec16[((IOTA - 218) & 511)]) + fVec16[((IOTA - 237) & 511)]) - fVec16[((IOTA - 252) & 511)]) + fVec16[((IOTA - 269) & 511)]) + fVec16[((IOTA - 282) & 511)]) + fVec16[((IOTA - 306) & 511)]) - fVec16[((IOTA - 315) & 511)]) - fVec16[((IOTA - 350) & 511)]) + fVec16[((IOTA - 358) & 511)]) + fVec16[((IOTA - 415) & 511)]) - fVec16[((IOTA - 431) & 511)]) - fVec16[((IOTA - 456) & 511)]) - fVec16[((IOTA - 509) & 511)])) + ((3.05185094e-05f * ((fVec16[((IOTA - 465) & 511)] - (((((((fVec16[((IOTA - 215) & 511)] - fVec16[((IOTA - 217) & 511)]) - fVec16[((IOTA - 245) & 511)]) + fVec16[((IOTA - 266) & 511)]) + fVec16[((IOTA - 283) & 511)]) + fVec16[((IOTA - 365) & 511)]) - fVec16[((IOTA - 394) & 511)]) + fVec16[((IOTA - 455) & 511)])) + fVec16[((IOTA - 507) & 511)])) + ((0.000152592547f * (((fVec16[((IOTA - 209) & 511)] - fVec16[((IOTA - 341) & 511)]) + fVec16[((IOTA - 346) & 511)]) + fVec16[((IOTA - 502) & 511)])) + ((0.000518814661f * (((((((fVec16[((IOTA - 35) & 511)] + fVec16[((IOTA - 297) & 511)]) - fVec16[((IOTA - 303) & 511)]) + fVec16[((IOTA - 344) & 511)]) - fVec16[((IOTA - 352) & 511)]) - fVec16[((IOTA - 370) & 511)]) - fVec16[((IOTA - 498) & 511)]) - fVec16[((IOTA - 499) & 511)])) + ((0.000183111057f * ((((((fVec16[((IOTA - 232) & 511)] + fVec16[((IOTA - 265) & 511)]) - fVec16[((IOTA - 349) & 511)]) - fVec16[((IOTA - 355) & 511)]) + fVec16[((IOTA - 357) & 511)]) - fVec16[((IOTA - 432) & 511)]) - fVec16[((IOTA - 496) & 511)])) + ((0.00103762932f * (((fVec16[((IOTA - 291) & 511)] + fVec16[((IOTA - 296) & 511)]) - fVec16[((IOTA - 403) & 511)]) - fVec16[((IOTA - 488) & 511)])) + ((0.00100711081f * (((((fVec16[((IOTA - 263) & 511)] - fVec16[((IOTA - 436) & 511)]) + fVec16[((IOTA - 453) & 511)]) - fVec16[((IOTA - 459) & 511)]) - fVec16[((IOTA - 463) & 511)]) - fVec16[((IOTA - 486) & 511)])) + ((0.000946073793f * ((((fVec16[((IOTA - 7) & 511)] + fVec16[((IOTA - 280) & 511)]) - fVec16[((IOTA - 334) & 511)]) - fVec16[((IOTA - 404) & 511)]) - fVec16[((IOTA - 485) & 511)])) + ((0.00140385143f * ((((((((((((fTemp17 + fVec16[((IOTA - 42) & 511)]) + fVec16[((IOTA - 148) & 511)]) - fVec16[((IOTA - 203) & 511)]) + fVec16[((IOTA - 279) & 511)]) + fVec16[((IOTA - 310) & 511)]) - fVec16[((IOTA - 320) & 511)]) + fVec16[((IOTA - 390) & 511)]) - fVec16[((IOTA - 461) & 511)]) - fVec16[((IOTA - 475) & 511)]) - fVec16[((IOTA - 477) & 511)]) - fVec16[((IOTA - 479) & 511)]) - fVec16[((IOTA - 481) & 511)])) + ((0.00143436994f * (((fVec16[((IOTA - 295) & 511)] - fVec16[((IOTA - 440) & 511)]) - fVec16[((IOTA - 476) & 511)]) - fVec16[((IOTA - 480) & 511)])) + ((0.00137333293f * (((fVec16[((IOTA - 167) & 511)] - fVec16[((IOTA - 248) & 511)]) - fVec16[((IOTA - 402) & 511)]) - fVec16[((IOTA - 478) & 511)])) + ((9.15555283e-05f * (((((fVec16[((IOTA - 268) & 511)] + fVec16[((IOTA - 289) & 511)]) - fVec16[((IOTA - 305) & 511)]) - fVec16[((IOTA - 314) & 511)]) - fVec16[((IOTA - 348) & 511)]) - fVec16[((IOTA - 472) & 511)])) + ((0.000427259132f * ((fVec16[((IOTA - 155) & 511)] - fVec16[((IOTA - 430) & 511)]) + fVec16[((IOTA - 471) & 511)])) + ((0.000915555283f * ((((((fVec16[((IOTA - 54) & 511)] + fVec16[((IOTA - 185) & 511)]) + fVec16[((IOTA - 329) & 511)]) + fVec16[((IOTA - 372) & 511)]) - fVec16[((IOTA - 381) & 511)]) - fVec16[((IOTA - 427) & 511)]) + fVec16[((IOTA - 470) & 511)])) + ((0.00122074038f * (((fVec16[((IOTA - 328) & 511)] + fVec16[((IOTA - 411) & 511)]) - fVec16[((IOTA - 445) & 511)]) + fVec16[((IOTA - 469) & 511)])) + ((0.00109866634f * ((((fVec16[((IOTA - 179) & 511)] - fVec16[((IOTA - 249) & 511)]) - fVec16[((IOTA - 339) & 511)]) + fVec16[((IOTA - 409) & 511)]) + fVec16[((IOTA - 467) & 511)])) + ((0.000488296151f * (((fVec16[((IOTA - 343) & 511)] - (fVec16[((IOTA - 177) & 511)] + fVec16[((IOTA - 300) & 511)])) - fVec16[((IOTA - 353) & 511)]) + fVec16[((IOTA - 454) & 511)])) + ((0.00115970336f * (((((fVec16[((IOTA - 1) & 511)] - fVec16[((IOTA - 235) & 511)]) + fVec16[((IOTA - 393) & 511)]) - fVec16[((IOTA - 419) & 511)]) - fVec16[((IOTA - 426) & 511)]) + fVec16[((IOTA - 452) & 511)])) + ((0.00177007355f * ((fVec16[((IOTA - 293) & 511)] + fVec16[((IOTA - 375) & 511)]) - fVec16[((IOTA - 449) & 511)])) + ((0.0019531846f * (((fVec16[((IOTA - 220) & 511)] + fVec16[((IOTA - 278) & 511)]) - fVec16[((IOTA - 422) & 511)]) - fVec16[((IOTA - 446) & 511)])) + ((0.000762962736f * (((fVec16[((IOTA - 312) & 511)] + fVec16[((IOTA - 361) & 511)]) - fVec16[((IOTA - 388) & 511)]) - fVec16[((IOTA - 442) & 511)])) + ((0.00158696249f * ((fVec16[((IOTA - 3) & 511)] + fVec16[((IOTA - 238) & 511)]) - fVec16[((IOTA - 439) & 511)])) + ((0.000701925717f * (fVec16[((IOTA - 244) & 511)] - fVec16[((IOTA - 428) & 511)])) + ((0.00170903653f * (fVec16[((IOTA - 373) & 511)] - fVec16[((IOTA - 424) & 511)])) + ((0.00183111057f * (((fVec16[((IOTA - 4) & 511)] + fVec16[((IOTA - 5) & 511)]) - fVec16[((IOTA - 401) & 511)]) - fVec16[((IOTA - 421) & 511)])) + ((0.00155644398f * (((((fVec16[((IOTA - 17) & 511)] - fVec16[((IOTA - 36) & 511)]) + fVec16[((IOTA - 164) & 511)]) - fVec16[((IOTA - 200) & 511)]) - fVec16[((IOTA - 338) & 511)]) - fVec16[((IOTA - 420) & 511)])) + ((0.000732444227f * (((fVec16[((IOTA - 184) & 511)] - fVec16[((IOTA - 317) & 511)]) + fVec16[((IOTA - 330) & 511)]) - fVec16[((IOTA - 418) & 511)])) + ((0.000885036774f * (((((fVec16[((IOTA - 63) & 511)] + fVec16[((IOTA - 205) & 511)]) - fVec16[((IOTA - 210) & 511)]) + fVec16[((IOTA - 219) & 511)]) - fVec16[((IOTA - 405) & 511)]) + fVec16[((IOTA - 413) & 511)])) + ((0.00253303628f * (fVec16[((IOTA - 207) & 511)] - fVec16[((IOTA - 399) & 511)])) + ((0.00247199927f * (((fVec16[((IOTA - 21) & 511)] + fVec16[((IOTA - 239) & 511)]) + fVec16[((IOTA - 259) & 511)]) - fVec16[((IOTA - 397) & 511)])) + ((0.00201422162f * (fVec16[((IOTA - 391) & 511)] - fVec16[((IOTA - 396) & 511)])) + ((0.00119022187f * (((((fVec16[((IOTA - 228) & 511)] + fVec16[((IOTA - 311) & 511)]) - fVec16[((IOTA - 321) & 511)]) + fVec16[((IOTA - 325) & 511)]) + fVec16[((IOTA - 376) & 511)]) - fVec16[((IOTA - 386) & 511)])) + ((0.00204474013f * ((fVec16[((IOTA - 242) & 511)] + fVec16[((IOTA - 260) & 511)]) + fVec16[((IOTA - 374) & 511)])) + ((0.00149540696f * ((fVec16[((IOTA - 6) & 511)] + fVec16[((IOTA - 192) & 511)]) + fVec16[((IOTA - 309) & 511)])) + ((0.00173955504f * (fVec16[((IOTA - 89) & 511)] + fVec16[((IOTA - 294) & 511)])) + ((0.00244148076f * fVec16[((IOTA - 277) & 511)]) + ((0.00296029542f * (fVec16[((IOTA - 257) & 511)] + fVec16[((IOTA - 275) & 511)])) + ((0.0028992584f * fVec16[((IOTA - 274) & 511)]) + ((0.00262459181f * fVec16[((IOTA - 273) & 511)]) + ((0.00207525864f * fVec16[((IOTA - 272) & 511)]) + ((0.001617481f * (fVec16[((IOTA - 28) & 511)] + fVec16[((IOTA - 261) & 511)])) + ((0.00271614734f * ((fVec16[((IOTA - 171) & 511)] + fVec16[((IOTA - 240) & 511)]) + fVec16[((IOTA - 258) & 511)])) + ((0.00219733268f * fVec16[((IOTA - 255) & 511)]) + ((0.00305185094f * fVec16[((IOTA - 227) & 511)]) + ((0.00466933195f * (fVec16[((IOTA - 160) & 511)] + fVec16[((IOTA - 225) & 511)])) + ((0.004852443f * fVec16[((IOTA - 224) & 511)]) + ((0.00488296151f * fVec16[((IOTA - 223) & 511)]) + ((0.00439466536f * fVec16[((IOTA - 222) & 511)]) + ((0.00329599902f * fVec16[((IOTA - 221) & 511)]) + ((0.00213629566f * fVec16[((IOTA - 206) & 511)]) + ((0.0045167394f * fVec16[((IOTA - 191) & 511)]) + ((0.00720236823f * fVec16[((IOTA - 190) & 511)]) + ((0.00878933072f * (fVec16[((IOTA - 84) & 511)] + fVec16[((IOTA - 189) & 511)])) + ((0.00799584948f * fVec16[((IOTA - 188) & 511)]) + ((0.00585955381f * (fVec16[((IOTA - 59) & 511)] + fVec16[((IOTA - 187) & 511)])) + ((0.00424207281f * (fVec16[((IOTA - 181) & 511)] + fVec16[((IOTA - 226) & 511)])) + ((0.00268562883f * fVec16[((IOTA - 183) & 511)]) + ((0.0042115543f * fVec16[((IOTA - 182) & 511)]) + ((0.00286873989f * fVec16[((IOTA - 180) & 511)]) + ((0.00314340647f * fVec16[((IOTA - 186) & 511)]) + ((0.00283822138f * fVec16[((IOTA - 175) & 511)]) + ((0.00454725791f * fVec16[((IOTA - 173) & 511)]) + ((0.00335703604f * fVec16[((IOTA - 172) & 511)]) + ((0.00427259132f * ((fVec16[((IOTA - 156) & 511)] - (fVec16[((IOTA - 38) & 511)] + fVec16[((IOTA - 132) & 511)])) + fVec16[((IOTA - 170) & 511)])) + ((0.00491348002f * fVec16[((IOTA - 169) & 511)]) + ((0.00436414685f * fVec16[((IOTA - 168) & 511)]) + ((0.00125125889f * (fVec16[((IOTA - 2) & 511)] - fVec16[((IOTA - 166) & 511)])) + ((0.00332651753f * fVec16[((IOTA - 163) & 511)]) + ((0.00457777642f * fVec16[((IOTA - 162) & 511)]) + ((0.00573747978f * fVec16[((IOTA - 161) & 511)]) + ((0.00509659108f * fVec16[((IOTA - 158) & 511)]) + ((0.00665303506f * fVec16[((IOTA - 157) & 511)]) + ((0.00790429395f * (fVec16[((IOTA - 58) & 511)] + fVec16[((IOTA - 152) & 511)])) + ((0.0187994018f * fVec16[((IOTA - 151) & 511)]) + ((0.0219733268f * fVec16[((IOTA - 150) & 511)]) + ((0.0137333293f * fVec16[((IOTA - 149) & 511)]) + ((0.00518814661f * (fVec16[((IOTA - 20) & 511)] - fVec16[((IOTA - 147) & 511)])) + ((0.00686666463f * fVec16[((IOTA - 130) & 511)]) + ((0.0147709586f * fVec16[((IOTA - 129) & 511)]) + ((0.0227973275f * fVec16[((IOTA - 128) & 511)]) + ((0.0274971779f * fVec16[((IOTA - 127) & 511)]) + ((0.0279854741f * fVec16[((IOTA - 126) & 511)]) + ((0.0205694754f * fVec16[((IOTA - 125) & 511)]) + ((0.00683614612f * fVec16[((IOTA - 124) & 511)]) + ((0.0137638478f * fVec16[((IOTA - 120) & 511)]) + ((0.0331431031f * fVec16[((IOTA - 119) & 511)]) + ((0.0446790978f * fVec16[((IOTA - 118) & 511)]) + ((0.0466322824f * fVec16[((IOTA - 117) & 511)]) + ((0.0394909531f * fVec16[((IOTA - 116) & 511)]) + ((0.0313730277f * fVec16[((IOTA - 115) & 511)]) + ((0.021149328f * fVec16[((IOTA - 114) & 511)]) + ((0.00692770164f * fVec16[((IOTA - 113) & 511)]) + ((0.00473036896f * fVec16[((IOTA - 102) & 511)]) + ((0.018097477f * fVec16[((IOTA - 101) & 511)]) + ((0.022461623f * fVec16[((IOTA - 100) & 511)]) + ((0.00900296029f * fVec16[((IOTA - 99) & 511)]) + ((0.027558215f * fVec16[((IOTA - 94) & 511)]) + ((0.043244727f * fVec16[((IOTA - 93) & 511)]) + ((0.0475783572f * fVec16[((IOTA - 92) & 511)]) + ((0.0350352488f * fVec16[((IOTA - 91) & 511)]) + ((0.0148319956f * fVec16[((IOTA - 90) & 511)]) + ((0.0282601397f * fVec16[((IOTA - 87) & 511)]) + ((0.0330515467f * fVec16[((IOTA - 86) & 511)]) + ((0.0338755473f * fVec16[((IOTA - 85) & 511)]) + ((0.00302133244f * fVec16[((IOTA - 83) & 511)]) + ((0.00653096102f * fVec16[((IOTA - 79) & 511)]) + ((0.0335703604f * fVec16[((IOTA - 78) & 511)]) + ((0.082491532f * fVec16[((IOTA - 77) & 511)]) + ((0.15045625f * fVec16[((IOTA - 76) & 511)]) + ((0.177617729f * fVec16[((IOTA - 75) & 511)]) + ((0.121219523f * fVec16[((IOTA - 74) & 511)]) + ((0.00222785119f * fVec16[((IOTA - 62) & 511)]) + ((0.00405896176f * fVec16[((IOTA - 60) & 511)]) + ((0.00888088625f * fVec16[((IOTA - 57) & 511)]) + ((0.00811792351f * fVec16[((IOTA - 56) & 511)]) + ((0.00540177617f * fVec16[((IOTA - 55) & 511)]) + ((0.00198370311f * fVec16[((IOTA - 47) & 511)]) + ((0.00854518265f * fVec16[((IOTA - 45) & 511)]) + ((0.00781273842f * fVec16[((IOTA - 44) & 511)]) + ((0.00506607257f * fVec16[((IOTA - 43) & 511)]) + ((0.0058290353f * fVec16[((IOTA - 33) & 511)]) + ((0.00833155308f * fVec16[((IOTA - 32) & 511)]) + ((0.009704886f * fVec16[((IOTA - 31) & 511)]) + ((0.00915555283f * fVec16[((IOTA - 30) & 511)]) + ((0.00631733146f * fVec16[((IOTA - 29) & 511)]) + ((0.00418103579f * fVec16[((IOTA - 18) & 511)]) + (0.00567644276f * fVec16[((IOTA - 19) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00057985168f * (((((fVec16[((IOTA - 331) & 511)] + fVec16[((IOTA - 377) & 511)]) + fVec16[((IOTA - 408) & 511)]) - fVec16[((IOTA - 450) & 511)]) + fVec16[((IOTA - 451) & 511)]) - fVec16[((IOTA - 511) & 511)])))))))) : (iSlow3 ? (iSlow24 ? (iSlow32 ? (iSlow36 ? (((0.00149540696f * (fVec15[((IOTA - 474) & 511)] + fVec15[((IOTA - 510) & 511)])) + ((0.00103762932f * (fVec15[((IOTA - 487) & 511)] + fVec15[((IOTA - 508) & 511)])) + ((0.000823999755f * ((fVec15[((IOTA - 363) & 511)] + fVec15[((IOTA - 494) & 511)]) + fVec15[((IOTA - 507) & 511)])) + ((0.00109866634f * ((((fVec15[((IOTA - 35) & 511)] + fVec15[((IOTA - 46) & 511)]) - fVec15[((IOTA - 360) & 511)]) - fVec15[((IOTA - 389) & 511)]) + fVec15[((IOTA - 498) & 511)])) + ((0.000152592547f * ((fVec15[((IOTA - 14) & 511)] + fVec15[((IOTA - 409) & 511)]) + fVec15[((IOTA - 492) & 511)])) + ((3.05185094e-05f * fVec15[((IOTA - 491) & 511)]) + ((0.000122074038f * (((fVec15[((IOTA - 34) & 511)] - fVec15[((IOTA - 399) & 511)]) - fVec15[((IOTA - 449) & 511)]) + fVec15[((IOTA - 490) & 511)])) + ((0.000366222113f * (((fVec15[((IOTA - 398) & 511)] + fVec15[((IOTA - 425) & 511)]) + fVec15[((IOTA - 464) & 511)]) + fVec15[((IOTA - 489) & 511)])) + ((0.00308236945f * fVec15[((IOTA - 483) & 511)]) + ((0.00305185094f * fVec15[((IOTA - 482) & 511)]) + ((0.00189214759f * (fVec15[((IOTA - 475) & 511)] - ((fVec15[((IOTA - 373) & 511)] - fVec15[((IOTA - 395) & 511)]) - fVec15[((IOTA - 471) & 511)]))) + ((0.000244148076f * fVec15[((IOTA - 463) & 511)]) + ((0.000427259132f * (((fVec15[((IOTA - 410) & 511)] - (fVec15[((IOTA - 200) & 511)] + fVec15[((IOTA - 408) & 511)])) + fVec15[((IOTA - 411) & 511)]) + fVec15[((IOTA - 460) & 511)])) + ((0.00122074038f * fVec15[((IOTA - 459) & 511)]) + ((0.00201422162f * (((((fVec15[((IOTA - 10) & 511)] - fVec15[((IOTA - 121) & 511)]) - fVec15[((IOTA - 303) & 511)]) - fVec15[((IOTA - 337) & 511)]) + fVec15[((IOTA - 456) & 511)]) + fVec15[((IOTA - 458) & 511)])) + ((0.00234992523f * (((fVec15[((IOTA - 36) & 511)] - fVec15[((IOTA - 349) & 511)]) + fVec15[((IOTA - 418) & 511)]) + fVec15[((IOTA - 457) & 511)])) + ((0.000885036774f * ((fVec15[((IOTA - 435) & 511)] - ((fVec15[((IOTA - 196) & 511)] - fVec15[((IOTA - 364) & 511)]) + fVec15[((IOTA - 401) & 511)])) + fVec15[((IOTA - 454) & 511)])) + ((0.00100711081f * ((((fVec15[((IOTA - 146) & 511)] - fVec15[((IOTA - 312) & 511)]) - fVec15[((IOTA - 339) & 511)]) - fVec15[((IOTA - 341) & 511)]) + fVec15[((IOTA - 453) & 511)])) + ((0.00418103579f * fVec15[((IOTA - 442) & 511)]) + ((0.00274666585f * fVec15[((IOTA - 441) & 511)]) + ((0.00143436994f * (fVec15[((IOTA - 147) & 511)] + fVec15[((IOTA - 440) & 511)])) + ((0.00390636921f * fVec15[((IOTA - 431) & 511)]) + ((0.000915555283f * ((fVec15[((IOTA - 20) & 511)] - fVec15[((IOTA - 313) & 511)]) + fVec15[((IOTA - 426) & 511)])) + ((9.15555283e-05f * (fVec15[((IOTA - 423) & 511)] + fVec15[((IOTA - 424) & 511)])) + ((0.00125125889f * (fVec15[((IOTA - 396) & 511)] + fVec15[((IOTA - 420) & 511)])) + ((0.000640888698f * fVec15[((IOTA - 414) & 511)]) + ((0.00341807306f * ((fVec15[((IOTA - 37) & 511)] - fVec15[((IOTA - 203) & 511)]) + fVec15[((IOTA - 393) & 511)])) + ((0.00375377666f * fVec15[((IOTA - 392) & 511)]) + ((0.00381481368f * (fVec15[((IOTA - 160) & 511)] - fVec15[((IOTA - 387) & 511)])) + ((0.00482192449f * ((fVec15[((IOTA - 134) & 511)] + fVec15[((IOTA - 159) & 511)]) - fVec15[((IOTA - 381) & 511)])) + ((0.00363170262f * fVec15[((IOTA - 376) & 511)]) + ((0.00433362834f * ((fVec15[((IOTA - 22) & 511)] - fVec15[((IOTA - 239) & 511)]) - fVec15[((IOTA - 372) & 511)])) + ((0.00619525742f * (fVec15[((IOTA - 103) & 511)] - fVec15[((IOTA - 371) & 511)])) + ((0.00222785119f * ((fVec15[((IOTA - 133) & 511)] - fVec15[((IOTA - 254) & 511)]) - fVec15[((IOTA - 368) & 511)])) + ((0.00210577715f * (fVec15[((IOTA - 161) & 511)] - fVec15[((IOTA - 353) & 511)])) + ((0.00262459181f * (((fVec15[((IOTA - 24) & 511)] - fVec15[((IOTA - 259) & 511)]) - fVec15[((IOTA - 348) & 511)]) + fVec15[((IOTA - 428) & 511)])) + ((0.00112918485f * (fVec15[((IOTA - 9) & 511)] - fVec15[((IOTA - 315) & 511)])) + ((0.00219733268f * (((fVec15[((IOTA - 157) & 511)] - fVec15[((IOTA - 256) & 511)]) - fVec15[((IOTA - 288) & 511)]) - fVec15[((IOTA - 304) & 511)])) + ((0.00268562883f * (((fVec15[((IOTA - 11) & 511)] + fVec15[((IOTA - 12) & 511)]) + fVec15[((IOTA - 39) & 511)]) - fVec15[((IOTA - 291) & 511)])) + ((0.00317392498f * ((fVec15[((IOTA - 21) & 511)] - fVec15[((IOTA - 283) & 511)]) - fVec15[((IOTA - 383) & 511)])) + ((0.00329599902f * ((fVec15[((IOTA - 112) & 511)] - fVec15[((IOTA - 273) & 511)]) - fVec15[((IOTA - 282) & 511)])) + ((0.00408948027f * (((fVec15[((IOTA - 23) & 511)] - fVec15[((IOTA - 217) & 511)]) - fVec15[((IOTA - 222) & 511)]) - fVec15[((IOTA - 243) & 511)])) + ((0.0045167394f * (fVec15[((IOTA - 76) & 511)] - fVec15[((IOTA - 240) & 511)])) + ((0.00399792474f * ((fVec15[((IOTA - 47) & 511)] - fVec15[((IOTA - 207) & 511)]) - fVec15[((IOTA - 237) & 511)])) + ((0.0054933317f * (fVec15[((IOTA - 48) & 511)] - fVec15[((IOTA - 231) & 511)])) + ((0.0051576281f * (fVec15[((IOTA - 49) & 511)] - fVec15[((IOTA - 227) & 511)])) + ((0.0058290353f * ((fVec15[((IOTA - 135) & 511)] - fVec15[((IOTA - 177) & 511)]) - fVec15[((IOTA - 188) & 511)])) + ((0.0106204413f * (fVec15[((IOTA - 111) & 511)] - fVec15[((IOTA - 184) & 511)])) + ((0.00790429395f * (fVec15[((IOTA - 139) & 511)] - fVec15[((IOTA - 174) & 511)])) + ((0.00457777642f * fVec15[((IOTA - 158) & 511)]) + ((0.00857570115f * fVec15[((IOTA - 137) & 511)]) + ((0.00653096102f * fVec15[((IOTA - 136) & 511)]) + ((0.00866725668f * fVec15[((IOTA - 124) & 511)]) + ((0.0177617725f * fVec15[((IOTA - 123) & 511)]) + ((0.0142826624f * fVec15[((IOTA - 122) & 511)]) + ((0.0148319956f * fVec15[((IOTA - 110) & 511)]) + ((0.0145268105f * fVec15[((IOTA - 109) & 511)]) + ((0.0164494775f * fVec15[((IOTA - 108) & 511)]) + ((0.0216681417f * fVec15[((IOTA - 107) & 511)]) + ((0.0282601397f * fVec15[((IOTA - 106) & 511)]) + ((0.0249031037f * fVec15[((IOTA - 105) & 511)]) + ((0.0164799951f * fVec15[((IOTA - 104) & 511)]) + ((0.034272287f * fVec15[((IOTA - 96) & 511)]) + ((0.0347911008f * fVec15[((IOTA - 95) & 511)]) + ((0.0119327372f * fVec15[((IOTA - 94) & 511)]) + ((0.0271919928f * fVec15[((IOTA - 81) & 511)]) + ((0.0210272539f * fVec15[((IOTA - 80) & 511)]) + ((0.0143436994f * fVec15[((IOTA - 79) & 511)]) + ((0.0110171819f * fVec15[((IOTA - 78) & 511)]) + ((0.0278634001f * fVec15[((IOTA - 77) & 511)]) + ((0.0148625141f * fVec15[((IOTA - 72) & 511)]) + ((0.224402606f * fVec15[((IOTA - 71) & 511)]) + ((0.335337371f * fVec15[((IOTA - 70) & 511)]) + ((0.272865981f * fVec15[((IOTA - 69) & 511)]) + ((0.126590773f * fVec15[((IOTA - 68) & 511)]) + ((0.0367137678f * fVec15[((IOTA - 67) & 511)]) + ((0.00964384899f * fVec15[((IOTA - 66) & 511)]) + ((0.00393688772f * fVec15[((IOTA - 65) & 511)]) + ((0.00332651753f * fVec15[((IOTA - 50) & 511)]) + ((0.000335703604f * fVec15[((IOTA - 8) & 511)]) + (0.00366222113f * fVec15[((IOTA - 38) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.0012817774f * (((fVec15[((IOTA - 26) & 511)] + fVec15[((IOTA - 58) & 511)]) + fVec15[((IOTA - 379) & 511)]) - fVec15[((IOTA - 509) & 511)])) + ((0.000701925717f * ((fVec15[((IOTA - 212) & 511)] - fVec15[((IOTA - 505) & 511)]) - fVec15[((IOTA - 506) & 511)])) + ((0.000732444227f * ((fVec15[((IOTA - 344) & 511)] - fVec15[((IOTA - 503) & 511)]) - fVec15[((IOTA - 504) & 511)])) + ((0.000671407208f * (((((fVec15[((IOTA - 400) & 511)] - fVec15[((IOTA - 421) & 511)]) + fVec15[((IOTA - 448) & 511)]) - fVec15[((IOTA - 488) & 511)]) - fVec15[((IOTA - 501) & 511)]) - fVec15[((IOTA - 502) & 511)])) + ((0.000762962736f * ((((((fVec15[((IOTA - 31) & 511)] - fVec15[((IOTA - 51) & 511)]) - fVec15[((IOTA - 365) & 511)]) + fVec15[((IOTA - 402) & 511)]) + fVec15[((IOTA - 403) & 511)]) - fVec15[((IOTA - 450) & 511)]) - fVec15[((IOTA - 500) & 511)])) + ((0.000946073793f * (((((fVec15[((IOTA - 5) & 511)] + fVec15[((IOTA - 57) & 511)]) + fVec15[((IOTA - 314) & 511)]) + fVec15[((IOTA - 343) & 511)]) - fVec15[((IOTA - 467) & 511)]) - fVec15[((IOTA - 499) & 511)])) + ((0.00119022187f * ((fVec15[((IOTA - 404) & 511)] - fVec15[((IOTA - 496) & 511)]) - fVec15[((IOTA - 497) & 511)])) + ((0.00106814783f * (fVec15[((IOTA - 342) & 511)] - fVec15[((IOTA - 495) & 511)])) + ((0.000457777642f * (((fVec15[((IOTA - 197) & 511)] - fVec15[((IOTA - 366) & 511)]) - fVec15[((IOTA - 436) & 511)]) - fVec15[((IOTA - 493) & 511)])) + ((0.00155644398f * (fVec15[((IOTA - 268) & 511)] - fVec15[((IOTA - 486) & 511)])) + ((0.00216681417f * ((((fVec15[((IOTA - 45) & 511)] + fVec15[((IOTA - 55) & 511)]) + fVec15[((IOTA - 323) & 511)]) + fVec15[((IOTA - 333) & 511)]) - fVec15[((IOTA - 485) & 511)])) + ((0.00277718436f * (fVec15[((IOTA - 53) & 511)] - fVec15[((IOTA - 484) & 511)])) + ((0.00280770287f * (((fVec15[((IOTA - 156) & 511)] + fVec15[((IOTA - 165) & 511)]) + fVec15[((IOTA - 250) & 511)]) - fVec15[((IOTA - 481) & 511)])) + ((0.00250251777f * ((((fVec15[((IOTA - 290) & 511)] + fVec15[((IOTA - 308) & 511)]) + fVec15[((IOTA - 356) & 511)]) + fVec15[((IOTA - 358) & 511)]) - fVec15[((IOTA - 480) & 511)])) + ((0.00238044374f * (((fVec15[((IOTA - 334) & 511)] + fVec15[((IOTA - 336) & 511)]) - fVec15[((IOTA - 433) & 511)]) - fVec15[((IOTA - 479) & 511)])) + ((0.00241096225f * ((fVec15[((IOTA - 27) & 511)] + fVec15[((IOTA - 202) & 511)]) - fVec15[((IOTA - 478) & 511)])) + ((0.00244148076f * (((((fVec15[((IOTA - 253) & 511)] + fVec15[((IOTA - 257) & 511)]) + fVec15[((IOTA - 305) & 511)]) + fVec15[((IOTA - 335) & 511)]) - fVec15[((IOTA - 417) & 511)]) - fVec15[((IOTA - 477) & 511)])) + ((0.00228888821f * (fVec15[((IOTA - 320) & 511)] - fVec15[((IOTA - 476) & 511)])) + ((0.00134281442f * (((fVec15[((IOTA - 30) & 511)] + fVec15[((IOTA - 213) & 511)]) - fVec15[((IOTA - 455) & 511)]) - fVec15[((IOTA - 473) & 511)])) + ((0.00152592547f * ((fVec15[((IOTA - 52) & 511)] - fVec15[((IOTA - 434) & 511)]) - fVec15[((IOTA - 472) & 511)])) + ((0.00213629566f * ((fVec15[((IOTA - 255) & 511)] + fVec15[((IOTA - 354) & 511)]) - fVec15[((IOTA - 470) & 511)])) + ((0.0019531846f * (fVec15[((IOTA - 350) & 511)] - fVec15[((IOTA - 469) & 511)])) + ((0.00146488845f * (((fVec15[((IOTA - 1) & 511)] + fVec15[((IOTA - 316) & 511)]) + fVec15[((IOTA - 338) & 511)]) - fVec15[((IOTA - 468) & 511)])) + ((0.00057985168f * (((((fVec15[((IOTA - 6) & 511)] - fVec15[((IOTA - 25) & 511)]) - fVec15[((IOTA - 162) & 511)]) + fVec15[((IOTA - 210) & 511)]) - fVec15[((IOTA - 439) & 511)]) - fVec15[((IOTA - 466) & 511)])) + ((0.000396740623f * ((((fVec15[((IOTA - 163) & 511)] + fVec15[((IOTA - 198) & 511)]) + fVec15[((IOTA - 326) & 511)]) + fVec15[((IOTA - 367) & 511)]) - fVec15[((IOTA - 465) & 511)])) + ((6.10370189e-05f * ((fVec15[((IOTA - 140) & 511)] - fVec15[((IOTA - 461) & 511)]) - fVec15[((IOTA - 462) & 511)])) + ((0.00131229591f * (((((((fVec15[((IOTA - 201) & 511)] + fVec15[((IOTA - 311) & 511)]) + fVec15[((IOTA - 328) & 511)]) + fVec15[((IOTA - 330) & 511)]) - fVec15[((IOTA - 390) & 511)]) - fVec15[((IOTA - 415) & 511)]) - fVec15[((IOTA - 446) & 511)]) - fVec15[((IOTA - 452) & 511)])) + ((0.00137333293f * ((((fVec15[((IOTA - 4) & 511)] + fVec15[((IOTA - 56) & 511)]) + fVec15[((IOTA - 324) & 511)]) + fVec15[((IOTA - 329) & 511)]) - fVec15[((IOTA - 451) & 511)])) + ((0.000213629566f * (fVec15[((IOTA - 199) & 511)] + fVec15[((IOTA - 447) & 511)])) + ((0.003234962f * ((fVec15[((IOTA - 248) & 511)] + fVec15[((IOTA - 272) & 511)]) - fVec15[((IOTA - 445) & 511)])) + ((0.00466933195f * (fVec15[((IOTA - 369) & 511)] - fVec15[((IOTA - 444) & 511)])) + ((0.00497451704f * (fVec15[((IOTA - 190) & 511)] - fVec15[((IOTA - 443) & 511)])) + ((0.000274666585f * (((fVec15[((IOTA - 211) & 511)] - fVec15[((IOTA - 413) & 511)]) - fVec15[((IOTA - 437) & 511)]) - fVec15[((IOTA - 438) & 511)])) + ((0.00326548051f * ((fVec15[((IOTA - 208) & 511)] + fVec15[((IOTA - 281) & 511)]) - fVec15[((IOTA - 432) & 511)])) + ((0.00402844325f * (fVec15[((IOTA - 206) & 511)] - fVec15[((IOTA - 430) & 511)])) + ((0.0035401471f * (fVec15[((IOTA - 18) & 511)] - fVec15[((IOTA - 429) & 511)])) + ((0.00167851802f * ((fVec15[((IOTA - 214) & 511)] + fVec15[((IOTA - 406) & 511)]) - fVec15[((IOTA - 427) & 511)])) + ((0.000305185094f * (((fVec15[((IOTA - 33) & 511)] - fVec15[((IOTA - 374) & 511)]) - fVec15[((IOTA - 412) & 511)]) - fVec15[((IOTA - 422) & 511)])) + ((0.00183111057f * ((fVec15[((IOTA - 195) & 511)] + fVec15[((IOTA - 266) & 511)]) - fVec15[((IOTA - 419) & 511)])) + ((0.00207525864f * ((fVec15[((IOTA - 301) & 511)] + fVec15[((IOTA - 319) & 511)]) - fVec15[((IOTA - 416) & 511)])) + ((0.00115970336f * (fVec15[((IOTA - 164) & 511)] + fVec15[((IOTA - 407) & 511)])) + ((0.00164799951f * fVec15[((IOTA - 405) & 511)]) + ((0.000793481246f * (fVec15[((IOTA - 340) & 511)] - fVec15[((IOTA - 397) & 511)])) + ((0.00265511032f * ((fVec15[((IOTA - 251) & 511)] + fVec15[((IOTA - 357) & 511)]) - fVec15[((IOTA - 394) & 511)])) + ((0.00314340647f * (((((fVec15[((IOTA - 274) & 511)] + fVec15[((IOTA - 280) & 511)]) + fVec15[((IOTA - 295) & 511)]) + fVec15[((IOTA - 296) & 511)]) + fVec15[((IOTA - 297) & 511)]) - fVec15[((IOTA - 391) & 511)])) + ((0.00302133244f * (((fVec15[((IOTA - 249) & 511)] + fVec15[((IOTA - 279) & 511)]) + fVec15[((IOTA - 293) & 511)]) + fVec15[((IOTA - 388) & 511)])) + ((0.00369273964f * (fVec15[((IOTA - 236) & 511)] + fVec15[((IOTA - 386) & 511)])) + ((0.00320444349f * fVec15[((IOTA - 385) & 511)]) + ((0.00286873989f * (((fVec15[((IOTA - 54) & 511)] + fVec15[((IOTA - 271) & 511)]) + fVec15[((IOTA - 275) & 511)]) + fVec15[((IOTA - 384) & 511)])) + ((0.00415051728f * (fVec15[((IOTA - 244) & 511)] + fVec15[((IOTA - 382) & 511)])) + ((0.0038758507f * ((fVec15[((IOTA - 204) & 511)] + fVec15[((IOTA - 221) & 511)]) + fVec15[((IOTA - 380) & 511)])) + ((0.00180059206f * (((((fVec15[((IOTA - 264) & 511)] + fVec15[((IOTA - 269) & 511)]) + fVec15[((IOTA - 310) & 511)]) + fVec15[((IOTA - 332) & 511)]) + fVec15[((IOTA - 351) & 511)]) - fVec15[((IOTA - 378) & 511)])) + ((0.00360118411f * (fVec15[((IOTA - 235) & 511)] - fVec15[((IOTA - 377) & 511)])) + ((0.0022583697f * ((((fVec15[((IOTA - 41) & 511)] + fVec15[((IOTA - 287) & 511)]) + fVec15[((IOTA - 309) & 511)]) + fVec15[((IOTA - 355) & 511)]) - fVec15[((IOTA - 375) & 511)])) + ((0.00637836847f * fVec15[((IOTA - 370) & 511)]) + ((0.000488296151f * ((fTemp16 - fVec15[((IOTA - 40) & 511)]) - fVec15[((IOTA - 362) & 511)])) + ((0.000183111057f * (fVec15[((IOTA - 7) & 511)] + fVec15[((IOTA - 361) & 511)])) + ((0.0019226661f * ((((fVec15[((IOTA - 209) & 511)] + fVec15[((IOTA - 261) & 511)]) + fVec15[((IOTA - 265) & 511)]) + fVec15[((IOTA - 302) & 511)]) + fVec15[((IOTA - 359) & 511)])) + ((0.00198370311f * (fVec15[((IOTA - 215) & 511)] + fVec15[((IOTA - 352) & 511)])) + ((0.00231940672f * ((((fVec15[((IOTA - 260) & 511)] + fVec15[((IOTA - 270) & 511)]) + fVec15[((IOTA - 289) & 511)]) + fVec15[((IOTA - 300) & 511)]) + fVec15[((IOTA - 347) & 511)])) + ((0.00140385143f * fVec15[((IOTA - 331) & 511)]) + ((0.000854518265f * fVec15[((IOTA - 327) & 511)]) + ((0.000610370189f * ((fVec15[((IOTA - 88) & 511)] + fVec15[((IOTA - 89) & 511)]) + fVec15[((IOTA - 325) & 511)])) + ((0.000976592302f * fVec15[((IOTA - 345) & 511)]) + ((0.00247199927f * ((fVec15[((IOTA - 286) & 511)] + fVec15[((IOTA - 321) & 511)]) + fVec15[((IOTA - 322) & 511)])) + ((0.00186162908f * ((fVec15[((IOTA - 15) & 511)] - (fVec15[((IOTA - 13) & 511)] - fVec15[((IOTA - 2) & 511)])) + fVec15[((IOTA - 318) & 511)])) + ((0.0025940733f * (fVec15[((IOTA - 258) & 511)] + fVec15[((IOTA - 307) & 511)])) + ((0.00256355479f * (((fVec15[((IOTA - 28) & 511)] + fVec15[((IOTA - 148) & 511)]) + fVec15[((IOTA - 252) & 511)]) + fVec15[((IOTA - 306) & 511)])) + ((0.00271614734f * ((((fVec15[((IOTA - 216) & 511)] + fVec15[((IOTA - 276) & 511)]) + fVec15[((IOTA - 277) & 511)]) + fVec15[((IOTA - 285) & 511)]) + fVec15[((IOTA - 299) & 511)])) + ((0.00299081393f * fVec15[((IOTA - 298) & 511)]) + ((0.00311288796f * fVec15[((IOTA - 294) & 511)]) + ((0.00283822138f * (fVec15[((IOTA - 278) & 511)] + fVec15[((IOTA - 292) & 511)])) + ((0.00296029542f * ((fVec15[((IOTA - 59) & 511)] + fVec15[((IOTA - 132) & 511)]) + fVec15[((IOTA - 284) & 511)])) + ((0.00158696249f * (fVec15[((IOTA - 64) & 511)] + fVec15[((IOTA - 263) & 511)])) + ((0.00170903653f * fVec15[((IOTA - 317) & 511)]) + ((0.00344859157f * fVec15[((IOTA - 247) & 511)]) + ((0.00378429517f * fVec15[((IOTA - 246) & 511)]) + ((0.00405896176f * (fVec15[((IOTA - 234) & 511)] + fVec15[((IOTA - 245) & 511)])) + ((0.00427259132f * fVec15[((IOTA - 242) & 511)]) + ((0.0042115543f * (fVec15[((IOTA - 192) & 511)] + fVec15[((IOTA - 238) & 511)])) + ((0.00476088747f * fVec15[((IOTA - 233) & 511)]) + ((0.00531022064f * fVec15[((IOTA - 232) & 511)]) + ((0.00561540574f * fVec15[((IOTA - 230) & 511)]) + ((0.00567644276f * fVec15[((IOTA - 229) & 511)]) + ((0.00555436872f * (fVec15[((IOTA - 43) & 511)] + fVec15[((IOTA - 228) & 511)])) + ((0.00491348002f * fVec15[((IOTA - 226) & 511)]) + ((0.004852443f * fVec15[((IOTA - 225) & 511)]) + ((0.00488296151f * fVec15[((IOTA - 224) & 511)]) + ((0.00463881344f * fVec15[((IOTA - 223) & 511)]) + ((0.00454725791f * (fVec15[((IOTA - 171) & 511)] + fVec15[((IOTA - 220) & 511)])) + ((0.00445570238f * fVec15[((IOTA - 241) & 511)]) + ((0.00543229468f * fVec15[((IOTA - 219) & 511)]) + ((0.00534073915f * fVec15[((IOTA - 218) & 511)]) + ((0.00411999878f * fVec15[((IOTA - 205) & 511)]) + ((0.00292977691f * fVec15[((IOTA - 194) & 511)]) + ((0.00396740623f * fVec15[((IOTA - 193) & 511)]) + ((0.00469985045f * (fVec15[((IOTA - 44) & 511)] + fVec15[((IOTA - 191) & 511)])) + ((0.00576799829f * fVec15[((IOTA - 189) & 511)]) + ((0.0057985168f * fVec15[((IOTA - 187) & 511)]) + ((0.00674459059f * fVec15[((IOTA - 186) & 511)]) + ((0.00891140476f * fVec15[((IOTA - 185) & 511)]) + ((0.0104678487f * fVec15[((IOTA - 183) & 511)]) + ((0.00863673817f * fVec15[((IOTA - 182) & 511)]) + ((0.00762962736f * fVec15[((IOTA - 181) & 511)]) + ((0.00827051606f * fVec15[((IOTA - 180) & 511)]) + ((0.00869777519f * fVec15[((IOTA - 179) & 511)]) + ((0.00756859034f * fVec15[((IOTA - 178) & 511)]) + ((0.00540177617f * fVec15[((IOTA - 176) & 511)]) + ((0.00634784997f * fVec15[((IOTA - 175) & 511)]) + ((0.00778221991f * fVec15[((IOTA - 173) & 511)]) + ((0.00607318338f * fVec15[((IOTA - 172) & 511)]) + ((0.00625629444f * (fVec15[((IOTA - 149) & 511)] + fVec15[((IOTA - 170) & 511)])) + ((0.00943021942f * fVec15[((IOTA - 169) & 511)]) + ((0.0120548112f * fVec15[((IOTA - 168) & 511)]) + ((0.0105288858f * fVec15[((IOTA - 167) & 511)]) + ((0.00680562761f * fVec15[((IOTA - 166) & 511)]) + ((0.00823999755f * fVec15[((IOTA - 155) & 511)]) + ((0.0122379223f * fVec15[((IOTA - 154) & 511)]) + ((0.0115970336f * fVec15[((IOTA - 153) & 511)]) + ((0.00814844202f * fVec15[((IOTA - 152) & 511)]) + ((0.00564592425f * fVec15[((IOTA - 151) & 511)]) + ((0.00640888698f * fVec15[((IOTA - 150) & 511)]) + ((0.00546281319f * fVec15[((IOTA - 145) & 511)]) + ((0.0144657735f * fVec15[((IOTA - 144) & 511)]) + ((0.0211188085f * fVec15[((IOTA - 143) & 511)]) + ((0.0201116987f * fVec15[((IOTA - 142) & 511)]) + ((0.011383404f * fVec15[((IOTA - 141) & 511)]) + ((0.0101321451f * (fVec15[((IOTA - 87) & 511)] - fVec15[((IOTA - 138) & 511)])) + ((0.00982696004f * fVec15[((IOTA - 131) & 511)]) + ((0.0171208847f * fVec15[((IOTA - 130) & 511)]) + ((0.0246284381f * fVec15[((IOTA - 129) & 511)]) + ((0.0281380657f * fVec15[((IOTA - 128) & 511)]) + ((0.0269173253f * fVec15[((IOTA - 127) & 511)]) + ((0.0191351064f * fVec15[((IOTA - 126) & 511)]) + ((0.00708029419f * fVec15[((IOTA - 125) & 511)]) + ((0.0188299213f * fVec15[((IOTA - 120) & 511)]) + ((0.0294503625f * fVec15[((IOTA - 119) & 511)]) + ((0.0306100659f * fVec15[((IOTA - 118) & 511)]) + ((0.0257881414f * fVec15[((IOTA - 117) & 511)]) + ((0.0206915494f * fVec15[((IOTA - 116) & 511)]) + ((0.0187383648f * fVec15[((IOTA - 115) & 511)]) + ((0.0153508103f * fVec15[((IOTA - 114) & 511)]) + ((0.00671407208f * fVec15[((IOTA - 113) & 511)]) + ((0.00500503555f * fVec15[((IOTA - 102) & 511)]) + ((0.0135196997f * fVec15[((IOTA - 101) & 511)]) + ((0.0247505121f * fVec15[((IOTA - 100) & 511)]) + ((0.0276497696f * fVec15[((IOTA - 99) & 511)]) + ((0.0159306619f * fVec15[((IOTA - 98) & 511)]) + ((0.013000885f * (fVec15[((IOTA - 93) & 511)] - fVec15[((IOTA - 97) & 511)])) + ((0.0307321399f * fVec15[((IOTA - 92) & 511)]) + ((0.0317697674f * fVec15[((IOTA - 91) & 511)]) + ((0.0152287362f * fVec15[((IOTA - 90) & 511)]) + ((0.0165715516f * fVec15[((IOTA - 86) & 511)]) + ((0.0270699188f * fVec15[((IOTA - 85) & 511)]) + ((0.0427564308f * fVec15[((IOTA - 84) & 511)]) + ((0.029114658f * fVec15[((IOTA - 83) & 511)]) + ((0.00732444227f * fVec15[((IOTA - 82) & 511)]) + ((0.0771507919f * fVec15[((IOTA - 75) & 511)]) + ((0.14944914f * fVec15[((IOTA - 74) & 511)]) + ((0.144718766f * fVec15[((IOTA - 73) & 511)]) + ((0.00726340525f * fVec15[((IOTA - 63) & 511)]) + ((0.00949125644f * fVec15[((IOTA - 62) & 511)]) + ((0.00894192327f * fVec15[((IOTA - 61) & 511)]) + ((0.00604266487f * fVec15[((IOTA - 60) & 511)]) + ((0.00460829493f * fVec15[((IOTA - 42) & 511)]) + ((0.000518814661f * fVec15[((IOTA - 32) & 511)]) + ((0.00204474013f * fVec15[((IOTA - 29) & 511)]) + ((0.00173955504f * fVec15[((IOTA - 3) & 511)]) + ((0.00357066561f * fVec15[((IOTA - 16) & 511)]) + (0.00424207281f * fVec15[((IOTA - 17) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.001617481f * ((((fVec15[((IOTA - 19) & 511)] + fVec15[((IOTA - 262) & 511)]) + fVec15[((IOTA - 267) & 511)]) + fVec15[((IOTA - 346) & 511)]) - fVec15[((IOTA - 511) & 511)])))) : (((0.000122074038f * ((((((((((((((((((((((fVec14[((IOTA - 98) & 511)] + fVec14[((IOTA - 168) & 511)]) + fVec14[((IOTA - 178) & 511)]) + fVec14[((IOTA - 227) & 511)]) - fVec14[((IOTA - 268) & 511)]) - fVec14[((IOTA - 273) & 511)]) + fVec14[((IOTA - 290) & 511)]) - fVec14[((IOTA - 335) & 511)]) + fVec14[((IOTA - 352) & 511)]) + fVec14[((IOTA - 353) & 511)]) + fVec14[((IOTA - 356) & 511)]) + fVec14[((IOTA - 387) & 511)]) + fVec14[((IOTA - 412) & 511)]) + fVec14[((IOTA - 414) & 511)]) - fVec14[((IOTA - 437) & 511)]) + fVec14[((IOTA - 446) & 511)]) - fVec14[((IOTA - 464) & 511)]) - fVec14[((IOTA - 466) & 511)]) - fVec14[((IOTA - 478) & 511)]) - fVec14[((IOTA - 479) & 511)]) + fVec14[((IOTA - 482) & 511)]) + fVec14[((IOTA - 484) & 511)]) - fVec14[((IOTA - 509) & 511)])) + ((6.10370189e-05f * ((((((((((((((((((((((fVec14[((IOTA - 169) & 511)] - fVec14[((IOTA - 177) & 511)]) + fVec14[((IOTA - 222) & 511)]) + fVec14[((IOTA - 231) & 511)]) - fVec14[((IOTA - 267) & 511)]) - fVec14[((IOTA - 272) & 511)]) + fVec14[((IOTA - 355) & 511)]) + fVec14[((IOTA - 366) & 511)]) - fVec14[((IOTA - 399) & 511)]) - fVec14[((IOTA - 410) & 511)]) + fVec14[((IOTA - 411) & 511)]) - fVec14[((IOTA - 430) & 511)]) + fVec14[((IOTA - 445) & 511)]) + fVec14[((IOTA - 447) & 511)]) - fVec14[((IOTA - 450) & 511)]) + fVec14[((IOTA - 452) & 511)]) - fVec14[((IOTA - 460) & 511)]) - fVec14[((IOTA - 474) & 511)]) - fVec14[((IOTA - 480) & 511)]) + fVec14[((IOTA - 492) & 511)]) + fVec14[((IOTA - 493) & 511)]) + fVec14[((IOTA - 500) & 511)]) + fVec14[((IOTA - 502) & 511)])) + (((0.000152592547f * (((((((((((fVec14[((IOTA - 234) & 511)] + fVec14[((IOTA - 262) & 511)]) + fVec14[((IOTA - 332) & 511)]) + fVec14[((IOTA - 340) & 511)]) + fVec14[((IOTA - 351) & 511)]) + fVec14[((IOTA - 372) & 511)]) + fVec14[((IOTA - 386) & 511)]) + fVec14[((IOTA - 415) & 511)]) + fVec14[((IOTA - 453) & 511)]) - fVec14[((IOTA - 461) & 511)]) - fVec14[((IOTA - 467) & 511)]) - fVec14[((IOTA - 469) & 511)])) + ((0.000305185094f * ((((((((((((fVec14[((IOTA - 224) & 511)] - fVec14[((IOTA - 229) & 511)]) + fVec14[((IOTA - 240) & 511)]) + fVec14[((IOTA - 259) & 511)]) - fVec14[((IOTA - 264) & 511)]) - fVec14[((IOTA - 269) & 511)]) - fVec14[((IOTA - 274) & 511)]) - fVec14[((IOTA - 278) & 511)]) - fVec14[((IOTA - 286) & 511)]) - fVec14[((IOTA - 287) & 511)]) + fVec14[((IOTA - 303) & 511)]) - fVec14[((IOTA - 417) & 511)]) + fVec14[((IOTA - 458) & 511)])) + ((0.000457777642f * (((((((((((((fVec14[((IOTA - 150) & 511)] + fVec14[((IOTA - 220) & 511)]) + fVec14[((IOTA - 238) & 511)]) - fVec14[((IOTA - 275) & 511)]) - fVec14[((IOTA - 276) & 511)]) - fVec14[((IOTA - 281) & 511)]) - fVec14[((IOTA - 282) & 511)]) - fVec14[((IOTA - 283) & 511)]) - fVec14[((IOTA - 284) & 511)]) + fVec14[((IOTA - 349) & 511)]) - fVec14[((IOTA - 370) & 511)]) + fVec14[((IOTA - 388) & 511)]) - fVec14[((IOTA - 424) & 511)]) + fVec14[((IOTA - 457) & 511)])) + ((0.000518814661f * ((((((((((((fVec14[((IOTA - 120) & 511)] + fVec14[((IOTA - 158) & 511)]) + fVec14[((IOTA - 219) & 511)]) + fVec14[((IOTA - 237) & 511)]) + fVec14[((IOTA - 254) & 511)]) + fVec14[((IOTA - 256) & 511)]) + fVec14[((IOTA - 294) & 511)]) + fVec14[((IOTA - 304) & 511)]) + fVec14[((IOTA - 346) & 511)]) + fVec14[((IOTA - 359) & 511)]) - fVec14[((IOTA - 368) & 511)]) - fVec14[((IOTA - 431) & 511)]) + fVec14[((IOTA - 456) & 511)])) + ((0.000427259132f * (((((((fVec14[((IOTA - 41) & 511)] + fVec14[((IOTA - 241) & 511)]) + fVec14[((IOTA - 258) & 511)]) - fVec14[((IOTA - 280) & 511)]) + fVec14[((IOTA - 319) & 511)]) + fVec14[((IOTA - 331) & 511)]) - fVec14[((IOTA - 408) & 511)]) + fVec14[((IOTA - 455) & 511)])) + ((0.000335703604f * (((((fVec14[((IOTA - 119) & 511)] - fVec14[((IOTA - 125) & 511)]) + fVec14[((IOTA - 167) & 511)]) + fVec14[((IOTA - 239) & 511)]) + fVec14[((IOTA - 345) & 511)]) - fVec14[((IOTA - 436) & 511)])) + ((0.000610370189f * ((((((((((fVec14[((IOTA - 175) & 511)] + fVec14[((IOTA - 242) & 511)]) + fVec14[((IOTA - 249) & 511)]) - fVec14[((IOTA - 315) & 511)]) + fVec14[((IOTA - 327) & 511)]) + fVec14[((IOTA - 348) & 511)]) - fVec14[((IOTA - 369) & 511)]) + fVec14[((IOTA - 400) & 511)]) - fVec14[((IOTA - 405) & 511)]) - fVec14[((IOTA - 418) & 511)]) - fVec14[((IOTA - 435) & 511)])) + ((0.00103762932f * ((((((((fVec14[((IOTA - 148) & 511)] + fVec14[((IOTA - 172) & 511)]) + fVec14[((IOTA - 174) & 511)]) + fVec14[((IOTA - 188) & 511)]) + fVec14[((IOTA - 191) & 511)]) + fVec14[((IOTA - 211) & 511)]) - fVec14[((IOTA - 396) & 511)]) - fVec14[((IOTA - 397) & 511)]) - fVec14[((IOTA - 433) & 511)])) + ((0.000915555283f * (((fVec14[((IOTA - 147) & 511)] + fVec14[((IOTA - 189) & 511)]) + fVec14[((IOTA - 197) & 511)]) - fVec14[((IOTA - 432) & 511)])) + ((0.000396740623f * (((((((((((((fVec14[((IOTA - 128) & 511)] - fVec14[((IOTA - 134) & 511)]) + fVec14[((IOTA - 204) & 511)]) + fVec14[((IOTA - 218) & 511)]) + fVec14[((IOTA - 226) & 511)]) + fVec14[((IOTA - 236) & 511)]) + fVec14[((IOTA - 250) & 511)]) + fVec14[((IOTA - 253) & 511)]) - fVec14[((IOTA - 285) & 511)]) + fVec14[((IOTA - 295) & 511)]) - fVec14[((IOTA - 301) & 511)]) + fVec14[((IOTA - 358) & 511)]) + fVec14[((IOTA - 389) & 511)]) - fVec14[((IOTA - 425) & 511)])) + ((0.000244148076f * ((((((((((fVec14[((IOTA - 221) & 511)] + fVec14[((IOTA - 232) & 511)]) + fVec14[((IOTA - 235) & 511)]) + fVec14[((IOTA - 251) & 511)]) + fVec14[((IOTA - 261) & 511)]) + fVec14[((IOTA - 291) & 511)]) + fVec14[((IOTA - 308) & 511)]) + fVec14[((IOTA - 362) & 511)]) + fVec14[((IOTA - 365) & 511)]) - fVec14[((IOTA - 367) & 511)]) - fVec14[((IOTA - 409) & 511)])) + ((0.000640888698f * (((((((fVec14[((IOTA - 181) & 511)] + fVec14[((IOTA - 182) & 511)]) + fVec14[((IOTA - 244) & 511)]) + fVec14[((IOTA - 245) & 511)]) - fVec14[((IOTA - 298) & 511)]) + fVec14[((IOTA - 347) & 511)]) + fVec14[((IOTA - 373) & 511)]) - fVec14[((IOTA - 407) & 511)])) + ((0.000762962736f * (((((fVec14[((IOTA - 83) & 511)] + fVec14[((IOTA - 124) & 511)]) + fVec14[((IOTA - 157) & 511)]) + fVec14[((IOTA - 194) & 511)]) + fVec14[((IOTA - 325) & 511)]) - fVec14[((IOTA - 406) & 511)])) + ((0.00119022187f * (fVec14[((IOTA - 200) & 511)] + fVec14[((IOTA - 402) & 511)])) + ((0.00134281442f * ((fVec14[((IOTA - 121) & 511)] - (fVec14[((IOTA - 113) & 511)] + fVec14[((IOTA - 114) & 511)])) - fVec14[((IOTA - 392) & 511)])) + ((0.00106814783f * (((fVec14[((IOTA - 137) & 511)] + fVec14[((IOTA - 199) & 511)]) + fVec14[((IOTA - 210) & 511)]) - fVec14[((IOTA - 391) & 511)])) + ((0.00189214759f * fVec14[((IOTA - 384) & 511)]) + ((0.001617481f * (fVec14[((IOTA - 130) & 511)] + fVec14[((IOTA - 383) & 511)])) + ((0.00311288796f * (fVec14[((IOTA - 80) & 511)] - fVec14[((IOTA - 379) & 511)])) + ((0.00131229591f * ((((fVec14[((IOTA - 94) & 511)] - fVec14[((IOTA - 102) & 511)]) + fVec14[((IOTA - 133) & 511)]) + fVec14[((IOTA - 187) & 511)]) - fVec14[((IOTA - 378) & 511)])) + ((0.00201422162f * (fVec14[((IOTA - 138) & 511)] + fVec14[((IOTA - 375) & 511)])) + ((0.00137333293f * fVec14[((IOTA - 374) & 511)]) + ((0.000366222113f * (((((((((fVec14[((IOTA - 118) & 511)] - fVec14[((IOTA - 127) & 511)]) + fVec14[((IOTA - 166) & 511)]) + fVec14[((IOTA - 213) & 511)]) - fVec14[((IOTA - 277) & 511)]) - fVec14[((IOTA - 279) & 511)]) + fVec14[((IOTA - 292) & 511)]) - fVec14[((IOTA - 314) & 511)]) - fVec14[((IOTA - 317) & 511)]) + fVec14[((IOTA - 361) & 511)])) + ((0.000488296151f * ((((fVec14[((IOTA - 139) & 511)] + fVec14[((IOTA - 225) & 511)]) + fVec14[((IOTA - 257) & 511)]) + fVec14[((IOTA - 293) & 511)]) + fVec14[((IOTA - 360) & 511)])) + ((0.00054933317f * ((fVec14[((IOTA - 255) & 511)] + fVec14[((IOTA - 307) & 511)]) + fVec14[((IOTA - 328) & 511)])) + ((0.000946073793f * ((fVec14[((IOTA - 111) & 511)] + fVec14[((IOTA - 190) & 511)]) + fVec14[((IOTA - 323) & 511)])) + ((0.00109866634f * fVec14[((IOTA - 202) & 511)]) + ((0.00180059206f * fVec14[((IOTA - 184) & 511)]) + ((0.00122074038f * (fVec14[((IOTA - 129) & 511)] + fVec14[((IOTA - 183) & 511)])) + ((0.00125125889f * fVec14[((IOTA - 173) & 511)]) + ((0.00115970336f * (fVec14[((IOTA - 143) & 511)] + fVec14[((IOTA - 149) & 511)])) + ((0.00164799951f * fVec14[((IOTA - 146) & 511)]) + ((0.00286873989f * (fVec14[((IOTA - 144) & 511)] + fVec14[((IOTA - 145) & 511)])) + ((0.00216681417f * fVec14[((IOTA - 131) & 511)]) + ((0.00177007355f * fVec14[((IOTA - 123) & 511)]) + ((0.00302133244f * fVec14[((IOTA - 110) & 511)]) + ((0.00262459181f * fVec14[((IOTA - 109) & 511)]) + ((0.00375377666f * fVec14[((IOTA - 104) & 511)]) + ((0.00436414685f * fVec14[((IOTA - 103) & 511)]) + ((0.00735496078f * fVec14[((IOTA - 93) & 511)]) + ((0.0128482925f * fVec14[((IOTA - 92) & 511)]) + ((0.0136112552f * fVec14[((IOTA - 91) & 511)]) + ((0.00683614612f * fVec14[((IOTA - 90) & 511)]) + ((0.00402844325f * ((fVec14[((IOTA - 79) & 511)] - fVec14[((IOTA - 82) & 511)]) - fVec14[((IOTA - 89) & 511)])) + ((0.00643940549f * fVec14[((IOTA - 85) & 511)]) + ((0.00784325693f * fVec14[((IOTA - 84) & 511)]) + ((0.00207525864f * fVec14[((IOTA - 78) & 511)]) + ((0.00241096225f * fVec14[((IOTA - 70) & 511)]) + ((0.00863673817f * fVec14[((IOTA - 69) & 511)]) + ((0.0153508103f * fVec14[((IOTA - 68) & 511)]) + ((0.0181890316f * fVec14[((IOTA - 67) & 511)]) + ((0.0160222184f * fVec14[((IOTA - 66) & 511)]) + ((0.0102542192f * fVec14[((IOTA - 65) & 511)]) + ((0.00393688772f * fVec14[((IOTA - 64) & 511)]) + ((0.01803644f * fVec14[((IOTA - 57) & 511)]) + ((0.0277108066f * fVec14[((IOTA - 56) & 511)]) + ((0.0215765871f * fVec14[((IOTA - 55) & 511)]) + (((((((((((((((((((((((((fSlow38 * fTemp0) + (0.090151675f * fVec14[((IOTA - 1) & 511)])) + (0.225989565f * fVec14[((IOTA - 2) & 511)])) + (0.284035772f * fVec14[((IOTA - 3) & 511)])) + (0.1200293f * fVec14[((IOTA - 4) & 511)])) + (0.099276714f * fVec14[((IOTA - 9) & 511)])) + (0.123264261f * fVec14[((IOTA - 10) & 511)])) + (0.0542313904f * fVec14[((IOTA - 11) & 511)])) + (0.00817896053f * fVec14[((IOTA - 12) & 511)])) + (0.00329599902f * fVec14[((IOTA - 13) & 511)])) + (0.0117801446f * fVec14[((IOTA - 14) & 511)])) + (0.0133365886f * fVec14[((IOTA - 20) & 511)])) + (0.0302743614f * fVec14[((IOTA - 21) & 511)])) + (0.0166020691f * fVec14[((IOTA - 22) & 511)])) + (0.0289620664f * fVec14[((IOTA - 27) & 511)])) + (0.0495925769f * fVec14[((IOTA - 28) & 511)])) + (0.0491042808f * fVec14[((IOTA - 29) & 511)])) + (0.0142826624f * fVec14[((IOTA - 30) & 511)])) + (0.0025940733f * fVec14[((IOTA - 35) & 511)])) + (0.00900296029f * fVec14[((IOTA - 36) & 511)])) + (0.0171208847f * fVec14[((IOTA - 37) & 511)])) + (0.024323253f * fVec14[((IOTA - 38) & 511)])) + (0.0301522873f * fVec14[((IOTA - 39) & 511)])) + (0.0176702179f * fVec14[((IOTA - 40) & 511)])) + (0.00778221991f * fVec14[((IOTA - 54) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (3.05185094e-05f * (((((((((((((((((((((((((((fVec14[((IOTA - 155) & 511)] + fVec14[((IOTA - 160) & 511)]) + fVec14[((IOTA - 205) & 511)]) - fVec14[((IOTA - 263) & 511)]) - fVec14[((IOTA - 289) & 511)]) - fVec14[((IOTA - 302) & 511)]) + fVec14[((IOTA - 318) & 511)]) - fVec14[((IOTA - 404) & 511)]) + fVec14[((IOTA - 427) & 511)]) - fVec14[((IOTA - 438) & 511)]) - fVec14[((IOTA - 439) & 511)]) + fVec14[((IOTA - 441) & 511)]) - fVec14[((IOTA - 443) & 511)]) - fVec14[((IOTA - 448) & 511)]) - fVec14[((IOTA - 471) & 511)]) - fVec14[((IOTA - 472) & 511)]) - fVec14[((IOTA - 473) & 511)]) + fVec14[((IOTA - 481) & 511)]) + fVec14[((IOTA - 485) & 511)]) - fVec14[((IOTA - 486) & 511)]) - fVec14[((IOTA - 487) & 511)]) - fVec14[((IOTA - 488) & 511)]) + fVec14[((IOTA - 490) & 511)]) + fVec14[((IOTA - 491) & 511)]) + fVec14[((IOTA - 494) & 511)]) - fVec14[((IOTA - 496) & 511)]) - fVec14[((IOTA - 497) & 511)]) - fVec14[((IOTA - 498) & 511)]))))) - (((0.000183111057f * ((((((((((((fVec14[((IOTA - 206) & 511)] + fVec14[((IOTA - 207) & 511)]) - fVec14[((IOTA - 208) & 511)]) + fVec14[((IOTA - 228) & 511)]) + fVec14[((IOTA - 230) & 511)]) + fVec14[((IOTA - 266) & 511)]) + fVec14[((IOTA - 271) & 511)]) - fVec14[((IOTA - 338) & 511)]) + fVec14[((IOTA - 463) & 511)]) + fVec14[((IOTA - 468) & 511)]) - fVec14[((IOTA - 483) & 511)]) + fVec14[((IOTA - 505) & 511)]) + fVec14[((IOTA - 508) & 511)])) + (((0.000274666585f * ((((((((((((fVec14[((IOTA - 161) & 511)] - fVec14[((IOTA - 217) & 511)]) - fVec14[((IOTA - 252) & 511)]) - fVec14[((IOTA - 260) & 511)]) + fVec14[((IOTA - 265) & 511)]) + fVec14[((IOTA - 270) & 511)]) + fVec14[((IOTA - 297) & 511)]) - fVec14[((IOTA - 341) & 511)]) - fVec14[((IOTA - 342) & 511)]) - fVec14[((IOTA - 350) & 511)]) - fVec14[((IOTA - 357) & 511)]) + fVec14[((IOTA - 390) & 511)]) - fVec14[((IOTA - 454) & 511)])) + ((0.000885036774f * (((((fVec14[((IOTA - 154) & 511)] - fVec14[((IOTA - 196) & 511)]) - fVec14[((IOTA - 320) & 511)]) + fVec14[((IOTA - 394) & 511)]) + fVec14[((IOTA - 395) & 511)]) + fVec14[((IOTA - 434) & 511)])) + ((0.00057985168f * (((((((fVec14[((IOTA - 164) & 511)] - fVec14[((IOTA - 156) & 511)]) - fVec14[((IOTA - 171) & 511)]) - fVec14[((IOTA - 179) & 511)]) + fVec14[((IOTA - 316) & 511)]) - fVec14[((IOTA - 329) & 511)]) - fVec14[((IOTA - 330) & 511)]) + fVec14[((IOTA - 423) & 511)])) + ((0.000671407208f * ((((fVec14[((IOTA - 108) & 511)] - fVec14[((IOTA - 243) & 511)]) - fVec14[((IOTA - 305) & 511)]) + fVec14[((IOTA - 398) & 511)]) + fVec14[((IOTA - 422) & 511)])) + ((0.000793481246f * ((((fVec14[((IOTA - 162) & 511)] - fVec14[((IOTA - 193) & 511)]) - fVec14[((IOTA - 203) & 511)]) - fVec14[((IOTA - 324) & 511)]) + fVec14[((IOTA - 421) & 511)])) + ((0.000854518265f * ((((fVec14[((IOTA - 112) & 511)] + fVec14[((IOTA - 126) & 511)]) - fVec14[((IOTA - 195) & 511)]) - fVec14[((IOTA - 247) & 511)]) + fVec14[((IOTA - 420) & 511)])) + ((0.000823999755f * ((((fVec14[((IOTA - 151) & 511)] - fVec14[((IOTA - 180) & 511)]) - fVec14[((IOTA - 248) & 511)]) + fVec14[((IOTA - 299) & 511)]) + fVec14[((IOTA - 419) & 511)])) + ((0.000701925717f * (((((fVec14[((IOTA - 77) & 511)] + fVec14[((IOTA - 117) & 511)]) - fVec14[((IOTA - 209) & 511)]) - fVec14[((IOTA - 212) & 511)]) - fVec14[((IOTA - 326) & 511)]) - fVec14[((IOTA - 403) & 511)])) + ((0.00112918485f * ((fVec14[((IOTA - 393) & 511)] - (fVec14[((IOTA - 321) & 511)] + fVec14[((IOTA - 322) & 511)])) - fVec14[((IOTA - 401) & 511)])) + ((0.000976592302f * (((fVec14[((IOTA - 163) & 511)] - fVec14[((IOTA - 192) & 511)]) - fVec14[((IOTA - 198) & 511)]) - fVec14[((IOTA - 385) & 511)])) + ((0.00228888821f * fVec14[((IOTA - 381) & 511)]) + ((0.00357066561f * fVec14[((IOTA - 380) & 511)]) + ((0.000732444227f * ((((fVec14[((IOTA - 136) & 511)] - fVec14[((IOTA - 246) & 511)]) + fVec14[((IOTA - 300) & 511)]) - fVec14[((IOTA - 306) & 511)]) - fVec14[((IOTA - 377) & 511)])) + ((0.0019226661f * ((fVec14[((IOTA - 116) & 511)] - fVec14[((IOTA - 122) & 511)]) - fVec14[((IOTA - 376) & 511)])) + ((0.0012817774f * (fVec14[((IOTA - 43) & 511)] - fVec14[((IOTA - 201) & 511)])) + ((0.00167851802f * (fVec14[((IOTA - 153) & 511)] - fVec14[((IOTA - 186) & 511)])) + ((0.0019531846f * (((fVec14[((IOTA - 95) & 511)] + fVec14[((IOTA - 105) & 511)]) + fVec14[((IOTA - 115) & 511)]) - fVec14[((IOTA - 185) & 511)])) + ((0.00173955504f * fVec14[((IOTA - 152) & 511)]) + ((0.00146488845f * fVec14[((IOTA - 142) & 511)]) + ((0.00314340647f * (fVec14[((IOTA - 86) & 511)] + fVec14[((IOTA - 141) & 511)])) + ((0.00222785119f * fVec14[((IOTA - 140) & 511)]) + ((0.00140385143f * fVec14[((IOTA - 135) & 511)]) + ((0.00231940672f * (fVec14[((IOTA - 99) & 511)] - fVec14[((IOTA - 132) & 511)])) + ((0.00503555406f * fVec14[((IOTA - 107) & 511)]) + ((0.0058290353f * (fVec14[((IOTA - 74) & 511)] + fVec14[((IOTA - 106) & 511)])) + ((0.00704977568f * fVec14[((IOTA - 101) & 511)]) + ((0.00695822015f * (fVec14[((IOTA - 73) & 511)] + fVec14[((IOTA - 100) & 511)])) + ((0.00100711081f * fVec14[((IOTA - 97) & 511)]) + ((0.00250251777f * fVec14[((IOTA - 96) & 511)]) + ((0.0124210333f * fVec14[((IOTA - 88) & 511)]) + ((0.0123294778f * fVec14[((IOTA - 87) & 511)]) + ((0.00152592547f * fVec14[((IOTA - 81) & 511)]) + ((0.00299081393f * fVec14[((IOTA - 76) & 511)]) + ((0.00479140598f * fVec14[((IOTA - 75) & 511)]) + ((0.00595110934f * fVec14[((IOTA - 72) & 511)]) + ((0.00292977691f * fVec14[((IOTA - 71) & 511)]) + ((0.00531022064f * fVec14[((IOTA - 63) & 511)]) + ((0.0271004364f * fVec14[((IOTA - 61) & 511)]) + ((0.0299386587f * fVec14[((IOTA - 60) & 511)]) + ((0.0210577715f * fVec14[((IOTA - 59) & 511)]) + ((0.00186162908f * fVec14[((IOTA - 58) & 511)]) + ((0.0051576281f * fVec14[((IOTA - 53) & 511)]) + ((0.0111697745f * fVec14[((IOTA - 52) & 511)]) + ((0.0122989593f * fVec14[((IOTA - 51) & 511)]) + ((0.0115665151f * fVec14[((IOTA - 50) & 511)]) + ((0.0168462172f * fVec14[((IOTA - 49) & 511)]) + ((0.0238959938f * fVec14[((IOTA - 48) & 511)]) + ((0.0249031037f * fVec14[((IOTA - 47) & 511)]) + ((0.0166631062f * fVec14[((IOTA - 46) & 511)]) + ((0.00671407208f * fVec14[((IOTA - 45) & 511)]) + ((0.0061342204f * fVec14[((IOTA - 42) & 511)]) + ((0.0132755516f * fVec14[((IOTA - 34) & 511)]) + ((0.0351268053f * fVec14[((IOTA - 33) & 511)]) + ((0.0489211716f * fVec14[((IOTA - 32) & 511)]) + ((0.0281991027f * fVec14[((IOTA - 31) & 511)]) + ((0.0112918485f * fVec14[((IOTA - 26) & 511)]) + ((0.0402233973f * fVec14[((IOTA - 25) & 511)]) + ((0.045289468f * fVec14[((IOTA - 24) & 511)]) + ((0.016296884f * fVec14[((IOTA - 23) & 511)]) + ((0.0158085879f * fVec14[((IOTA - 19) & 511)]) + ((0.0410473943f * fVec14[((IOTA - 18) & 511)]) + ((0.0611285754f * fVec14[((IOTA - 17) & 511)]) + ((0.0554521307f * fVec14[((IOTA - 16) & 511)]) + ((0.0252693258f * fVec14[((IOTA - 15) & 511)]) + ((0.0571306497f * fVec14[((IOTA - 8) & 511)]) + ((0.265114278f * fVec14[((IOTA - 7) & 511)]) + ((0.344004631f * fVec14[((IOTA - 6) & 511)]) + ((0.169530317f * fVec14[((IOTA - 5) & 511)]) + (0.0169988107f * fVec14[((IOTA - 62) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000213629566f * ((((((((((((((((((fVec14[((IOTA - 44) & 511)] - fVec14[((IOTA - 159) & 511)]) - fVec14[((IOTA - 170) & 511)]) - fVec14[((IOTA - 176) & 511)]) - fVec14[((IOTA - 233) & 511)]) + fVec14[((IOTA - 288) & 511)]) + fVec14[((IOTA - 334) & 511)]) - fVec14[((IOTA - 337) & 511)]) - fVec14[((IOTA - 343) & 511)]) - fVec14[((IOTA - 344) & 511)]) - fVec14[((IOTA - 363) & 511)]) - fVec14[((IOTA - 364) & 511)]) + fVec14[((IOTA - 371) & 511)]) + fVec14[((IOTA - 426) & 511)]) - fVec14[((IOTA - 428) & 511)]) - fVec14[((IOTA - 429) & 511)]) + fVec14[((IOTA - 462) & 511)]) + fVec14[((IOTA - 506) & 511)]) + fVec14[((IOTA - 507) & 511)])))) + (9.15555283e-05f * (((((((fVec14[((IOTA - 475) & 511)] - (((((((((((((((((fVec14[((IOTA - 165) & 511)] + fVec14[((IOTA - 214) & 511)]) + fVec14[((IOTA - 216) & 511)]) + fVec14[((IOTA - 223) & 511)]) + fVec14[((IOTA - 296) & 511)]) + fVec14[((IOTA - 311) & 511)]) + fVec14[((IOTA - 312) & 511)]) - fVec14[((IOTA - 313) & 511)]) - fVec14[((IOTA - 333) & 511)]) + fVec14[((IOTA - 336) & 511)]) + fVec14[((IOTA - 339) & 511)]) + fVec14[((IOTA - 354) & 511)]) - fVec14[((IOTA - 382) & 511)]) + fVec14[((IOTA - 413) & 511)]) - fVec14[((IOTA - 449) & 511)]) + fVec14[((IOTA - 459) & 511)]) - fVec14[((IOTA - 465) & 511)]) - fVec14[((IOTA - 470) & 511)])) + fVec14[((IOTA - 476) & 511)]) + fVec14[((IOTA - 477) & 511)]) - fVec14[((IOTA - 501) & 511)]) + fVec14[((IOTA - 504) & 511)]) + fVec14[((IOTA - 510) & 511)]) + fVec14[((IOTA - 511) & 511)]))))) : (iSlow33 ? (((0.000640888698f * ((((((((fVec13[((IOTA - 145) & 511)] - fVec13[((IOTA - 183) & 511)]) + fVec13[((IOTA - 241) & 511)]) + fVec13[((IOTA - 316) & 511)]) + fVec13[((IOTA - 324) & 511)]) + fVec13[((IOTA - 415) & 511)]) + fVec13[((IOTA - 434) & 511)]) - fVec13[((IOTA - 495) & 511)]) - fVec13[((IOTA - 507) & 511)])) + ((0.000152592547f * ((((((((((((fVec13[((IOTA - 35) & 511)] + fVec13[((IOTA - 44) & 511)]) + fVec13[((IOTA - 46) & 511)]) + fVec13[((IOTA - 285) & 511)]) - fVec13[((IOTA - 286) & 511)]) + fVec13[((IOTA - 289) & 511)]) + fVec13[((IOTA - 292) & 511)]) - fVec13[((IOTA - 362) & 511)]) + fVec13[((IOTA - 441) & 511)]) - fVec13[((IOTA - 465) & 511)]) + fVec13[((IOTA - 484) & 511)]) - fVec13[((IOTA - 489) & 511)]) - fVec13[((IOTA - 500) & 511)])) + ((0.000610370189f * (((((((((((((fVec13[((IOTA - 92) & 511)] + fVec13[((IOTA - 216) & 511)]) - fVec13[((IOTA - 231) & 511)]) + fVec13[((IOTA - 243) & 511)]) + fVec13[((IOTA - 340) & 511)]) + fVec13[((IOTA - 344) & 511)]) + fVec13[((IOTA - 353) & 511)]) + fVec13[((IOTA - 375) & 511)]) + fVec13[((IOTA - 391) & 511)]) + fVec13[((IOTA - 435) & 511)]) + fVec13[((IOTA - 436) & 511)]) + fVec13[((IOTA - 437) & 511)]) + fVec13[((IOTA - 459) & 511)]) - fVec13[((IOTA - 498) & 511)])) + ((0.000732444227f * (((((((fVec13[((IOTA - 260) & 511)] + fVec13[((IOTA - 325) & 511)]) + fVec13[((IOTA - 342) & 511)]) + fVec13[((IOTA - 388) & 511)]) + fVec13[((IOTA - 414) & 511)]) - fVec13[((IOTA - 470) & 511)]) - fVec13[((IOTA - 496) & 511)]) - fVec13[((IOTA - 497) & 511)])) + ((0.00057985168f * (((((fVec13[((IOTA - 268) & 511)] + fVec13[((IOTA - 305) & 511)]) + fVec13[((IOTA - 360) & 511)]) + fVec13[((IOTA - 372) & 511)]) + fVec13[((IOTA - 438) & 511)]) - fVec13[((IOTA - 494) & 511)])) + ((0.000274666585f * ((((((fVec13[((IOTA - 58) & 511)] + fVec13[((IOTA - 148) & 511)]) + fVec13[((IOTA - 309) & 511)]) + fVec13[((IOTA - 361) & 511)]) + fVec13[((IOTA - 462) & 511)]) - fVec13[((IOTA - 478) & 511)]) - fVec13[((IOTA - 491) & 511)])) + ((0.000244148076f * ((((fVec13[((IOTA - 127) & 511)] - fVec13[((IOTA - 229) & 511)]) + fVec13[((IOTA - 389) & 511)]) + fVec13[((IOTA - 463) & 511)]) + fVec13[((IOTA - 483) & 511)])) + ((0.000213629566f * ((((((fVec13[((IOTA - 152) & 511)] - fVec13[((IOTA - 227) & 511)]) - fVec13[((IOTA - 228) & 511)]) - fVec13[((IOTA - 287) & 511)]) + fVec13[((IOTA - 390) & 511)]) + fVec13[((IOTA - 472) & 511)]) + fVec13[((IOTA - 482) & 511)])) + ((0.000335703604f * ((((((fVec13[((IOTA - 91) & 511)] - fVec13[((IOTA - 236) & 511)]) + fVec13[((IOTA - 255) & 511)]) + fVec13[((IOTA - 270) & 511)]) + fVec13[((IOTA - 376) & 511)]) + fVec13[((IOTA - 377) & 511)]) - fVec13[((IOTA - 479) & 511)])) + ((0.000793481246f * (((((((((((fVec13[((IOTA - 244) & 511)] + fVec13[((IOTA - 261) & 511)]) + fVec13[((IOTA - 315) & 511)]) + fVec13[((IOTA - 354) & 511)]) + fVec13[((IOTA - 370) & 511)]) + fVec13[((IOTA - 408) & 511)]) + fVec13[((IOTA - 409) & 511)]) + fVec13[((IOTA - 410) & 511)]) + fVec13[((IOTA - 411) & 511)]) + fVec13[((IOTA - 455) & 511)]) - fVec13[((IOTA - 467) & 511)]) + fVec13[((IOTA - 475) & 511)])) + ((0.000915555283f * (((((((fVec13[((IOTA - 262) & 511)] + fVec13[((IOTA - 329) & 511)]) + fVec13[((IOTA - 331) & 511)]) + fVec13[((IOTA - 357) & 511)]) + fVec13[((IOTA - 400) & 511)]) + fVec13[((IOTA - 429) & 511)]) + fVec13[((IOTA - 458) & 511)]) + fVec13[((IOTA - 474) & 511)])) + ((0.000305185094f * (((((((fVec13[((IOTA - 60) & 511)] + fVec13[((IOTA - 196) & 511)]) - fVec13[((IOTA - 226) & 511)]) + fVec13[((IOTA - 247) & 511)]) + fVec13[((IOTA - 300) & 511)]) - fVec13[((IOTA - 443) & 511)]) + fVec13[((IOTA - 461) & 511)]) - fVec13[((IOTA - 471) & 511)])) + ((0.000427259132f * (((((((((fVec13[((IOTA - 59) & 511)] + fVec13[((IOTA - 239) & 511)]) + fVec13[((IOTA - 291) & 511)]) + fVec13[((IOTA - 297) & 511)]) + fVec13[((IOTA - 310) & 511)]) + fVec13[((IOTA - 349) & 511)]) + fVec13[((IOTA - 352) & 511)]) + fVec13[((IOTA - 381) & 511)]) + fVec13[((IOTA - 445) & 511)]) + fVec13[((IOTA - 460) & 511)])) + ((0.00122074038f * ((((((((fVec13[((IOTA - 137) & 511)] + fVec13[((IOTA - 146) & 511)]) + fVec13[((IOTA - 160) & 511)]) - fVec13[((IOTA - 164) & 511)]) + fVec13[((IOTA - 256) & 511)]) + fVec13[((IOTA - 258) & 511)]) + fVec13[((IOTA - 383) & 511)]) + fVec13[((IOTA - 446) & 511)]) + fVec13[((IOTA - 457) & 511)])) + ((0.00173955504f * ((fVec13[((IOTA - 211) & 511)] - fVec13[((IOTA - 197) & 511)]) - fVec13[((IOTA - 453) & 511)])) + ((0.000122074038f * (((((((fVec13[((IOTA - 1) & 511)] - fVec13[((IOTA - 26) & 511)]) + fVec13[((IOTA - 33) & 511)]) + fVec13[((IOTA - 34) & 511)]) + fVec13[((IOTA - 36) & 511)]) + fVec13[((IOTA - 224) & 511)]) - fVec13[((IOTA - 294) & 511)]) - fVec13[((IOTA - 444) & 511)])) + ((0.00131229591f * (((fVec13[((IOTA - 223) & 511)] + fVec13[((IOTA - 320) & 511)]) + fVec13[((IOTA - 421) & 511)]) + fVec13[((IOTA - 456) & 511)])) + (((0.000885036774f * ((((((fVec13[((IOTA - 193) & 511)] + fVec13[((IOTA - 312) & 511)]) + fVec13[((IOTA - 318) & 511)]) + fVec13[((IOTA - 330) & 511)]) + fVec13[((IOTA - 335) & 511)]) + fVec13[((IOTA - 398) & 511)]) + fVec13[((IOTA - 432) & 511)])) + ((0.00109866634f * (((((fVec13[((IOTA - 70) & 511)] + fVec13[((IOTA - 173) & 511)]) + fVec13[((IOTA - 205) & 511)]) + fVec13[((IOTA - 264) & 511)]) + fVec13[((IOTA - 327) & 511)]) + fVec13[((IOTA - 427) & 511)])) + ((0.00125125889f * (fVec13[((IOTA - 395) & 511)] + fVec13[((IOTA - 426) & 511)])) + ((0.0012817774f * ((fVec13[((IOTA - 321) & 511)] + fVec13[((IOTA - 420) & 511)]) + fVec13[((IOTA - 425) & 511)])) + ((0.00119022187f * ((fVec13[((IOTA - 201) & 511)] + fVec13[((IOTA - 422) & 511)]) + fVec13[((IOTA - 424) & 511)])) + ((0.00112918485f * (((((fVec13[((IOTA - 214) & 511)] + fVec13[((IOTA - 250) & 511)]) + fVec13[((IOTA - 319) & 511)]) + fVec13[((IOTA - 366) & 511)]) + fVec13[((IOTA - 392) & 511)]) + fVec13[((IOTA - 423) & 511)])) + ((0.00103762932f * (((fVec13[((IOTA - 276) & 511)] + fVec13[((IOTA - 328) & 511)]) + fVec13[((IOTA - 397) & 511)]) + fVec13[((IOTA - 419) & 511)])) + ((0.00106814783f * (fVec13[((IOTA - 322) & 511)] + fVec13[((IOTA - 401) & 511)])) + ((0.00115970336f * (fVec13[((IOTA - 263) & 511)] + fVec13[((IOTA - 396) & 511)])) + ((0.00140385143f * ((((fVec13[((IOTA - 184) & 511)] + fVec13[((IOTA - 194) & 511)]) + fVec13[((IOTA - 275) & 511)]) + fVec13[((IOTA - 387) & 511)]) + fVec13[((IOTA - 394) & 511)])) + ((0.00137333293f * (fVec13[((IOTA - 274) & 511)] + fVec13[((IOTA - 393) & 511)])) + ((0.00167851802f * fVec13[((IOTA - 384) & 511)]) + ((0.000854518265f * (((((fVec13[((IOTA - 251) & 511)] + fVec13[((IOTA - 259) & 511)]) + fVec13[((IOTA - 273) & 511)]) + fVec13[((IOTA - 283) & 511)]) + fVec13[((IOTA - 373) & 511)]) + fVec13[((IOTA - 374) & 511)])) + ((0.00149540696f * fVec13[((IOTA - 369) & 511)]) + ((0.00204474013f * (fVec13[((IOTA - 208) & 511)] + fVec13[((IOTA - 368) & 511)])) + ((0.0019531846f * (((fVec13[((IOTA - 155) & 511)] - fVec13[((IOTA - 174) & 511)]) + fVec13[((IOTA - 209) & 511)]) + fVec13[((IOTA - 367) & 511)])) + ((0.00143436994f * fVec13[((IOTA - 257) & 511)]) + ((0.00244148076f * fVec13[((IOTA - 222) & 511)]) + ((0.00302133244f * (fVec13[((IOTA - 219) & 511)] + fVec13[((IOTA - 221) & 511)])) + ((0.00238044374f * fVec13[((IOTA - 218) & 511)]) + ((0.00152592547f * (fVec13[((IOTA - 172) & 511)] + fVec13[((IOTA - 217) & 511)])) + ((0.00201422162f * (fVec13[((IOTA - 212) & 511)] + fVec13[((IOTA - 213) & 511)])) + ((0.001617481f * (fVec13[((IOTA - 143) & 511)] + fVec13[((IOTA - 210) & 511)])) + ((0.00219733268f * fVec13[((IOTA - 207) & 511)]) + ((0.00134281442f * fVec13[((IOTA - 206) & 511)]) + ((0.00100711081f * (fVec13[((IOTA - 159) & 511)] + fVec13[((IOTA - 203) & 511)])) + ((0.00155644398f * fVec13[((IOTA - 202) & 511)]) + ((0.00283822138f * (fVec13[((IOTA - 118) & 511)] - fVec13[((IOTA - 199) & 511)])) + ((0.00183111057f * fVec13[((IOTA - 195) & 511)]) + ((0.00216681417f * fVec13[((IOTA - 186) & 511)]) + ((0.00305185094f * fVec13[((IOTA - 185) & 511)]) + ((0.00341807306f * (fVec13[((IOTA - 108) & 511)] - fVec13[((IOTA - 177) & 511)])) + ((0.0119327372f * fVec13[((IOTA - 167) & 511)]) + ((0.0192571804f * fVec13[((IOTA - 166) & 511)]) + ((0.0124210333f * fVec13[((IOTA - 165) & 511)]) + ((0.00411999878f * fVec13[((IOTA - 153) & 511)]) + ((0.00213629566f * fVec13[((IOTA - 147) & 511)]) + ((0.00231940672f * fVec13[((IOTA - 142) & 511)]) + ((0.00448622089f * fVec13[((IOTA - 141) & 511)]) + ((0.00650044251f * fVec13[((IOTA - 140) & 511)]) + ((0.00769066438f * fVec13[((IOTA - 139) & 511)]) + ((0.00546281319f * fVec13[((IOTA - 138) & 511)]) + ((0.021332439f * (fVec13[((IOTA - 129) & 511)] - fVec13[((IOTA - 132) & 511)])) + ((0.0118717002f * fVec13[((IOTA - 130) & 511)]) + ((0.0150761437f * fVec13[((IOTA - 128) & 511)]) + ((0.0143742179f * (fVec13[((IOTA - 109) & 511)] - fVec13[((IOTA - 126) & 511)])) + ((0.00488296151f * fVec13[((IOTA - 117) & 511)]) + ((0.00634784997f * fVec13[((IOTA - 116) & 511)]) + ((0.016296884f * fVec13[((IOTA - 112) & 511)]) + ((0.0232245866f * fVec13[((IOTA - 111) & 511)]) + ((0.021149328f * fVec13[((IOTA - 110) & 511)]) + ((0.0266731773f * fVec13[((IOTA - 102) & 511)]) + ((0.0370494723f * fVec13[((IOTA - 101) & 511)]) + ((0.0351268053f * fVec13[((IOTA - 100) & 511)]) + ((0.00436414685f * fVec13[((IOTA - 99) & 511)]) + ((0.00665303506f * fVec13[((IOTA - 94) & 511)]) + ((0.0221869573f * fVec13[((IOTA - 93) & 511)]) + ((0.0578630939f * fVec13[((IOTA - 84) & 511)]) + ((0.105227821f * fVec13[((IOTA - 83) & 511)]) + ((0.0943327099f * fVec13[((IOTA - 82) & 511)]) + ((0.0272530299f * fVec13[((IOTA - 77) & 511)]) + ((0.229682297f * fVec13[((IOTA - 76) & 511)]) + ((0.27979371f * fVec13[((IOTA - 75) & 511)]) + ((0.165532395f * fVec13[((IOTA - 74) & 511)]) + ((0.0477309488f * fVec13[((IOTA - 73) & 511)]) + ((0.0067751091f * fVec13[((IOTA - 71) & 511)]) + (0.00933866389f * fVec13[((IOTA - 72) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000396740623f * (((((((((((((fVec13[((IOTA - 246) & 511)] + fVec13[((IOTA - 266) & 511)]) + fVec13[((IOTA - 277) & 511)]) + fVec13[((IOTA - 290) & 511)]) + fVec13[((IOTA - 350) & 511)]) + fVec13[((IOTA - 351) & 511)]) + fVec13[((IOTA - 378) & 511)]) + fVec13[((IOTA - 379) & 511)]) + fVec13[((IOTA - 440) & 511)]) - fVec13[((IOTA - 454) & 511)]) + fVec13[((IOTA - 476) & 511)]) - fVec13[((IOTA - 492) & 511)]) - fVec13[((IOTA - 499) & 511)]) - fVec13[((IOTA - 510) & 511)])))))))))))))))))))) - (((0.000457777642f * (((((fVec13[((IOTA - 225) & 511)] - fVec13[((IOTA - 248) & 511)]) - fVec13[((IOTA - 348) & 511)]) + fVec13[((IOTA - 364) & 511)]) - fVec13[((IOTA - 371) & 511)]) + fVec13[((IOTA - 509) & 511)])) + ((0.000518814661f * (((((((((fVec13[((IOTA - 254) & 511)] - fVec13[((IOTA - 345) & 511)]) - fVec13[((IOTA - 346) & 511)]) - fVec13[((IOTA - 347) & 511)]) - fVec13[((IOTA - 404) & 511)]) - fVec13[((IOTA - 416) & 511)]) - fVec13[((IOTA - 417) & 511)]) + fVec13[((IOTA - 466) & 511)]) + fVec13[((IOTA - 493) & 511)]) + fVec13[((IOTA - 508) & 511)])) + ((0.000762962736f * (((((((((((fVec13[((IOTA - 200) & 511)] - fVec13[((IOTA - 245) & 511)]) - fVec13[((IOTA - 282) & 511)]) - fVec13[((IOTA - 323) & 511)]) - fVec13[((IOTA - 336) & 511)]) - fVec13[((IOTA - 359) & 511)]) - fVec13[((IOTA - 382) & 511)]) - fVec13[((IOTA - 407) & 511)]) - fVec13[((IOTA - 412) & 511)]) - fVec13[((IOTA - 413) & 511)]) - fVec13[((IOTA - 433) & 511)]) + fVec13[((IOTA - 506) & 511)])) + ((0.000823999755f * ((((((fVec13[((IOTA - 192) & 511)] - fVec13[((IOTA - 204) & 511)]) + fVec13[((IOTA - 232) & 511)]) - fVec13[((IOTA - 265) & 511)]) - fVec13[((IOTA - 358) & 511)]) - fVec13[((IOTA - 399) & 511)]) + fVec13[((IOTA - 505) & 511)])) + ((0.000671407208f * (((((((((fVec13[((IOTA - 64) & 511)] - fVec13[((IOTA - 284) & 511)]) - fVec13[((IOTA - 306) & 511)]) - fVec13[((IOTA - 311) & 511)]) - fVec13[((IOTA - 317) & 511)]) - fVec13[((IOTA - 337) & 511)]) - fVec13[((IOTA - 341) & 511)]) - fVec13[((IOTA - 406) & 511)]) - fVec13[((IOTA - 418) & 511)]) + fVec13[((IOTA - 504) & 511)])) + ((9.15555283e-05f * ((((((((((((((((((fVec13[((IOTA - 6) & 511)] - (fTemp14 + fVec13[((IOTA - 2) & 511)])) + fVec13[((IOTA - 7) & 511)]) - fVec13[((IOTA - 31) & 511)]) - fVec13[((IOTA - 32) & 511)]) - fVec13[((IOTA - 37) & 511)]) + fVec13[((IOTA - 40) & 511)]) - fVec13[((IOTA - 43) & 511)]) - fVec13[((IOTA - 47) & 511)]) + fVec13[((IOTA - 56) & 511)]) + fVec13[((IOTA - 63) & 511)]) - fVec13[((IOTA - 238) & 511)]) + fVec13[((IOTA - 288) & 511)]) + fVec13[((IOTA - 293) & 511)]) + fVec13[((IOTA - 295) & 511)]) + fVec13[((IOTA - 302) & 511)]) - fVec13[((IOTA - 464) & 511)]) + fVec13[((IOTA - 488) & 511)]) + fVec13[((IOTA - 502) & 511)])) + ((3.05185094e-05f * ((((((((((((((((((((((((((fVec13[((IOTA - 4) & 511)] + fVec13[((IOTA - 8) & 511)]) + fVec13[((IOTA - 10) & 511)]) + fVec13[((IOTA - 13) & 511)]) + fVec13[((IOTA - 14) & 511)]) + fVec13[((IOTA - 16) & 511)]) + fVec13[((IOTA - 20) & 511)]) - fVec13[((IOTA - 22) & 511)]) - fVec13[((IOTA - 24) & 511)]) - fVec13[((IOTA - 30) & 511)]) - fVec13[((IOTA - 48) & 511)]) - fVec13[((IOTA - 49) & 511)]) - fVec13[((IOTA - 50) & 511)]) - fVec13[((IOTA - 53) & 511)]) - fVec13[((IOTA - 54) & 511)]) + fVec13[((IOTA - 55) & 511)]) - fVec13[((IOTA - 57) & 511)]) - fVec13[((IOTA - 144) & 511)]) + fVec13[((IOTA - 237) & 511)]) + fVec13[((IOTA - 278) & 511)]) + fVec13[((IOTA - 279) & 511)]) - fVec13[((IOTA - 301) & 511)]) - fVec13[((IOTA - 303) & 511)]) + fVec13[((IOTA - 477) & 511)]) - fVec13[((IOTA - 481) & 511)]) - fVec13[((IOTA - 485) & 511)]) + fVec13[((IOTA - 501) & 511)])) + ((0.000183111057f * (((((((((fVec13[((IOTA - 27) & 511)] + fVec13[((IOTA - 28) & 511)]) - fVec13[((IOTA - 45) & 511)]) - fVec13[((IOTA - 168) & 511)]) - fVec13[((IOTA - 280) & 511)]) - fVec13[((IOTA - 296) & 511)]) - fVec13[((IOTA - 365) & 511)]) + fVec13[((IOTA - 442) & 511)]) + fVec13[((IOTA - 480) & 511)]) + fVec13[((IOTA - 490) & 511)])) + ((6.10370189e-05f * (((((((((((((((fVec13[((IOTA - 5) & 511)] - fVec13[((IOTA - 3) & 511)]) + fVec13[((IOTA - 11) & 511)]) + fVec13[((IOTA - 12) & 511)]) + fVec13[((IOTA - 17) & 511)]) + fVec13[((IOTA - 18) & 511)]) + fVec13[((IOTA - 19) & 511)]) - fVec13[((IOTA - 23) & 511)]) + fVec13[((IOTA - 25) & 511)]) + fVec13[((IOTA - 29) & 511)]) + fVec13[((IOTA - 39) & 511)]) + fVec13[((IOTA - 41) & 511)]) - fVec13[((IOTA - 61) & 511)]) + fVec13[((IOTA - 62) & 511)]) + fVec13[((IOTA - 252) & 511)]) + fVec13[((IOTA - 487) & 511)])) + ((0.000701925717f * (((fVec13[((IOTA - 253) & 511)] - fVec13[((IOTA - 343) & 511)]) - fVec13[((IOTA - 403) & 511)]) - fVec13[((IOTA - 473) & 511)])) + ((0.000946073793f * (((((((fVec13[((IOTA - 171) & 511)] + fVec13[((IOTA - 234) & 511)]) - fVec13[((IOTA - 314) & 511)]) - fVec13[((IOTA - 326) & 511)]) - fVec13[((IOTA - 334) & 511)]) - fVec13[((IOTA - 430) & 511)]) + fVec13[((IOTA - 468) & 511)]) + fVec13[((IOTA - 469) & 511)])) + ((0.00241096225f * fVec13[((IOTA - 452) & 511)]) + ((0.00189214759f * ((((fVec13[((IOTA - 187) & 511)] - fVec13[((IOTA - 386) & 511)]) - fVec13[((IOTA - 447) & 511)]) - fVec13[((IOTA - 448) & 511)]) + fVec13[((IOTA - 451) & 511)])) + ((0.00054933317f * (((((((((fVec13[((IOTA - 235) & 511)] - fVec13[((IOTA - 240) & 511)]) - fVec13[((IOTA - 267) & 511)]) - fVec13[((IOTA - 272) & 511)]) - fVec13[((IOTA - 281) & 511)]) - fVec13[((IOTA - 338) & 511)]) - fVec13[((IOTA - 339) & 511)]) - fVec13[((IOTA - 405) & 511)]) - fVec13[((IOTA - 439) & 511)]) + fVec13[((IOTA - 450) & 511)])) + ((0.000976592302f * ((((((((((fVec13[((IOTA - 233) & 511)] - fVec13[((IOTA - 249) & 511)]) - fVec13[((IOTA - 313) & 511)]) - fVec13[((IOTA - 332) & 511)]) - fVec13[((IOTA - 333) & 511)]) - fVec13[((IOTA - 355) & 511)]) - fVec13[((IOTA - 356) & 511)]) - fVec13[((IOTA - 402) & 511)]) - fVec13[((IOTA - 428) & 511)]) - fVec13[((IOTA - 431) & 511)]) - fVec13[((IOTA - 449) & 511)])) + ((0.00198370311f * (fVec13[((IOTA - 179) & 511)] - fVec13[((IOTA - 385) & 511)])) + ((0.000488296151f * (fVec13[((IOTA - 363) & 511)] - (((((fVec13[((IOTA - 215) & 511)] + fVec13[((IOTA - 242) & 511)]) + fVec13[((IOTA - 269) & 511)]) + fVec13[((IOTA - 298) & 511)]) + fVec13[((IOTA - 299) & 511)]) + fVec13[((IOTA - 307) & 511)]))) + ((0.003234962f * (fVec13[((IOTA - 178) & 511)] - fVec13[((IOTA - 220) & 511)])) + ((0.00320444349f * fVec13[((IOTA - 198) & 511)]) + ((0.00296029542f * fVec13[((IOTA - 191) & 511)]) + ((0.00418103579f * fVec13[((IOTA - 190) & 511)]) + ((0.00555436872f * fVec13[((IOTA - 189) & 511)]) + ((0.00424207281f * fVec13[((IOTA - 188) & 511)]) + ((0.00326548051f * fVec13[((IOTA - 182) & 511)]) + ((0.0035401471f * (fVec13[((IOTA - 175) & 511)] + fVec13[((IOTA - 181) & 511)])) + ((0.0042115543f * fVec13[((IOTA - 180) & 511)]) + ((0.00512710959f * (fVec13[((IOTA - 176) & 511)] - fVec13[((IOTA - 154) & 511)])) + ((0.00500503555f * fVec13[((IOTA - 170) & 511)]) + ((0.00717184972f * fVec13[((IOTA - 169) & 511)]) + ((0.0113528855f * fVec13[((IOTA - 163) & 511)]) + ((0.0110782189f * fVec13[((IOTA - 162) & 511)]) + ((0.00396740623f * fVec13[((IOTA - 161) & 511)]) + ((0.00482192449f * fVec13[((IOTA - 158) & 511)]) + ((0.00708029419f * fVec13[((IOTA - 157) & 511)]) + ((0.00393688772f * fVec13[((IOTA - 156) & 511)]) + ((0.00378429517f * fVec13[((IOTA - 151) & 511)]) + ((0.00427259132f * (fVec13[((IOTA - 114) & 511)] + fVec13[((IOTA - 150) & 511)])) + ((0.0019226661f * fVec13[((IOTA - 149) & 511)]) + ((0.00561540574f * fVec13[((IOTA - 136) & 511)]) + ((0.0164799951f * fVec13[((IOTA - 135) & 511)]) + ((0.025879696f * fVec13[((IOTA - 134) & 511)]) + ((0.0284127332f * fVec13[((IOTA - 133) & 511)]) + ((0.00531022064f * fVec13[((IOTA - 131) & 511)]) + ((0.021088291f * fVec13[((IOTA - 125) & 511)]) + ((0.0244758446f * (fVec13[((IOTA - 106) & 511)] + fVec13[((IOTA - 124) & 511)])) + ((0.0229499191f * (fVec13[((IOTA - 121) & 511)] + fVec13[((IOTA - 123) & 511)])) + ((0.0238349568f * fVec13[((IOTA - 122) & 511)]) + ((0.0170598477f * fVec13[((IOTA - 120) & 511)]) + ((0.00756859034f * fVec13[((IOTA - 119) & 511)]) + ((0.00228888821f * fVec13[((IOTA - 115) & 511)]) + ((0.00344859157f * fVec13[((IOTA - 113) & 511)]) + ((0.0106509598f * fVec13[((IOTA - 107) & 511)]) + ((0.0365611762f * fVec13[((IOTA - 105) & 511)]) + ((0.035950806f * fVec13[((IOTA - 104) & 511)]) + ((0.0136417737f * fVec13[((IOTA - 103) & 511)]) + ((0.030915251f * fVec13[((IOTA - 98) & 511)]) + ((0.0541093163f * fVec13[((IOTA - 97) & 511)]) + ((0.0468153954f * fVec13[((IOTA - 96) & 511)]) + ((0.0141911069f * fVec13[((IOTA - 95) & 511)]) + ((0.0241096225f * fVec13[((IOTA - 90) & 511)]) + ((0.025696585f * fVec13[((IOTA - 89) & 511)]) + ((0.0665913895f * fVec13[((IOTA - 88) & 511)]) + ((0.0647602752f * fVec13[((IOTA - 87) & 511)]) + ((0.0534073934f * fVec13[((IOTA - 86) & 511)]) + ((0.0061342204f * fVec13[((IOTA - 85) & 511)]) + ((0.0209967345f * fVec13[((IOTA - 81) & 511)]) + ((0.14630574f * fVec13[((IOTA - 80) & 511)]) + ((0.243934453f * fVec13[((IOTA - 79) & 511)]) + ((0.178075507f * fVec13[((IOTA - 78) & 511)]) + ((0.00497451704f * fVec13[((IOTA - 69) & 511)]) + ((0.00860621966f * fVec13[((IOTA - 68) & 511)]) + ((0.00869777519f * fVec13[((IOTA - 67) & 511)]) + ((0.00308236945f * fVec13[((IOTA - 65) & 511)]) + (0.00643940549f * fVec13[((IOTA - 66) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * ((((((fVec13[((IOTA - 230) & 511)] - fVec13[((IOTA - 271) & 511)]) - fVec13[((IOTA - 304) & 511)]) - fVec13[((IOTA - 308) & 511)]) - fVec13[((IOTA - 380) & 511)]) + fVec13[((IOTA - 503) & 511)]) + fVec13[((IOTA - 511) & 511)])))) : (((0.000122074038f * (((((((fVec12[((IOTA - 275) & 511)] + fVec12[((IOTA - 279) & 511)]) - fVec12[((IOTA - 338) & 511)]) - fVec12[((IOTA - 378) & 511)]) - fVec12[((IOTA - 413) & 511)]) - fVec12[((IOTA - 470) & 511)]) - fVec12[((IOTA - 471) & 511)]) + fVec12[((IOTA - 501) & 511)])) + ((0.000427259132f * ((((((fVec12[((IOTA - 278) & 511)] - fVec12[((IOTA - 308) & 511)]) - fVec12[((IOTA - 346) & 511)]) - fVec12[((IOTA - 349) & 511)]) - fVec12[((IOTA - 415) & 511)]) - fVec12[((IOTA - 427) & 511)]) + fVec12[((IOTA - 497) & 511)])) + ((0.000244148076f * (((fVec12[((IOTA - 182) & 511)] - fVec12[((IOTA - 198) & 511)]) - fVec12[((IOTA - 392) & 511)]) + fVec12[((IOTA - 496) & 511)])) + ((0.000152592547f * (((((fVec12[((IOTA - 411) & 511)] + fVec12[((IOTA - 412) & 511)]) - fVec12[((IOTA - 472) & 511)]) + fVec12[((IOTA - 484) & 511)]) + fVec12[((IOTA - 487) & 511)]) - fVec12[((IOTA - 489) & 511)])) + ((0.000335703604f * (((((fVec12[((IOTA - 276) & 511)] - fVec12[((IOTA - 280) & 511)]) - fVec12[((IOTA - 363) & 511)]) - fVec12[((IOTA - 414) & 511)]) - fVec12[((IOTA - 469) & 511)]) - fVec12[((IOTA - 481) & 511)])) + ((0.000915555283f * ((((((((fVec12[((IOTA - 178) & 511)] - fVec12[((IOTA - 179) & 511)]) - fVec12[((IOTA - 181) & 511)]) - fVec12[((IOTA - 293) & 511)]) - fVec12[((IOTA - 313) & 511)]) - fVec12[((IOTA - 314) & 511)]) - fVec12[((IOTA - 379) & 511)]) - fVec12[((IOTA - 448) & 511)]) - fVec12[((IOTA - 479) & 511)])) + ((0.00054933317f * (((((((((((fVec12[((IOTA - 202) & 511)] + fVec12[((IOTA - 211) & 511)]) - fVec12[((IOTA - 267) & 511)]) - fVec12[((IOTA - 270) & 511)]) - fVec12[((IOTA - 303) & 511)]) - fVec12[((IOTA - 343) & 511)]) - fVec12[((IOTA - 371) & 511)]) - fVec12[((IOTA - 403) & 511)]) - fVec12[((IOTA - 431) & 511)]) - fVec12[((IOTA - 433) & 511)]) + fVec12[((IOTA - 457) & 511)]) - fVec12[((IOTA - 476) & 511)])) + ((0.00155644398f * (fVec12[((IOTA - 168) & 511)] - fVec12[((IOTA - 466) & 511)])) + ((0.00244148076f * (fVec12[((IOTA - 177) & 511)] + fVec12[((IOTA - 444) & 511)])) + ((0.00189214759f * ((((fVec12[((IOTA - 162) & 511)] - fVec12[((IOTA - 196) & 511)]) - fVec12[((IOTA - 253) & 511)]) - fVec12[((IOTA - 260) & 511)]) - fVec12[((IOTA - 441) & 511)])) + ((0.00100711081f * ((((((((((fVec12[((IOTA - 54) & 511)] + fVec12[((IOTA - 187) & 511)]) - fVec12[((IOTA - 262) & 511)]) - fVec12[((IOTA - 291) & 511)]) - fVec12[((IOTA - 319) & 511)]) - fVec12[((IOTA - 321) & 511)]) - fVec12[((IOTA - 323) & 511)]) - fVec12[((IOTA - 329) & 511)]) - fVec12[((IOTA - 332) & 511)]) - fVec12[((IOTA - 407) & 511)]) - fVec12[((IOTA - 424) & 511)])) + ((0.00134281442f * (((fVec12[((IOTA - 142) & 511)] - fVec12[((IOTA - 180) & 511)]) - fVec12[((IOTA - 247) & 511)]) - fVec12[((IOTA - 399) & 511)])) + ((0.00115970336f * (((fVec12[((IOTA - 199) & 511)] - fVec12[((IOTA - 294) & 511)]) - fVec12[((IOTA - 300) & 511)]) - fVec12[((IOTA - 380) & 511)])) + ((0.00131229591f * (((fVec12[((IOTA - 106) & 511)] - fVec12[((IOTA - 285) & 511)]) - fVec12[((IOTA - 299) & 511)]) + fVec12[((IOTA - 375) & 511)])) + ((0.000732444227f * (((((((fVec12[((IOTA - 170) & 511)] - fVec12[((IOTA - 234) & 511)]) - fVec12[((IOTA - 310) & 511)]) - fVec12[((IOTA - 325) & 511)]) - fVec12[((IOTA - 327) & 511)]) - fVec12[((IOTA - 357) & 511)]) - fVec12[((IOTA - 358) & 511)]) - fVec12[((IOTA - 359) & 511)])) + ((0.00143436994f * ((((fVec12[((IOTA - 164) & 511)] - fVec12[((IOTA - 203) & 511)]) - fVec12[((IOTA - 246) & 511)]) - fVec12[((IOTA - 283) & 511)]) - fVec12[((IOTA - 284) & 511)])) + ((0.00234992523f * (fVec12[((IOTA - 165) & 511)] - fVec12[((IOTA - 259) & 511)])) + ((0.00216681417f * (fVec12[((IOTA - 138) & 511)] - fVec12[((IOTA - 242) & 511)])) + ((0.00125125889f * fVec12[((IOTA - 214) & 511)]) + ((0.00173955504f * fVec12[((IOTA - 213) & 511)]) + ((0.00152592547f * fVec12[((IOTA - 212) & 511)]) + ((0.00180059206f * (fVec12[((IOTA - 183) & 511)] - fVec12[((IOTA - 209) & 511)])) + ((0.00296029542f * (fVec12[((IOTA - 185) & 511)] - fVec12[((IOTA - 204) & 511)])) + ((0.00198370311f * fVec12[((IOTA - 201) & 511)]) + ((0.00213629566f * fVec12[((IOTA - 200) & 511)]) + ((0.00238044374f * fVec12[((IOTA - 186) & 511)]) + ((0.00463881344f * fVec12[((IOTA - 176) & 511)]) + ((0.00714133121f * fVec12[((IOTA - 175) & 511)]) + ((0.0083925901f * fVec12[((IOTA - 174) & 511)]) + ((0.00692770164f * fVec12[((IOTA - 173) & 511)]) + ((0.00482192449f * fVec12[((IOTA - 172) & 511)]) + ((0.00250251777f * fVec12[((IOTA - 171) & 511)]) + ((0.00314340647f * fVec12[((IOTA - 166) & 511)]) + ((0.00402844325f * fVec12[((IOTA - 161) & 511)]) + ((0.00616473891f * fVec12[((IOTA - 160) & 511)]) + ((0.00625629444f * fVec12[((IOTA - 159) & 511)]) + ((0.00518814661f * fVec12[((IOTA - 158) & 511)]) + ((0.00219733268f * fVec12[((IOTA - 157) & 511)]) + ((0.0170598477f * fVec12[((IOTA - 147) & 511)]) + ((0.00924710836f * fVec12[((IOTA - 146) & 511)]) + ((0.0131534776f * fVec12[((IOTA - 140) & 511)]) + ((0.00997955259f * fVec12[((IOTA - 139) & 511)]) + ((0.00357066561f * fVec12[((IOTA - 135) & 511)]) + ((0.0104068117f * fVec12[((IOTA - 134) & 511)]) + ((0.00598162785f * fVec12[((IOTA - 133) & 511)]) + ((0.0108340709f * fVec12[((IOTA - 149) & 511)]) + ((0.0180669576f * fVec12[((IOTA - 148) & 511)]) + ((0.00378429517f * fVec12[((IOTA - 125) & 511)]) + ((0.0169072542f * fVec12[((IOTA - 124) & 511)]) + ((0.0296639912f * fVec12[((IOTA - 123) & 511)]) + ((0.0379039906f * fVec12[((IOTA - 122) & 511)]) + ((0.0347300656f * fVec12[((IOTA - 121) & 511)]) + ((0.0206305124f * fVec12[((IOTA - 120) & 511)]) + ((0.00396740623f * fVec12[((IOTA - 115) & 511)]) + ((0.0232551042f * fVec12[((IOTA - 114) & 511)]) + ((0.0313119926f * fVec12[((IOTA - 113) & 511)]) + ((0.0311288796f * fVec12[((IOTA - 112) & 511)]) + ((0.0263374746f * fVec12[((IOTA - 111) & 511)]) + ((0.0269478448f * fVec12[((IOTA - 110) & 511)]) + ((0.0248420667f * fVec12[((IOTA - 109) & 511)]) + ((0.0201727357f * fVec12[((IOTA - 108) & 511)]) + ((0.0137028107f * fVec12[((IOTA - 107) & 511)]) + ((0.0149540696f * fVec12[((IOTA - 97) & 511)]) + ((0.0361949541f * fVec12[((IOTA - 96) & 511)]) + ((0.0514236875f * fVec12[((IOTA - 95) & 511)]) + ((0.0527054667f * fVec12[((IOTA - 94) & 511)]) + ((0.017853329f * fVec12[((IOTA - 93) & 511)]) + ((0.0231940672f * fVec12[((IOTA - 88) & 511)]) + ((0.0430311002f * fVec12[((IOTA - 87) & 511)]) + ((0.0452589504f * fVec12[((IOTA - 86) & 511)]) + ((0.0191045869f * fVec12[((IOTA - 85) & 511)]) + ((0.0312814713f * fVec12[((IOTA - 82) & 511)]) + ((0.0321665108f * fVec12[((IOTA - 81) & 511)]) + ((0.0377208777f * fVec12[((IOTA - 80) & 511)]) + ((0.0221259203f * fVec12[((IOTA - 79) & 511)]) + ((0.0202032533f * fVec12[((IOTA - 78) & 511)]) + ((0.0122684408f * fVec12[((IOTA - 77) & 511)]) + ((0.00683614612f * fVec12[((IOTA - 76) & 511)]) + ((0.0298165847f * fVec12[((IOTA - 71) & 511)]) + ((0.131473735f * fVec12[((IOTA - 70) & 511)]) + ((0.212347791f * fVec12[((IOTA - 69) & 511)]) + ((0.163365588f * fVec12[((IOTA - 68) & 511)]) + ((0.00595110934f * fVec12[((IOTA - 59) & 511)]) + ((0.00973540451f * fVec12[((IOTA - 58) & 511)]) + ((0.00982696004f * fVec12[((IOTA - 57) & 511)]) + ((0.00369273964f * fVec12[((IOTA - 55) & 511)]) + (0.00735496078f * fVec12[((IOTA - 56) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((9.15555283e-05f * ((((((((((fVec12[((IOTA - 40) & 511)] + fVec12[((IOTA - 41) & 511)]) + fVec12[((IOTA - 42) & 511)]) - fVec12[((IOTA - 215) & 511)]) + fVec12[((IOTA - 274) & 511)]) + fVec12[((IOTA - 340) & 511)]) + fVec12[((IOTA - 482) & 511)]) - fVec12[((IOTA - 488) & 511)]) + fVec12[((IOTA - 495) & 511)]) + fVec12[((IOTA - 503) & 511)]) + fVec12[((IOTA - 504) & 511)])) + ((0.000274666585f * ((((((fVec12[((IOTA - 50) & 511)] + fVec12[((IOTA - 273) & 511)]) + fVec12[((IOTA - 307) & 511)]) + fVec12[((IOTA - 384) & 511)]) + fVec12[((IOTA - 391) & 511)]) + fVec12[((IOTA - 474) & 511)]) - fVec12[((IOTA - 500) & 511)])) + ((0.000396740623f * (((fVec12[((IOTA - 342) & 511)] + fVec12[((IOTA - 347) & 511)]) + fVec12[((IOTA - 353) & 511)]) - fVec12[((IOTA - 499) & 511)])) + ((0.000457777642f * (((((((fVec12[((IOTA - 271) & 511)] + fVec12[((IOTA - 348) & 511)]) + fVec12[((IOTA - 362) & 511)]) + fVec12[((IOTA - 390) & 511)]) + fVec12[((IOTA - 409) & 511)]) + fVec12[((IOTA - 416) & 511)]) + fVec12[((IOTA - 490) & 511)]) - fVec12[((IOTA - 498) & 511)])) + ((0.000518814661f * ((((((fVec12[((IOTA - 145) & 511)] + fVec12[((IOTA - 235) & 511)]) + fVec12[((IOTA - 345) & 511)]) + fVec12[((IOTA - 366) & 511)]) + fVec12[((IOTA - 447) & 511)]) + fVec12[((IOTA - 455) & 511)]) + fVec12[((IOTA - 494) & 511)])) + ((0.000854518265f * (((((((fVec12[((IOTA - 233) & 511)] + fVec12[((IOTA - 281) & 511)]) + fVec12[((IOTA - 328) & 511)]) - fVec12[((IOTA - 374) & 511)]) + fVec12[((IOTA - 418) & 511)]) + fVec12[((IOTA - 436) & 511)]) - fVec12[((IOTA - 458) & 511)]) + fVec12[((IOTA - 493) & 511)])) + ((0.000946073793f * ((((fVec12[((IOTA - 218) & 511)] + fVec12[((IOTA - 320) & 511)]) + fVec12[((IOTA - 449) & 511)]) + fVec12[((IOTA - 478) & 511)]) + fVec12[((IOTA - 492) & 511)])) + ((0.000793481246f * ((((((fVec12[((IOTA - 222) & 511)] + fVec12[((IOTA - 302) & 511)]) + fVec12[((IOTA - 395) & 511)]) + fVec12[((IOTA - 408) & 511)]) + fVec12[((IOTA - 421) & 511)]) + fVec12[((IOTA - 477) & 511)]) + fVec12[((IOTA - 491) & 511)])) + ((0.000183111057f * (((((((fVec12[((IOTA - 51) & 511)] + fVec12[((IOTA - 372) & 511)]) - fVec12[((IOTA - 386) & 511)]) + fVec12[((IOTA - 442) & 511)]) - fVec12[((IOTA - 456) & 511)]) + fVec12[((IOTA - 473) & 511)]) - fVec12[((IOTA - 485) & 511)]) - fVec12[((IOTA - 486) & 511)])) + ((0.000671407208f * (((((fVec12[((IOTA - 221) & 511)] + fVec12[((IOTA - 264) & 511)]) + fVec12[((IOTA - 326) & 511)]) + fVec12[((IOTA - 356) & 511)]) + fVec12[((IOTA - 367) & 511)]) + fVec12[((IOTA - 480) & 511)])) + ((0.000366222113f * (((((fVec12[((IOTA - 272) & 511)] + fVec12[((IOTA - 350) & 511)]) + fVec12[((IOTA - 365) & 511)]) + fVec12[((IOTA - 393) & 511)]) + fVec12[((IOTA - 429) & 511)]) + fVec12[((IOTA - 475) & 511)])) + ((0.000762962736f * ((((fVec12[((IOTA - 228) & 511)] + fVec12[((IOTA - 263) & 511)]) + fVec12[((IOTA - 334) & 511)]) + fVec12[((IOTA - 464) & 511)]) + fVec12[((IOTA - 468) & 511)])) + ((0.0012817774f * (((fVec12[((IOTA - 397) & 511)] + fVec12[((IOTA - 400) & 511)]) + fVec12[((IOTA - 437) & 511)]) + fVec12[((IOTA - 467) & 511)])) + ((0.00137333293f * (((fVec12[((IOTA - 261) & 511)] - fVec12[((IOTA - 376) & 511)]) + fVec12[((IOTA - 398) & 511)]) + fVec12[((IOTA - 465) & 511)])) + ((0.000701925717f * ((fVec12[((IOTA - 360) & 511)] + fVec12[((IOTA - 405) & 511)]) - fVec12[((IOTA - 462) & 511)])) + ((0.00103762932f * ((((((fVec12[((IOTA - 287) & 511)] + fVec12[((IOTA - 288) & 511)]) + fVec12[((IOTA - 289) & 511)]) + fVec12[((IOTA - 322) & 511)]) + fVec12[((IOTA - 381) & 511)]) - fVec12[((IOTA - 459) & 511)]) - fVec12[((IOTA - 461) & 511)])) + ((0.00109866634f * (((((((fVec12[((IOTA - 83) & 511)] + fVec12[((IOTA - 223) & 511)]) + fVec12[((IOTA - 231) & 511)]) + fVec12[((IOTA - 318) & 511)]) + fVec12[((IOTA - 330) & 511)]) + fVec12[((IOTA - 331) & 511)]) + fVec12[((IOTA - 401) & 511)]) - fVec12[((IOTA - 460) & 511)])) + ((0.00140385143f * ((fVec12[((IOTA - 240) & 511)] + fVec12[((IOTA - 248) & 511)]) + fVec12[((IOTA - 454) & 511)])) + ((0.00210577715f * fVec12[((IOTA - 453) & 511)]) + ((0.0022583697f * ((fVec12[((IOTA - 243) & 511)] + fVec12[((IOTA - 255) & 511)]) + fVec12[((IOTA - 452) & 511)])) + ((0.00177007355f * (fVec12[((IOTA - 132) & 511)] + fVec12[((IOTA - 451) & 511)])) + ((0.00122074038f * ((fVec12[((IOTA - 217) & 511)] + fVec12[((IOTA - 282) & 511)]) + fVec12[((IOTA - 450) & 511)])) + ((0.000610370189f * (((((fVec12[((IOTA - 265) & 511)] + fVec12[((IOTA - 269) & 511)]) + fVec12[((IOTA - 355) & 511)]) + fVec12[((IOTA - 361) & 511)]) + fVec12[((IOTA - 426) & 511)]) - fVec12[((IOTA - 446) & 511)])) + ((0.0019531846f * (fVec12[((IOTA - 438) & 511)] - fVec12[((IOTA - 445) & 511)])) + ((0.00158696249f * (fVec12[((IOTA - 98) & 511)] - fVec12[((IOTA - 443) & 511)])) + ((0.00277718436f * fVec12[((IOTA - 440) & 511)]) + ((0.00262459181f * fVec12[((IOTA - 439) & 511)]) + ((0.00057985168f * ((((((((fVec12[((IOTA - 220) & 511)] + fVec12[((IOTA - 266) & 511)]) + fVec12[((IOTA - 268) & 511)]) + fVec12[((IOTA - 309) & 511)]) + fVec12[((IOTA - 344) & 511)]) + fVec12[((IOTA - 383) & 511)]) + fVec12[((IOTA - 394) & 511)]) + fVec12[((IOTA - 432) & 511)]) + fVec12[((IOTA - 435) & 511)])) + ((0.000488296151f * (((((((fVec12[((IOTA - 150) & 511)] - fVec12[((IOTA - 277) & 511)]) + fVec12[((IOTA - 336) & 511)]) + fVec12[((IOTA - 354) & 511)]) + fVec12[((IOTA - 389) & 511)]) + fVec12[((IOTA - 404) & 511)]) + fVec12[((IOTA - 430) & 511)]) + fVec12[((IOTA - 434) & 511)])) + ((0.000305185094f * ((((((((fVec12[((IOTA - 238) & 511)] + fVec12[((IOTA - 304) & 511)]) + fVec12[((IOTA - 337) & 511)]) + fVec12[((IOTA - 351) & 511)]) + fVec12[((IOTA - 352) & 511)]) + fVec12[((IOTA - 364) & 511)]) - fVec12[((IOTA - 373) & 511)]) + fVec12[((IOTA - 388) & 511)]) + fVec12[((IOTA - 428) & 511)])) + ((0.000823999755f * ((((((((fVec12[((IOTA - 239) & 511)] + fVec12[((IOTA - 311) & 511)]) + fVec12[((IOTA - 368) & 511)]) + fVec12[((IOTA - 370) & 511)]) - fVec12[((IOTA - 377) & 511)]) + fVec12[((IOTA - 382) & 511)]) + fVec12[((IOTA - 402) & 511)]) + fVec12[((IOTA - 420) & 511)]) + fVec12[((IOTA - 425) & 511)])) + ((0.000976592302f * ((((((fVec12[((IOTA - 188) & 511)] + fVec12[((IOTA - 227) & 511)]) + fVec12[((IOTA - 232) & 511)]) + fVec12[((IOTA - 301) & 511)]) + fVec12[((IOTA - 315) & 511)]) + fVec12[((IOTA - 406) & 511)]) + fVec12[((IOTA - 423) & 511)])) + ((0.000885036774f * ((((((((fVec12[((IOTA - 216) & 511)] + fVec12[((IOTA - 229) & 511)]) + fVec12[((IOTA - 292) & 511)]) + fVec12[((IOTA - 312) & 511)]) + fVec12[((IOTA - 324) & 511)]) + fVec12[((IOTA - 333) & 511)]) + fVec12[((IOTA - 369) & 511)]) + fVec12[((IOTA - 419) & 511)]) + fVec12[((IOTA - 422) & 511)])) + ((0.000640888698f * (((((fVec12[((IOTA - 60) & 511)] - fVec12[((IOTA - 163) & 511)]) + fVec12[((IOTA - 210) & 511)]) + fVec12[((IOTA - 219) & 511)]) + fVec12[((IOTA - 335) & 511)]) + fVec12[((IOTA - 417) & 511)])) + ((0.00106814783f * (((fVec12[((IOTA - 230) & 511)] + fVec12[((IOTA - 290) & 511)]) + fVec12[((IOTA - 316) & 511)]) + fVec12[((IOTA - 396) & 511)])) + ((0.000213629566f * (((((fVec12[((IOTA - 49) & 511)] - fVec12[((IOTA - 53) & 511)]) + fVec12[((IOTA - 236) & 511)]) + fVec12[((IOTA - 305) & 511)]) + fVec12[((IOTA - 306) & 511)]) + fVec12[((IOTA - 341) & 511)])) + ((0.00112918485f * (fVec12[((IOTA - 286) & 511)] + fVec12[((IOTA - 317) & 511)])) + ((0.00149540696f * (fVec12[((IOTA - 226) & 511)] + fVec12[((IOTA - 298) & 511)])) + ((0.00164799951f * ((fVec12[((IOTA - 245) & 511)] + fVec12[((IOTA - 296) & 511)]) + fVec12[((IOTA - 297) & 511)])) + ((0.00146488845f * ((fVec12[((IOTA - 197) & 511)] + fVec12[((IOTA - 224) & 511)]) + fVec12[((IOTA - 295) & 511)])) + ((0.00265511032f * (fVec12[((IOTA - 257) & 511)] + fVec12[((IOTA - 258) & 511)])) + ((0.00247199927f * (fVec12[((IOTA - 119) & 511)] + fVec12[((IOTA - 256) & 511)])) + ((0.00207525864f * (fVec12[((IOTA - 251) & 511)] + fVec12[((IOTA - 254) & 511)])) + ((0.0019226661f * fVec12[((IOTA - 252) & 511)]) + ((0.00201422162f * (fVec12[((IOTA - 244) & 511)] + fVec12[((IOTA - 250) & 511)])) + ((0.00170903653f * (fVec12[((IOTA - 225) & 511)] + fVec12[((IOTA - 249) & 511)])) + ((0.00186162908f * fVec12[((IOTA - 241) & 511)]) + ((0.00271614734f * fVec12[((IOTA - 208) & 511)]) + ((0.00350962859f * fVec12[((IOTA - 207) & 511)]) + ((0.00390636921f * fVec12[((IOTA - 206) & 511)]) + ((0.00372325815f * fVec12[((IOTA - 205) & 511)]) + ((0.00241096225f * fVec12[((IOTA - 195) & 511)]) + ((0.00299081393f * (fVec12[((IOTA - 189) & 511)] + fVec12[((IOTA - 194) & 511)])) + ((0.0038758507f * fVec12[((IOTA - 193) & 511)]) + ((0.00476088747f * fVec12[((IOTA - 192) & 511)]) + ((0.00527970213f * fVec12[((IOTA - 191) & 511)]) + ((0.00460829493f * fVec12[((IOTA - 190) & 511)]) + ((0.00280770287f * ((fVec12[((IOTA - 156) & 511)] - fVec12[((IOTA - 167) & 511)]) - fVec12[((IOTA - 184) & 511)])) + ((0.00921658985f * fVec12[((IOTA - 155) & 511)]) + ((0.013061922f * fVec12[((IOTA - 154) & 511)]) + ((0.0143131809f * fVec12[((IOTA - 153) & 511)]) + ((0.0137333293f * fVec12[((IOTA - 152) & 511)]) + ((0.00985747855f * fVec12[((IOTA - 151) & 511)]) + ((0.00540177617f * fVec12[((IOTA - 144) & 511)]) + ((0.00494399853f * fVec12[((IOTA - 143) & 511)]) + ((0.00878933072f * (fVec12[((IOTA - 105) & 511)] - fVec12[((IOTA - 141) & 511)])) + ((0.00689718314f * fVec12[((IOTA - 137) & 511)]) + ((0.00555436872f * fVec12[((IOTA - 136) & 511)]) + ((0.00772118289f * (fVec12[((IOTA - 130) & 511)] + fVec12[((IOTA - 131) & 511)])) + ((0.00796533097f * fVec12[((IOTA - 129) & 511)]) + ((0.00781273842f * fVec12[((IOTA - 128) & 511)]) + ((0.00759910885f * fVec12[((IOTA - 127) & 511)]) + ((0.00430310983f * fVec12[((IOTA - 126) & 511)]) + ((0.0202337727f * fVec12[((IOTA - 118) & 511)]) + ((0.0260933265f * fVec12[((IOTA - 117) & 511)]) + ((0.0141300699f * fVec12[((IOTA - 116) & 511)]) + ((0.00753807183f * fVec12[((IOTA - 104) & 511)]) + ((0.00793481246f * fVec12[((IOTA - 103) & 511)]) + ((0.0168462172f * fVec12[((IOTA - 102) & 511)]) + ((0.0181585141f * fVec12[((IOTA - 101) & 511)]) + ((0.0142521439f * fVec12[((IOTA - 100) & 511)]) + ((0.0150761437f * fVec12[((IOTA - 99) & 511)]) + ((0.0257881414f * fVec12[((IOTA - 92) & 511)]) + ((0.0519730225f * fVec12[((IOTA - 91) & 511)]) + ((0.0462355427f * fVec12[((IOTA - 90) & 511)]) + ((0.0133365886f * fVec12[((IOTA - 89) & 511)]) + ((0.0025940733f * fVec12[((IOTA - 84) & 511)]) + ((0.0042115543f * fVec12[((IOTA - 75) & 511)]) + ((0.0311593991f * fVec12[((IOTA - 74) & 511)]) + ((0.0362254716f * fVec12[((IOTA - 73) & 511)]) + ((0.0383922867f * fVec12[((IOTA - 72) & 511)]) + ((0.0329294726f * fVec12[((IOTA - 67) & 511)]) + ((0.247413561f * fVec12[((IOTA - 66) & 511)]) + ((0.313516647f * fVec12[((IOTA - 65) & 511)]) + ((0.195654169f * fVec12[((IOTA - 64) & 511)]) + ((0.0600909442f * fVec12[((IOTA - 63) & 511)]) + ((0.00628681295f * fVec12[((IOTA - 61) & 511)]) + (0.0114749596f * fVec12[((IOTA - 62) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (3.05185094e-05f * ((((((((((((((((((((((((fVec12[((IOTA - 2) & 511)] + fVec12[((IOTA - 3) & 511)]) + fVec12[((IOTA - 4) & 511)]) + fVec12[((IOTA - 5) & 511)]) + fVec12[((IOTA - 6) & 511)]) + fVec12[((IOTA - 7) & 511)]) + fVec12[((IOTA - 11) & 511)]) + fVec12[((IOTA - 12) & 511)]) + fVec12[((IOTA - 13) & 511)]) + fVec12[((IOTA - 15) & 511)]) + fVec12[((IOTA - 16) & 511)]) - fVec12[((IOTA - 19) & 511)]) + fVec12[((IOTA - 25) & 511)]) + fVec12[((IOTA - 26) & 511)]) + fVec12[((IOTA - 27) & 511)]) + fVec12[((IOTA - 28) & 511)]) + fVec12[((IOTA - 29) & 511)]) + fVec12[((IOTA - 32) & 511)]) + fVec12[((IOTA - 33) & 511)]) + fVec12[((IOTA - 38) & 511)]) + fVec12[((IOTA - 43) & 511)]) - fVec12[((IOTA - 44) & 511)]) - fVec12[((IOTA - 45) & 511)]) - fVec12[((IOTA - 46) & 511)]) - fVec12[((IOTA - 508) & 511)]))) + (6.10370189e-05f * (((((((((((((fVec12[((IOTA - 14) & 511)] + fVec12[((IOTA - 39) & 511)]) + fVec12[((IOTA - 48) & 511)]) - fVec12[((IOTA - 169) & 511)]) + fVec12[((IOTA - 237) & 511)]) + fVec12[((IOTA - 339) & 511)]) - fVec12[((IOTA - 385) & 511)]) + fVec12[((IOTA - 410) & 511)]) - fVec12[((IOTA - 463) & 511)]) - fVec12[((IOTA - 483) & 511)]) - fVec12[((IOTA - 506) & 511)]) - fVec12[((IOTA - 507) & 511)]) + fVec12[((IOTA - 510) & 511)]) + fVec12[((IOTA - 511) & 511)])))))) : (iSlow25 ? (iSlow29 ? (((0.000457777642f * ((((((((fVec11[((IOTA - 160) & 511)] - fVec11[((IOTA - 191) & 511)]) - fVec11[((IOTA - 210) & 511)]) + fVec11[((IOTA - 234) & 511)]) + fVec11[((IOTA - 314) & 511)]) - fVec11[((IOTA - 336) & 511)]) - fVec11[((IOTA - 484) & 511)]) - fVec11[((IOTA - 489) & 511)]) - fVec11[((IOTA - 509) & 511)])) + ((0.000640888698f * (((((fVec11[((IOTA - 192) & 511)] + fVec11[((IOTA - 310) & 511)]) - fVec11[((IOTA - 338) & 511)]) + fVec11[((IOTA - 350) & 511)]) - fVec11[((IOTA - 483) & 511)]) - fVec11[((IOTA - 508) & 511)])) + ((0.000762962736f * ((((((((fVec11[((IOTA - 224) & 511)] + fVec11[((IOTA - 278) & 511)]) + fVec11[((IOTA - 284) & 511)]) + fVec11[((IOTA - 348) & 511)]) - fVec11[((IOTA - 450) & 511)]) - fVec11[((IOTA - 482) & 511)]) + fVec11[((IOTA - 499) & 511)]) - fVec11[((IOTA - 505) & 511)]) - fVec11[((IOTA - 507) & 511)])) + ((0.000854518265f * (((fVec11[((IOTA - 243) & 511)] - fVec11[((IOTA - 472) & 511)]) - fVec11[((IOTA - 492) & 511)]) - fVec11[((IOTA - 506) & 511)])) + ((0.000366222113f * ((((((fVec11[((IOTA - 306) & 511)] + fVec11[((IOTA - 324) & 511)]) + fVec11[((IOTA - 426) & 511)]) + fVec11[((IOTA - 445) & 511)]) + fVec11[((IOTA - 455) & 511)]) + fVec11[((IOTA - 498) & 511)]) + fVec11[((IOTA - 502) & 511)])) + ((0.000732444227f * (((((((fVec11[((IOTA - 238) & 511)] + fVec11[((IOTA - 323) & 511)]) + fVec11[((IOTA - 414) & 511)]) + fVec11[((IOTA - 422) & 511)]) + fVec11[((IOTA - 449) & 511)]) - fVec11[((IOTA - 480) & 511)]) - fVec11[((IOTA - 491) & 511)]) + fVec11[((IOTA - 501) & 511)])) + ((0.000823999755f * ((((fVec11[((IOTA - 197) & 511)] + fVec11[((IOTA - 351) & 511)]) + fVec11[((IOTA - 423) & 511)]) - fVec11[((IOTA - 428) & 511)]) + fVec11[((IOTA - 500) & 511)])) + ((0.000793481246f * ((((((((((fVec11[((IOTA - 181) & 511)] - fVec11[((IOTA - 231) & 511)]) + fVec11[((IOTA - 241) & 511)]) + fVec11[((IOTA - 277) & 511)]) + fVec11[((IOTA - 293) & 511)]) + fVec11[((IOTA - 295) & 511)]) + fVec11[((IOTA - 312) & 511)]) + fVec11[((IOTA - 424) & 511)]) - fVec11[((IOTA - 464) & 511)]) - fVec11[((IOTA - 481) & 511)]) - fVec11[((IOTA - 495) & 511)])) + ((0.000885036774f * (((((fVec11[((IOTA - 279) & 511)] + fVec11[((IOTA - 282) & 511)]) + fVec11[((IOTA - 283) & 511)]) + fVec11[((IOTA - 319) & 511)]) - fVec11[((IOTA - 391) & 511)]) - fVec11[((IOTA - 494) & 511)])) + ((0.000915555283f * ((fVec11[((IOTA - 298) & 511)] + fVec11[((IOTA - 457) & 511)]) - fVec11[((IOTA - 493) & 511)])) + ((0.000244148076f * (((((((fVec11[((IOTA - 59) & 511)] + fVec11[((IOTA - 182) & 511)]) + fVec11[((IOTA - 300) & 511)]) + fVec11[((IOTA - 316) & 511)]) + fVec11[((IOTA - 332) & 511)]) + fVec11[((IOTA - 359) & 511)]) - fVec11[((IOTA - 416) & 511)]) - fVec11[((IOTA - 485) & 511)])) + ((0.000396740623f * ((fVec11[((IOTA - 236) & 511)] - fVec11[((IOTA - 404) & 511)]) - fVec11[((IOTA - 478) & 511)])) + ((0.000183111057f * ((((((fVec11[((IOTA - 58) & 511)] + fVec11[((IOTA - 60) & 511)]) + fVec11[((IOTA - 226) & 511)]) - fVec11[((IOTA - 303) & 511)]) + fVec11[((IOTA - 415) & 511)]) - fVec11[((IOTA - 427) & 511)]) + fVec11[((IOTA - 476) & 511)])) + ((0.000274666585f * ((((fVec11[((IOTA - 209) & 511)] - fVec11[((IOTA - 302) & 511)]) - fVec11[((IOTA - 341) & 511)]) + fVec11[((IOTA - 463) & 511)]) + fVec11[((IOTA - 474) & 511)])) + ((6.10370189e-05f * (((((((((fVec11[((IOTA - 29) & 511)] + fVec11[((IOTA - 30) & 511)]) + fVec11[((IOTA - 34) & 511)]) + fVec11[((IOTA - 35) & 511)]) + fVec11[((IOTA - 37) & 511)]) + fVec11[((IOTA - 49) & 511)]) + fVec11[((IOTA - 50) & 511)]) + fVec11[((IOTA - 51) & 511)]) + fVec11[((IOTA - 333) & 511)]) - fVec11[((IOTA - 473) & 511)])) + ((0.00274666585f * (fVec11[((IOTA - 217) & 511)] - fVec11[((IOTA - 470) & 511)])) + ((0.00231940672f * (fVec11[((IOTA - 202) & 511)] - fVec11[((IOTA - 466) & 511)])) + ((0.00167851802f * ((fVec11[((IOTA - 222) & 511)] - fVec11[((IOTA - 438) & 511)]) - fVec11[((IOTA - 465) & 511)])) + ((0.00146488845f * ((((fVec11[((IOTA - 195) & 511)] + fVec11[((IOTA - 252) & 511)]) + fVec11[((IOTA - 265) & 511)]) + fVec11[((IOTA - 271) & 511)]) + fVec11[((IOTA - 462) & 511)])) + ((0.00253303628f * (fVec11[((IOTA - 459) & 511)] + fVec11[((IOTA - 461) & 511)])) + ((0.00164799951f * (((fVec11[((IOTA - 272) & 511)] + fVec11[((IOTA - 408) & 511)]) - fVec11[((IOTA - 442) & 511)]) + fVec11[((IOTA - 458) & 511)])) + ((0.00170903653f * ((fVec11[((IOTA - 246) & 511)] + fVec11[((IOTA - 354) & 511)]) - fVec11[((IOTA - 453) & 511)])) + ((0.00250251777f * ((((fVec11[((IOTA - 255) & 511)] + fVec11[((IOTA - 256) & 511)]) + fVec11[((IOTA - 367) & 511)]) + fVec11[((IOTA - 384) & 511)]) - fVec11[((IOTA - 452) & 511)])) + ((0.00158696249f * (((fVec11[((IOTA - 247) & 511)] - fVec11[((IOTA - 402) & 511)]) - fVec11[((IOTA - 434) & 511)]) + fVec11[((IOTA - 448) & 511)])) + ((0.001617481f * (((fVec11[((IOTA - 146) & 511)] + fVec11[((IOTA - 273) & 511)]) + fVec11[((IOTA - 274) & 511)]) + fVec11[((IOTA - 447) & 511)])) + ((0.00106814783f * (fVec11[((IOTA - 322) & 511)] + fVec11[((IOTA - 446) & 511)])) + ((0.00103762932f * ((((((fVec11[((IOTA - 280) & 511)] + fVec11[((IOTA - 289) & 511)]) + fVec11[((IOTA - 292) & 511)]) + fVec11[((IOTA - 297) & 511)]) + fVec11[((IOTA - 347) & 511)]) - fVec11[((IOTA - 365) & 511)]) - fVec11[((IOTA - 443) & 511)])) + ((0.00198370311f * ((fVec11[((IOTA - 260) & 511)] + fVec11[((IOTA - 410) & 511)]) - fVec11[((IOTA - 441) & 511)])) + ((0.00204474013f * ((fVec11[((IOTA - 372) & 511)] - fVec11[((IOTA - 377) & 511)]) - fVec11[((IOTA - 440) & 511)])) + ((0.0019226661f * (((fVec11[((IOTA - 150) & 511)] + fVec11[((IOTA - 253) & 511)]) + fVec11[((IOTA - 412) & 511)]) - fVec11[((IOTA - 439) & 511)])) + ((0.00155644398f * ((fVec11[((IOTA - 207) & 511)] - fVec11[((IOTA - 433) & 511)]) - fVec11[((IOTA - 435) & 511)])) + ((0.00143436994f * ((((fVec11[((IOTA - 261) & 511)] + fVec11[((IOTA - 268) & 511)]) + fVec11[((IOTA - 353) & 511)]) - fVec11[((IOTA - 431) & 511)]) - fVec11[((IOTA - 432) & 511)])) + ((0.00134281442f * ((fVec11[((IOTA - 200) & 511)] + fVec11[((IOTA - 244) & 511)]) - fVec11[((IOTA - 429) & 511)])) + ((0.000671407208f * ((((fVec11[((IOTA - 213) & 511)] + fVec11[((IOTA - 294) & 511)]) - fVec11[((IOTA - 360) & 511)]) - fVec11[((IOTA - 418) & 511)]) + fVec11[((IOTA - 425) & 511)])) + ((0.00137333293f * ((fVec11[((IOTA - 199) & 511)] + fVec11[((IOTA - 248) & 511)]) + fVec11[((IOTA - 413) & 511)])) + ((0.00180059206f * (((fVec11[((IOTA - 167) & 511)] + fVec11[((IOTA - 215) & 511)]) + fVec11[((IOTA - 356) & 511)]) + fVec11[((IOTA - 409) & 511)])) + ((0.00100711081f * ((((fVec11[((IOTA - 208) & 511)] + fVec11[((IOTA - 223) & 511)]) - fVec11[((IOTA - 230) & 511)]) + fVec11[((IOTA - 281) & 511)]) + fVec11[((IOTA - 406) & 511)])) + ((0.000305185094f * ((((((fVec11[((IOTA - 233) & 511)] + fVec11[((IOTA - 315) & 511)]) + fVec11[((IOTA - 317) & 511)]) - fVec11[((IOTA - 327) & 511)]) + fVec11[((IOTA - 331) & 511)]) - fVec11[((IOTA - 335) & 511)]) + fVec11[((IOTA - 405) & 511)])) + ((0.000976592302f * (((fVec11[((IOTA - 296) & 511)] + fVec11[((IOTA - 344) & 511)]) + fVec11[((IOTA - 358) & 511)]) - fVec11[((IOTA - 403) & 511)])) + ((0.00238044374f * (((fVec11[((IOTA - 254) & 511)] - fVec11[((IOTA - 363) & 511)]) - fVec11[((IOTA - 374) & 511)]) - fVec11[((IOTA - 400) & 511)])) + ((0.00207525864f * fVec11[((IOTA - 411) & 511)]) + ((0.0025940733f * ((fVec11[((IOTA - 205) & 511)] + fVec11[((IOTA - 221) & 511)]) - fVec11[((IOTA - 395) & 511)])) + ((0.00268562883f * (fVec11[((IOTA - 203) & 511)] - fVec11[((IOTA - 394) & 511)])) + ((0.00234992523f * (fVec11[((IOTA - 259) & 511)] - fVec11[((IOTA - 393) & 511)])) + ((0.00247199927f * (fVec11[((IOTA - 257) & 511)] + fVec11[((IOTA - 388) & 511)])) + ((0.00347911008f * fVec11[((IOTA - 387) & 511)]) + ((0.0035401471f * fVec11[((IOTA - 385) & 511)]) + ((0.00109866634f * ((((fVec11[((IOTA - 102) & 511)] + fVec11[((IOTA - 193) & 511)]) + fVec11[((IOTA - 320) & 511)]) + fVec11[((IOTA - 352) & 511)]) - fVec11[((IOTA - 378) & 511)])) + ((0.000427259132f * ((fVec11[((IOTA - 235) & 511)] + fVec11[((IOTA - 237) & 511)]) - fVec11[((IOTA - 373) & 511)])) + ((0.00427259132f * fVec11[((IOTA - 371) & 511)]) + ((0.0054933317f * fVec11[((IOTA - 370) & 511)]) + ((0.00546281319f * fVec11[((IOTA - 369) & 511)]) + ((0.00433362834f * fVec11[((IOTA - 368) & 511)]) + ((0.00201422162f * ((fVec11[((IOTA - 136) & 511)] + fVec11[((IOTA - 206) & 511)]) - fVec11[((IOTA - 364) & 511)])) + ((0.00122074038f * (((fVec11[((IOTA - 214) & 511)] + fVec11[((IOTA - 264) & 511)]) + fVec11[((IOTA - 321) & 511)]) + fVec11[((IOTA - 346) & 511)])) + ((0.00125125889f * (fVec11[((IOTA - 270) & 511)] + fVec11[((IOTA - 345) & 511)])) + ((9.15555283e-05f * ((fVec11[((IOTA - 57) & 511)] - fVec11[((IOTA - 301) & 511)]) + fVec11[((IOTA - 342) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((fVec11[((IOTA - 13) & 511)] + fVec11[((IOTA - 14) & 511)]) + fVec11[((IOTA - 15) & 511)]) + fVec11[((IOTA - 17) & 511)]) + fVec11[((IOTA - 19) & 511)]) + fVec11[((IOTA - 21) & 511)]) + fVec11[((IOTA - 22) & 511)]) + fVec11[((IOTA - 23) & 511)]) + fVec11[((IOTA - 26) & 511)]) + fVec11[((IOTA - 27) & 511)]) + fVec11[((IOTA - 28) & 511)]) + fVec11[((IOTA - 31) & 511)]) + fVec11[((IOTA - 32) & 511)]) + fVec11[((IOTA - 33) & 511)]) + fVec11[((IOTA - 36) & 511)]) + fVec11[((IOTA - 38) & 511)]) + fVec11[((IOTA - 39) & 511)]) + fVec11[((IOTA - 40) & 511)]) + fVec11[((IOTA - 41) & 511)]) + fVec11[((IOTA - 42) & 511)]) + fVec11[((IOTA - 43) & 511)]) + fVec11[((IOTA - 44) & 511)]) + fVec11[((IOTA - 45) & 511)]) + fVec11[((IOTA - 46) & 511)]) + fVec11[((IOTA - 47) & 511)]) + fVec11[((IOTA - 48) & 511)]) + fVec11[((IOTA - 52) & 511)]) + fVec11[((IOTA - 53) & 511)]) + fVec11[((IOTA - 54) & 511)]) + fVec11[((IOTA - 55) & 511)]) + fVec11[((IOTA - 56) & 511)]) + fVec11[((IOTA - 69) & 511)]) - fVec11[((IOTA - 304) & 511)]) + fVec11[((IOTA - 325) & 511)])) + ((0.000701925717f * (((fVec11[((IOTA - 242) & 511)] + fVec11[((IOTA - 288) & 511)]) + fVec11[((IOTA - 311) & 511)]) + fVec11[((IOTA - 313) & 511)])) + ((0.00112918485f * (((fVec11[((IOTA - 262) & 511)] + fVec11[((IOTA - 263) & 511)]) + fVec11[((IOTA - 290) & 511)]) + fVec11[((IOTA - 291) & 511)])) + ((0.000946073793f * ((fVec11[((IOTA - 196) & 511)] - fVec11[((IOTA - 229) & 511)]) + fVec11[((IOTA - 276) & 511)])) + ((0.00241096225f * (fVec11[((IOTA - 216) & 511)] + fVec11[((IOTA - 258) & 511)])) + ((0.0012817774f * (fVec11[((IOTA - 198) & 511)] + fVec11[((IOTA - 251) & 511)])) + ((0.00115970336f * ((fVec11[((IOTA - 240) & 511)] + fVec11[((IOTA - 249) & 511)]) + fVec11[((IOTA - 250) & 511)])) + ((0.00119022187f * fVec11[((IOTA - 239) & 511)]) + ((0.00338755455f * fVec11[((IOTA - 220) & 511)]) + ((0.00360118411f * fVec11[((IOTA - 219) & 511)]) + ((0.00314340647f * fVec11[((IOTA - 218) & 511)]) + ((0.00280770287f * fVec11[((IOTA - 204) & 511)]) + ((0.00527970213f * (fVec11[((IOTA - 161) & 511)] - fVec11[((IOTA - 187) & 511)])) + ((0.0061342204f * (fVec11[((IOTA - 152) & 511)] - fVec11[((IOTA - 171) & 511)])) + ((0.00463881344f * fVec11[((IOTA - 166) & 511)]) + ((0.00860621966f * fVec11[((IOTA - 165) & 511)]) + ((0.00949125644f * fVec11[((IOTA - 164) & 511)]) + ((0.00784325693f * fVec11[((IOTA - 163) & 511)]) + ((0.00698873866f * fVec11[((IOTA - 162) & 511)]) + ((0.00369273964f * fVec11[((IOTA - 155) & 511)]) + ((0.00668355357f * fVec11[((IOTA - 154) & 511)]) + ((0.00653096102f * fVec11[((IOTA - 153) & 511)]) + ((0.00497451704f * fVec11[((IOTA - 151) & 511)]) + ((0.00302133244f * fVec11[((IOTA - 145) & 511)]) + ((0.00445570238f * fVec11[((IOTA - 144) & 511)]) + ((0.00634784997f * fVec11[((IOTA - 143) & 511)]) + ((0.0101016266f * fVec11[((IOTA - 142) & 511)]) + ((0.0129093295f * fVec11[((IOTA - 141) & 511)]) + ((0.0154728843f * fVec11[((IOTA - 140) & 511)]) + ((0.0130314035f * fVec11[((IOTA - 138) & 511)]) + ((0.00714133121f * fVec11[((IOTA - 137) & 511)]) + ((0.00448622089f * (fVec11[((IOTA - 129) & 511)] - fVec11[((IOTA - 135) & 511)])) + ((0.021088291f * fVec11[((IOTA - 128) & 511)]) + ((0.0253303628f * fVec11[((IOTA - 127) & 511)]) + ((0.0122074038f * fVec11[((IOTA - 126) & 511)]) + ((0.00454725791f * fVec11[((IOTA - 115) & 511)]) + ((0.0176091809f * fVec11[((IOTA - 113) & 511)]) + ((0.0153813288f * fVec11[((IOTA - 112) & 511)]) + ((0.019348735f * fVec11[((IOTA - 111) & 511)]) + ((0.0186468102f * (fVec11[((IOTA - 99) & 511)] + fVec11[((IOTA - 110) & 511)])) + ((0.0156865139f * fVec11[((IOTA - 139) & 511)]) + ((0.0167241432f * fVec11[((IOTA - 109) & 511)]) + ((0.00308236945f * fVec11[((IOTA - 108) & 511)]) + ((0.0285042878f * fVec11[((IOTA - 101) & 511)]) + ((0.0377513953f * fVec11[((IOTA - 100) & 511)]) + ((0.00830103457f * fVec11[((IOTA - 82) & 511)]) + ((0.024567401f * fVec11[((IOTA - 81) & 511)]) + ((0.0556962788f * fVec11[((IOTA - 76) & 511)]) + ((0.262367636f * fVec11[((IOTA - 75) & 511)]) + ((0.322672188f * fVec11[((IOTA - 74) & 511)]) + ((0.202337712f * fVec11[((IOTA - 73) & 511)]) + ((0.0761131644f * fVec11[((IOTA - 72) & 511)]) + ((0.00616473891f * fVec11[((IOTA - 70) & 511)]) + (0.0209967345f * fVec11[((IOTA - 71) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((0.000122074038f * (((fVec11[((IOTA - 227) & 511)] + fVec11[((IOTA - 477) & 511)]) + fVec11[((IOTA - 486) & 511)]) + fVec11[((IOTA - 497) & 511)])) + ((0.00054933317f * (((fVec11[((IOTA - 228) & 511)] - fVec11[((IOTA - 366) & 511)]) + fVec11[((IOTA - 479) & 511)]) + fVec11[((IOTA - 496) & 511)])) + ((0.000610370189f * ((((fVec11[((IOTA - 339) & 511)] - (fVec11[((IOTA - 299) & 511)] - fVec11[((IOTA - 337) & 511)])) - fVec11[((IOTA - 349) & 511)]) - fVec11[((IOTA - 456) & 511)]) + fVec11[((IOTA - 490) & 511)])) + ((0.000335703604f * ((((((fVec11[((IOTA - 62) & 511)] + fVec11[((IOTA - 380) & 511)]) - fVec11[((IOTA - 382) & 511)]) - fVec11[((IOTA - 421) & 511)]) + fVec11[((IOTA - 444) & 511)]) - fVec11[((IOTA - 475) & 511)]) + fVec11[((IOTA - 488) & 511)])) + ((0.00189214759f * (fVec11[((IOTA - 397) & 511)] + fVec11[((IOTA - 471) & 511)])) + ((0.00320444349f * fVec11[((IOTA - 469) & 511)]) + ((0.00317392498f * fVec11[((IOTA - 468) & 511)]) + ((0.00283822138f * fVec11[((IOTA - 467) & 511)]) + ((0.00296029542f * (fVec11[((IOTA - 376) & 511)] - fVec11[((IOTA - 460) & 511)])) + ((0.000488296151f * (((((((fVec11[((IOTA - 147) & 511)] + fVec11[((IOTA - 149) & 511)]) - fVec11[((IOTA - 286) & 511)]) - fVec11[((IOTA - 287) & 511)]) - fVec11[((IOTA - 307) & 511)]) - fVec11[((IOTA - 308) & 511)]) + fVec11[((IOTA - 379) & 511)]) + fVec11[((IOTA - 454) & 511)])) + ((0.00210577715f * (fVec11[((IOTA - 183) & 511)] + fVec11[((IOTA - 451) & 511)])) + ((0.00152592547f * (((fVec11[((IOTA - 361) & 511)] + fVec11[((IOTA - 430) & 511)]) + fVec11[((IOTA - 436) & 511)]) + fVec11[((IOTA - 437) & 511)])) + ((0.00057985168f * ((((fVec11[((IOTA - 180) & 511)] - fVec11[((IOTA - 285) & 511)]) - fVec11[((IOTA - 309) & 511)]) - fVec11[((IOTA - 318) & 511)]) + fVec11[((IOTA - 419) & 511)])) + ((0.00140385143f * ((fVec11[((IOTA - 63) & 511)] - fVec11[((IOTA - 267) & 511)]) - fVec11[((IOTA - 407) & 511)])) + ((0.00216681417f * fVec11[((IOTA - 401) & 511)]) + ((0.00219733268f * ((fVec11[((IOTA - 362) & 511)] + fVec11[((IOTA - 396) & 511)]) + fVec11[((IOTA - 399) & 511)])) + ((0.0019531846f * fVec11[((IOTA - 398) & 511)]) + ((0.00173955504f * (((fVec11[((IOTA - 156) & 511)] - fVec11[((IOTA - 201) & 511)]) - fVec11[((IOTA - 245) & 511)]) + fVec11[((IOTA - 392) & 511)])) + ((0.00131229591f * ((((fVec11[((IOTA - 148) & 511)] - fVec11[((IOTA - 269) & 511)]) - fVec11[((IOTA - 275) & 511)]) - fVec11[((IOTA - 383) & 511)]) - fVec11[((IOTA - 389) & 511)])) + ((0.00393688772f * (fVec11[((IOTA - 176) & 511)] - fVec11[((IOTA - 386) & 511)])) + ((0.000213629566f * ((((fVec11[((IOTA - 232) & 511)] + fVec11[((IOTA - 326) & 511)]) + fVec11[((IOTA - 328) & 511)]) - fVec11[((IOTA - 330) & 511)]) + fVec11[((IOTA - 381) & 511)])) + ((0.00329599902f * fVec11[((IOTA - 375) & 511)]) + ((0.00149540696f * (((fVec11[((IOTA - 190) & 511)] - fVec11[((IOTA - 194) & 511)]) - fVec11[((IOTA - 266) & 511)]) - fVec11[((IOTA - 357) & 511)])) + ((0.00186162908f * (fVec11[((IOTA - 189) & 511)] - fVec11[((IOTA - 355) & 511)])) + ((0.00332651753f * fVec11[((IOTA - 188) & 511)]) + ((0.00524918362f * fVec11[((IOTA - 186) & 511)]) + ((0.00482192449f * fVec11[((IOTA - 185) & 511)]) + ((0.00411999878f * (fVec11[((IOTA - 175) & 511)] + fVec11[((IOTA - 184) & 511)])) + ((0.00262459181f * fVec11[((IOTA - 179) & 511)]) + ((0.00424207281f * (fVec11[((IOTA - 177) & 511)] + fVec11[((IOTA - 178) & 511)])) + ((0.004852443f * fVec11[((IOTA - 174) & 511)]) + ((0.00643940549f * fVec11[((IOTA - 173) & 511)]) + ((0.00723288674f * fVec11[((IOTA - 172) & 511)]) + ((0.00418103579f * fVec11[((IOTA - 170) & 511)]) + ((0.00244148076f * fVec11[((IOTA - 169) & 511)]) + ((0.00469985045f * fVec11[((IOTA - 159) & 511)]) + ((0.00671407208f * fVec11[((IOTA - 158) & 511)]) + ((0.00598162785f * fVec11[((IOTA - 157) & 511)]) + ((0.0119022187f * fVec11[((IOTA - 134) & 511)]) + ((0.0209356975f * fVec11[((IOTA - 133) & 511)]) + ((0.0278939176f * fVec11[((IOTA - 132) & 511)]) + ((0.0261543635f * fVec11[((IOTA - 131) & 511)]) + ((0.0138554033f * fVec11[((IOTA - 130) & 511)]) + ((0.00732444227f * fVec11[((IOTA - 125) & 511)]) + ((0.0230109561f * fVec11[((IOTA - 124) & 511)]) + ((0.0318002887f * fVec11[((IOTA - 123) & 511)]) + ((0.0320139155f * fVec11[((IOTA - 122) & 511)]) + ((0.0305185094f * fVec11[((IOTA - 121) & 511)]) + ((0.030915251f * fVec11[((IOTA - 120) & 511)]) + ((0.0316171758f * fVec11[((IOTA - 119) & 511)]) + ((0.0247199927f * fVec11[((IOTA - 118) & 511)]) + ((0.0166936256f * fVec11[((IOTA - 117) & 511)]) + ((0.00656147953f * fVec11[((IOTA - 116) & 511)]) + ((0.0128482925f * (fVec11[((IOTA - 106) & 511)] - fVec11[((IOTA - 114) & 511)])) + ((0.0077517014f * fVec11[((IOTA - 107) & 511)]) + ((0.0202337727f * fVec11[((IOTA - 105) & 511)]) + ((0.0255745109f * fVec11[((IOTA - 104) & 511)]) + ((0.0202948097f * fVec11[((IOTA - 103) & 511)]) + ((0.00888088625f * fVec11[((IOTA - 98) & 511)]) + ((0.0280770287f * fVec11[((IOTA - 97) & 511)]) + ((0.0375682861f * fVec11[((IOTA - 96) & 511)]) + ((0.0332651772f * fVec11[((IOTA - 95) & 511)]) + ((0.0188909583f * fVec11[((IOTA - 94) & 511)]) + ((0.00576799829f * fVec11[((IOTA - 93) & 511)]) + ((0.0106509598f * fVec11[((IOTA - 92) & 511)]) + ((0.0177312549f * fVec11[((IOTA - 91) & 511)]) + ((0.0428479873f * fVec11[((IOTA - 90) & 511)]) + ((0.0478530228f * fVec11[((IOTA - 89) & 511)]) + ((0.0300302133f * fVec11[((IOTA - 88) & 511)]) + ((0.0282601397f * fVec11[((IOTA - 87) & 511)]) + ((0.021210365f * fVec11[((IOTA - 86) & 511)]) + ((0.0343333222f * fVec11[((IOTA - 85) & 511)]) + ((0.0370799899f * fVec11[((IOTA - 84) & 511)]) + ((0.0412915424f * fVec11[((IOTA - 83) & 511)]) + ((0.0549027994f * fVec11[((IOTA - 80) & 511)]) + ((0.139866322f * fVec11[((IOTA - 79) & 511)]) + ((0.193578899f * fVec11[((IOTA - 78) & 511)]) + ((0.128757596f * fVec11[((IOTA - 77) & 511)]) + (((0.0105288858f * fVec11[((IOTA - 66) & 511)]) + ((0.00793481246f * fVec11[((IOTA - 65) & 511)]) + ((0.00402844325f * fVec11[((IOTA - 64) & 511)]) + (0.0102542192f * fVec11[((IOTA - 67) & 511)])))) + (0.00720236823f * fVec11[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000518814661f * (((((fVec11[((IOTA - 211) & 511)] - fVec11[((IOTA - 225) & 511)]) + fVec11[((IOTA - 340) & 511)]) - fVec11[((IOTA - 343) & 511)]) + fVec11[((IOTA - 417) & 511)]) + fVec11[((IOTA - 504) & 511)]))) + (0.000152592547f * ((((((((fVec11[((IOTA - 168) & 511)] - fVec11[((IOTA - 305) & 511)]) + fVec11[((IOTA - 334) & 511)]) - fVec11[((IOTA - 390) & 511)]) + fVec11[((IOTA - 420) & 511)]) + fVec11[((IOTA - 487) & 511)]) + fVec11[((IOTA - 503) & 511)]) + fVec11[((IOTA - 510) & 511)]) - fVec11[((IOTA - 511) & 511)])))) : (((0.0019226661f * ((((fVec10[((IOTA - 204) & 511)] + fVec10[((IOTA - 222) & 511)]) + fVec10[((IOTA - 259) & 511)]) + fVec10[((IOTA - 299) & 511)]) - fVec10[((IOTA - 509) & 511)])) + ((0.00149540696f * ((fVec10[((IOTA - 323) & 511)] - fVec10[((IOTA - 435) & 511)]) - fVec10[((IOTA - 507) & 511)])) + ((0.00213629566f * ((((fVec10[((IOTA - 163) & 511)] + fVec10[((IOTA - 271) & 511)]) + fVec10[((IOTA - 273) & 511)]) - fVec10[((IOTA - 439) & 511)]) - fVec10[((IOTA - 504) & 511)])) + ((0.00207525864f * (((fVec10[((IOTA - 293) & 511)] + fVec10[((IOTA - 379) & 511)]) + fVec10[((IOTA - 407) & 511)]) - fVec10[((IOTA - 502) & 511)])) + ((0.00103762932f * (fVec10[((IOTA - 295) & 511)] - fVec10[((IOTA - 500) & 511)])) + ((0.000885036774f * ((((fVec10[((IOTA - 312) & 511)] + fVec10[((IOTA - 315) & 511)]) + fVec10[((IOTA - 324) & 511)]) + fVec10[((IOTA - 332) & 511)]) - fVec10[((IOTA - 499) & 511)])) + ((0.00122074038f * (fVec10[((IOTA - 187) & 511)] - fVec10[((IOTA - 498) & 511)])) + ((0.00170903653f * (((((fVec10[((IOTA - 193) & 511)] + fVec10[((IOTA - 229) & 511)]) + fVec10[((IOTA - 408) & 511)]) + fVec10[((IOTA - 409) & 511)]) - fVec10[((IOTA - 456) & 511)]) - fVec10[((IOTA - 497) & 511)])) + ((0.00198370311f * ((((fVec10[((IOTA - 270) & 511)] + fVec10[((IOTA - 309) & 511)]) + fVec10[((IOTA - 388) & 511)]) - fVec10[((IOTA - 473) & 511)]) - fVec10[((IOTA - 496) & 511)])) + ((0.00143436994f * (((fVec10[((IOTA - 306) & 511)] + fVec10[((IOTA - 331) & 511)]) + fVec10[((IOTA - 448) & 511)]) - fVec10[((IOTA - 494) & 511)])) + ((0.00115970336f * ((fVec10[((IOTA - 345) & 511)] - fVec10[((IOTA - 452) & 511)]) - fVec10[((IOTA - 493) & 511)])) + ((0.00131229591f * ((((fVec10[((IOTA - 311) & 511)] + fVec10[((IOTA - 322) & 511)]) + fVec10[((IOTA - 330) & 511)]) - fVec10[((IOTA - 366) & 511)]) - fVec10[((IOTA - 492) & 511)])) + ((0.00167851802f * ((((fVec10[((IOTA - 221) & 511)] + fVec10[((IOTA - 308) & 511)]) - fVec10[((IOTA - 327) & 511)]) - fVec10[((IOTA - 436) & 511)]) - fVec10[((IOTA - 491) & 511)])) + ((0.00180059206f * (((fVec10[((IOTA - 310) & 511)] - fVec10[((IOTA - 416) & 511)]) - fVec10[((IOTA - 486) & 511)]) - fVec10[((IOTA - 490) & 511)])) + ((0.0012817774f * (fVec10[((IOTA - 307) & 511)] - fVec10[((IOTA - 487) & 511)])) + ((0.00234992523f * (fVec10[((IOTA - 292) & 511)] - fVec10[((IOTA - 483) & 511)])) + ((0.00305185094f * (fVec10[((IOTA - 200) & 511)] - fVec10[((IOTA - 479) & 511)])) + ((0.00302133244f * ((fVec10[((IOTA - 216) & 511)] + fVec10[((IOTA - 380) & 511)]) - fVec10[((IOTA - 478) & 511)])) + ((0.00219733268f * ((fVec10[((IOTA - 254) & 511)] + fVec10[((IOTA - 276) & 511)]) - fVec10[((IOTA - 474) & 511)])) + ((0.00210577715f * (((fVec10[((IOTA - 64) & 511)] + fVec10[((IOTA - 231) & 511)]) + fVec10[((IOTA - 300) & 511)]) - fVec10[((IOTA - 472) & 511)])) + ((0.00274666585f * (fVec10[((IOTA - 223) & 511)] - fVec10[((IOTA - 471) & 511)])) + ((0.00366222113f * (((fVec10[((IOTA - 177) & 511)] + fVec10[((IOTA - 205) & 511)]) + fVec10[((IOTA - 228) & 511)]) - fVec10[((IOTA - 470) & 511)])) + ((0.00375377666f * (((fVec10[((IOTA - 241) & 511)] + fVec10[((IOTA - 244) & 511)]) - fVec10[((IOTA - 444) & 511)]) - fVec10[((IOTA - 468) & 511)])) + ((0.00244148076f * (((fVec10[((IOTA - 253) & 511)] - fVec10[((IOTA - 362) & 511)]) - fVec10[((IOTA - 419) & 511)]) - fVec10[((IOTA - 467) & 511)])) + ((0.000488296151f * ((fVec10[((IOTA - 194) & 511)] - fVec10[((IOTA - 317) & 511)]) + fVec10[((IOTA - 463) & 511)])) + ((0.000457777642f * (((fVec10[((IOTA - 260) & 511)] + fVec10[((IOTA - 336) & 511)]) + fVec10[((IOTA - 372) & 511)]) + fVec10[((IOTA - 459) & 511)])) + ((0.000335703604f * (((fVec10[((IOTA - 120) & 511)] + fVec10[((IOTA - 329) & 511)]) - fVec10[((IOTA - 424) & 511)]) + fVec10[((IOTA - 458) & 511)])) + ((0.00057985168f * ((fVec10[((IOTA - 186) & 511)] + fVec10[((IOTA - 339) & 511)]) - fVec10[((IOTA - 457) & 511)])) + ((0.00140385143f * (((((((fVec10[((IOTA - 207) & 511)] + fVec10[((IOTA - 262) & 511)]) + fVec10[((IOTA - 297) & 511)]) - fVec10[((IOTA - 361) & 511)]) + fVec10[((IOTA - 385) & 511)]) - fVec10[((IOTA - 390) & 511)]) - fVec10[((IOTA - 396) & 511)]) - fVec10[((IOTA - 451) & 511)])) + ((0.000122074038f * ((((fVec10[((IOTA - 343) & 511)] - (((((((((fVec10[((IOTA - 18) & 511)] + fVec10[((IOTA - 28) & 511)]) + fVec10[((IOTA - 38) & 511)]) + fVec10[((IOTA - 39) & 511)]) + fVec10[((IOTA - 47) & 511)]) + fVec10[((IOTA - 48) & 511)]) + fVec10[((IOTA - 53) & 511)]) - fVec10[((IOTA - 57) & 511)]) + fVec10[((IOTA - 203) & 511)]) - fVec10[((IOTA - 334) & 511)])) - fVec10[((IOTA - 351) & 511)]) + fVec10[((IOTA - 423) & 511)]) + fVec10[((IOTA - 449) & 511)])) + ((0.00296029542f * (((fVec10[((IOTA - 240) & 511)] + fVec10[((IOTA - 266) & 511)]) - fVec10[((IOTA - 376) & 511)]) - fVec10[((IOTA - 441) & 511)])) + ((0.00247199927f * (((fVec10[((IOTA - 267) & 511)] - fVec10[((IOTA - 373) & 511)]) - fVec10[((IOTA - 417) & 511)]) - fVec10[((IOTA - 440) & 511)])) + ((0.00177007355f * (fVec10[((IOTA - 357) & 511)] - fVec10[((IOTA - 437) & 511)])) + ((0.000823999755f * (fVec10[((IOTA - 58) & 511)] - fVec10[((IOTA - 433) & 511)])) + ((0.00201422162f * ((fVec10[((IOTA - 174) & 511)] + fVec10[((IOTA - 284) & 511)]) - fVec10[((IOTA - 430) & 511)])) + ((0.00164799951f * (fVec10[((IOTA - 404) & 511)] - fVec10[((IOTA - 426) & 511)])) + ((0.00100711081f * (((fVec10[((IOTA - 230) & 511)] - fVec10[((IOTA - 328) & 511)]) + fVec10[((IOTA - 359) & 511)]) - fVec10[((IOTA - 425) & 511)])) + ((0.000640888698f * (fVec10[((IOTA - 321) & 511)] - fVec10[((IOTA - 421) & 511)])) + ((0.000610370189f * (fVec10[((IOTA - 201) & 511)] - fVec10[((IOTA - 414) & 511)])) + ((0.00054933317f * ((fVec10[((IOTA - 340) & 511)] + fVec10[((IOTA - 344) & 511)]) + fVec10[((IOTA - 412) & 511)])) + ((0.00158696249f * (fVec10[((IOTA - 275) & 511)] + fVec10[((IOTA - 410) & 511)])) + ((0.000427259132f * (fVec10[((IOTA - 389) & 511)] - fVec10[((IOTA - 403) & 511)])) + ((0.000305185094f * (fVec10[((IOTA - 150) & 511)] + fVec10[((IOTA - 399) & 511)])) + ((0.000671407208f * (fVec10[((IOTA - 131) & 511)] + fVec10[((IOTA - 398) & 511)])) + ((0.00332651753f * ((fVec10[((IOTA - 290) & 511)] + fVec10[((IOTA - 302) & 511)]) - fVec10[((IOTA - 394) & 511)])) + ((0.00360118411f * (fVec10[((IOTA - 371) & 511)] - fVec10[((IOTA - 392) & 511)])) + ((0.00271614734f * fVec10[((IOTA - 387) & 511)]) + ((0.000518814661f * fVec10[((IOTA - 384) & 511)]) + ((0.000366222113f * (fVec10[((IOTA - 261) & 511)] + fVec10[((IOTA - 383) & 511)])) + ((0.00134281442f * (fVec10[((IOTA - 102) & 511)] + fVec10[((IOTA - 382) & 511)])) + ((0.00146488845f * ((fVec10[((IOTA - 196) & 511)] + fVec10[((IOTA - 294) & 511)]) - fVec10[((IOTA - 377) & 511)])) + ((0.00390636921f * (fVec10[((IOTA - 218) & 511)] - fVec10[((IOTA - 374) & 511)])) + ((0.00531022064f * (fVec10[((IOTA - 170) & 511)] + fVec10[((IOTA - 370) & 511)])) + ((0.00463881344f * fVec10[((IOTA - 369) & 511)]) + ((0.00357066561f * (fVec10[((IOTA - 185) & 511)] + fVec10[((IOTA - 355) & 511)])) + ((0.00405896176f * fVec10[((IOTA - 354) & 511)]) + ((0.00344859157f * fVec10[((IOTA - 353) & 511)]) + ((0.000274666585f * (((((fVec10[((IOTA - 316) & 511)] - fVec10[((IOTA - 320) & 511)]) - fVec10[((IOTA - 325) & 511)]) + fVec10[((IOTA - 333) & 511)]) + fVec10[((IOTA - 335) & 511)]) + fVec10[((IOTA - 341) & 511)])) + ((0.000915555283f * (fVec10[((IOTA - 313) & 511)] - fVec10[((IOTA - 319) & 511)])) + ((0.000976592302f * (fVec10[((IOTA - 296) & 511)] - fVec10[((IOTA - 318) & 511)])) + ((0.00109866634f * fVec10[((IOTA - 314) & 511)]) + ((0.00335703604f * ((fVec10[((IOTA - 197) & 511)] + fVec10[((IOTA - 206) & 511)]) + fVec10[((IOTA - 304) & 511)])) + ((0.00363170262f * (fVec10[((IOTA - 217) & 511)] + fVec10[((IOTA - 303) & 511)])) + ((0.00262459181f * (((fVec10[((IOTA - 147) & 511)] + fVec10[((IOTA - 263) & 511)]) + fVec10[((IOTA - 291) & 511)]) + fVec10[((IOTA - 301) & 511)])) + ((0.0045167394f * (fVec10[((IOTA - 237) & 511)] + fVec10[((IOTA - 289) & 511)])) + ((0.00558488723f * (fVec10[((IOTA - 226) & 511)] + fVec10[((IOTA - 288) & 511)])) + ((0.00567644276f * ((fVec10[((IOTA - 142) & 511)] + fVec10[((IOTA - 165) & 511)]) + fVec10[((IOTA - 287) & 511)])) + ((0.00460829493f * fVec10[((IOTA - 286) & 511)]) + ((0.00308236945f * fVec10[((IOTA - 285) & 511)]) + ((0.003234962f * (((((fVec10[((IOTA - 214) & 511)] + fVec10[((IOTA - 219) & 511)]) + fVec10[((IOTA - 247) & 511)]) + fVec10[((IOTA - 251) & 511)]) + fVec10[((IOTA - 277) & 511)]) + fVec10[((IOTA - 282) & 511)])) + ((0.00436414685f * ((fVec10[((IOTA - 188) & 511)] + fVec10[((IOTA - 242) & 511)]) + fVec10[((IOTA - 281) & 511)])) + ((0.00509659108f * fVec10[((IOTA - 280) & 511)]) + ((0.00521866512f * (fVec10[((IOTA - 140) & 511)] + fVec10[((IOTA - 279) & 511)])) + ((0.00442518387f * fVec10[((IOTA - 278) & 511)]) + ((0.00173955504f * fVec10[((IOTA - 274) & 511)]) + ((0.00228888821f * fVec10[((IOTA - 272) & 511)]) + ((0.0019531846f * fVec10[((IOTA - 268) & 511)]) + ((0.00329599902f * (fVec10[((IOTA - 245) & 511)] + fVec10[((IOTA - 265) & 511)])) + ((0.00320444349f * fVec10[((IOTA - 264) & 511)]) + ((0.0035401471f * fVec10[((IOTA - 258) & 511)]) + ((0.00427259132f * (fVec10[((IOTA - 243) & 511)] + fVec10[((IOTA - 257) & 511)])) + ((0.00378429517f * fVec10[((IOTA - 256) & 511)]) + ((0.00265511032f * fVec10[((IOTA - 255) & 511)]) + ((0.00283822138f * fVec10[((IOTA - 252) & 511)]) + ((0.00347911008f * (fVec10[((IOTA - 249) & 511)] + fVec10[((IOTA - 250) & 511)])) + ((0.00338755455f * fVec10[((IOTA - 248) & 511)]) + ((0.00311288796f * fVec10[((IOTA - 246) & 511)]) + ((0.00350962859f * (fVec10[((IOTA - 213) & 511)] + fVec10[((IOTA - 238) & 511)])) + ((0.00546281319f * fVec10[((IOTA - 236) & 511)]) + ((0.00607318338f * (fVec10[((IOTA - 233) & 511)] + fVec10[((IOTA - 235) & 511)])) + ((0.00674459059f * fVec10[((IOTA - 234) & 511)]) + ((0.0042115543f * fVec10[((IOTA - 232) & 511)]) + ((0.0051576281f * fVec10[((IOTA - 227) & 511)]) + ((0.00506607257f * fVec10[((IOTA - 225) & 511)]) + ((0.00399792474f * fVec10[((IOTA - 224) & 511)]) + ((0.00241096225f * fVec10[((IOTA - 305) & 511)]) + ((0.004852443f * fVec10[((IOTA - 199) & 511)]) + ((0.00473036896f * fVec10[((IOTA - 198) & 511)]) + ((0.00372325815f * fVec10[((IOTA - 192) & 511)]) + ((0.00555436872f * fVec10[((IOTA - 191) & 511)]) + ((0.00732444227f * fVec10[((IOTA - 190) & 511)]) + ((0.00704977568f * fVec10[((IOTA - 189) & 511)]) + ((0.0105594043f * fVec10[((IOTA - 183) & 511)]) + ((0.0100100711f * fVec10[((IOTA - 182) & 511)]) + ((0.00811792351f * fVec10[((IOTA - 181) & 511)]) + ((0.00769066438f * fVec10[((IOTA - 180) & 511)]) + ((0.0077517014f * (fVec10[((IOTA - 168) & 511)] + fVec10[((IOTA - 179) & 511)])) + ((0.00665303506f * fVec10[((IOTA - 178) & 511)]) + ((0.000946073793f * fVec10[((IOTA - 176) & 511)]) + ((0.00424207281f * fVec10[((IOTA - 173) & 511)]) + ((0.0054933317f * fVec10[((IOTA - 172) & 511)]) + ((0.00524918362f * fVec10[((IOTA - 171) & 511)]) + ((0.00625629444f * fVec10[((IOTA - 169) & 511)]) + ((0.00848414563f * fVec10[((IOTA - 167) & 511)]) + ((0.00762962736f * fVec10[((IOTA - 166) & 511)]) + ((0.00341807306f * fVec10[((IOTA - 164) & 511)]) + ((0.000732444227f * fVec10[((IOTA - 155) & 511)]) + ((0.00909451582f * fVec10[((IOTA - 154) & 511)]) + ((0.0147099216f * fVec10[((IOTA - 153) & 511)]) + ((0.0151676992f * fVec10[((IOTA - 152) & 511)]) + ((0.00823999755f * (fVec10[((IOTA - 63) & 511)] + fVec10[((IOTA - 151) & 511)])) + ((0.00881984923f * fVec10[((IOTA - 146) & 511)]) + ((0.0122379223f * fVec10[((IOTA - 145) & 511)]) + ((0.0121463668f * fVec10[((IOTA - 144) & 511)]) + ((0.00802636798f * fVec10[((IOTA - 143) & 511)]) + ((0.00396740623f * fVec10[((IOTA - 141) & 511)]) + ((0.00527970213f * fVec10[((IOTA - 139) & 511)]) + ((0.00445570238f * fVec10[((IOTA - 138) & 511)]) + ((0.00787377544f * fVec10[((IOTA - 130) & 511)]) + ((0.0182195511f * fVec10[((IOTA - 129) & 511)]) + ((0.0299996957f * fVec10[((IOTA - 128) & 511)]) + ((0.035523545f * fVec10[((IOTA - 127) & 511)]) + ((0.0328379162f * fVec10[((IOTA - 126) & 511)]) + ((0.0187383648f * fVec10[((IOTA - 125) & 511)]) + ((0.013000885f * fVec10[((IOTA - 119) & 511)]) + ((0.0235297717f * fVec10[((IOTA - 118) & 511)]) + ((0.0279244371f * fVec10[((IOTA - 117) & 511)]) + ((0.0283516962f * fVec10[((IOTA - 116) & 511)]) + ((0.0258491784f * fVec10[((IOTA - 115) & 511)]) + ((0.021210365f * fVec10[((IOTA - 114) & 511)]) + ((0.0145878475f * fVec10[((IOTA - 113) & 511)]) + ((0.00680562761f * fVec10[((IOTA - 112) & 511)]) + ((0.0105288858f * fVec10[((IOTA - 101) & 511)]) + ((0.0266426597f * fVec10[((IOTA - 100) & 511)]) + ((0.0308236945f * fVec10[((IOTA - 99) & 511)]) + ((0.0211188085f * fVec10[((IOTA - 98) & 511)]) + ((0.0253303628f * fVec10[((IOTA - 92) & 511)]) + ((0.0335093252f * fVec10[((IOTA - 91) & 511)]) + ((0.0351573229f * fVec10[((IOTA - 90) & 511)]) + ((0.0110782189f * fVec10[((IOTA - 89) & 511)]) + ((0.0135196997f * fVec10[((IOTA - 86) & 511)]) + ((0.0190740693f * fVec10[((IOTA - 85) & 511)]) + ((0.0221564379f * fVec10[((IOTA - 84) & 511)]) + ((0.0143436994f * fVec10[((IOTA - 83) & 511)]) + ((0.00543229468f * fVec10[((IOTA - 82) & 511)]) + ((0.0502945036f * fVec10[((IOTA - 75) & 511)]) + ((0.160344243f * fVec10[((IOTA - 74) & 511)]) + ((0.206396684f * fVec10[((IOTA - 73) & 511)]) + ((0.0972319692f * fVec10[((IOTA - 72) & 511)]) + ((0.0107425153f * fVec10[((IOTA - 62) & 511)]) + ((0.00973540451f * fVec10[((IOTA - 61) & 511)]) + ((0.00292977691f * fVec10[((IOTA - 59) & 511)]) + (0.00659199804f * fVec10[((IOTA - 60) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.00231940672f * (((((fVec10[((IOTA - 111) & 511)] - fVec10[((IOTA - 212) & 511)]) - fVec10[((IOTA - 368) & 511)]) + fVec10[((IOTA - 401) & 511)]) + fVec10[((IOTA - 485) & 511)]) + fVec10[((IOTA - 510) & 511)])) + ((0.00155644398f * ((fVec10[((IOTA - 350) & 511)] + fVec10[((IOTA - 489) & 511)]) + fVec10[((IOTA - 506) & 511)])) + ((0.00183111057f * ((((((fVec10[((IOTA - 148) & 511)] - fVec10[((IOTA - 269) & 511)]) - fVec10[((IOTA - 298) & 511)]) - fVec10[((IOTA - 352) & 511)]) + fVec10[((IOTA - 454) & 511)]) + fVec10[((IOTA - 495) & 511)]) + fVec10[((IOTA - 505) & 511)])) + ((0.0022583697f * ((fVec10[((IOTA - 210) & 511)] - fVec10[((IOTA - 220) & 511)]) + fVec10[((IOTA - 503) & 511)])) + ((0.00152592547f * ((fVec10[((IOTA - 420) & 511)] - fVec10[((IOTA - 447) & 511)]) + fVec10[((IOTA - 501) & 511)])) + ((0.00125125889f * (fVec10[((IOTA - 453) & 511)] + fVec10[((IOTA - 488) & 511)])) + ((0.00250251777f * ((fVec10[((IOTA - 395) & 511)] + fVec10[((IOTA - 429) & 511)]) + fVec10[((IOTA - 484) & 511)])) + ((0.00222785119f * ((fVec10[((IOTA - 161) & 511)] + fVec10[((IOTA - 427) & 511)]) + fVec10[((IOTA - 482) & 511)])) + ((0.00238044374f * (((fVec10[((IOTA - 364) & 511)] - fVec10[((IOTA - 386) & 511)]) + fVec10[((IOTA - 475) & 511)]) + fVec10[((IOTA - 481) & 511)])) + ((0.001617481f * fVec10[((IOTA - 508) & 511)]) + ((0.00277718436f * (fVec10[((IOTA - 480) & 511)] - ((((fVec10[((IOTA - 215) & 511)] - fVec10[((IOTA - 391) & 511)]) + fVec10[((IOTA - 405) & 511)]) - fVec10[((IOTA - 418) & 511)]) - fVec10[((IOTA - 477) & 511)]))) + ((0.00253303628f * (fVec10[((IOTA - 428) & 511)] + fVec10[((IOTA - 476) & 511)])) + ((0.00418103579f * (fVec10[((IOTA - 65) & 511)] + fVec10[((IOTA - 469) & 511)])) + ((0.000793481246f * (fVec10[((IOTA - 208) & 511)] + fVec10[((IOTA - 466) & 511)])) + ((0.000396740623f * ((((fVec10[((IOTA - 88) & 511)] - fVec10[((IOTA - 337) & 511)]) - fVec10[((IOTA - 338) & 511)]) - fVec10[((IOTA - 378) & 511)]) - fVec10[((IOTA - 465) & 511)])) + ((0.000762962736f * (fVec10[((IOTA - 202) & 511)] - fVec10[((IOTA - 464) & 511)])) + ((3.05185094e-05f * ((((((((((((((((((((fTemp11 + fVec10[((IOTA - 4) & 511)]) + fVec10[((IOTA - 5) & 511)]) + fVec10[((IOTA - 10) & 511)]) + fVec10[((IOTA - 11) & 511)]) + fVec10[((IOTA - 14) & 511)]) + fVec10[((IOTA - 21) & 511)]) + fVec10[((IOTA - 22) & 511)]) + fVec10[((IOTA - 25) & 511)]) + fVec10[((IOTA - 27) & 511)]) + fVec10[((IOTA - 31) & 511)]) + fVec10[((IOTA - 32) & 511)]) + fVec10[((IOTA - 34) & 511)]) + fVec10[((IOTA - 41) & 511)]) + fVec10[((IOTA - 45) & 511)]) - fVec10[((IOTA - 342) & 511)]) + fVec10[((IOTA - 360) & 511)]) + fVec10[((IOTA - 367) & 511)]) - fVec10[((IOTA - 422) & 511)]) - fVec10[((IOTA - 446) & 511)]) - fVec10[((IOTA - 462) & 511)])) + ((0.000152592547f * ((((fVec10[((IOTA - 49) & 511)] + fVec10[((IOTA - 50) & 511)]) - fVec10[((IOTA - 195) & 511)]) - fVec10[((IOTA - 347) & 511)]) + fVec10[((IOTA - 461) & 511)])) + ((9.15555283e-05f * (((((((((((fVec10[((IOTA - 6) & 511)] + fVec10[((IOTA - 7) & 511)]) + fVec10[((IOTA - 16) & 511)]) + fVec10[((IOTA - 17) & 511)]) + fVec10[((IOTA - 19) & 511)]) + fVec10[((IOTA - 30) & 511)]) + fVec10[((IOTA - 37) & 511)]) + fVec10[((IOTA - 40) & 511)]) + fVec10[((IOTA - 51) & 511)]) + fVec10[((IOTA - 175) & 511)]) + fVec10[((IOTA - 397) & 511)]) - fVec10[((IOTA - 460) & 511)])) + ((0.00216681417f * ((((fVec10[((IOTA - 93) & 511)] - fVec10[((IOTA - 283) & 511)]) + fVec10[((IOTA - 402) & 511)]) + fVec10[((IOTA - 445) & 511)]) + fVec10[((IOTA - 455) & 511)])) + ((0.00112918485f * ((((fVec10[((IOTA - 81) & 511)] - fVec10[((IOTA - 346) & 511)]) - fVec10[((IOTA - 411) & 511)]) + fVec10[((IOTA - 434) & 511)]) + fVec10[((IOTA - 450) & 511)])) + ((0.00415051728f * fVec10[((IOTA - 443) & 511)]) + ((0.00369273964f * (fVec10[((IOTA - 393) & 511)] + fVec10[((IOTA - 442) & 511)])) + ((0.00189214759f * ((fVec10[((IOTA - 349) & 511)] + fVec10[((IOTA - 365) & 511)]) + fVec10[((IOTA - 438) & 511)])) + ((0.000854518265f * fVec10[((IOTA - 432) & 511)]) + ((0.00137333293f * ((fVec10[((IOTA - 326) & 511)] - fVec10[((IOTA - 358) & 511)]) + fVec10[((IOTA - 431) & 511)])) + ((0.00119022187f * (fVec10[((IOTA - 415) & 511)] - (fVec10[((IOTA - 124) & 511)] - fVec10[((IOTA - 348) & 511)]))) + ((6.10370189e-05f * (((((((((((fVec10[((IOTA - 8) & 511)] + fVec10[((IOTA - 9) & 511)]) + fVec10[((IOTA - 15) & 511)]) + fVec10[((IOTA - 20) & 511)]) - fVec10[((IOTA - 26) & 511)]) + fVec10[((IOTA - 29) & 511)]) + fVec10[((IOTA - 36) & 511)]) + fVec10[((IOTA - 46) & 511)]) + fVec10[((IOTA - 52) & 511)]) + fVec10[((IOTA - 56) & 511)]) + fVec10[((IOTA - 211) & 511)]) + fVec10[((IOTA - 413) & 511)])) + ((0.00106814783f * fVec10[((IOTA - 400) & 511)]) + ((0.00256355479f * ((fVec10[((IOTA - 209) & 511)] - fVec10[((IOTA - 356) & 511)]) - fVec10[((IOTA - 381) & 511)])) + ((0.0038758507f * fVec10[((IOTA - 375) & 511)]) + ((0.00286873989f * (fVec10[((IOTA - 79) & 511)] - fVec10[((IOTA - 239) & 511)])) + ((0.00756859034f * (fVec10[((IOTA - 157) & 511)] - fVec10[((IOTA - 184) & 511)])) + ((0.000183111057f * ((fVec10[((IOTA - 54) & 511)] + fVec10[((IOTA - 55) & 511)]) - fVec10[((IOTA - 162) & 511)])) + ((0.00381481368f * (fVec10[((IOTA - 80) & 511)] + fVec10[((IOTA - 160) & 511)])) + ((0.00512710959f * fVec10[((IOTA - 159) & 511)]) + ((0.00640888698f * fVec10[((IOTA - 158) & 511)]) + ((0.00494399853f * fVec10[((IOTA - 156) & 511)]) + ((0.00384533219f * fVec10[((IOTA - 149) & 511)]) + ((0.000213629566f * fVec10[((IOTA - 137) & 511)]) + ((0.00537125766f * fVec10[((IOTA - 136) & 511)]) + ((0.00994903408f * fVec10[((IOTA - 135) & 511)]) + ((0.0087282937f * fVec10[((IOTA - 133) & 511)]) + ((0.00433362834f * fVec10[((IOTA - 132) & 511)]) + ((0.0107730338f * fVec10[((IOTA - 134) & 511)]) + ((0.0142521439f * fVec10[((IOTA - 123) & 511)]) + ((0.0177007355f * fVec10[((IOTA - 122) & 511)]) + ((0.0125125889f * fVec10[((IOTA - 121) & 511)]) + ((0.00930814538f * fVec10[((IOTA - 110) & 511)]) + ((0.0142826624f * fVec10[((IOTA - 109) & 511)]) + ((0.0118717002f * fVec10[((IOTA - 108) & 511)]) + ((0.0156865139f * fVec10[((IOTA - 107) & 511)]) + ((0.0218207352f * fVec10[((IOTA - 106) & 511)]) + ((0.0286568813f * fVec10[((IOTA - 105) & 511)]) + ((0.0215460677f * fVec10[((IOTA - 104) & 511)]) + ((0.0142216254f * fVec10[((IOTA - 103) & 511)]) + ((0.0110171819f * fVec10[((IOTA - 97) & 511)]) + ((0.0313730277f * fVec10[((IOTA - 96) & 511)]) + ((0.0399792492f * fVec10[((IOTA - 95) & 511)]) + ((0.022644734f * fVec10[((IOTA - 94) & 511)]) + ((0.000244148076f * fVec10[((IOTA - 87) & 511)]) + ((0.0277718436f * fVec10[((IOTA - 78) & 511)]) + ((0.0496230982f * fVec10[((IOTA - 77) & 511)]) + ((0.0390942097f * fVec10[((IOTA - 76) & 511)]) + ((0.127964109f * fVec10[((IOTA - 71) & 511)]) + ((0.298715174f * fVec10[((IOTA - 70) & 511)]) + ((0.296731472f * fVec10[((IOTA - 69) & 511)]) + ((0.162541583f * fVec10[((IOTA - 68) & 511)]) + ((0.0134281442f * fVec10[((IOTA - 66) & 511)]) + (0.0510879867f * fVec10[((IOTA - 67) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00268562883f * ((fVec10[((IOTA - 363) & 511)] - fVec10[((IOTA - 406) & 511)]) + fVec10[((IOTA - 511) & 511)]))))) : (iSlow26 ? (((0.000885036774f * ((((((((((fVec9[((IOTA - 29) & 511)] + fVec9[((IOTA - 204) & 511)]) + fVec9[((IOTA - 243) & 511)]) - fVec9[((IOTA - 254) & 511)]) - fVec9[((IOTA - 255) & 511)]) - fVec9[((IOTA - 256) & 511)]) + fVec9[((IOTA - 299) & 511)]) - fVec9[((IOTA - 398) & 511)]) - fVec9[((IOTA - 435) & 511)]) - fVec9[((IOTA - 475) & 511)]) - fVec9[((IOTA - 508) & 511)])) + ((0.000152592547f * ((fVec9[((IOTA - 302) & 511)] + fVec9[((IOTA - 448) & 511)]) - fVec9[((IOTA - 506) & 511)])) + ((0.000335703604f * ((((((((fVec9[((IOTA - 66) & 511)] + fVec9[((IOTA - 207) & 511)]) - fVec9[((IOTA - 212) & 511)]) - fVec9[((IOTA - 258) & 511)]) + fVec9[((IOTA - 346) & 511)]) - fVec9[((IOTA - 387) & 511)]) + fVec9[((IOTA - 492) & 511)]) - fVec9[((IOTA - 494) & 511)]) + fVec9[((IOTA - 505) & 511)])) + ((0.000701925717f * (((fVec9[((IOTA - 287) & 511)] - fVec9[((IOTA - 339) & 511)]) + fVec9[((IOTA - 350) & 511)]) + fVec9[((IOTA - 502) & 511)])) + ((0.000427259132f * (((((fVec9[((IOTA - 55) & 511)] - fVec9[((IOTA - 294) & 511)]) + fVec9[((IOTA - 352) & 511)]) + fVec9[((IOTA - 355) & 511)]) + fVec9[((IOTA - 356) & 511)]) + fVec9[((IOTA - 501) & 511)])) + ((6.10370189e-05f * ((((((((fVec9[((IOTA - 261) & 511)] + fVec9[((IOTA - 271) & 511)]) - fVec9[((IOTA - 280) & 511)]) + fVec9[((IOTA - 292) & 511)]) + fVec9[((IOTA - 296) & 511)]) - fVec9[((IOTA - 305) & 511)]) - fVec9[((IOTA - 404) & 511)]) + fVec9[((IOTA - 493) & 511)]) + fVec9[((IOTA - 500) & 511)])) + ((0.000762962736f * (((((((((((((fVec9[((IOTA - 42) & 511)] - fVec9[((IOTA - 197) & 511)]) + fVec9[((IOTA - 205) & 511)]) + fVec9[((IOTA - 226) & 511)]) + fVec9[((IOTA - 242) & 511)]) - fVec9[((IOTA - 253) & 511)]) + fVec9[((IOTA - 273) & 511)]) - fVec9[((IOTA - 340) & 511)]) - fVec9[((IOTA - 342) & 511)]) + fVec9[((IOTA - 348) & 511)]) + fVec9[((IOTA - 366) & 511)]) + fVec9[((IOTA - 463) & 511)]) - fVec9[((IOTA - 495) & 511)]) - fVec9[((IOTA - 498) & 511)])) + ((0.00122074038f * ((((fVec9[((IOTA - 17) & 511)] + fVec9[((IOTA - 43) & 511)]) + fVec9[((IOTA - 370) & 511)]) - fVec9[((IOTA - 414) & 511)]) - fVec9[((IOTA - 485) & 511)])) + ((0.00186162908f * (((fVec9[((IOTA - 190) & 511)] + fVec9[((IOTA - 193) & 511)]) - fVec9[((IOTA - 458) & 511)]) - fVec9[((IOTA - 484) & 511)])) + ((0.000305185094f * ((((((fVec9[((IOTA - 28) & 511)] + fVec9[((IOTA - 34) & 511)]) + fVec9[((IOTA - 281) & 511)]) - fVec9[((IOTA - 295) & 511)]) - fVec9[((IOTA - 379) & 511)]) - fVec9[((IOTA - 403) & 511)]) - fVec9[((IOTA - 476) & 511)])) + ((0.00180059206f * (fVec9[((IOTA - 58) & 511)] - fVec9[((IOTA - 474) & 511)])) + ((0.00344859157f * (fVec9[((IOTA - 369) & 511)] - fVec9[((IOTA - 470) & 511)])) + ((0.00189214759f * ((fVec9[((IOTA - 85) & 511)] + fVec9[((IOTA - 176) & 511)]) - fVec9[((IOTA - 468) & 511)])) + ((9.15555283e-05f * (((((fVec9[((IOTA - 2) & 511)] + fVec9[((IOTA - 8) & 511)]) + fVec9[((IOTA - 260) & 511)]) - fVec9[((IOTA - 262) & 511)]) + fVec9[((IOTA - 345) & 511)]) - fVec9[((IOTA - 466) & 511)])) + ((3.05185094e-05f * ((((fVec9[((IOTA - 270) & 511)] + fVec9[((IOTA - 303) & 511)]) - fVec9[((IOTA - 304) & 511)]) - fVec9[((IOTA - 405) & 511)]) - fVec9[((IOTA - 461) & 511)])) + ((0.000640888698f * (((fVec9[((IOTA - 153) & 511)] - fVec9[((IOTA - 402) & 511)]) - fVec9[((IOTA - 436) & 511)]) - fVec9[((IOTA - 460) & 511)])) + ((0.0012817774f * ((((((((fVec9[((IOTA - 5) & 511)] + fVec9[((IOTA - 18) & 511)]) + fVec9[((IOTA - 32) & 511)]) - fVec9[((IOTA - 200) & 511)]) - fVec9[((IOTA - 213) & 511)]) - fVec9[((IOTA - 447) & 511)]) + fVec9[((IOTA - 449) & 511)]) + fVec9[((IOTA - 451) & 511)]) - fVec9[((IOTA - 459) & 511)])) + ((0.00265511032f * (fVec9[((IOTA - 167) & 511)] - fVec9[((IOTA - 456) & 511)])) + ((0.00268562883f * ((fVec9[((IOTA - 233) & 511)] + fVec9[((IOTA - 383) & 511)]) - fVec9[((IOTA - 455) & 511)])) + ((0.00213629566f * ((fVec9[((IOTA - 221) & 511)] + fVec9[((IOTA - 232) & 511)]) - fVec9[((IOTA - 454) & 511)])) + ((0.00112918485f * ((fVec9[((IOTA - 196) & 511)] - fVec9[((IOTA - 214) & 511)]) - fVec9[((IOTA - 453) & 511)])) + ((0.000183111057f * ((((((fVec9[((IOTA - 15) & 511)] + fVec9[((IOTA - 41) & 511)]) - fVec9[((IOTA - 54) & 511)]) - fVec9[((IOTA - 239) & 511)]) + fVec9[((IOTA - 289) & 511)]) - fVec9[((IOTA - 309) & 511)]) + fVec9[((IOTA - 452) & 511)])) + ((0.00170903653f * (fVec9[((IOTA - 57) & 511)] + fVec9[((IOTA - 450) & 511)])) + ((0.00396740623f * (((fVec9[((IOTA - 158) & 511)] + fVec9[((IOTA - 368) & 511)]) - fVec9[((IOTA - 393) & 511)]) - fVec9[((IOTA - 444) & 511)])) + ((0.00201422162f * (fVec9[((IOTA - 236) & 511)] - fVec9[((IOTA - 441) & 511)])) + ((0.00125125889f * (((((((fVec9[((IOTA - 30) & 511)] - fVec9[((IOTA - 198) & 511)]) + fVec9[((IOTA - 220) & 511)]) - fVec9[((IOTA - 266) & 511)]) - fVec9[((IOTA - 317) & 511)]) + fVec9[((IOTA - 386) & 511)]) - fVec9[((IOTA - 434) & 511)]) - fVec9[((IOTA - 440) & 511)])) + ((0.00231940672f * (((fVec9[((IOTA - 60) & 511)] + fVec9[((IOTA - 231) & 511)]) + fVec9[((IOTA - 248) & 511)]) - fVec9[((IOTA - 432) & 511)])) + ((0.00302133244f * ((fVec9[((IOTA - 210) & 511)] - fVec9[((IOTA - 361) & 511)]) - fVec9[((IOTA - 431) & 511)])) + ((0.00299081393f * (fVec9[((IOTA - 194) & 511)] - fVec9[((IOTA - 426) & 511)])) + ((0.000946073793f * ((((fVec9[((IOTA - 33) & 511)] - fVec9[((IOTA - 202) & 511)]) - fVec9[((IOTA - 215) & 511)]) - fVec9[((IOTA - 378) & 511)]) - fVec9[((IOTA - 421) & 511)])) + ((0.00253303628f * ((((fVec9[((IOTA - 179) & 511)] + fVec9[((IOTA - 222) & 511)]) + fVec9[((IOTA - 229) & 511)]) - fVec9[((IOTA - 417) & 511)]) - fVec9[((IOTA - 419) & 511)])) + ((0.00210577715f * (fVec9[((IOTA - 247) & 511)] - fVec9[((IOTA - 416) & 511)])) + ((0.000854518265f * ((((fVec9[((IOTA - 16) & 511)] + fVec9[((IOTA - 86) & 511)]) + fVec9[((IOTA - 283) & 511)]) - fVec9[((IOTA - 320) & 511)]) - fVec9[((IOTA - 413) & 511)])) + ((0.00106814783f * (((fVec9[((IOTA - 46) & 511)] + fVec9[((IOTA - 245) & 511)]) - fVec9[((IOTA - 401) & 511)]) - fVec9[((IOTA - 410) & 511)])) + ((0.00109866634f * (((((fVec9[((IOTA - 19) & 511)] - fVec9[((IOTA - 23) & 511)]) - fVec9[((IOTA - 218) & 511)]) + fVec9[((IOTA - 225) & 511)]) + fVec9[((IOTA - 285) & 511)]) - fVec9[((IOTA - 409) & 511)])) + ((0.00622577593f * (fVec9[((IOTA - 187) & 511)] - fVec9[((IOTA - 391) & 511)])) + ((0.00228888821f * ((fVec9[((IOTA - 189) & 511)] - fVec9[((IOTA - 325) & 511)]) + fVec9[((IOTA - 385) & 511)])) + ((0.00271614734f * fVec9[((IOTA - 384) & 511)]) + ((0.00204474013f * (fVec9[((IOTA - 223) & 511)] + fVec9[((IOTA - 382) & 511)])) + ((0.00119022187f * ((((fVec9[((IOTA - 4) & 511)] - fVec9[((IOTA - 201) & 511)]) + fVec9[((IOTA - 274) & 511)]) - fVec9[((IOTA - 336) & 511)]) + fVec9[((IOTA - 381) & 511)])) + ((0.000244148076f * ((((fVec9[((IOTA - 166) & 511)] + fVec9[((IOTA - 203) & 511)]) - fVec9[((IOTA - 310) & 511)]) + fVec9[((IOTA - 357) & 511)]) + fVec9[((IOTA - 380) & 511)])) + ((0.00152592547f * (((fVec9[((IOTA - 44) & 511)] + fVec9[((IOTA - 45) & 511)]) - fVec9[((IOTA - 323) & 511)]) - fVec9[((IOTA - 371) & 511)])) + ((0.00277718436f * fVec9[((IOTA - 367) & 511)]) + ((0.00134281442f * ((((fVec9[((IOTA - 82) & 511)] + fVec9[((IOTA - 177) & 511)]) + fVec9[((IOTA - 227) & 511)]) - fVec9[((IOTA - 330) & 511)]) - fVec9[((IOTA - 365) & 511)])) + ((0.00140385143f * ((fVec9[((IOTA - 31) & 511)] - fVec9[((IOTA - 316) & 511)]) - fVec9[((IOTA - 332) & 511)])) + ((0.0019226661f * (fVec9[((IOTA - 192) & 511)] - fVec9[((IOTA - 324) & 511)])) + ((0.000274666585f * (((fVec9[((IOTA - 272) & 511)] - fVec9[((IOTA - 293) & 511)]) - fVec9[((IOTA - 307) & 511)]) - fVec9[((IOTA - 308) & 511)])) + ((0.000732444227f * (((fVec9[((IOTA - 3) & 511)] + fVec9[((IOTA - 20) & 511)]) - fVec9[((IOTA - 48) & 511)]) + fVec9[((IOTA - 300) & 511)])) + ((0.000396740623f * fVec9[((IOTA - 288) & 511)]) + ((0.000610370189f * (((fVec9[((IOTA - 7) & 511)] + fVec9[((IOTA - 250) & 511)]) + fVec9[((IOTA - 277) & 511)]) + fVec9[((IOTA - 282) & 511)])) + ((0.00183111057f * fVec9[((IOTA - 249) & 511)]) + ((0.00283822138f * fVec9[((IOTA - 235) & 511)]) + ((0.00286873989f * fVec9[((IOTA - 234) & 511)]) + ((0.003234962f * fVec9[((IOTA - 209) & 511)]) + ((0.00411999878f * fVec9[((IOTA - 188) & 511)]) + ((0.00750755332f * fVec9[((IOTA - 186) & 511)]) + ((0.00827051606f * fVec9[((IOTA - 185) & 511)]) + ((0.00759910885f * fVec9[((IOTA - 184) & 511)]) + ((0.00747703481f * fVec9[((IOTA - 183) & 511)]) + ((0.00714133121f * (fVec9[((IOTA - 148) & 511)] + fVec9[((IOTA - 182) & 511)])) + ((0.00448622089f * (fVec9[((IOTA - 174) & 511)] + fVec9[((IOTA - 180) & 511)])) + ((0.00326548051f * fVec9[((IOTA - 175) & 511)]) + ((0.0122379223f * fVec9[((IOTA - 170) & 511)]) + ((0.00918607134f * fVec9[((IOTA - 169) & 511)]) + ((0.00653096102f * fVec9[((IOTA - 168) & 511)]) + ((0.00769066438f * (fVec9[((IOTA - 79) & 511)] - fVec9[((IOTA - 164) & 511)])) + ((0.00570696127f * fVec9[((IOTA - 173) & 511)]) + ((0.00946073793f * fVec9[((IOTA - 157) & 511)]) + ((0.0105288858f * fVec9[((IOTA - 156) & 511)]) + ((0.00888088625f * fVec9[((IOTA - 155) & 511)]) + ((0.00366222113f * fVec9[((IOTA - 154) & 511)]) + ((0.00900296029f * fVec9[((IOTA - 172) & 511)]) + ((0.0150761437f * fVec9[((IOTA - 147) & 511)]) + ((0.0216071047f * fVec9[((IOTA - 146) & 511)]) + ((0.0195928831f * fVec9[((IOTA - 145) & 511)]) + ((0.0155949583f * fVec9[((IOTA - 144) & 511)]) + ((0.00967436749f * fVec9[((IOTA - 143) & 511)]) + ((0.00506607257f * fVec9[((IOTA - 142) & 511)]) + ((0.00897244178f * (fVec9[((IOTA - 122) & 511)] - fVec9[((IOTA - 136) & 511)])) + ((0.00772118289f * fVec9[((IOTA - 133) & 511)]) + ((0.0149235511f * fVec9[((IOTA - 132) & 511)]) + ((0.024567401f * fVec9[((IOTA - 131) & 511)]) + ((0.0296334736f * (fVec9[((IOTA - 115) & 511)] + fVec9[((IOTA - 130) & 511)])) + ((0.0110171819f * fVec9[((IOTA - 127) & 511)]) + ((0.00726340525f * (fVec9[((IOTA - 62) & 511)] - fVec9[((IOTA - 123) & 511)])) + ((0.01126133f * fVec9[((IOTA - 171) & 511)]) + ((0.0312204361f * fVec9[((IOTA - 129) & 511)]) + ((0.0232856236f * fVec9[((IOTA - 128) & 511)]) + ((0.0167851802f * fVec9[((IOTA - 121) & 511)]) + ((0.0231635496f * fVec9[((IOTA - 120) & 511)]) + ((0.0257881414f * fVec9[((IOTA - 119) & 511)]) + ((0.0341196954f * fVec9[((IOTA - 118) & 511)]) + ((0.0393993966f * fVec9[((IOTA - 117) & 511)]) + ((0.0404370241f * fVec9[((IOTA - 116) & 511)]) + ((0.0187688842f * fVec9[((IOTA - 114) & 511)]) + ((0.0102542192f * fVec9[((IOTA - 113) & 511)]) + ((0.00305185094f * fVec9[((IOTA - 112) & 511)]) + ((0.0244148076f * fVec9[((IOTA - 104) & 511)]) + ((0.0507827997f * fVec9[((IOTA - 103) & 511)]) + ((0.0677510947f * fVec9[((IOTA - 102) & 511)]) + ((0.0533158369f * fVec9[((IOTA - 101) & 511)]) + ((0.025879696f * fVec9[((IOTA - 100) & 511)]) + ((0.0228278451f * fVec9[((IOTA - 94) & 511)]) + ((0.05301065f * fVec9[((IOTA - 93) & 511)]) + ((0.075716421f * fVec9[((IOTA - 92) & 511)]) + ((0.0605182052f * fVec9[((IOTA - 91) & 511)]) + ((0.0310678426f * fVec9[((IOTA - 90) & 511)]) + ((0.015991699f * fVec9[((IOTA - 89) & 511)]) + ((0.0112308115f * fVec9[((IOTA - 88) & 511)]) + ((0.012939848f * fVec9[((IOTA - 87) & 511)]) + ((0.00802636798f * fVec9[((IOTA - 83) & 511)]) + ((0.0509353913f * fVec9[((IOTA - 78) & 511)]) + ((0.102298044f * fVec9[((IOTA - 77) & 511)]) + ((0.147587508f * fVec9[((IOTA - 76) & 511)]) + ((0.136326179f * fVec9[((IOTA - 75) & 511)]) + ((0.0639973134f * fVec9[((IOTA - 74) & 511)]) + ((0.00546281319f * fVec9[((IOTA - 65) & 511)]) + ((0.00930814538f * fVec9[((IOTA - 64) & 511)]) + ((0.00445570238f * fVec9[((IOTA - 61) & 511)]) + (0.00927762687f * fVec9[((IOTA - 63) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((((0.000671407208f * (fVec9[((IOTA - 53) & 511)] - fVec9[((IOTA - 504) & 511)])) + ((0.000793481246f * (((((((fVec9[((IOTA - 267) & 511)] - fVec9[((IOTA - 298) & 511)]) + fVec9[((IOTA - 312) & 511)]) - fVec9[((IOTA - 349) & 511)]) + fVec9[((IOTA - 412) & 511)]) + fVec9[((IOTA - 423) & 511)]) - fVec9[((IOTA - 464) & 511)]) - fVec9[((IOTA - 503) & 511)])) + ((0.000366222113f * ((((((fVec9[((IOTA - 141) & 511)] + fVec9[((IOTA - 219) & 511)]) - fVec9[((IOTA - 238) & 511)]) - fVec9[((IOTA - 353) & 511)]) - fVec9[((IOTA - 354) & 511)]) - fVec9[((IOTA - 488) & 511)]) + fVec9[((IOTA - 499) & 511)])) + ((0.000488296151f * (((((fVec9[((IOTA - 40) & 511)] - fVec9[((IOTA - 159) & 511)]) - fVec9[((IOTA - 297) & 511)]) - fVec9[((IOTA - 301) & 511)]) - fVec9[((IOTA - 462) & 511)]) - fVec9[((IOTA - 491) & 511)])) + ((0.00054933317f * ((((((((fVec9[((IOTA - 1) & 511)] + fVec9[((IOTA - 14) & 511)]) + fVec9[((IOTA - 35) & 511)]) + fVec9[((IOTA - 311) & 511)]) + fVec9[((IOTA - 343) & 511)]) - fVec9[((IOTA - 347) & 511)]) - fVec9[((IOTA - 351) & 511)]) + fVec9[((IOTA - 486) & 511)]) - fVec9[((IOTA - 490) & 511)])) + ((0.000518814661f * (((((fVec9[((IOTA - 152) & 511)] + fVec9[((IOTA - 396) & 511)]) + fVec9[((IOTA - 422) & 511)]) + fVec9[((IOTA - 437) & 511)]) - fVec9[((IOTA - 465) & 511)]) - fVec9[((IOTA - 489) & 511)])) + ((0.00219733268f * fVec9[((IOTA - 483) & 511)]) + ((0.00222785119f * fVec9[((IOTA - 482) & 511)]) + ((0.0019531846f * (fVec9[((IOTA - 328) & 511)] + fVec9[((IOTA - 481) & 511)])) + ((0.00146488845f * (((fVec9[((IOTA - 49) & 511)] - fVec9[((IOTA - 224) & 511)]) + fVec9[((IOTA - 334) & 511)]) + fVec9[((IOTA - 480) & 511)])) + ((0.000915555283f * ((fVec9[((IOTA - 411) & 511)] + fVec9[((IOTA - 467) & 511)]) + fVec9[((IOTA - 479) & 511)])) + ((0.000457777642f * (((((((fVec9[((IOTA - 9) & 511)] + fVec9[((IOTA - 22) & 511)]) + fVec9[((IOTA - 27) & 511)]) + fVec9[((IOTA - 149) & 511)]) + fVec9[((IOTA - 358) & 511)]) + fVec9[((IOTA - 397) & 511)]) + fVec9[((IOTA - 407) & 511)]) + fVec9[((IOTA - 478) & 511)])) + ((0.000213629566f * (((((((fVec9[((IOTA - 251) & 511)] - ((fVec9[((IOTA - 21) & 511)] + fVec9[((IOTA - 47) & 511)]) + fVec9[((IOTA - 241) & 511)])) + fVec9[((IOTA - 268) & 511)]) + fVec9[((IOTA - 279) & 511)]) - fVec9[((IOTA - 290) & 511)]) - fVec9[((IOTA - 291) & 511)]) + fVec9[((IOTA - 344) & 511)]) + fVec9[((IOTA - 477) & 511)])) + ((0.00274666585f * fVec9[((IOTA - 473) & 511)]) + ((0.00341807306f * (fVec9[((IOTA - 362) & 511)] + fVec9[((IOTA - 472) & 511)])) + ((0.00363170262f * fVec9[((IOTA - 471) & 511)]) + ((0.00280770287f * ((fVec9[((IOTA - 364) & 511)] + fVec9[((IOTA - 418) & 511)]) + fVec9[((IOTA - 469) & 511)])) + ((0.00238044374f * ((((fVec9[((IOTA - 150) & 511)] - fVec9[((IOTA - 195) & 511)]) + fVec9[((IOTA - 388) & 511)]) + fVec9[((IOTA - 425) & 511)]) + fVec9[((IOTA - 457) & 511)])) + ((0.00262459181f * fVec9[((IOTA - 446) & 511)]) + ((0.00360118411f * fVec9[((IOTA - 445) & 511)]) + ((0.00369273964f * (fVec9[((IOTA - 430) & 511)] + fVec9[((IOTA - 443) & 511)])) + ((0.0028992584f * fVec9[((IOTA - 442) & 511)]) + ((0.000823999755f * (((((fVec9[((IOTA - 252) & 511)] + fVec9[((IOTA - 319) & 511)]) + fVec9[((IOTA - 338) & 511)]) + fVec9[((IOTA - 341) & 511)]) + fVec9[((IOTA - 408) & 511)]) + fVec9[((IOTA - 439) & 511)])) + ((0.00167851802f * (((fVec9[((IOTA - 38) & 511)] - fVec9[((IOTA - 59) & 511)]) - fVec9[((IOTA - 208) & 511)]) + fVec9[((IOTA - 433) & 511)])) + ((0.00405896176f * fVec9[((IOTA - 429) & 511)]) + ((0.00393688772f * fVec9[((IOTA - 428) & 511)]) + ((0.00357066561f * (fVec9[((IOTA - 374) & 511)] + fVec9[((IOTA - 427) & 511)])) + ((0.00155644398f * ((fVec9[((IOTA - 24) & 511)] - fVec9[((IOTA - 211) & 511)]) + fVec9[((IOTA - 424) & 511)])) + ((0.00177007355f * fVec9[((IOTA - 420) & 511)]) + ((0.001617481f * (fVec9[((IOTA - 25) & 511)] + fVec9[((IOTA - 415) & 511)])) + ((0.000122074038f * ((((fVec9[((IOTA - 206) & 511)] + fVec9[((IOTA - 240) & 511)]) + fVec9[((IOTA - 259) & 511)]) + fVec9[((IOTA - 306) & 511)]) + fVec9[((IOTA - 406) & 511)])) + ((0.00137333293f * ((((fVec9[((IOTA - 199) & 511)] + fVec9[((IOTA - 314) & 511)]) + fVec9[((IOTA - 335) & 511)]) + fVec9[((IOTA - 399) & 511)]) + fVec9[((IOTA - 400) & 511)])) + ((0.00131229591f * (((((fVec9[((IOTA - 11) & 511)] + fVec9[((IOTA - 36) & 511)]) + fVec9[((IOTA - 322) & 511)]) + fVec9[((IOTA - 331) & 511)]) + fVec9[((IOTA - 359) & 511)]) + fVec9[((IOTA - 395) & 511)])) + ((0.00247199927f * ((fVec9[((IOTA - 160) & 511)] + fVec9[((IOTA - 376) & 511)]) + fVec9[((IOTA - 394) & 511)])) + ((0.00527970213f * fVec9[((IOTA - 392) & 511)]) + ((0.00592059083f * fVec9[((IOTA - 390) & 511)]) + ((0.00454725791f * fVec9[((IOTA - 389) & 511)]) + ((0.00158696249f * ((fVec9[((IOTA - 51) & 511)] + fVec9[((IOTA - 329) & 511)]) + fVec9[((IOTA - 377) & 511)])) + ((0.00308236945f * fVec9[((IOTA - 375) & 511)]) + ((0.00375377666f * fVec9[((IOTA - 373) & 511)]) + ((0.00332651753f * fVec9[((IOTA - 372) & 511)]) + ((0.00347911008f * fVec9[((IOTA - 363) & 511)]) + ((0.0022583697f * ((fVec9[((IOTA - 151) & 511)] - fVec9[((IOTA - 230) & 511)]) + fVec9[((IOTA - 360) & 511)])) + ((0.00149540696f * ((fVec9[((IOTA - 217) & 511)] + fVec9[((IOTA - 315) & 511)]) + fVec9[((IOTA - 333) & 511)])) + ((0.00234992523f * fVec9[((IOTA - 327) & 511)]) + ((0.00250251777f * (fVec9[((IOTA - 134) & 511)] + fVec9[((IOTA - 326) & 511)])) + ((0.00115970336f * ((((((fVec9[((IOTA - 13) & 511)] + fVec9[((IOTA - 26) & 511)]) + fVec9[((IOTA - 39) & 511)]) + fVec9[((IOTA - 52) & 511)]) - fVec9[((IOTA - 56) & 511)]) - fVec9[((IOTA - 276) & 511)]) + fVec9[((IOTA - 313) & 511)])) + ((0.00143436994f * ((((fVec9[((IOTA - 12) & 511)] - fVec9[((IOTA - 191) & 511)]) - fVec9[((IOTA - 246) & 511)]) + fVec9[((IOTA - 265) & 511)]) - fVec9[((IOTA - 275) & 511)])) + ((0.000976592302f * ((((fTemp10 + fVec9[((IOTA - 10) & 511)]) - fVec9[((IOTA - 178) & 511)]) + fVec9[((IOTA - 216) & 511)]) - fVec9[((IOTA - 244) & 511)])) + ((0.00173955504f * ((fVec9[((IOTA - 37) & 511)] + fVec9[((IOTA - 50) & 511)]) - fVec9[((IOTA - 228) & 511)])) + ((0.00717184972f * (fVec9[((IOTA - 162) & 511)] - fVec9[((IOTA - 181) & 511)])) + ((0.00378429517f * fVec9[((IOTA - 165) & 511)]) + ((0.0090334788f * fVec9[((IOTA - 163) & 511)]) + ((0.00390636921f * fVec9[((IOTA - 161) & 511)]) + ((0.00460829493f * fVec9[((IOTA - 140) & 511)]) + ((0.00744651631f * fVec9[((IOTA - 139) & 511)]) + ((0.00949125644f * fVec9[((IOTA - 138) & 511)]) + ((0.00830103457f * fVec9[((IOTA - 137) & 511)]) + ((0.00595110934f * fVec9[((IOTA - 135) & 511)]) + ((0.00543229468f * fVec9[((IOTA - 126) & 511)]) + ((0.0180669576f * fVec9[((IOTA - 125) & 511)]) + ((0.0183416251f * fVec9[((IOTA - 124) & 511)]) + ((0.00976592302f * fVec9[((IOTA - 111) & 511)]) + ((0.0245979186f * fVec9[((IOTA - 110) & 511)]) + ((0.037446212f * fVec9[((IOTA - 109) & 511)]) + ((0.0490432456f * fVec9[((IOTA - 108) & 511)]) + ((0.0473952442f * fVec9[((IOTA - 107) & 511)]) + ((0.0294503625f * fVec9[((IOTA - 106) & 511)]) + ((0.00558488723f * fVec9[((IOTA - 105) & 511)]) + ((0.0185247362f * fVec9[((IOTA - 99) & 511)]) + ((0.0523392446f * fVec9[((IOTA - 98) & 511)]) + ((0.075075537f * fVec9[((IOTA - 97) & 511)]) + ((0.0540177636f * fVec9[((IOTA - 96) & 511)]) + ((0.0249641407f * fVec9[((IOTA - 95) & 511)]) + ((0.00869777519f * fVec9[((IOTA - 84) & 511)]) + ((0.00735496078f * fVec9[((IOTA - 81) & 511)]) + ((0.0189825129f * fVec9[((IOTA - 80) & 511)]) + ((0.07849361f * fVec9[((IOTA - 73) & 511)]) + ((0.223242894f * fVec9[((IOTA - 72) & 511)]) + ((0.291695923f * fVec9[((IOTA - 71) & 511)]) + ((0.241187781f * fVec9[((IOTA - 70) & 511)]) + ((0.119144261f * fVec9[((IOTA - 69) & 511)]) + ((0.00671407208f * fVec9[((IOTA - 67) & 511)]) + (0.0345774703f * fVec9[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00057985168f * (((fVec9[((IOTA - 257) & 511)] + fVec9[((IOTA - 263) & 511)]) + fVec9[((IOTA - 438) & 511)]) + fVec9[((IOTA - 507) & 511)]))) + (0.00103762932f * (fVec9[((IOTA - 510) & 511)] - ((fVec9[((IOTA - 6) & 511)] - fVec9[((IOTA - 321) & 511)]) - fVec9[((IOTA - 497) & 511)])))) + (0.00100711081f * ((fVec9[((IOTA - 509) & 511)] - ((((((fVec9[((IOTA - 237) & 511)] - fVec9[((IOTA - 264) & 511)]) + fVec9[((IOTA - 284) & 511)]) + fVec9[((IOTA - 286) & 511)]) - fVec9[((IOTA - 318) & 511)]) - fVec9[((IOTA - 337) & 511)]) - fVec9[((IOTA - 496) & 511)])) + fVec9[((IOTA - 511) & 511)])))) : (((0.000335703604f * (((((((((((fVec8[((IOTA - 18) & 511)] + fVec8[((IOTA - 251) & 511)]) - fVec8[((IOTA - 301) & 511)]) - fVec8[((IOTA - 306) & 511)]) + fVec8[((IOTA - 323) & 511)]) + fVec8[((IOTA - 326) & 511)]) - fVec8[((IOTA - 367) & 511)]) + fVec8[((IOTA - 419) & 511)]) - fVec8[((IOTA - 439) & 511)]) + fVec8[((IOTA - 454) & 511)]) + fVec8[((IOTA - 462) & 511)]) + fVec8[((IOTA - 510) & 511)])) + ((0.000244148076f * ((((((fVec8[((IOTA - 54) & 511)] - (fVec8[((IOTA - 53) & 511)] - fVec8[((IOTA - 20) & 511)])) + fVec8[((IOTA - 265) & 511)]) + fVec8[((IOTA - 420) & 511)]) - fVec8[((IOTA - 440) & 511)]) + fVec8[((IOTA - 461) & 511)]) + fVec8[((IOTA - 507) & 511)])) + ((3.05185094e-05f * (((((((((((((fVec8[((IOTA - 1) & 511)] - fVec8[((IOTA - 33) & 511)]) - fVec8[((IOTA - 37) & 511)]) + fVec8[((IOTA - 38) & 511)]) - fVec8[((IOTA - 39) & 511)]) + fVec8[((IOTA - 40) & 511)]) - fVec8[((IOTA - 41) & 511)]) - fVec8[((IOTA - 45) & 511)]) + fVec8[((IOTA - 263) & 511)]) + fVec8[((IOTA - 352) & 511)]) + fVec8[((IOTA - 353) & 511)]) - fVec8[((IOTA - 359) & 511)]) - fVec8[((IOTA - 456) & 511)]) - fVec8[((IOTA - 506) & 511)])) + ((0.000488296151f * ((((fVec8[((IOTA - 318) & 511)] + fVec8[((IOTA - 423) & 511)]) + fVec8[((IOTA - 425) & 511)]) - fVec8[((IOTA - 486) & 511)]) - fVec8[((IOTA - 504) & 511)])) + ((0.00054933317f * ((((((((((fVec8[((IOTA - 261) & 511)] + fVec8[((IOTA - 272) & 511)]) + fVec8[((IOTA - 288) & 511)]) + fVec8[((IOTA - 310) & 511)]) + fVec8[((IOTA - 320) & 511)]) + fVec8[((IOTA - 322) & 511)]) + fVec8[((IOTA - 368) & 511)]) - fVec8[((IOTA - 399) & 511)]) + fVec8[((IOTA - 424) & 511)]) + fVec8[((IOTA - 493) & 511)]) + fVec8[((IOTA - 499) & 511)])) + ((0.00106814783f * ((fVec8[((IOTA - 435) & 511)] + fVec8[((IOTA - 464) & 511)]) + fVec8[((IOTA - 498) & 511)])) + ((0.00149540696f * ((fVec8[((IOTA - 210) & 511)] + fVec8[((IOTA - 483) & 511)]) + fVec8[((IOTA - 496) & 511)])) + ((0.0012817774f * (((fVec8[((IOTA - 224) & 511)] + fVec8[((IOTA - 229) & 511)]) + fVec8[((IOTA - 416) & 511)]) + fVec8[((IOTA - 495) & 511)])) + ((0.000915555283f * ((fVec8[((IOTA - 315) & 511)] - fVec8[((IOTA - 488) & 511)]) + fVec8[((IOTA - 494) & 511)])) + ((0.000213629566f * (((fVec8[((IOTA - 325) & 511)] - ((((fVec8[((IOTA - 23) & 511)] - fVec8[((IOTA - 52) & 511)]) + fVec8[((IOTA - 57) & 511)]) + fVec8[((IOTA - 160) & 511)]) - fVec8[((IOTA - 309) & 511)])) + fVec8[((IOTA - 382) & 511)]) + fVec8[((IOTA - 492) & 511)])) + ((9.15555283e-05f * (((((((fVec8[((IOTA - 3) & 511)] + fVec8[((IOTA - 28) & 511)]) + fVec8[((IOTA - 34) & 511)]) + fVec8[((IOTA - 44) & 511)]) + fVec8[((IOTA - 46) & 511)]) + fVec8[((IOTA - 242) & 511)]) - fVec8[((IOTA - 476) & 511)]) - fVec8[((IOTA - 491) & 511)])) + ((0.000732444227f * (((fVec8[((IOTA - 163) & 511)] - fVec8[((IOTA - 259) & 511)]) + fVec8[((IOTA - 337) & 511)]) - fVec8[((IOTA - 489) & 511)])) + ((0.000152592547f * ((((((((fVec8[((IOTA - 5) & 511)] + fVec8[((IOTA - 24) & 511)]) - fVec8[((IOTA - 25) & 511)]) - fVec8[((IOTA - 27) & 511)]) - fVec8[((IOTA - 59) & 511)]) - fVec8[((IOTA - 180) & 511)]) + fVec8[((IOTA - 389) & 511)]) + fVec8[((IOTA - 441) & 511)]) + fVec8[((IOTA - 485) & 511)])) + ((0.00186162908f * ((fVec8[((IOTA - 268) & 511)] + fVec8[((IOTA - 345) & 511)]) + fVec8[((IOTA - 482) & 511)])) + ((0.00189214759f * fVec8[((IOTA - 481) & 511)]) + ((0.00143436994f * (((((fVec8[((IOTA - 135) & 511)] + fVec8[((IOTA - 218) & 511)]) + fVec8[((IOTA - 296) & 511)]) - fVec8[((IOTA - 390) & 511)]) + fVec8[((IOTA - 433) & 511)]) + fVec8[((IOTA - 479) & 511)])) + ((0.00103762932f * fVec8[((IOTA - 478) & 511)]) + ((0.00180059206f * ((fVec8[((IOTA - 269) & 511)] + fVec8[((IOTA - 468) & 511)]) - fVec8[((IOTA - 474) & 511)])) + ((0.00173955504f * (((fVec8[((IOTA - 226) & 511)] + fVec8[((IOTA - 252) & 511)]) + fVec8[((IOTA - 280) & 511)]) - fVec8[((IOTA - 471) & 511)])) + ((0.000793481246f * (fVec8[((IOTA - 143) & 511)] + fVec8[((IOTA - 469) & 511)])) + ((0.00210577715f * (fVec8[((IOTA - 343) & 511)] + fVec8[((IOTA - 466) & 511)])) + ((0.00164799951f * (fVec8[((IOTA - 220) & 511)] + fVec8[((IOTA - 465) & 511)])) + ((0.000640888698f * ((((fVec8[((IOTA - 9) & 511)] + fVec8[((IOTA - 317) & 511)]) + fVec8[((IOTA - 350) & 511)]) + fVec8[((IOTA - 418) & 511)]) + fVec8[((IOTA - 463) & 511)])) + ((0.000122074038f * ((((((((((fVec8[((IOTA - 26) & 511)] - fVec8[((IOTA - 29) & 511)]) + fVec8[((IOTA - 48) & 511)]) - fVec8[((IOTA - 51) & 511)]) - fVec8[((IOTA - 238) & 511)]) + fVec8[((IOTA - 264) & 511)]) + fVec8[((IOTA - 300) & 511)]) - fVec8[((IOTA - 308) & 511)]) + fVec8[((IOTA - 354) & 511)]) - fVec8[((IOTA - 438) & 511)]) + fVec8[((IOTA - 460) & 511)])) + ((0.000671407208f * (fVec8[((IOTA - 428) & 511)] + fVec8[((IOTA - 453) & 511)])) + ((0.00274666585f * fVec8[((IOTA - 449) & 511)]) + ((0.00329599902f * ((fVec8[((IOTA - 74) & 511)] - fVec8[((IOTA - 172) & 511)]) + fVec8[((IOTA - 447) & 511)])) + ((0.00320444349f * fVec8[((IOTA - 446) & 511)]) + ((0.00296029542f * fVec8[((IOTA - 445) & 511)]) + ((0.000701925717f * (((((fVec8[((IOTA - 14) & 511)] + fVec8[((IOTA - 233) & 511)]) + fVec8[((IOTA - 271) & 511)]) + fVec8[((IOTA - 316) & 511)]) - fVec8[((IOTA - 362) & 511)]) + fVec8[((IOTA - 436) & 511)])) + ((0.00131229591f * fVec8[((IOTA - 434) & 511)]) + ((0.00146488845f * ((((((fVec8[((IOTA - 227) & 511)] + fVec8[((IOTA - 230) & 511)]) + fVec8[((IOTA - 297) & 511)]) + fVec8[((IOTA - 330) & 511)]) + fVec8[((IOTA - 332) & 511)]) + fVec8[((IOTA - 369) & 511)]) + fVec8[((IOTA - 432) & 511)])) + ((0.00115970336f * ((fVec8[((IOTA - 285) & 511)] + fVec8[((IOTA - 400) & 511)]) + fVec8[((IOTA - 430) & 511)])) + ((0.000457777642f * (((((fVec8[((IOTA - 16) & 511)] - fVec8[((IOTA - 256) & 511)]) + fVec8[((IOTA - 289) & 511)]) + fVec8[((IOTA - 292) & 511)]) - fVec8[((IOTA - 376) & 511)]) + fVec8[((IOTA - 422) & 511)])) + ((0.00119022187f * (((fVec8[((IOTA - 209) & 511)] + fVec8[((IOTA - 222) & 511)]) + fVec8[((IOTA - 339) & 511)]) + fVec8[((IOTA - 414) & 511)])) + ((0.000762962736f * (((fVec8[((IOTA - 241) & 511)] + fVec8[((IOTA - 274) & 511)]) + fVec8[((IOTA - 336) & 511)]) + fVec8[((IOTA - 413) & 511)])) + ((0.00305185094f * (fVec8[((IOTA - 372) & 511)] + fVec8[((IOTA - 448) & 511)])) + ((0.00311288796f * fVec8[((IOTA - 406) & 511)]) + ((0.00411999878f * (fVec8[((IOTA - 214) & 511)] + fVec8[((IOTA - 405) & 511)])) + ((0.00479140598f * fVec8[((IOTA - 404) & 511)]) + ((0.00491348002f * fVec8[((IOTA - 403) & 511)]) + ((0.00427259132f * fVec8[((IOTA - 402) & 511)]) + ((0.0028992584f * fVec8[((IOTA - 401) & 511)]) + ((0.0019531846f * ((fVec8[((IOTA - 173) & 511)] - fVec8[((IOTA - 189) & 511)]) - fVec8[((IOTA - 397) & 511)])) + ((0.00216681417f * (fVec8[((IOTA - 282) & 511)] - fVec8[((IOTA - 394) & 511)])) + ((0.0025940733f * (((fVec8[((IOTA - 60) & 511)] + fVec8[((IOTA - 206) & 511)]) + fVec8[((IOTA - 207) & 511)]) - fVec8[((IOTA - 392) & 511)])) + ((0.00198370311f * fVec8[((IOTA - 388) & 511)]) + ((0.004852443f * fVec8[((IOTA - 386) & 511)]) + ((0.00442518387f * fVec8[((IOTA - 384) & 511)]) + ((0.00265511032f * fVec8[((IOTA - 383) & 511)]) + ((0.0022583697f * ((fVec8[((IOTA - 211) & 511)] + fVec8[((IOTA - 254) & 511)]) + fVec8[((IOTA - 374) & 511)])) + ((0.00286873989f * ((fVec8[((IOTA - 215) & 511)] + fVec8[((IOTA - 371) & 511)]) + fVec8[((IOTA - 373) & 511)])) + ((0.00122074038f * fVec8[((IOTA - 348) & 511)]) + ((0.00155644398f * ((fVec8[((IOTA - 200) & 511)] + fVec8[((IOTA - 217) & 511)]) + fVec8[((IOTA - 331) & 511)])) + ((0.00057985168f * (fVec8[((IOTA - 293) & 511)] + fVec8[((IOTA - 321) & 511)])) + ((0.0019226661f * ((fVec8[((IOTA - 205) & 511)] + fVec8[((IOTA - 231) & 511)]) + fVec8[((IOTA - 283) & 511)])) + ((0.00170903653f * fVec8[((IOTA - 221) & 511)]) + ((0.00396740623f * fVec8[((IOTA - 213) & 511)]) + ((0.00363170262f * fVec8[((IOTA - 212) & 511)]) + ((0.00448622089f * (fVec8[((IOTA - 141) & 511)] - fVec8[((IOTA - 185) & 511)])) + ((0.0054933317f * (fVec8[((IOTA - 168) & 511)] - fVec8[((IOTA - 179) & 511)])) + ((0.00781273842f * (((fVec8[((IOTA - 109) & 511)] + fVec8[((IOTA - 140) & 511)]) - fVec8[((IOTA - 176) & 511)]) - fVec8[((IOTA - 178) & 511)])) + ((0.0143436994f * fVec8[((IOTA - 167) & 511)]) + ((0.0168462172f * fVec8[((IOTA - 166) & 511)]) + ((0.0140079958f * fVec8[((IOTA - 165) & 511)]) + ((0.00622577593f * fVec8[((IOTA - 154) & 511)]) + ((0.0175481439f * fVec8[((IOTA - 153) & 511)]) + ((0.0213629566f * fVec8[((IOTA - 152) & 511)]) + ((0.0116885891f * fVec8[((IOTA - 151) & 511)]) + ((0.00228888821f * fVec8[((IOTA - 142) & 511)]) + ((0.0111087374f * fVec8[((IOTA - 139) & 511)]) + ((0.0133671071f * fVec8[((IOTA - 138) & 511)]) + ((0.0121768853f * fVec8[((IOTA - 137) & 511)]) + ((0.00790429395f * fVec8[((IOTA - 136) & 511)]) + ((0.0130924406f * fVec8[((IOTA - 126) & 511)]) + ((0.0178228095f * fVec8[((IOTA - 125) & 511)]) + ((0.0146488845f * fVec8[((IOTA - 124) & 511)]) + ((0.00631733146f * fVec8[((IOTA - 123) & 511)]) + ((0.00393688772f * fVec8[((IOTA - 127) & 511)]) + ((0.00415051728f * fVec8[((IOTA - 110) & 511)]) + ((0.0176091809f * fVec8[((IOTA - 108) & 511)]) + ((0.0189519953f * fVec8[((IOTA - 107) & 511)]) + ((0.0221564379f * fVec8[((IOTA - 106) & 511)]) + ((0.0223090313f * fVec8[((IOTA - 105) & 511)]) + ((0.0120548112f * fVec8[((IOTA - 104) & 511)]) + ((0.0124210333f * fVec8[((IOTA - 103) & 511)]) + ((0.00476088747f * fVec8[((IOTA - 95) & 511)]) + ((0.025818659f * fVec8[((IOTA - 94) & 511)]) + ((0.0453505069f * fVec8[((IOTA - 93) & 511)]) + ((0.0352793969f * fVec8[((IOTA - 92) & 511)]) + ((0.0110477004f * fVec8[((IOTA - 91) & 511)]) + ((0.00292977691f * fVec8[((IOTA - 79) & 511)]) + ((0.0411694683f * fVec8[((IOTA - 73) & 511)]) + ((0.0252388082f * fVec8[((IOTA - 72) & 511)]) + ((0.097354047f * fVec8[((IOTA - 66) & 511)]) + ((0.234748378f * fVec8[((IOTA - 65) & 511)]) + ((0.29374066f * fVec8[((IOTA - 64) & 511)]) + ((0.237586603f * fVec8[((IOTA - 63) & 511)]) + ((0.118472852f * fVec8[((IOTA - 62) & 511)]) + ((0.00439466536f * fVec8[((IOTA - 11) & 511)]) + (0.028992584f * fVec8[((IOTA - 61) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000427259132f * ((((((((fVec8[((IOTA - 17) & 511)] - fVec8[((IOTA - 58) & 511)]) - fVec8[((IOTA - 80) & 511)]) + fVec8[((IOTA - 247) & 511)]) - fVec8[((IOTA - 262) & 511)]) - fVec8[((IOTA - 273) & 511)]) - fVec8[((IOTA - 426) & 511)]) + fVec8[((IOTA - 490) & 511)]) - fVec8[((IOTA - 509) & 511)])) + ((0.000396740623f * ((((((fVec8[((IOTA - 307) & 511)] - fVec8[((IOTA - 356) & 511)]) - fVec8[((IOTA - 357) & 511)]) + fVec8[((IOTA - 361) & 511)]) - fVec8[((IOTA - 409) & 511)]) + fVec8[((IOTA - 501) & 511)]) - fVec8[((IOTA - 508) & 511)])) + ((0.000274666585f * ((((((fVec8[((IOTA - 55) & 511)] - (fVec8[((IOTA - 7) & 511)] - fVec8[((IOTA - 21) & 511)])) - fVec8[((IOTA - 351) & 511)]) - fVec8[((IOTA - 412) & 511)]) - fVec8[((IOTA - 421) & 511)]) - fVec8[((IOTA - 437) & 511)]) + fVec8[((IOTA - 505) & 511)])) + ((0.000610370189f * (((((fVec8[((IOTA - 15) & 511)] - fVec8[((IOTA - 290) & 511)]) + fVec8[((IOTA - 305) & 511)]) - fVec8[((IOTA - 477) & 511)]) + fVec8[((IOTA - 502) & 511)]) + fVec8[((IOTA - 503) & 511)])) + ((0.00140385143f * ((((fVec8[((IOTA - 159) & 511)] - fVec8[((IOTA - 240) & 511)]) - fVec8[((IOTA - 415) & 511)]) - fVec8[((IOTA - 431) & 511)]) - fVec8[((IOTA - 497) & 511)])) + ((0.000854518265f * ((((((((fVec8[((IOTA - 235) & 511)] + fVec8[((IOTA - 244) & 511)]) - fVec8[((IOTA - 278) & 511)]) - fVec8[((IOTA - 294) & 511)]) - fVec8[((IOTA - 299) & 511)]) + fVec8[((IOTA - 302) & 511)]) - fVec8[((IOTA - 311) & 511)]) + fVec8[((IOTA - 366) & 511)]) + fVec8[((IOTA - 487) & 511)])) + ((0.000885036774f * (((fVec8[((IOTA - 304) & 511)] - fVec8[((IOTA - 349) & 511)]) - fVec8[((IOTA - 442) & 511)]) - fVec8[((IOTA - 484) & 511)])) + ((0.00167851802f * (((((fVec8[((IOTA - 162) & 511)] - fVec8[((IOTA - 204) & 511)]) + fVec8[((IOTA - 258) & 511)]) - fVec8[((IOTA - 443) & 511)]) - fVec8[((IOTA - 451) & 511)]) - fVec8[((IOTA - 480) & 511)])) + ((0.000946073793f * ((((((((fVec8[((IOTA - 237) & 511)] - fVec8[((IOTA - 275) & 511)]) - fVec8[((IOTA - 276) & 511)]) + fVec8[((IOTA - 303) & 511)]) - fVec8[((IOTA - 314) & 511)]) - fVec8[((IOTA - 338) & 511)]) + fVec8[((IOTA - 363) & 511)]) - fVec8[((IOTA - 429) & 511)]) + fVec8[((IOTA - 475) & 511)])) + ((0.00241096225f * fVec8[((IOTA - 473) & 511)]) + ((0.00238044374f * ((fVec8[((IOTA - 381) & 511)] + fVec8[((IOTA - 391) & 511)]) + fVec8[((IOTA - 472) & 511)])) + ((0.000518814661f * ((((((fVec8[((IOTA - 245) & 511)] - fVec8[((IOTA - 287) & 511)]) - fVec8[((IOTA - 291) & 511)]) - fVec8[((IOTA - 319) & 511)]) - fVec8[((IOTA - 327) & 511)]) - fVec8[((IOTA - 427) & 511)]) + fVec8[((IOTA - 470) & 511)])) + ((0.00222785119f * ((fVec8[((IOTA - 78) & 511)] - fVec8[((IOTA - 201) & 511)]) - fVec8[((IOTA - 467) & 511)])) + ((0.00112918485f * (((((fVec8[((IOTA - 169) & 511)] - fVec8[((IOTA - 174) & 511)]) - fVec8[((IOTA - 295) & 511)]) - fVec8[((IOTA - 329) & 511)]) + fVec8[((IOTA - 365) & 511)]) - fVec8[((IOTA - 452) & 511)])) + ((0.00219733268f * ((fVec8[((IOTA - 102) & 511)] - fVec8[((IOTA - 281) & 511)]) - fVec8[((IOTA - 450) & 511)])) + ((0.00244148076f * ((fVec8[((IOTA - 196) & 511)] + fVec8[((IOTA - 377) & 511)]) - fVec8[((IOTA - 444) & 511)])) + ((0.000976592302f * (((fVec8[((IOTA - 13) & 511)] - fVec8[((IOTA - 277) & 511)]) - fVec8[((IOTA - 312) & 511)]) - fVec8[((IOTA - 417) & 511)])) + ((0.00109866634f * ((((((fVec8[((IOTA - 10) & 511)] - fVec8[((IOTA - 223) & 511)]) - fVec8[((IOTA - 228) & 511)]) - fVec8[((IOTA - 270) & 511)]) - fVec8[((IOTA - 313) & 511)]) + fVec8[((IOTA - 364) & 511)]) - fVec8[((IOTA - 408) & 511)])) + ((0.00207525864f * (fVec8[((IOTA - 395) & 511)] - fVec8[((IOTA - 407) & 511)])) + ((0.00152592547f * (((((fVec8[((IOTA - 161) & 511)] - fVec8[((IOTA - 208) & 511)]) - fVec8[((IOTA - 232) & 511)]) - fVec8[((IOTA - 284) & 511)]) - fVec8[((IOTA - 340) & 511)]) + fVec8[((IOTA - 398) & 511)])) + ((0.00201422162f * (((fVec8[((IOTA - 195) & 511)] - fVec8[((IOTA - 216) & 511)]) - fVec8[((IOTA - 342) & 511)]) + fVec8[((IOTA - 396) & 511)])) + ((0.00247199927f * fVec8[((IOTA - 393) & 511)]) + ((0.00381481368f * (fVec8[((IOTA - 186) & 511)] - fVec8[((IOTA - 387) & 511)])) + ((0.00518814661f * (fVec8[((IOTA - 128) & 511)] - fVec8[((IOTA - 385) & 511)])) + ((0.00418103579f * fVec8[((IOTA - 380) & 511)]) + ((0.00494399853f * fVec8[((IOTA - 379) & 511)]) + ((0.0042115543f * fVec8[((IOTA - 378) & 511)]) + ((0.00125125889f * ((fVec8[((IOTA - 248) & 511)] - fVec8[((IOTA - 333) & 511)]) - fVec8[((IOTA - 375) & 511)])) + ((0.00231940672f * (((fVec8[((IOTA - 188) & 511)] - fVec8[((IOTA - 202) & 511)]) - fVec8[((IOTA - 253) & 511)]) - fVec8[((IOTA - 370) & 511)])) + ((0.000305185094f * ((fVec8[((IOTA - 19) & 511)] - fVec8[((IOTA - 324) & 511)]) + fVec8[((IOTA - 360) & 511)])) + ((0.000183111057f * ((((fVec8[((IOTA - 6) & 511)] - fVec8[((IOTA - 22) & 511)]) - fVec8[((IOTA - 50) & 511)]) + fVec8[((IOTA - 260) & 511)]) - fVec8[((IOTA - 358) & 511)])) + ((0.000366222113f * (((fVec8[((IOTA - 8) & 511)] - fVec8[((IOTA - 56) & 511)]) + fVec8[((IOTA - 234) & 511)]) - fVec8[((IOTA - 355) & 511)])) + ((0.00137333293f * ((fVec8[((IOTA - 236) & 511)] - fVec8[((IOTA - 298) & 511)]) - fVec8[((IOTA - 347) & 511)])) + ((0.00204474013f * (fVec8[((IOTA - 191) & 511)] - fVec8[((IOTA - 344) & 511)])) + ((0.00177007355f * ((fVec8[((IOTA - 194) & 511)] - fVec8[((IOTA - 219) & 511)]) - fVec8[((IOTA - 341) & 511)])) + ((0.000823999755f * ((((((fVec8[((IOTA - 181) & 511)] - fVec8[((IOTA - 199) & 511)]) - fVec8[((IOTA - 239) & 511)]) - fVec8[((IOTA - 255) & 511)]) - fVec8[((IOTA - 286) & 511)]) - fVec8[((IOTA - 328) & 511)]) - fVec8[((IOTA - 335) & 511)])) + ((0.00100711081f * (((fVec8[((IOTA - 243) & 511)] + fVec8[((IOTA - 250) & 511)]) - fVec8[((IOTA - 266) & 511)]) - fVec8[((IOTA - 334) & 511)])) + ((0.00134281442f * (fVec8[((IOTA - 257) & 511)] - fVec8[((IOTA - 279) & 511)])) + ((0.00158696249f * ((fVec8[((IOTA - 187) & 511)] + fVec8[((IOTA - 249) & 511)]) - fVec8[((IOTA - 267) & 511)])) + ((0.001617481f * ((((fVec8[((IOTA - 192) & 511)] + fVec8[((IOTA - 198) & 511)]) - fVec8[((IOTA - 203) & 511)]) - fVec8[((IOTA - 225) & 511)]) - fVec8[((IOTA - 346) & 511)])) + ((0.00234992523f * fVec8[((IOTA - 197) & 511)]) + ((0.00262459181f * (fVec8[((IOTA - 190) & 511)] + fVec8[((IOTA - 193) & 511)])) + ((0.00561540574f * ((fVec8[((IOTA - 100) & 511)] - fVec8[((IOTA - 164) & 511)]) + fVec8[((IOTA - 184) & 511)])) + ((0.00527970213f * fVec8[((IOTA - 183) & 511)]) + ((0.00271614734f * fVec8[((IOTA - 182) & 511)]) + ((0.0105288858f * fVec8[((IOTA - 177) & 511)]) + ((0.003234962f * fVec8[((IOTA - 175) & 511)]) + ((0.00552385021f * fVec8[((IOTA - 171) & 511)]) + ((0.0038758507f * fVec8[((IOTA - 170) & 511)]) + ((0.00848414563f * fVec8[((IOTA - 158) & 511)]) + ((0.0135196997f * fVec8[((IOTA - 157) & 511)]) + ((0.0139774773f * fVec8[((IOTA - 156) & 511)]) + ((0.00531022064f * fVec8[((IOTA - 155) & 511)]) + ((0.00326548051f * fVec8[((IOTA - 150) & 511)]) + ((0.0200506616f * fVec8[((IOTA - 149) & 511)]) + ((0.0284127332f * fVec8[((IOTA - 148) & 511)]) + ((0.0287179183f * fVec8[((IOTA - 147) & 511)]) + ((0.0200201422f * fVec8[((IOTA - 146) & 511)]) + ((0.00946073793f * fVec8[((IOTA - 145) & 511)]) + ((0.00302133244f * fVec8[((IOTA - 144) & 511)]) + ((0.00537125766f * fVec8[((IOTA - 134) & 511)]) + ((0.0110782189f * fVec8[((IOTA - 133) & 511)]) + ((0.0151982177f * fVec8[((IOTA - 132) & 511)]) + ((0.0169072542f * fVec8[((IOTA - 131) & 511)]) + ((0.0159611814f * fVec8[((IOTA - 130) & 511)]) + ((0.0124515519f * fVec8[((IOTA - 129) & 511)]) + ((0.00601214636f * fVec8[((IOTA - 122) & 511)]) + ((0.0163884405f * fVec8[((IOTA - 121) & 511)]) + ((0.0232856236f * fVec8[((IOTA - 120) & 511)]) + ((0.0274666585f * fVec8[((IOTA - 119) & 511)]) + ((0.0281685852f * fVec8[((IOTA - 118) & 511)]) + ((0.0322885849f * fVec8[((IOTA - 117) & 511)]) + ((0.0362254716f * fVec8[((IOTA - 116) & 511)]) + ((0.0383312479f * fVec8[((IOTA - 115) & 511)]) + ((0.0391552486f * fVec8[((IOTA - 114) & 511)]) + ((0.0290231034f * fVec8[((IOTA - 113) & 511)]) + ((0.0186468102f * fVec8[((IOTA - 112) & 511)]) + ((0.00589007232f * fVec8[((IOTA - 111) & 511)]) + ((0.00299081393f * fVec8[((IOTA - 101) & 511)]) + ((0.0137943663f * fVec8[((IOTA - 99) & 511)]) + ((0.0121463668f * fVec8[((IOTA - 98) & 511)]) + ((0.0165105145f * fVec8[((IOTA - 97) & 511)]) + ((0.00384533219f * fVec8[((IOTA - 96) & 511)]) + ((0.0198065136f * fVec8[((IOTA - 90) & 511)]) + ((0.0325022116f * fVec8[((IOTA - 89) & 511)]) + ((0.0314340666f * fVec8[((IOTA - 88) & 511)]) + ((0.0153508103f * fVec8[((IOTA - 87) & 511)]) + ((0.00524918362f * fVec8[((IOTA - 86) & 511)]) + ((0.0131839961f * fVec8[((IOTA - 85) & 511)]) + ((0.0398266539f * fVec8[((IOTA - 84) & 511)]) + ((0.0556047261f * fVec8[((IOTA - 83) & 511)]) + ((0.0494094677f * fVec8[((IOTA - 82) & 511)]) + ((0.0324106589f * fVec8[((IOTA - 81) & 511)]) + ((0.0484328754f * fVec8[((IOTA - 77) & 511)]) + ((0.0455030985f * fVec8[((IOTA - 76) & 511)]) + ((0.0392773226f * fVec8[((IOTA - 75) & 511)]) + ((0.0139164403f * fVec8[((IOTA - 71) & 511)]) + ((0.144810334f * fVec8[((IOTA - 70) & 511)]) + ((0.19299905f * fVec8[((IOTA - 69) & 511)]) + ((0.185125276f * fVec8[((IOTA - 68) & 511)]) + ((0.00308236945f * fVec8[((IOTA - 12) & 511)]) + (0.0730918273f * fVec8[((IOTA - 67) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (6.10370189e-05f * ((((((((((((fVec8[((IOTA - 4) & 511)] - fVec8[((IOTA - 30) & 511)]) + fVec8[((IOTA - 31) & 511)]) - fVec8[((IOTA - 32) & 511)]) - fVec8[((IOTA - 36) & 511)]) - fVec8[((IOTA - 42) & 511)]) + fVec8[((IOTA - 47) & 511)]) + fVec8[((IOTA - 49) & 511)]) - fVec8[((IOTA - 455) & 511)]) + fVec8[((IOTA - 457) & 511)]) - fVec8[((IOTA - 459) & 511)]) - fVec8[((IOTA - 500) & 511)]) - fVec8[((IOTA - 511) & 511)]))))))) : (iSlow4 ? (iSlow16 ? (iSlow20 ? (((9.15555283e-05f * (((((((((((((((((fVec7[((IOTA - 211) & 511)] + fVec7[((IOTA - 215) & 511)]) + fVec7[((IOTA - 280) & 511)]) - fVec7[((IOTA - 294) & 511)]) + fVec7[((IOTA - 339) & 511)]) + fVec7[((IOTA - 372) & 511)]) - fVec7[((IOTA - 402) & 511)]) + fVec7[((IOTA - 406) & 511)]) + fVec7[((IOTA - 411) & 511)]) - fVec7[((IOTA - 435) & 511)]) + fVec7[((IOTA - 444) & 511)]) + fVec7[((IOTA - 450) & 511)]) - fVec7[((IOTA - 464) & 511)]) - fVec7[((IOTA - 477) & 511)]) + fVec7[((IOTA - 488) & 511)]) + fVec7[((IOTA - 491) & 511)]) + fVec7[((IOTA - 495) & 511)]) + fVec7[((IOTA - 506) & 511)])) + ((0.000274666585f * (((((((((((fVec7[((IOTA - 276) & 511)] + fVec7[((IOTA - 287) & 511)]) + fVec7[((IOTA - 338) & 511)]) - fVec7[((IOTA - 351) & 511)]) - fVec7[((IOTA - 352) & 511)]) + fVec7[((IOTA - 405) & 511)]) + fVec7[((IOTA - 414) & 511)]) + fVec7[((IOTA - 445) & 511)]) + fVec7[((IOTA - 454) & 511)]) - fVec7[((IOTA - 467) & 511)]) + fVec7[((IOTA - 486) & 511)]) + fVec7[((IOTA - 501) & 511)])) + ((0.000183111057f * (((((((((((fVec7[((IOTA - 155) & 511)] - fVec7[((IOTA - 156) & 511)]) - fVec7[((IOTA - 227) & 511)]) + fVec7[((IOTA - 278) & 511)]) + fVec7[((IOTA - 293) & 511)]) + fVec7[((IOTA - 308) & 511)]) + fVec7[((IOTA - 343) & 511)]) - fVec7[((IOTA - 350) & 511)]) + fVec7[((IOTA - 413) & 511)]) + fVec7[((IOTA - 460) & 511)]) + fVec7[((IOTA - 481) & 511)]) + fVec7[((IOTA - 500) & 511)])) + (((0.000518814661f * (((((((fVec7[((IOTA - 253) & 511)] - fVec7[((IOTA - 264) & 511)]) - fVec7[((IOTA - 296) & 511)]) - fVec7[((IOTA - 323) & 511)]) + fVec7[((IOTA - 360) & 511)]) + fVec7[((IOTA - 416) & 511)]) + fVec7[((IOTA - 432) & 511)]) + fVec7[((IOTA - 458) & 511)])) + ((0.000640888698f * (((((((((((fVec7[((IOTA - 151) & 511)] + fVec7[((IOTA - 247) & 511)]) + fVec7[((IOTA - 251) & 511)]) + fVec7[((IOTA - 252) & 511)]) - fVec7[((IOTA - 265) & 511)]) - fVec7[((IOTA - 297) & 511)]) - fVec7[((IOTA - 309) & 511)]) - fVec7[((IOTA - 363) & 511)]) - fVec7[((IOTA - 421) & 511)]) + fVec7[((IOTA - 430) & 511)]) + fVec7[((IOTA - 431) & 511)]) + fVec7[((IOTA - 457) & 511)])) + ((0.000488296151f * ((((fVec7[((IOTA - 291) & 511)] - (((fVec7[((IOTA - 171) & 511)] + fVec7[((IOTA - 196) & 511)]) - fVec7[((IOTA - 244) & 511)]) + fVec7[((IOTA - 261) & 511)])) + fVec7[((IOTA - 358) & 511)]) + fVec7[((IOTA - 359) & 511)]) + fVec7[((IOTA - 455) & 511)])) + ((0.000457777642f * ((((((fVec7[((IOTA - 179) & 511)] + fVec7[((IOTA - 213) & 511)]) - fVec7[((IOTA - 236) & 511)]) + fVec7[((IOTA - 290) & 511)]) + fVec7[((IOTA - 391) & 511)]) - fVec7[((IOTA - 401) & 511)]) + fVec7[((IOTA - 429) & 511)])) + ((0.000762962736f * ((((((fVec7[((IOTA - 134) & 511)] - fVec7[((IOTA - 197) & 511)]) - fVec7[((IOTA - 233) & 511)]) - fVec7[((IOTA - 267) & 511)]) + fVec7[((IOTA - 333) & 511)]) - fVec7[((IOTA - 422) & 511)]) - fVec7[((IOTA - 426) & 511)])) + ((0.000823999755f * ((fVec7[((IOTA - 389) & 511)] - fVec7[((IOTA - 400) & 511)]) - fVec7[((IOTA - 423) & 511)])) + ((0.001617481f * ((((fVec7[((IOTA - 189) & 511)] + fVec7[((IOTA - 317) & 511)]) - fVec7[((IOTA - 325) & 511)]) - fVec7[((IOTA - 381) & 511)]) - fVec7[((IOTA - 397) & 511)])) + ((0.000946073793f * fVec7[((IOTA - 388) & 511)]) + ((0.00167851802f * fVec7[((IOTA - 377) & 511)]) + ((0.00170903653f * ((fVec7[((IOTA - 97) & 511)] - fVec7[((IOTA - 170) & 511)]) + fVec7[((IOTA - 376) & 511)])) + ((0.00146488845f * ((fVec7[((IOTA - 86) & 511)] - fVec7[((IOTA - 328) & 511)]) - fVec7[((IOTA - 366) & 511)])) + ((0.00149540696f * (fVec7[((IOTA - 132) & 511)] - fVec7[((IOTA - 365) & 511)])) + ((0.00100711081f * ((fVec7[((IOTA - 334) & 511)] - (fVec7[((IOTA - 198) & 511)] + fVec7[((IOTA - 300) & 511)])) + fVec7[((IOTA - 335) & 511)])) + ((0.000915555283f * (((((fVec7[((IOTA - 180) & 511)] + fVec7[((IOTA - 218) & 511)]) + fVec7[((IOTA - 221) & 511)]) - fVec7[((IOTA - 229) & 511)]) - fVec7[((IOTA - 232) & 511)]) + fVec7[((IOTA - 321) & 511)])) + ((0.00183111057f * (fVec7[((IOTA - 182) & 511)] + fVec7[((IOTA - 318) & 511)])) + ((0.00189214759f * (fVec7[((IOTA - 131) & 511)] - fVec7[((IOTA - 313) & 511)])) + ((0.0012817774f * (((fVec7[((IOTA - 133) & 511)] - fVec7[((IOTA - 207) & 511)]) + fVec7[((IOTA - 220) & 511)]) - fVec7[((IOTA - 310) & 511)])) + ((0.00198370311f * fVec7[((IOTA - 306) & 511)]) + ((0.00201422162f * ((fVec7[((IOTA - 85) & 511)] + fVec7[((IOTA - 150) & 511)]) + fVec7[((IOTA - 305) & 511)])) + ((0.00122074038f * fVec7[((IOTA - 304) & 511)]) + ((0.000732444227f * ((((((fVec7[((IOTA - 117) & 511)] - fVec7[((IOTA - 173) & 511)]) + fVec7[((IOTA - 190) & 511)]) - fVec7[((IOTA - 266) & 511)]) - fVec7[((IOTA - 268) & 511)]) - fVec7[((IOTA - 298) & 511)]) - fVec7[((IOTA - 302) & 511)])) + ((0.00131229591f * fVec7[((IOTA - 219) & 511)]) + ((0.0022583697f * fVec7[((IOTA - 188) & 511)]) + ((0.00265511032f * fVec7[((IOTA - 187) & 511)]) + ((0.00283822138f * fVec7[((IOTA - 186) & 511)]) + ((0.00253303628f * ((fVec7[((IOTA - 129) & 511)] - fVec7[((IOTA - 165) & 511)]) + fVec7[((IOTA - 184) & 511)])) + ((0.00216681417f * fVec7[((IOTA - 183) & 511)]) + ((0.00317392498f * (fVec7[((IOTA - 146) & 511)] - fVec7[((IOTA - 169) & 511)])) + ((0.00244148076f * (fVec7[((IOTA - 130) & 511)] - fVec7[((IOTA - 163) & 511)])) + ((0.00158696249f * (fVec7[((IOTA - 127) & 511)] - fVec7[((IOTA - 162) & 511)])) + ((0.00311288796f * fVec7[((IOTA - 149) & 511)]) + ((0.00338755455f * fVec7[((IOTA - 148) & 511)]) + ((0.00320444349f * fVec7[((IOTA - 147) & 511)]) + ((0.00314340647f * fVec7[((IOTA - 145) & 511)]) + ((0.00213629566f * fVec7[((IOTA - 144) & 511)]) + ((0.00540177617f * (fVec7[((IOTA - 39) & 511)] - fVec7[((IOTA - 139) & 511)])) + ((0.0019531846f * fVec7[((IOTA - 128) & 511)]) + ((0.00238044374f * fVec7[((IOTA - 126) & 511)]) + ((0.00396740623f * fVec7[((IOTA - 125) & 511)]) + ((0.00350962859f * fVec7[((IOTA - 123) & 511)]) + ((0.00231940672f * fVec7[((IOTA - 122) & 511)]) + ((0.0035401471f * fVec7[((IOTA - 121) & 511)]) + ((0.00698873866f * fVec7[((IOTA - 120) & 511)]) + ((0.0090334788f * fVec7[((IOTA - 119) & 511)]) + ((0.00656147953f * fVec7[((IOTA - 118) & 511)]) + ((0.0144657735f * (fVec7[((IOTA - 81) & 511)] - fVec7[((IOTA - 101) & 511)])) + ((0.00863673817f * (fVec7[((IOTA - 30) & 511)] - fVec7[((IOTA - 100) & 511)])) + ((0.00506607257f * fVec7[((IOTA - 96) & 511)]) + ((0.011200293f * fVec7[((IOTA - 95) & 511)]) + ((0.0208136234f * fVec7[((IOTA - 93) & 511)]) + ((0.0188909583f * fVec7[((IOTA - 92) & 511)]) + ((0.013061922f * fVec7[((IOTA - 91) & 511)]) + ((0.00701925717f * fVec7[((IOTA - 90) & 511)]) + ((0.00360118411f * fVec7[((IOTA - 89) & 511)]) + ((0.00262459181f * fVec7[((IOTA - 88) & 511)]) + ((0.00207525864f * fVec7[((IOTA - 87) & 511)]) + ((0.00500503555f * fVec7[((IOTA - 84) & 511)]) + ((0.0104373302f * fVec7[((IOTA - 83) & 511)]) + ((0.0152287362f * fVec7[((IOTA - 82) & 511)]) + ((0.00689718314f * fVec7[((IOTA - 80) & 511)]) + ((0.00393688772f * fVec7[((IOTA - 73) & 511)]) + ((0.0146488845f * fVec7[((IOTA - 72) & 511)]) + ((0.0210272539f * fVec7[((IOTA - 71) & 511)]) + ((0.0188604388f * fVec7[((IOTA - 70) & 511)]) + ((0.0127567369f * fVec7[((IOTA - 69) & 511)]) + ((0.00817896053f * fVec7[((IOTA - 68) & 511)]) + ((0.00595110934f * fVec7[((IOTA - 67) & 511)]) + ((0.00469985045f * fVec7[((IOTA - 66) & 511)]) + ((0.0176091809f * fVec7[((IOTA - 94) & 511)]) + ((0.00518814661f * fVec7[((IOTA - 64) & 511)]) + ((0.00430310983f * fVec7[((IOTA - 63) & 511)]) + ((0.00961333048f * fVec7[((IOTA - 58) & 511)]) + ((0.0314951017f * fVec7[((IOTA - 57) & 511)]) + ((0.0402233973f * fVec7[((IOTA - 56) & 511)]) + ((0.0336924344f * fVec7[((IOTA - 55) & 511)]) + ((0.0190740693f * fVec7[((IOTA - 54) & 511)]) + ((0.0057985168f * fVec7[((IOTA - 53) & 511)]) + ((0.0133671071f * fVec7[((IOTA - 45) & 511)]) + ((0.0260322895f * fVec7[((IOTA - 44) & 511)]) + ((0.0264900662f * fVec7[((IOTA - 43) & 511)]) + ((0.0216071047f * fVec7[((IOTA - 42) & 511)]) + ((0.0153813288f * fVec7[((IOTA - 41) & 511)]) + ((((((0.09118931f * fVec7[((IOTA - 10) & 511)]) + ((0.0208441429f * fVec7[((IOTA - 9) & 511)]) + ((0.0692465007f * fVec7[((IOTA - 5) & 511)]) + ((0.26633504f * fVec7[((IOTA - 4) & 511)]) + ((0.273323774f * fVec7[((IOTA - 3) & 511)]) + ((0.165135652f * fVec7[((IOTA - 2) & 511)]) + ((0.068300426f * fVec7[((IOTA - 1) & 511)]) + ((fSlow23 * fTemp0) + ((0.0353709534f * fVec7[((IOTA - 18) & 511)]) + ((((0.0171208847f * fVec7[((IOTA - 11) & 511)]) + (0.0225531794f * fVec7[((IOTA - 17) & 511)])) + (0.0363170281f * fVec7[((IOTA - 19) & 511)])) + (0.0217291787f * fVec7[((IOTA - 20) & 511)]))))))))))) + (0.0602435395f * fVec7[((IOTA - 27) & 511)])) + (0.0859706402f * fVec7[((IOTA - 28) & 511)])) + (0.0617694631f * fVec7[((IOTA - 29) & 511)])) + (0.0105594043f * fVec7[((IOTA - 40) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * ((((fVec7[((IOTA - 292) & 511)] - (((((fVec7[((IOTA - 195) & 511)] - fVec7[((IOTA - 217) & 511)]) + fVec7[((IOTA - 241) & 511)]) - fVec7[((IOTA - 254) & 511)]) + fVec7[((IOTA - 260) & 511)]) - fVec7[((IOTA - 274) & 511)])) - fVec7[((IOTA - 469) & 511)]) - fVec7[((IOTA - 470) & 511)]) + fVec7[((IOTA - 485) & 511)])))))) - (((3.05185094e-05f * (((((((((((((((((((fVec7[((IOTA - 98) & 511)] + fVec7[((IOTA - 178) & 511)]) - fVec7[((IOTA - 340) & 511)]) - fVec7[((IOTA - 341) & 511)]) + fVec7[((IOTA - 362) & 511)]) + fVec7[((IOTA - 407) & 511)]) + fVec7[((IOTA - 408) & 511)]) - fVec7[((IOTA - 419) & 511)]) - fVec7[((IOTA - 428) & 511)]) + fVec7[((IOTA - 439) & 511)]) + fVec7[((IOTA - 442) & 511)]) + fVec7[((IOTA - 443) & 511)]) - fVec7[((IOTA - 451) & 511)]) - fVec7[((IOTA - 489) & 511)]) - fVec7[((IOTA - 490) & 511)]) - fVec7[((IOTA - 496) & 511)]) - fVec7[((IOTA - 497) & 511)]) - fVec7[((IOTA - 507) & 511)]) - fVec7[((IOTA - 508) & 511)]) + fVec7[((IOTA - 509) & 511)])) + ((0.000152592547f * (((((((((((((((((fVec7[((IOTA - 152) & 511)] + fVec7[((IOTA - 153) & 511)]) - fVec7[((IOTA - 154) & 511)]) - fVec7[((IOTA - 223) & 511)]) + fVec7[((IOTA - 271) & 511)]) - fVec7[((IOTA - 272) & 511)]) - fVec7[((IOTA - 315) & 511)]) - fVec7[((IOTA - 348) & 511)]) + fVec7[((IOTA - 353) & 511)]) + fVec7[((IOTA - 370) & 511)]) - fVec7[((IOTA - 395) & 511)]) - fVec7[((IOTA - 412) & 511)]) - fVec7[((IOTA - 453) & 511)]) + fVec7[((IOTA - 465) & 511)]) - fVec7[((IOTA - 487) & 511)]) - fVec7[((IOTA - 493) & 511)]) - fVec7[((IOTA - 494) & 511)]) - fVec7[((IOTA - 505) & 511)])) + ((0.000244148076f * ((fVec7[((IOTA - 238) & 511)] - fVec7[((IOTA - 255) & 511)]) - fVec7[((IOTA - 504) & 511)])) + ((0.000305185094f * ((((((((((((fVec7[((IOTA - 160) & 511)] + fVec7[((IOTA - 192) & 511)]) - fVec7[((IOTA - 214) & 511)]) + fVec7[((IOTA - 237) & 511)]) + fVec7[((IOTA - 239) & 511)]) - fVec7[((IOTA - 275) & 511)]) - fVec7[((IOTA - 288) & 511)]) + fVec7[((IOTA - 472) & 511)]) + fVec7[((IOTA - 473) & 511)]) + fVec7[((IOTA - 475) & 511)]) - fVec7[((IOTA - 482) & 511)]) - fVec7[((IOTA - 502) & 511)]) - fVec7[((IOTA - 503) & 511)])) + ((0.000427259132f * (((((((((((((((((fVec7[((IOTA - 52) & 511)] + fVec7[((IOTA - 135) & 511)]) + fVec7[((IOTA - 159) & 511)]) + fVec7[((IOTA - 210) & 511)]) - fVec7[((IOTA - 212) & 511)]) - fVec7[((IOTA - 222) & 511)]) + fVec7[((IOTA - 240) & 511)]) + fVec7[((IOTA - 262) & 511)]) + fVec7[((IOTA - 263) & 511)]) - fVec7[((IOTA - 347) & 511)]) + fVec7[((IOTA - 369) & 511)]) + fVec7[((IOTA - 386) & 511)]) - fVec7[((IOTA - 387) & 511)]) - fVec7[((IOTA - 390) & 511)]) + fVec7[((IOTA - 427) & 511)]) - fVec7[((IOTA - 446) & 511)]) - fVec7[((IOTA - 447) & 511)]) - fVec7[((IOTA - 484) & 511)])) + ((0.000396740623f * (((((((((fVec7[((IOTA - 270) & 511)] - fVec7[((IOTA - 284) & 511)]) - fVec7[((IOTA - 285) & 511)]) - fVec7[((IOTA - 289) & 511)]) - fVec7[((IOTA - 344) & 511)]) - fVec7[((IOTA - 355) & 511)]) - fVec7[((IOTA - 361) & 511)]) - fVec7[((IOTA - 415) & 511)]) - fVec7[((IOTA - 418) & 511)]) - fVec7[((IOTA - 483) & 511)])) + ((0.000213629566f * ((((((((((((((fVec7[((IOTA - 172) & 511)] - fVec7[((IOTA - 243) & 511)]) - fVec7[((IOTA - 256) & 511)]) - fVec7[((IOTA - 257) & 511)]) - fVec7[((IOTA - 277) & 511)]) - fVec7[((IOTA - 282) & 511)]) - fVec7[((IOTA - 322) & 511)]) - fVec7[((IOTA - 373) & 511)]) + fVec7[((IOTA - 379) & 511)]) - fVec7[((IOTA - 403) & 511)]) + fVec7[((IOTA - 436) & 511)]) + fVec7[((IOTA - 437) & 511)]) - fVec7[((IOTA - 449) & 511)]) + fVec7[((IOTA - 466) & 511)]) + fVec7[((IOTA - 476) & 511)])) + ((0.000610370189f * (((((fVec7[((IOTA - 157) & 511)] - fVec7[((IOTA - 248) & 511)]) - fVec7[((IOTA - 250) & 511)]) + fVec7[((IOTA - 269) & 511)]) - fVec7[((IOTA - 346) & 511)]) - fVec7[((IOTA - 456) & 511)])) + ((0.000335703604f * ((((((((((((((fVec7[((IOTA - 193) & 511)] + fVec7[((IOTA - 194) & 511)]) - fVec7[((IOTA - 273) & 511)]) - fVec7[((IOTA - 283) & 511)]) - fVec7[((IOTA - 286) & 511)]) + fVec7[((IOTA - 295) & 511)]) - fVec7[((IOTA - 332) & 511)]) - fVec7[((IOTA - 404) & 511)]) + fVec7[((IOTA - 420) & 511)]) - fVec7[((IOTA - 433) & 511)]) - fVec7[((IOTA - 448) & 511)]) - fVec7[((IOTA - 459) & 511)]) + fVec7[((IOTA - 468) & 511)]) + fVec7[((IOTA - 471) & 511)]) + fVec7[((IOTA - 474) & 511)])) + ((0.000885036774f * (((fVec7[((IOTA - 209) & 511)] - fVec7[((IOTA - 378) & 511)]) + fVec7[((IOTA - 424) & 511)]) + fVec7[((IOTA - 425) & 511)])) + ((0.00054933317f * (((((((fVec7[((IOTA - 228) & 511)] - fVec7[((IOTA - 249) & 511)]) + fVec7[((IOTA - 330) & 511)]) - fVec7[((IOTA - 337) & 511)]) - fVec7[((IOTA - 356) & 511)]) - fVec7[((IOTA - 357) & 511)]) - fVec7[((IOTA - 374) & 511)]) - fVec7[((IOTA - 417) & 511)])) + ((0.00125125889f * fVec7[((IOTA - 399) & 511)]) + ((0.00164799951f * ((fVec7[((IOTA - 175) & 511)] + fVec7[((IOTA - 382) & 511)]) + fVec7[((IOTA - 398) & 511)])) + ((0.000976592302f * ((((fVec7[((IOTA - 199) & 511)] + fVec7[((IOTA - 314) & 511)]) + fVec7[((IOTA - 329) & 511)]) - fVec7[((IOTA - 392) & 511)]) + fVec7[((IOTA - 396) & 511)])) + ((0.00112918485f * ((fVec7[((IOTA - 203) & 511)] + fVec7[((IOTA - 230) & 511)]) - fVec7[((IOTA - 394) & 511)])) + ((0.00140385143f * ((((fVec7[((IOTA - 62) & 511)] + fVec7[((IOTA - 110) & 511)]) - fVec7[((IOTA - 181) & 511)]) + fVec7[((IOTA - 205) & 511)]) - fVec7[((IOTA - 393) & 511)])) + ((0.00109866634f * (fVec7[((IOTA - 231) & 511)] + fVec7[((IOTA - 385) & 511)])) + ((0.00137333293f * ((fVec7[((IOTA - 26) & 511)] + fVec7[((IOTA - 204) & 511)]) + fVec7[((IOTA - 384) & 511)])) + ((0.00115970336f * ((fVec7[((IOTA - 208) & 511)] + fVec7[((IOTA - 324) & 511)]) + fVec7[((IOTA - 380) & 511)])) + ((0.00119022187f * ((((fVec7[((IOTA - 109) & 511)] - fVec7[((IOTA - 307) & 511)]) + fVec7[((IOTA - 364) & 511)]) + fVec7[((IOTA - 367) & 511)]) - fVec7[((IOTA - 375) & 511)])) + ((0.000793481246f * (fVec7[((IOTA - 200) & 511)] + fVec7[((IOTA - 368) & 511)])) + (((0.00057985168f * (fVec7[((IOTA - 235) & 511)] - fVec7[((IOTA - 345) & 511)])) + ((0.000854518265f * ((fVec7[((IOTA - 202) & 511)] + fVec7[((IOTA - 299) & 511)]) - fVec7[((IOTA - 336) & 511)])) + ((0.00152592547f * fVec7[((IOTA - 383) & 511)]) + ((0.00180059206f * (fVec7[((IOTA - 136) & 511)] + fVec7[((IOTA - 327) & 511)])) + ((0.00186162908f * (fVec7[((IOTA - 311) & 511)] + fVec7[((IOTA - 326) & 511)])) + ((0.00143436994f * (fVec7[((IOTA - 174) & 511)] - fVec7[((IOTA - 320) & 511)])) + ((0.00173955504f * (fVec7[((IOTA - 35) & 511)] - fVec7[((IOTA - 319) & 511)])) + ((0.00106814783f * (fVec7[((IOTA - 301) & 511)] - fVec7[((IOTA - 316) & 511)])) + ((0.00219733268f * fVec7[((IOTA - 312) & 511)]) + ((0.000701925717f * (fVec7[((IOTA - 158) & 511)] - fVec7[((IOTA - 246) & 511)])) + ((0.000671407208f * ((((fVec7[((IOTA - 161) & 511)] + fVec7[((IOTA - 177) & 511)]) + fVec7[((IOTA - 201) & 511)]) + fVec7[((IOTA - 234) & 511)]) - fVec7[((IOTA - 245) & 511)])) + ((0.00134281442f * (fVec7[((IOTA - 176) & 511)] + fVec7[((IOTA - 206) & 511)])) + ((0.00280770287f * (fVec7[((IOTA - 142) & 511)] - fVec7[((IOTA - 185) & 511)])) + ((0.00384533219f * fVec7[((IOTA - 168) & 511)]) + ((0.00347911008f * fVec7[((IOTA - 167) & 511)]) + ((0.00277718436f * (fVec7[((IOTA - 108) & 511)] + fVec7[((IOTA - 166) & 511)])) + ((0.00268562883f * fVec7[((IOTA - 164) & 511)]) + ((0.00512710959f * fVec7[((IOTA - 141) & 511)]) + ((0.00604266487f * fVec7[((IOTA - 140) & 511)]) + ((0.00411999878f * fVec7[((IOTA - 138) & 511)]) + ((0.00299081393f * fVec7[((IOTA - 137) & 511)]) + ((0.00463881344f * (fVec7[((IOTA - 113) & 511)] - fVec7[((IOTA - 124) & 511)])) + ((0.00408948027f * fVec7[((IOTA - 116) & 511)]) + ((0.00534073915f * fVec7[((IOTA - 115) & 511)]) + ((0.00479140598f * fVec7[((IOTA - 114) & 511)]) + ((0.0045167394f * fVec7[((IOTA - 112) & 511)]) + ((0.00308236945f * fVec7[((IOTA - 111) & 511)]) + ((0.00405896176f * fVec7[((IOTA - 107) & 511)]) + ((0.00402844325f * fVec7[((IOTA - 106) & 511)]) + ((0.00494399853f * fVec7[((IOTA - 105) & 511)]) + ((0.0093691824f * fVec7[((IOTA - 104) & 511)]) + ((0.0150151066f * fVec7[((IOTA - 103) & 511)]) + ((0.0172429588f * fVec7[((IOTA - 102) & 511)]) + ((0.00329599902f * fVec7[((IOTA - 99) & 511)]) + ((0.00256355479f * fVec7[((IOTA - 79) & 511)]) + ((0.00891140476f * fVec7[((IOTA - 78) & 511)]) + ((0.0113528855f * fVec7[((IOTA - 77) & 511)]) + ((0.0118717002f * fVec7[((IOTA - 76) & 511)]) + ((0.0104678487f * fVec7[((IOTA - 75) & 511)]) + ((0.00537125766f * fVec7[((IOTA - 74) & 511)]) + ((0.00433362834f * (fVec7[((IOTA - 38) & 511)] - fVec7[((IOTA - 65) & 511)])) + ((0.0109256264f * fVec7[((IOTA - 61) & 511)]) + ((0.0171819218f * fVec7[((IOTA - 60) & 511)]) + ((0.0110171819f * fVec7[((IOTA - 59) & 511)]) + ((0.00616473891f * fVec7[((IOTA - 51) & 511)]) + ((0.0215155501f * fVec7[((IOTA - 50) & 511)]) + ((0.0407116935f * fVec7[((IOTA - 49) & 511)]) + ((0.045716729f * fVec7[((IOTA - 48) & 511)]) + ((0.0319223627f * fVec7[((IOTA - 47) & 511)]) + ((0.00869777519f * fVec7[((IOTA - 46) & 511)]) + ((0.0103762932f * fVec7[((IOTA - 37) & 511)]) + ((0.0058290353f * fVec7[((IOTA - 36) & 511)]) + ((0.0163884405f * fVec7[((IOTA - 34) & 511)]) + ((0.0443739146f * fVec7[((IOTA - 33) & 511)]) + ((0.0589007251f * fVec7[((IOTA - 32) & 511)]) + ((((((((0.164799958f * fVec7[((IOTA - 8) & 511)]) + ((0.287484348f * fVec7[((IOTA - 7) & 511)]) + ((0.191259503f * fVec7[((IOTA - 6) & 511)]) + ((0.138859212f * fVec7[((IOTA - 13) & 511)]) + ((((0.0893581957f * fVec7[((IOTA - 12) & 511)]) + (0.108096562f * fVec7[((IOTA - 14) & 511)])) + (0.0534989461f * fVec7[((IOTA - 15) & 511)])) + (0.00805688649f * fVec7[((IOTA - 16) & 511)])))))) + (0.0107730338f * fVec7[((IOTA - 21) & 511)])) + (0.0492568761f * fVec7[((IOTA - 22) & 511)])) + (0.0682088658f * fVec7[((IOTA - 23) & 511)])) + (0.0728782043f * fVec7[((IOTA - 24) & 511)])) + (0.0547196865f * fVec7[((IOTA - 25) & 511)])) + (0.0397656187f * fVec7[((IOTA - 31) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (6.10370189e-05f * ((((((((((((fVec7[((IOTA - 143) & 511)] - fVec7[((IOTA - 216) & 511)]) - fVec7[((IOTA - 224) & 511)]) - fVec7[((IOTA - 225) & 511)]) - fVec7[((IOTA - 342) & 511)]) + fVec7[((IOTA - 349) & 511)]) - fVec7[((IOTA - 410) & 511)]) - fVec7[((IOTA - 452) & 511)]) - fVec7[((IOTA - 461) & 511)]) + fVec7[((IOTA - 463) & 511)]) - fVec7[((IOTA - 479) & 511)]) - fVec7[((IOTA - 498) & 511)]) + fVec7[((IOTA - 510) & 511)])))))))))))))))))))))))) + (0.000122074038f * (((((((((((((fVec7[((IOTA - 242) & 511)] - fVec7[((IOTA - 258) & 511)]) + fVec7[((IOTA - 259) & 511)]) - fVec7[((IOTA - 279) & 511)]) - fVec7[((IOTA - 281) & 511)]) - fVec7[((IOTA - 303) & 511)]) + fVec7[((IOTA - 331) & 511)]) - fVec7[((IOTA - 354) & 511)]) - fVec7[((IOTA - 434) & 511)]) + fVec7[((IOTA - 438) & 511)]) - fVec7[((IOTA - 480) & 511)]) - fVec7[((IOTA - 492) & 511)]) - fVec7[((IOTA - 499) & 511)]) + fVec7[((IOTA - 511) & 511)])))) : (((0.000427259132f * (((((((((((fVec6[((IOTA - 172) & 511)] - fVec6[((IOTA - 178) & 511)]) - fVec6[((IOTA - 248) & 511)]) - fVec6[((IOTA - 249) & 511)]) - fVec6[((IOTA - 295) & 511)]) - fVec6[((IOTA - 296) & 511)]) + fVec6[((IOTA - 321) & 511)]) + fVec6[((IOTA - 343) & 511)]) + fVec6[((IOTA - 417) & 511)]) + fVec6[((IOTA - 479) & 511)]) + fVec6[((IOTA - 481) & 511)]) - fVec6[((IOTA - 510) & 511)])) + ((0.000244148076f * ((((((fVec6[((IOTA - 59) & 511)] + fVec6[((IOTA - 204) & 511)]) + fVec6[((IOTA - 267) & 511)]) - fVec6[((IOTA - 299) & 511)]) + fVec6[((IOTA - 323) & 511)]) - fVec6[((IOTA - 497) & 511)]) - fVec6[((IOTA - 509) & 511)])) + ((9.15555283e-05f * ((((((((((((fVec6[((IOTA - 18) & 511)] + fVec6[((IOTA - 19) & 511)]) + fVec6[((IOTA - 22) & 511)]) + fVec6[((IOTA - 23) & 511)]) + fVec6[((IOTA - 43) & 511)]) + fVec6[((IOTA - 50) & 511)]) + fVec6[((IOTA - 53) & 511)]) - fVec6[((IOTA - 215) & 511)]) + fVec6[((IOTA - 268) & 511)]) - fVec6[((IOTA - 469) & 511)]) - fVec6[((IOTA - 487) & 511)]) - fVec6[((IOTA - 506) & 511)]) - fVec6[((IOTA - 508) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((((fTemp7 + fVec6[((IOTA - 1) & 511)]) + fVec6[((IOTA - 2) & 511)]) + fVec6[((IOTA - 3) & 511)]) + fVec6[((IOTA - 4) & 511)]) + fVec6[((IOTA - 5) & 511)]) + fVec6[((IOTA - 10) & 511)]) + fVec6[((IOTA - 11) & 511)]) + fVec6[((IOTA - 12) & 511)]) + fVec6[((IOTA - 16) & 511)]) - fVec6[((IOTA - 25) & 511)]) + fVec6[((IOTA - 28) & 511)]) + fVec6[((IOTA - 30) & 511)]) + fVec6[((IOTA - 32) & 511)]) + fVec6[((IOTA - 34) & 511)]) + fVec6[((IOTA - 38) & 511)]) - fVec6[((IOTA - 40) & 511)]) + fVec6[((IOTA - 41) & 511)]) + fVec6[((IOTA - 46) & 511)]) + fVec6[((IOTA - 49) & 511)]) + fVec6[((IOTA - 54) & 511)]) - fVec6[((IOTA - 56) & 511)]) - fVec6[((IOTA - 233) & 511)]) + fVec6[((IOTA - 236) & 511)]) - fVec6[((IOTA - 246) & 511)]) + fVec6[((IOTA - 305) & 511)]) + fVec6[((IOTA - 315) & 511)]) - fVec6[((IOTA - 318) & 511)]) + fVec6[((IOTA - 398) & 511)]) - fVec6[((IOTA - 401) & 511)]) + fVec6[((IOTA - 402) & 511)]) - fVec6[((IOTA - 464) & 511)]) - fVec6[((IOTA - 484) & 511)]) - fVec6[((IOTA - 486) & 511)]) + fVec6[((IOTA - 498) & 511)]) - fVec6[((IOTA - 507) & 511)])) + ((0.000274666585f * (((((((((fVec6[((IOTA - 60) & 511)] - fVec6[((IOTA - 271) & 511)]) + fVec6[((IOTA - 303) & 511)]) + fVec6[((IOTA - 326) & 511)]) + fVec6[((IOTA - 345) & 511)]) - fVec6[((IOTA - 353) & 511)]) - fVec6[((IOTA - 367) & 511)]) + fVec6[((IOTA - 470) & 511)]) + fVec6[((IOTA - 482) & 511)]) - fVec6[((IOTA - 505) & 511)])) + ((0.000305185094f * ((((((((fVec6[((IOTA - 242) & 511)] + fVec6[((IOTA - 243) & 511)]) - fVec6[((IOTA - 247) & 511)]) - fVec6[((IOTA - 292) & 511)]) - fVec6[((IOTA - 297) & 511)]) + fVec6[((IOTA - 354) & 511)]) + fVec6[((IOTA - 384) & 511)]) + fVec6[((IOTA - 500) & 511)]) - fVec6[((IOTA - 503) & 511)])) + ((6.10370189e-05f * ((((((((((((((fVec6[((IOTA - 17) & 511)] + fVec6[((IOTA - 20) & 511)]) + fVec6[((IOTA - 39) & 511)]) + fVec6[((IOTA - 44) & 511)]) + fVec6[((IOTA - 45) & 511)]) - fVec6[((IOTA - 62) & 511)]) + fVec6[((IOTA - 245) & 511)]) + fVec6[((IOTA - 283) & 511)]) - fVec6[((IOTA - 290) & 511)]) + fVec6[((IOTA - 310) & 511)]) - fVec6[((IOTA - 342) & 511)]) + fVec6[((IOTA - 377) & 511)]) + fVec6[((IOTA - 483) & 511)]) - fVec6[((IOTA - 485) & 511)]) - fVec6[((IOTA - 502) & 511)])) + ((0.000183111057f * (((((((((((((fVec6[((IOTA - 27) & 511)] + fVec6[((IOTA - 35) & 511)]) + fVec6[((IOTA - 37) & 511)]) + fVec6[((IOTA - 179) & 511)]) - fVec6[((IOTA - 241) & 511)]) - fVec6[((IOTA - 257) & 511)]) + fVec6[((IOTA - 266) & 511)]) - fVec6[((IOTA - 289) & 511)]) - fVec6[((IOTA - 316) & 511)]) + fVec6[((IOTA - 324) & 511)]) - fVec6[((IOTA - 400) & 511)]) - fVec6[((IOTA - 408) & 511)]) + fVec6[((IOTA - 418) & 511)]) + fVec6[((IOTA - 501) & 511)])) + ((0.000457777642f * (((fVec6[((IOTA - 312) & 511)] + fVec6[((IOTA - 419) & 511)]) + fVec6[((IOTA - 480) & 511)]) - fVec6[((IOTA - 496) & 511)])) + ((0.000518814661f * ((((((((fVec6[((IOTA - 26) & 511)] + fVec6[((IOTA - 211) & 511)]) + fVec6[((IOTA - 216) & 511)]) + fVec6[((IOTA - 282) & 511)]) - fVec6[((IOTA - 286) & 511)]) - fVec6[((IOTA - 341) & 511)]) + fVec6[((IOTA - 436) & 511)]) - fVec6[((IOTA - 467) & 511)]) - fVec6[((IOTA - 493) & 511)])) + ((0.000885036774f * ((fVec6[((IOTA - 395) & 511)] - fVec6[((IOTA - 407) & 511)]) - fVec6[((IOTA - 491) & 511)])) + ((0.00109866634f * (((fVec6[((IOTA - 218) & 511)] + fVec6[((IOTA - 329) & 511)]) + fVec6[((IOTA - 410) & 511)]) + fVec6[((IOTA - 476) & 511)])) + ((0.00186162908f * ((fVec6[((IOTA - 356) & 511)] + fVec6[((IOTA - 425) & 511)]) + fVec6[((IOTA - 474) & 511)])) + ((0.00177007355f * (((fVec6[((IOTA - 260) & 511)] + fVec6[((IOTA - 422) & 511)]) + fVec6[((IOTA - 458) & 511)]) + fVec6[((IOTA - 473) & 511)])) + ((0.00137333293f * fVec6[((IOTA - 472) & 511)]) + ((0.000793481246f * (((fVec6[((IOTA - 264) & 511)] + fVec6[((IOTA - 272) & 511)]) - fVec6[((IOTA - 378) & 511)]) + fVec6[((IOTA - 471) & 511)])) + ((0.000640888698f * (fVec6[((IOTA - 336) & 511)] - fVec6[((IOTA - 466) & 511)])) + ((0.00149540696f * (((fVec6[((IOTA - 153) & 511)] - fVec6[((IOTA - 213) & 511)]) - fVec6[((IOTA - 383) & 511)]) + fVec6[((IOTA - 461) & 511)])) + ((0.00173955504f * ((fVec6[((IOTA - 446) & 511)] + fVec6[((IOTA - 457) & 511)]) + fVec6[((IOTA - 459) & 511)])) + ((0.0025940733f * (((fVec6[((IOTA - 357) & 511)] + fVec6[((IOTA - 369) & 511)]) - fVec6[((IOTA - 450) & 511)]) - fVec6[((IOTA - 452) & 511)])) + ((0.00119022187f * (fVec6[((IOTA - 275) & 511)] - fVec6[((IOTA - 449) & 511)])) + ((0.00143436994f * ((((fVec6[((IOTA - 273) & 511)] - fVec6[((IOTA - 348) & 511)]) + fVec6[((IOTA - 391) & 511)]) + fVec6[((IOTA - 421) & 511)]) + fVec6[((IOTA - 447) & 511)])) + ((0.00112918485f * ((fVec6[((IOTA - 360) & 511)] + fVec6[((IOTA - 392) & 511)]) + fVec6[((IOTA - 444) & 511)])) + ((0.000976592302f * ((fVec6[((IOTA - 355) & 511)] + fVec6[((IOTA - 420) & 511)]) + fVec6[((IOTA - 442) & 511)])) + ((0.00100711081f * ((((((fVec6[((IOTA - 234) & 511)] - fVec6[((IOTA - 278) & 511)]) + fVec6[((IOTA - 330) & 511)]) - fVec6[((IOTA - 351) & 511)]) + fVec6[((IOTA - 374) & 511)]) + fVec6[((IOTA - 434) & 511)]) + fVec6[((IOTA - 440) & 511)])) + ((0.00140385143f * fVec6[((IOTA - 433) & 511)]) + ((0.0019531846f * (fVec6[((IOTA - 138) & 511)] + fVec6[((IOTA - 431) & 511)])) + ((0.00210577715f * fVec6[((IOTA - 430) & 511)]) + ((0.00213629566f * fVec6[((IOTA - 429) & 511)]) + ((0.0019226661f * (((fVec6[((IOTA - 169) & 511)] + fVec6[((IOTA - 415) & 511)]) + fVec6[((IOTA - 424) & 511)]) + fVec6[((IOTA - 427) & 511)])) + ((0.00189214759f * ((((fVec6[((IOTA - 209) & 511)] + fVec6[((IOTA - 261) & 511)]) - fVec6[((IOTA - 379) & 511)]) + fVec6[((IOTA - 423) & 511)]) + fVec6[((IOTA - 426) & 511)])) + ((0.00238044374f * (fVec6[((IOTA - 385) & 511)] + fVec6[((IOTA - 414) & 511)])) + ((0.00155644398f * (fVec6[((IOTA - 262) & 511)] + fVec6[((IOTA - 411) & 511)])) + ((0.00054933317f * (((((((fVec6[((IOTA - 192) & 511)] - fVec6[((IOTA - 203) & 511)]) - fVec6[((IOTA - 270) & 511)]) - fVec6[((IOTA - 284) & 511)]) - fVec6[((IOTA - 294) & 511)]) + fVec6[((IOTA - 313) & 511)]) + fVec6[((IOTA - 376) & 511)]) + fVec6[((IOTA - 409) & 511)])) + ((0.00332651753f * ((fVec6[((IOTA - 70) & 511)] + fVec6[((IOTA - 154) & 511)]) + fVec6[((IOTA - 389) & 511)])) + ((0.00433362834f * fVec6[((IOTA - 388) & 511)]) + ((0.00399792474f * fVec6[((IOTA - 386) & 511)]) + ((0.00274666585f * (fVec6[((IOTA - 370) & 511)] - fVec6[((IOTA - 382) & 511)])) + ((0.0028992584f * ((fVec6[((IOTA - 220) & 511)] - fVec6[((IOTA - 227) & 511)]) - fVec6[((IOTA - 380) & 511)])) + ((0.00125125889f * ((fVec6[((IOTA - 191) & 511)] + fVec6[((IOTA - 235) & 511)]) + fVec6[((IOTA - 373) & 511)])) + ((0.00152592547f * ((fVec6[((IOTA - 445) & 511)] + fVec6[((IOTA - 456) & 511)]) + fVec6[((IOTA - 475) & 511)])) + ((0.00170903653f * fVec6[((IOTA - 372) & 511)]) + ((0.00219733268f * fVec6[((IOTA - 371) & 511)]) + ((0.00286873989f * fVec6[((IOTA - 358) & 511)]) + ((0.000122074038f * (((((((((((fVec6[((IOTA - 21) & 511)] + fVec6[((IOTA - 31) & 511)]) + fVec6[((IOTA - 33) & 511)]) + fVec6[((IOTA - 36) & 511)]) + fVec6[((IOTA - 51) & 511)]) + fVec6[((IOTA - 52) & 511)]) + fVec6[((IOTA - 58) & 511)]) + fVec6[((IOTA - 156) & 511)]) - fVec6[((IOTA - 280) & 511)]) - fVec6[((IOTA - 302) & 511)]) + fVec6[((IOTA - 325) & 511)]) - fVec6[((IOTA - 338) & 511)])) + ((0.001617481f * ((fVec6[((IOTA - 205) & 511)] + fVec6[((IOTA - 210) & 511)]) + fVec6[((IOTA - 274) & 511)])) + ((0.00241096225f * ((fVec6[((IOTA - 206) & 511)] + fVec6[((IOTA - 207) & 511)]) + fVec6[((IOTA - 222) & 511)])) + ((0.00335703604f * ((fVec6[((IOTA - 170) & 511)] + fVec6[((IOTA - 171) & 511)]) - fVec6[((IOTA - 180) & 511)])) + ((0.00341807306f * fVec6[((IOTA - 168) & 511)]) + ((0.00659199804f * fVec6[((IOTA - 167) & 511)]) + ((0.0121158483f * fVec6[((IOTA - 166) & 511)]) + ((0.0137943663f * fVec6[((IOTA - 165) & 511)]) + ((0.00833155308f * fVec6[((IOTA - 164) & 511)]) + ((0.0118106632f * (fVec6[((IOTA - 102) & 511)] - fVec6[((IOTA - 160) & 511)])) + ((0.00338755455f * fVec6[((IOTA - 155) & 511)]) + ((0.00692770164f * fVec6[((IOTA - 144) & 511)]) + ((0.00848414563f * (fVec6[((IOTA - 71) & 511)] + fVec6[((IOTA - 143) & 511)])) + ((0.0100711081f * fVec6[((IOTA - 142) & 511)]) + ((0.00881984923f * fVec6[((IOTA - 141) & 511)]) + ((0.00906399731f * fVec6[((IOTA - 140) & 511)]) + ((0.00674459059f * fVec6[((IOTA - 139) & 511)]) + ((0.0168767367f * (fVec6[((IOTA - 129) & 511)] - fVec6[((IOTA - 136) & 511)])) + ((0.00619525742f * fVec6[((IOTA - 131) & 511)]) + ((0.0133060701f * (fVec6[((IOTA - 128) & 511)] + fVec6[((IOTA - 130) & 511)])) + ((0.00408948027f * fVec6[((IOTA - 127) & 511)]) + ((0.0331736207f * (fVec6[((IOTA - 82) & 511)] - fVec6[((IOTA - 122) & 511)])) + ((0.00512710959f * fVec6[((IOTA - 116) & 511)]) + ((0.0231635496f * fVec6[((IOTA - 115) & 511)]) + ((0.0184026621f * fVec6[((IOTA - 114) & 511)]) + ((0.0120242927f * fVec6[((IOTA - 113) & 511)]) + ((0.00271614734f * fVec6[((IOTA - 112) & 511)]) + ((0.012817774f * fVec6[((IOTA - 111) & 511)]) + ((0.0195013285f * fVec6[((IOTA - 110) & 511)]) + ((0.0226142164f * fVec6[((IOTA - 109) & 511)]) + ((0.0164494775f * fVec6[((IOTA - 108) & 511)]) + ((0.0519425049f * fVec6[((IOTA - 101) & 511)]) + ((0.0458082817f * fVec6[((IOTA - 100) & 511)]) + ((0.0323191024f * fVec6[((IOTA - 99) & 511)]) + ((0.0351878405f * fVec6[((IOTA - 90) & 511)]) + ((0.0329294726f * fVec6[((IOTA - 89) & 511)]) + ((0.0181890316f * fVec6[((IOTA - 88) & 511)]) + ((0.00653096102f * fVec6[((IOTA - 84) & 511)]) + ((0.0411389507f * fVec6[((IOTA - 83) & 511)]) + ((0.167943358f * fVec6[((IOTA - 76) & 511)]) + ((0.29374066f * fVec6[((IOTA - 75) & 511)]) + ((0.262337118f * fVec6[((IOTA - 74) & 511)]) + ((0.0365001373f * fVec6[((IOTA - 72) & 511)]) + (0.132389292f * fVec6[((IOTA - 73) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000366222113f * (((((fVec6[((IOTA - 298) & 511)] + fVec6[((IOTA - 300) & 511)]) - fVec6[((IOTA - 320) & 511)]) - fVec6[((IOTA - 322) & 511)]) + fVec6[((IOTA - 468) & 511)]) + fVec6[((IOTA - 504) & 511)])) + ((0.000213629566f * ((((fVec6[((IOTA - 309) & 511)] - fVec6[((IOTA - 311) & 511)]) - fVec6[((IOTA - 319) & 511)]) - fVec6[((IOTA - 337) & 511)]) - fVec6[((IOTA - 499) & 511)])) + ((0.000701925717f * ((((fVec6[((IOTA - 212) & 511)] - fVec6[((IOTA - 217) & 511)]) - fVec6[((IOTA - 332) & 511)]) - fVec6[((IOTA - 477) & 511)]) + fVec6[((IOTA - 492) & 511)])) + ((0.000915555283f * (((((fVec6[((IOTA - 107) & 511)] + fVec6[((IOTA - 254) & 511)]) - fVec6[((IOTA - 328) & 511)]) - fVec6[((IOTA - 334) & 511)]) - fVec6[((IOTA - 335) & 511)]) + fVec6[((IOTA - 490) & 511)])) + ((0.000671407208f * (((((fVec6[((IOTA - 146) & 511)] + fVec6[((IOTA - 255) & 511)]) + fVec6[((IOTA - 352) & 511)]) - fVec6[((IOTA - 396) & 511)]) + fVec6[((IOTA - 404) & 511)]) + fVec6[((IOTA - 489) & 511)])) + ((0.000335703604f * ((((((fVec6[((IOTA - 269) & 511)] + fVec6[((IOTA - 301) & 511)]) - fVec6[((IOTA - 304) & 511)]) + fVec6[((IOTA - 306) & 511)]) - fVec6[((IOTA - 397) & 511)]) - fVec6[((IOTA - 448) & 511)]) + fVec6[((IOTA - 488) & 511)])) + ((0.000488296151f * ((((((fVec6[((IOTA - 361) & 511)] - ((((fVec6[((IOTA - 265) & 511)] + fVec6[((IOTA - 276) & 511)]) - fVec6[((IOTA - 293) & 511)]) - fVec6[((IOTA - 308) & 511)]) - fVec6[((IOTA - 339) & 511)])) - fVec6[((IOTA - 437) & 511)]) + fVec6[((IOTA - 465) & 511)]) - fVec6[((IOTA - 478) & 511)]) + fVec6[((IOTA - 494) & 511)]) + fVec6[((IOTA - 495) & 511)])) + ((0.000610370189f * (((((fVec6[((IOTA - 63) & 511)] - fVec6[((IOTA - 258) & 511)]) + fVec6[((IOTA - 307) & 511)]) - fVec6[((IOTA - 327) & 511)]) - fVec6[((IOTA - 438) & 511)]) - fVec6[((IOTA - 463) & 511)])) + ((0.00115970336f * ((fVec6[((IOTA - 405) & 511)] - fVec6[((IOTA - 416) & 511)]) - fVec6[((IOTA - 462) & 511)])) + ((0.00164799951f * (fVec6[((IOTA - 196) & 511)] - fVec6[((IOTA - 460) & 511)])) + ((0.000946073793f * ((fVec6[((IOTA - 347) & 511)] - fVec6[((IOTA - 443) & 511)]) - fVec6[((IOTA - 455) & 511)])) + ((0.00134281442f * (fVec6[((IOTA - 253) & 511)] + fVec6[((IOTA - 453) & 511)])) + ((0.00314340647f * ((fVec6[((IOTA - 226) & 511)] + fVec6[((IOTA - 381) & 511)]) + fVec6[((IOTA - 451) & 511)])) + ((0.00103762932f * ((((fVec6[((IOTA - 202) & 511)] + fVec6[((IOTA - 224) & 511)]) - fVec6[((IOTA - 393) & 511)]) - fVec6[((IOTA - 394) & 511)]) - fVec6[((IOTA - 441) & 511)])) + ((0.000854518265f * ((fVec6[((IOTA - 190) & 511)] - fVec6[((IOTA - 331) & 511)]) - fVec6[((IOTA - 439) & 511)])) + ((0.000732444227f * (((((fVec6[((IOTA - 250) & 511)] + fVec6[((IOTA - 279) & 511)]) + fVec6[((IOTA - 285) & 511)]) - fVec6[((IOTA - 333) & 511)]) - fVec6[((IOTA - 375) & 511)]) - fVec6[((IOTA - 435) & 511)])) + ((0.00167851802f * (fVec6[((IOTA - 193) & 511)] - fVec6[((IOTA - 432) & 511)])) + ((0.00207525864f * ((fVec6[((IOTA - 198) & 511)] - fVec6[((IOTA - 208) & 511)]) - fVec6[((IOTA - 428) & 511)])) + ((0.00231940672f * (fVec6[((IOTA - 199) & 511)] - fVec6[((IOTA - 413) & 511)])) + ((0.00198370311f * ((fVec6[((IOTA - 163) & 511)] - fVec6[((IOTA - 219) & 511)]) - fVec6[((IOTA - 412) & 511)])) + ((0.0012817774f * (((fVec6[((IOTA - 251) & 511)] - fVec6[((IOTA - 259) & 511)]) - fVec6[((IOTA - 263) & 511)]) + fVec6[((IOTA - 406) & 511)])) + ((0.000152592547f * ((fVec6[((IOTA - 399) & 511)] - (((((fVec6[((IOTA - 29) & 511)] + fVec6[((IOTA - 61) & 511)]) + fVec6[((IOTA - 244) & 511)]) - fVec6[((IOTA - 288) & 511)]) - fVec6[((IOTA - 291) & 511)]) - fVec6[((IOTA - 317) & 511)])) + fVec6[((IOTA - 403) & 511)])) + ((0.0022583697f * ((fVec6[((IOTA - 230) & 511)] - fVec6[((IOTA - 359) & 511)]) - fVec6[((IOTA - 390) & 511)])) + ((0.00463881344f * (fVec6[((IOTA - 364) & 511)] - fVec6[((IOTA - 387) & 511)])) + ((0.00158696249f * (fVec6[((IOTA - 252) & 511)] - fVec6[((IOTA - 368) & 511)])) + ((0.00247199927f * (fVec6[((IOTA - 64) & 511)] + fVec6[((IOTA - 366) & 511)])) + ((0.00411999878f * fVec6[((IOTA - 365) & 511)]) + ((0.00384533219f * fVec6[((IOTA - 363) & 511)]) + ((0.00228888821f * ((fVec6[((IOTA - 228) & 511)] + fVec6[((IOTA - 229) & 511)]) + fVec6[((IOTA - 362) & 511)])) + ((0.00131229591f * (fVec6[((IOTA - 197) & 511)] + fVec6[((IOTA - 350) & 511)])) + ((0.00146488845f * ((fVec6[((IOTA - 201) & 511)] + fVec6[((IOTA - 232) & 511)]) + fVec6[((IOTA - 349) & 511)])) + ((0.000396740623f * (((fVec6[((IOTA - 277) & 511)] + fVec6[((IOTA - 287) & 511)]) - fVec6[((IOTA - 314) & 511)]) + fVec6[((IOTA - 346) & 511)])) + ((0.00106814783f * (fVec6[((IOTA - 237) & 511)] + fVec6[((IOTA - 240) & 511)])) + ((0.00183111057f * fVec6[((IOTA - 239) & 511)]) + ((0.00201422162f * fVec6[((IOTA - 238) & 511)]) + ((0.00222785119f * fVec6[((IOTA - 231) & 511)]) + ((0.000823999755f * (fVec6[((IOTA - 214) & 511)] - fVec6[((IOTA - 223) & 511)])) + ((0.00317392498f * (fVec6[((IOTA - 152) & 511)] - fVec6[((IOTA - 221) & 511)])) + ((0.00268562883f * fVec6[((IOTA - 225) & 511)]) + ((0.00204474013f * fVec6[((IOTA - 200) & 511)]) + ((0.00283822138f * fVec6[((IOTA - 195) & 511)]) + ((0.003234962f * fVec6[((IOTA - 194) & 511)]) + ((0.00494399853f * fVec6[((IOTA - 189) & 511)]) + ((0.00787377544f * fVec6[((IOTA - 188) & 511)]) + ((0.00878933072f * fVec6[((IOTA - 187) & 511)]) + ((0.00735496078f * fVec6[((IOTA - 186) & 511)]) + ((0.00482192449f * fVec6[((IOTA - 185) & 511)]) + ((0.00280770287f * fVec6[((IOTA - 184) & 511)]) + ((0.00253303628f * fVec6[((IOTA - 183) & 511)]) + ((0.00469985045f * fVec6[((IOTA - 182) & 511)]) + ((0.00506607257f * fVec6[((IOTA - 181) & 511)]) + ((0.00415051728f * fVec6[((IOTA - 177) & 511)]) + ((0.00854518265f * fVec6[((IOTA - 176) & 511)]) + ((0.0104983672f * (fVec6[((IOTA - 67) & 511)] + fVec6[((IOTA - 175) & 511)])) + ((0.00967436749f * fVec6[((IOTA - 174) & 511)]) + ((0.00567644276f * (fVec6[((IOTA - 147) & 511)] + fVec6[((IOTA - 173) & 511)])) + ((0.0101626636f * fVec6[((IOTA - 162) & 511)]) + ((0.0126346629f * fVec6[((IOTA - 161) & 511)]) + ((0.0124515519f * fVec6[((IOTA - 159) & 511)]) + ((0.0108951079f * fVec6[((IOTA - 158) & 511)]) + ((0.00747703481f * fVec6[((IOTA - 151) & 511)]) + ((0.01126133f * fVec6[((IOTA - 150) & 511)]) + ((0.0110477004f * fVec6[((IOTA - 149) & 511)]) + ((0.00924710836f * fVec6[((IOTA - 148) & 511)]) + ((0.00350962859f * (fVec6[((IOTA - 69) & 511)] - fVec6[((IOTA - 145) & 511)])) + ((0.00762962736f * fVec6[((IOTA - 137) & 511)]) + ((0.0228278451f * fVec6[((IOTA - 135) & 511)]) + ((0.0237739198f * fVec6[((IOTA - 134) & 511)]) + ((0.0157780703f * fVec6[((IOTA - 133) & 511)]) + ((0.00527970213f * fVec6[((IOTA - 132) & 511)]) + ((0.00668355357f * fVec6[((IOTA - 126) & 511)]) + ((0.0202032533f * fVec6[((IOTA - 125) & 511)]) + ((0.0296945106f * fVec6[((IOTA - 124) & 511)]) + ((0.0375377685f * fVec6[((IOTA - 123) & 511)]) + ((0.0281991027f * fVec6[((IOTA - 121) & 511)]) + ((0.0202948097f * fVec6[((IOTA - 120) & 511)]) + ((0.0166631062f * fVec6[((IOTA - 119) & 511)]) + ((0.0153813288f * fVec6[((IOTA - 118) & 511)]) + ((0.00634784997f * fVec6[((IOTA - 117) & 511)]) + ((0.0184636991f * fVec6[((IOTA - 106) & 511)]) + ((0.0329599902f * fVec6[((IOTA - 105) & 511)]) + ((0.0393078402f * fVec6[((IOTA - 104) & 511)]) + ((0.00622577593f * fVec6[((IOTA - 157) & 511)]) + ((0.0193182174f * fVec6[((IOTA - 103) & 511)]) + ((0.0176091809f * fVec6[((IOTA - 98) & 511)]) + ((0.0398266539f * fVec6[((IOTA - 97) & 511)]) + ((0.045716729f * fVec6[((IOTA - 96) & 511)]) + ((0.0266731773f * fVec6[((IOTA - 95) & 511)]) + ((0.0216681417f * fVec6[((IOTA - 94) & 511)]) + ((0.0371105075f * fVec6[((IOTA - 93) & 511)]) + ((0.0266426597f * fVec6[((IOTA - 92) & 511)]) + ((0.016113773f * fVec6[((IOTA - 91) & 511)]) + ((0.0444959886f * fVec6[((IOTA - 87) & 511)]) + ((0.050141912f * fVec6[((IOTA - 86) & 511)]) + ((0.0364085808f * fVec6[((IOTA - 85) & 511)]) + ((0.0217902157f * fVec6[((IOTA - 81) & 511)]) + ((0.129032254f * fVec6[((IOTA - 80) & 511)]) + ((0.194555491f * fVec6[((IOTA - 79) & 511)]) + ((0.183141574f * fVec6[((IOTA - 78) & 511)]) + ((0.037018951f * fVec6[((IOTA - 77) & 511)]) + ((0.00869777519f * fVec6[((IOTA - 68) & 511)]) + ((0.00576799829f * fVec6[((IOTA - 65) & 511)]) + (0.00897244178f * fVec6[((IOTA - 66) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00057985168f * ((((fVec6[((IOTA - 256) & 511)] - fVec6[((IOTA - 281) & 511)]) + fVec6[((IOTA - 340) & 511)]) - fVec6[((IOTA - 344) & 511)]) + fVec6[((IOTA - 511) & 511)]))))) : (iSlow17 ? (((0.000488296151f * ((fVec5[((IOTA - 347) & 511)] - fVec5[((IOTA - 489) & 511)]) + fVec5[((IOTA - 510) & 511)])) + ((0.000274666585f * (((((((fVec5[((IOTA - 56) & 511)] + fVec5[((IOTA - 196) & 511)]) - fVec5[((IOTA - 261) & 511)]) + fVec5[((IOTA - 265) & 511)]) + fVec5[((IOTA - 308) & 511)]) + fVec5[((IOTA - 309) & 511)]) + fVec5[((IOTA - 353) & 511)]) + fVec5[((IOTA - 508) & 511)])) + ((0.00057985168f * ((((fVec5[((IOTA - 247) & 511)] + fVec5[((IOTA - 250) & 511)]) + fVec5[((IOTA - 325) & 511)]) + fVec5[((IOTA - 346) & 511)]) - fVec5[((IOTA - 505) & 511)])) + ((0.000244148076f * ((((((((((fVec5[((IOTA - 55) & 511)] - fVec5[((IOTA - 252) & 511)]) - fVec5[((IOTA - 254) & 511)]) - fVec5[((IOTA - 302) & 511)]) + fVec5[((IOTA - 307) & 511)]) + fVec5[((IOTA - 333) & 511)]) + fVec5[((IOTA - 357) & 511)]) + fVec5[((IOTA - 358) & 511)]) + fVec5[((IOTA - 438) & 511)]) + fVec5[((IOTA - 439) & 511)]) - fVec5[((IOTA - 502) & 511)])) + ((0.000122074038f * ((((fVec5[((IOTA - 26) & 511)] + fVec5[((IOTA - 251) & 511)]) + fVec5[((IOTA - 332) & 511)]) - fVec5[((IOTA - 496) & 511)]) + fVec5[((IOTA - 501) & 511)])) + ((0.000396740623f * ((((fVec5[((IOTA - 329) & 511)] - ((((fVec5[((IOTA - 141) & 511)] - fVec5[((IOTA - 211) & 511)]) + fVec5[((IOTA - 260) & 511)]) + fVec5[((IOTA - 290) & 511)]) - fVec5[((IOTA - 322) & 511)])) + fVec5[((IOTA - 437) & 511)]) + fVec5[((IOTA - 487) & 511)]) + fVec5[((IOTA - 498) & 511)])) + ((0.000183111057f * (((fVec5[((IOTA - 57) & 511)] - fVec5[((IOTA - 255) & 511)]) + fVec5[((IOTA - 330) & 511)]) + fVec5[((IOTA - 497) & 511)])) + ((0.000762962736f * ((((((((fVec5[((IOTA - 159) & 511)] + fVec5[((IOTA - 200) & 511)]) - fVec5[((IOTA - 280) & 511)]) - fVec5[((IOTA - 288) & 511)]) - fVec5[((IOTA - 298) & 511)]) - fVec5[((IOTA - 387) & 511)]) + fVec5[((IOTA - 479) & 511)]) - fVec5[((IOTA - 490) & 511)]) - fVec5[((IOTA - 494) & 511)])) + ((0.000976592302f * ((((((((fVec5[((IOTA - 249) & 511)] - fVec5[((IOTA - 268) & 511)]) + fVec5[((IOTA - 327) & 511)]) - fVec5[((IOTA - 385) & 511)]) + fVec5[((IOTA - 425) & 511)]) + fVec5[((IOTA - 442) & 511)]) + fVec5[((IOTA - 461) & 511)]) + fVec5[((IOTA - 480) & 511)]) - fVec5[((IOTA - 492) & 511)])) + ((6.10370189e-05f * (((((((((((((((((((((((((((fVec5[((IOTA - 9) & 511)] + fVec5[((IOTA - 10) & 511)]) + fVec5[((IOTA - 11) & 511)]) + fVec5[((IOTA - 18) & 511)]) + fVec5[((IOTA - 19) & 511)]) + fVec5[((IOTA - 20) & 511)]) + fVec5[((IOTA - 21) & 511)]) + fVec5[((IOTA - 22) & 511)]) + fVec5[((IOTA - 27) & 511)]) + fVec5[((IOTA - 29) & 511)]) + fVec5[((IOTA - 30) & 511)]) + fVec5[((IOTA - 31) & 511)]) + fVec5[((IOTA - 32) & 511)]) + fVec5[((IOTA - 34) & 511)]) + fVec5[((IOTA - 36) & 511)]) + fVec5[((IOTA - 37) & 511)]) + fVec5[((IOTA - 38) & 511)]) + fVec5[((IOTA - 40) & 511)]) + fVec5[((IOTA - 41) & 511)]) + fVec5[((IOTA - 42) & 511)]) + fVec5[((IOTA - 43) & 511)]) + fVec5[((IOTA - 44) & 511)]) + fVec5[((IOTA - 50) & 511)]) + fVec5[((IOTA - 53) & 511)]) - fVec5[((IOTA - 212) & 511)]) + fVec5[((IOTA - 305) & 511)]) - fVec5[((IOTA - 463) & 511)]) - fVec5[((IOTA - 488) & 511)])) + ((0.00125125889f * (fVec5[((IOTA - 481) & 511)] + fVec5[((IOTA - 485) & 511)])) + ((0.00155644398f * fVec5[((IOTA - 483) & 511)]) + ((0.00146488845f * ((fVec5[((IOTA - 314) & 511)] + fVec5[((IOTA - 412) & 511)]) + fVec5[((IOTA - 482) & 511)])) + ((0.000701925717f * (((fVec5[((IOTA - 360) & 511)] + fVec5[((IOTA - 408) & 511)]) + fVec5[((IOTA - 436) & 511)]) + fVec5[((IOTA - 478) & 511)])) + ((0.00115970336f * ((fVec5[((IOTA - 342) & 511)] + fVec5[((IOTA - 435) & 511)]) + fVec5[((IOTA - 476) & 511)])) + ((0.00152592547f * (fVec5[((IOTA - 460) & 511)] + fVec5[((IOTA - 475) & 511)])) + ((0.0019226661f * (fVec5[((IOTA - 406) & 511)] + fVec5[((IOTA - 473) & 511)])) + ((0.0012817774f * (fVec5[((IOTA - 421) & 511)] + fVec5[((IOTA - 471) & 511)])) + ((0.000671407208f * (((fVec5[((IOTA - 197) & 511)] + fVec5[((IOTA - 352) & 511)]) - fVec5[((IOTA - 450) & 511)]) + fVec5[((IOTA - 470) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((fTemp6 + fVec5[((IOTA - 2) & 511)]) + fVec5[((IOTA - 3) & 511)]) + fVec5[((IOTA - 4) & 511)]) + fVec5[((IOTA - 5) & 511)]) + fVec5[((IOTA - 6) & 511)]) + fVec5[((IOTA - 7) & 511)]) + fVec5[((IOTA - 8) & 511)]) + fVec5[((IOTA - 12) & 511)]) + fVec5[((IOTA - 13) & 511)]) + fVec5[((IOTA - 14) & 511)]) + fVec5[((IOTA - 15) & 511)]) + fVec5[((IOTA - 16) & 511)]) + fVec5[((IOTA - 17) & 511)]) + fVec5[((IOTA - 23) & 511)]) + fVec5[((IOTA - 24) & 511)]) + fVec5[((IOTA - 25) & 511)]) + fVec5[((IOTA - 28) & 511)]) + fVec5[((IOTA - 51) & 511)]) + fVec5[((IOTA - 52) & 511)]) + fVec5[((IOTA - 58) & 511)]) + fVec5[((IOTA - 66) & 511)]) + fVec5[((IOTA - 209) & 511)]) - fVec5[((IOTA - 266) & 511)]) - fVec5[((IOTA - 304) & 511)]) + fVec5[((IOTA - 469) & 511)])) + ((0.00234992523f * ((fVec5[((IOTA - 414) & 511)] + fVec5[((IOTA - 433) & 511)]) + fVec5[((IOTA - 458) & 511)])) + ((0.000946073793f * (((fVec5[((IOTA - 248) & 511)] - fVec5[((IOTA - 279) & 511)]) - fVec5[((IOTA - 386) & 511)]) + fVec5[((IOTA - 455) & 511)])) + ((9.15555283e-05f * (((((((((((((((fVec5[((IOTA - 33) & 511)] + fVec5[((IOTA - 35) & 511)]) + fVec5[((IOTA - 39) & 511)]) + fVec5[((IOTA - 45) & 511)]) + fVec5[((IOTA - 46) & 511)]) + fVec5[((IOTA - 47) & 511)]) + fVec5[((IOTA - 48) & 511)]) + fVec5[((IOTA - 49) & 511)]) + fVec5[((IOTA - 246) & 511)]) - fVec5[((IOTA - 262) & 511)]) - fVec5[((IOTA - 303) & 511)]) + fVec5[((IOTA - 331) & 511)]) + fVec5[((IOTA - 354) & 511)]) + fVec5[((IOTA - 355) & 511)]) - fVec5[((IOTA - 373) & 511)]) - fVec5[((IOTA - 454) & 511)])) + ((0.00357066561f * fVec5[((IOTA - 445) & 511)]) + ((0.00308236945f * (fVec5[((IOTA - 366) & 511)] + fVec5[((IOTA - 432) & 511)])) + ((0.00375377666f * (fVec5[((IOTA - 365) & 511)] + fVec5[((IOTA - 431) & 511)])) + ((0.00418103579f * (fVec5[((IOTA - 430) & 511)] - (fVec5[((IOTA - 191) & 511)] - fVec5[((IOTA - 429) & 511)]))) + ((0.00363170262f * (fVec5[((IOTA - 160) & 511)] + fVec5[((IOTA - 428) & 511)])) + ((0.00164799951f * fVec5[((IOTA - 420) & 511)]) + ((0.00189214759f * fVec5[((IOTA - 419) & 511)]) + ((0.00216681417f * fVec5[((IOTA - 417) & 511)]) + ((0.00265511032f * fVec5[((IOTA - 404) & 511)]) + ((0.00494399853f * fVec5[((IOTA - 396) & 511)]) + ((0.00704977568f * fVec5[((IOTA - 394) & 511)]) + ((0.00708029419f * fVec5[((IOTA - 393) & 511)]) + ((0.00616473891f * fVec5[((IOTA - 392) & 511)]) + ((0.00430310983f * fVec5[((IOTA - 391) & 511)]) + ((0.00222785119f * fVec5[((IOTA - 390) & 511)]) + ((0.000305185094f * ((fVec5[((IOTA - 310) & 511)] + fVec5[((IOTA - 323) & 511)]) - fVec5[((IOTA - 388) & 511)])) + ((0.00103762932f * (((fVec5[((IOTA - 199) & 511)] - fVec5[((IOTA - 213) & 511)]) + fVec5[((IOTA - 320) & 511)]) - fVec5[((IOTA - 384) & 511)])) + ((0.00396740623f * fVec5[((IOTA - 378) & 511)]) + ((0.00503555406f * fVec5[((IOTA - 377) & 511)]) + ((0.00512710959f * fVec5[((IOTA - 376) & 511)]) + ((0.00158696249f * ((fVec5[((IOTA - 162) & 511)] - fVec5[((IOTA - 214) & 511)]) + fVec5[((IOTA - 367) & 511)])) + ((0.00314340647f * fVec5[((IOTA - 363) & 511)]) + ((0.00231940672f * (fVec5[((IOTA - 132) & 511)] + fVec5[((IOTA - 362) & 511)])) + ((0.000213629566f * fVec5[((IOTA - 356) & 511)]) + ((0.000823999755f * fVec5[((IOTA - 345) & 511)]) + ((0.00112918485f * ((fVec5[((IOTA - 198) & 511)] - fVec5[((IOTA - 293) & 511)]) + fVec5[((IOTA - 343) & 511)])) + ((0.000152592547f * ((fVec5[((IOTA - 54) & 511)] + fVec5[((IOTA - 263) & 511)]) + fVec5[((IOTA - 306) & 511)])) + ((0.00180059206f * (fVec5[((IOTA - 89) & 511)] - fVec5[((IOTA - 240) & 511)])) + ((0.00448622089f * (fVec5[((IOTA - 78) & 511)] - fVec5[((IOTA - 164) & 511)])) + ((0.00415051728f * fVec5[((IOTA - 161) & 511)]) + ((0.000793481246f * fVec5[((IOTA - 137) & 511)]) + ((0.0038758507f * fVec5[((IOTA - 136) & 511)]) + ((0.00799584948f * fVec5[((IOTA - 135) & 511)]) + ((0.0110477004f * fVec5[((IOTA - 134) & 511)]) + ((0.00894192327f * fVec5[((IOTA - 133) & 511)]) + ((0.0214850307f * fVec5[((IOTA - 123) & 511)]) + ((0.0155339213f * fVec5[((IOTA - 122) & 511)]) + ((0.00256355479f * fVec5[((IOTA - 121) & 511)]) + ((0.025818659f * (fVec5[((IOTA - 82) & 511)] - fVec5[((IOTA - 115) & 511)])) + ((0.00454725791f * fVec5[((IOTA - 111) & 511)]) + ((0.0118717002f * fVec5[((IOTA - 110) & 511)]) + ((0.0176091809f * fVec5[((IOTA - 109) & 511)]) + ((0.0239265114f * fVec5[((IOTA - 108) & 511)]) + ((0.0328379162f * fVec5[((IOTA - 107) & 511)]) + ((0.0287789553f * fVec5[((IOTA - 106) & 511)]) + ((0.022644734f * fVec5[((IOTA - 105) & 511)]) + ((0.0101016266f * fVec5[((IOTA - 104) & 511)]) + ((0.0154728843f * fVec5[((IOTA - 98) & 511)]) + ((0.0399487279f * fVec5[((IOTA - 97) & 511)]) + ((0.0332041383f * fVec5[((IOTA - 96) & 511)]) + ((0.0126346629f * fVec5[((IOTA - 95) & 511)]) + ((0.0513016135f * fVec5[((IOTA - 81) & 511)]) + ((0.0737327188f * fVec5[((IOTA - 80) & 511)]) + ((0.0633869469f * fVec5[((IOTA - 79) & 511)]) + ((0.0624408722f * fVec5[((IOTA - 73) & 511)]) + ((0.214819789f * fVec5[((IOTA - 72) & 511)]) + ((0.289773256f * fVec5[((IOTA - 71) & 511)]) + ((0.245704517f * fVec5[((IOTA - 70) & 511)]) + ((0.126773894f * fVec5[((IOTA - 69) & 511)]) + ((0.00640888698f * fVec5[((IOTA - 67) & 511)]) + (0.0365916938f * fVec5[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.000427259132f * ((((((fVec5[((IOTA - 195) & 511)] - fVec5[((IOTA - 210) & 511)]) + fVec5[((IOTA - 289) & 511)]) - fVec5[((IOTA - 334) & 511)]) + fVec5[((IOTA - 368) & 511)]) - fVec5[((IOTA - 462) & 511)]) - fVec5[((IOTA - 509) & 511)])) + ((0.000335703604f * ((((fVec5[((IOTA - 245) & 511)] + fVec5[((IOTA - 256) & 511)]) - fVec5[((IOTA - 264) & 511)]) - fVec5[((IOTA - 324) & 511)]) + fVec5[((IOTA - 506) & 511)])) + ((0.000640888698f * ((((((fVec5[((IOTA - 244) & 511)] + fVec5[((IOTA - 258) & 511)]) + fVec5[((IOTA - 299) & 511)]) - fVec5[((IOTA - 321) & 511)]) - fVec5[((IOTA - 335) & 511)]) - fVec5[((IOTA - 423) & 511)]) + fVec5[((IOTA - 504) & 511)])) + ((0.000518814661f * ((((((fVec5[((IOTA - 59) & 511)] + fVec5[((IOTA - 208) & 511)]) + fVec5[((IOTA - 259) & 511)]) + fVec5[((IOTA - 300) & 511)]) + fVec5[((IOTA - 381) & 511)]) + fVec5[((IOTA - 468) & 511)]) + fVec5[((IOTA - 503) & 511)])) + ((0.000366222113f * ((((fVec5[((IOTA - 253) & 511)] + fVec5[((IOTA - 301) & 511)]) - fVec5[((IOTA - 359) & 511)]) - fVec5[((IOTA - 440) & 511)]) - fVec5[((IOTA - 500) & 511)])) + ((0.000915555283f * (((((((fVec5[((IOTA - 292) & 511)] + fVec5[((IOTA - 297) & 511)]) - fVec5[((IOTA - 336) & 511)]) - fVec5[((IOTA - 411) & 511)]) - fVec5[((IOTA - 422) & 511)]) + fVec5[((IOTA - 467) & 511)]) + fVec5[((IOTA - 491) & 511)]) + fVec5[((IOTA - 493) & 511)])) + ((0.000885036774f * (((fVec5[((IOTA - 242) & 511)] - fVec5[((IOTA - 326) & 511)]) + fVec5[((IOTA - 465) & 511)]) - fVec5[((IOTA - 486) & 511)])) + ((0.00149540696f * ((fVec5[((IOTA - 269) & 511)] + fVec5[((IOTA - 452) & 511)]) - fVec5[((IOTA - 484) & 511)])) + ((0.000854518265f * ((fVec5[((IOTA - 281) & 511)] - fVec5[((IOTA - 380) & 511)]) - fVec5[((IOTA - 477) & 511)])) + ((0.00183111057f * ((fVec5[((IOTA - 286) & 511)] - fVec5[((IOTA - 456) & 511)]) - fVec5[((IOTA - 474) & 511)])) + ((0.00173955504f * (((fVec5[((IOTA - 193) & 511)] + fVec5[((IOTA - 283) & 511)]) - fVec5[((IOTA - 443) & 511)]) - fVec5[((IOTA - 472) & 511)])) + ((0.00100711081f * (((((fVec5[((IOTA - 194) & 511)] - fVec5[((IOTA - 312) & 511)]) - fVec5[((IOTA - 344) & 511)]) - fVec5[((IOTA - 349) & 511)]) + fVec5[((IOTA - 453) & 511)]) + fVec5[((IOTA - 466) & 511)])) + ((0.00054933317f * (((((fVec5[((IOTA - 257) & 511)] - fVec5[((IOTA - 311) & 511)]) - fVec5[((IOTA - 410) & 511)]) - fVec5[((IOTA - 441) & 511)]) - fVec5[((IOTA - 449) & 511)]) + fVec5[((IOTA - 464) & 511)])) + ((0.00204474013f * (((fVec5[((IOTA - 177) & 511)] - fVec5[((IOTA - 413) & 511)]) - fVec5[((IOTA - 418) & 511)]) - fVec5[((IOTA - 459) & 511)])) + ((0.00228888821f * ((((((fVec5[((IOTA - 60) & 511)] + fVec5[((IOTA - 236) & 511)]) + fVec5[((IOTA - 271) & 511)]) + fVec5[((IOTA - 275) & 511)]) - fVec5[((IOTA - 402) & 511)]) - fVec5[((IOTA - 416) & 511)]) - fVec5[((IOTA - 457) & 511)])) + ((0.00140385143f * (fVec5[((IOTA - 138) & 511)] + fVec5[((IOTA - 451) & 511)])) + ((0.00201422162f * ((fVec5[((IOTA - 216) & 511)] - fVec5[((IOTA - 400) & 511)]) - fVec5[((IOTA - 448) & 511)])) + ((0.00326548051f * ((fVec5[((IOTA - 158) & 511)] + fVec5[((IOTA - 226) & 511)]) - fVec5[((IOTA - 447) & 511)])) + ((0.00381481368f * (((fVec5[((IOTA - 218) & 511)] + fVec5[((IOTA - 222) & 511)]) + fVec5[((IOTA - 227) & 511)]) - fVec5[((IOTA - 446) & 511)])) + ((0.00274666585f * ((fVec5[((IOTA - 372) & 511)] - fVec5[((IOTA - 427) & 511)]) - fVec5[((IOTA - 444) & 511)])) + ((0.00170903653f * ((fVec5[((IOTA - 277) & 511)] - fVec5[((IOTA - 426) & 511)]) - fVec5[((IOTA - 434) & 511)])) + ((0.000610370189f * (((fVec5[((IOTA - 90) & 511)] + fVec5[((IOTA - 291) & 511)]) - fVec5[((IOTA - 389) & 511)]) - fVec5[((IOTA - 424) & 511)])) + ((0.00241096225f * ((fVec5[((IOTA - 225) & 511)] - fVec5[((IOTA - 379) & 511)]) - fVec5[((IOTA - 415) & 511)])) + ((0.00131229591f * ((((fVec5[((IOTA - 241) & 511)] + fVec5[((IOTA - 287) & 511)]) - fVec5[((IOTA - 338) & 511)]) + fVec5[((IOTA - 383) & 511)]) - fVec5[((IOTA - 407) & 511)])) + ((0.00247199927f * ((fVec5[((IOTA - 272) & 511)] - fVec5[((IOTA - 374) & 511)]) - fVec5[((IOTA - 405) & 511)])) + ((0.0025940733f * (fVec5[((IOTA - 235) & 511)] - fVec5[((IOTA - 403) & 511)])) + ((0.00213629566f * ((fVec5[((IOTA - 239) & 511)] + fVec5[((IOTA - 284) & 511)]) - fVec5[((IOTA - 401) & 511)])) + ((0.0022583697f * (fVec5[((IOTA - 223) & 511)] - fVec5[((IOTA - 399) & 511)])) + ((0.00277718436f * (fVec5[((IOTA - 232) & 511)] - fVec5[((IOTA - 398) & 511)])) + ((0.00372325815f * (fVec5[((IOTA - 173) & 511)] - fVec5[((IOTA - 397) & 511)])) + ((0.00619525742f * ((fVec5[((IOTA - 157) & 511)] + fVec5[((IOTA - 185) & 511)]) - fVec5[((IOTA - 395) & 511)])) + ((0.00119022187f * ((((fVec5[((IOTA - 203) & 511)] + fVec5[((IOTA - 282) & 511)]) + fVec5[((IOTA - 295) & 511)]) - fVec5[((IOTA - 350) & 511)]) + fVec5[((IOTA - 382) & 511)])) + ((0.00427259132f * (fVec5[((IOTA - 370) & 511)] - fVec5[((IOTA - 375) & 511)])) + ((0.00442518387f * fVec5[((IOTA - 371) & 511)]) + ((0.00262459181f * fVec5[((IOTA - 369) & 511)]) + ((0.00366222113f * (fVec5[((IOTA - 174) & 511)] - fVec5[((IOTA - 364) & 511)])) + ((0.00143436994f * ((((((fVec5[((IOTA - 204) & 511)] + fVec5[((IOTA - 206) & 511)]) - fVec5[((IOTA - 315) & 511)]) - fVec5[((IOTA - 316) & 511)]) - fVec5[((IOTA - 317) & 511)]) - fVec5[((IOTA - 318) & 511)]) - fVec5[((IOTA - 361) & 511)])) + ((0.00106814783f * ((fVec5[((IOTA - 140) & 511)] + fVec5[((IOTA - 296) & 511)]) - fVec5[((IOTA - 351) & 511)])) + ((0.000732444227f * (((fVec5[((IOTA - 202) & 511)] + fVec5[((IOTA - 243) & 511)]) - fVec5[((IOTA - 328) & 511)]) - fVec5[((IOTA - 348) & 511)])) + ((0.00122074038f * (fVec5[((IOTA - 294) & 511)] - fVec5[((IOTA - 341) & 511)])) + ((0.00134281442f * ((fVec5[((IOTA - 278) & 511)] - fVec5[((IOTA - 319) & 511)]) - fVec5[((IOTA - 340) & 511)])) + ((0.00137333293f * ((fVec5[((IOTA - 205) & 511)] - fVec5[((IOTA - 313) & 511)]) - fVec5[((IOTA - 339) & 511)])) + ((0.00109866634f * (fVec5[((IOTA - 207) & 511)] - fVec5[((IOTA - 337) & 511)])) + ((0.00219733268f * fVec5[((IOTA - 285) & 511)]) + ((0.00207525864f * ((fVec5[((IOTA - 237) & 511)] + fVec5[((IOTA - 238) & 511)]) + fVec5[((IOTA - 276) & 511)])) + ((0.00244148076f * fVec5[((IOTA - 274) & 511)]) + ((0.00253303628f * (fVec5[((IOTA - 217) & 511)] + fVec5[((IOTA - 273) & 511)])) + ((0.0019531846f * fVec5[((IOTA - 270) & 511)]) + ((0.00292977691f * fVec5[((IOTA - 234) & 511)]) + ((0.0028992584f * fVec5[((IOTA - 233) & 511)]) + ((0.00268562883f * fVec5[((IOTA - 231) & 511)]) + ((0.00296029542f * fVec5[((IOTA - 230) & 511)]) + ((0.00347911008f * fVec5[((IOTA - 229) & 511)]) + ((0.00378429517f * fVec5[((IOTA - 228) & 511)]) + ((0.00186162908f * (fVec5[((IOTA - 215) & 511)] + fVec5[((IOTA - 224) & 511)])) + ((0.00537125766f * fVec5[((IOTA - 221) & 511)]) + ((0.00601214636f * fVec5[((IOTA - 220) & 511)]) + ((0.00518814661f * fVec5[((IOTA - 219) & 511)]) + ((0.00311288796f * fVec5[((IOTA - 192) & 511)]) + ((0.00469985045f * (fVec5[((IOTA - 155) & 511)] + fVec5[((IOTA - 188) & 511)])) + ((0.00445570238f * fVec5[((IOTA - 187) & 511)]) + ((0.00491348002f * fVec5[((IOTA - 186) & 511)]) + ((0.00479140598f * fVec5[((IOTA - 190) & 511)]) + ((0.00827051606f * fVec5[((IOTA - 184) & 511)]) + ((0.0109866634f * fVec5[((IOTA - 183) & 511)]) + ((0.0124210333f * fVec5[((IOTA - 182) & 511)]) + ((0.0118106632f * fVec5[((IOTA - 181) & 511)]) + ((0.00924710836f * fVec5[((IOTA - 180) & 511)]) + ((0.00555436872f * (fVec5[((IOTA - 170) & 511)] + fVec5[((IOTA - 179) & 511)])) + ((0.00299081393f * fVec5[((IOTA - 178) & 511)]) + ((0.00280770287f * fVec5[((IOTA - 176) & 511)]) + ((0.00350962859f * fVec5[((IOTA - 175) & 511)]) + ((0.00344859157f * fVec5[((IOTA - 172) & 511)]) + ((0.00424207281f * fVec5[((IOTA - 171) & 511)]) + ((0.00802636798f * fVec5[((IOTA - 169) & 511)]) + ((0.00943021942f * fVec5[((IOTA - 168) & 511)]) + ((0.00994903408f * (fVec5[((IOTA - 152) & 511)] + fVec5[((IOTA - 167) & 511)])) + ((0.00759910885f * fVec5[((IOTA - 166) & 511)]) + ((0.00592059083f * fVec5[((IOTA - 165) & 511)]) + ((0.00250251777f * fVec5[((IOTA - 163) & 511)]) + ((0.00689718314f * fVec5[((IOTA - 156) & 511)]) + ((0.00466933195f * fVec5[((IOTA - 154) & 511)]) + ((0.00659199804f * fVec5[((IOTA - 153) & 511)]) + ((0.0117496261f * fVec5[((IOTA - 151) & 511)]) + ((0.0116885891f * fVec5[((IOTA - 150) & 511)]) + ((0.0083925901f * fVec5[((IOTA - 149) & 511)]) + ((0.00405896176f * fVec5[((IOTA - 148) & 511)]) + ((0.00408948027f * (fVec5[((IOTA - 142) & 511)] + fVec5[((IOTA - 147) & 511)])) + ((0.004852443f * fVec5[((IOTA - 189) & 511)]) + ((0.0101931822f * fVec5[((IOTA - 146) & 511)]) + ((0.0156559963f * fVec5[((IOTA - 145) & 511)]) + ((0.0156865139f * fVec5[((IOTA - 144) & 511)]) + ((0.0105594043f * fVec5[((IOTA - 143) & 511)]) + ((0.00198370311f * fVec5[((IOTA - 139) & 511)]) + ((0.00912503432f * fVec5[((IOTA - 131) & 511)]) + ((0.0247505121f * fVec5[((IOTA - 130) & 511)]) + ((0.0390636921f * fVec5[((IOTA - 129) & 511)]) + ((0.045289468f * fVec5[((IOTA - 128) & 511)]) + ((0.0405285805f * fVec5[((IOTA - 127) & 511)]) + ((0.0261238441f * fVec5[((IOTA - 126) & 511)]) + ((0.00436414685f * fVec5[((IOTA - 125) & 511)]) + ((0.0142521439f * (fVec5[((IOTA - 99) & 511)] - fVec5[((IOTA - 124) & 511)])) + ((0.0123294778f * fVec5[((IOTA - 120) & 511)]) + ((0.0236518458f * fVec5[((IOTA - 119) & 511)]) + ((0.0266121402f * fVec5[((IOTA - 118) & 511)]) + ((0.0275887325f * fVec5[((IOTA - 117) & 511)]) + ((0.0270393994f * fVec5[((IOTA - 116) & 511)]) + ((0.0195928831f * fVec5[((IOTA - 114) & 511)]) + ((0.0133060701f * fVec5[((IOTA - 113) & 511)]) + ((0.00531022064f * (fVec5[((IOTA - 61) & 511)] + fVec5[((IOTA - 112) & 511)])) + ((0.0121768853f * fVec5[((IOTA - 103) & 511)]) + ((0.0341807306f * fVec5[((IOTA - 102) & 511)]) + ((0.0408948027f * fVec5[((IOTA - 101) & 511)]) + ((0.0325632505f * fVec5[((IOTA - 100) & 511)]) + ((0.015991699f * fVec5[((IOTA - 94) & 511)]) + ((0.0314645842f * fVec5[((IOTA - 93) & 511)]) + ((0.0108645894f * (fVec5[((IOTA - 63) & 511)] + fVec5[((IOTA - 88) & 511)])) + ((0.017914366f * fVec5[((IOTA - 91) & 511)]) + ((0.0350962877f * fVec5[((IOTA - 92) & 511)]) + ((0.0382396914f * fVec5[((IOTA - 87) & 511)]) + ((0.0424512476f * fVec5[((IOTA - 86) & 511)]) + ((0.0508438386f * fVec5[((IOTA - 85) & 511)]) + ((0.0291451775f * fVec5[((IOTA - 84) & 511)]) + ((0.0140995514f * fVec5[((IOTA - 83) & 511)]) + ((0.0828272328f * fVec5[((IOTA - 77) & 511)]) + ((0.166753143f * fVec5[((IOTA - 76) & 511)]) + ((0.171575055f * fVec5[((IOTA - 75) & 511)]) + ((0.0925931558f * fVec5[((IOTA - 74) & 511)]) + ((0.00634784997f * fVec5[((IOTA - 65) & 511)]) + ((0.00863673817f * fVec5[((IOTA - 62) & 511)]) + (0.0103457747f * fVec5[((IOTA - 64) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000457777642f * ((((fVec5[((IOTA - 267) & 511)] - fVec5[((IOTA - 409) & 511)]) + fVec5[((IOTA - 495) & 511)]) - fVec5[((IOTA - 499) & 511)]) - fVec5[((IOTA - 511) & 511)])))) : (((0.00122074038f * ((((((fVec4[((IOTA - 243) & 511)] - fVec4[((IOTA - 248) & 511)]) - fVec4[((IOTA - 284) & 511)]) - fVec4[((IOTA - 431) & 511)]) + fVec4[((IOTA - 472) & 511)]) + fVec4[((IOTA - 488) & 511)]) + fVec4[((IOTA - 506) & 511)])) + ((0.00177007355f * ((((fVec4[((IOTA - 193) & 511)] - fVec4[((IOTA - 261) & 511)]) - fVec4[((IOTA - 317) & 511)]) + fVec4[((IOTA - 463) & 511)]) + fVec4[((IOTA - 501) & 511)])) + ((0.00103762932f * ((((fVec4[((IOTA - 185) & 511)] + fVec4[((IOTA - 208) & 511)]) - fVec4[((IOTA - 299) & 511)]) + fVec4[((IOTA - 456) & 511)]) + fVec4[((IOTA - 498) & 511)])) + ((0.000488296151f * (((((((((fVec4[((IOTA - 229) & 511)] - fVec4[((IOTA - 321) & 511)]) + fVec4[((IOTA - 332) & 511)]) - fVec4[((IOTA - 349) & 511)]) - fVec4[((IOTA - 369) & 511)]) - fVec4[((IOTA - 387) & 511)]) - fVec4[((IOTA - 469) & 511)]) + fVec4[((IOTA - 484) & 511)]) + fVec4[((IOTA - 491) & 511)]) + fVec4[((IOTA - 496) & 511)])) + ((0.000213629566f * (((((((((((((((fVec4[((IOTA - 80) & 511)] + fVec4[((IOTA - 81) & 511)]) + fVec4[((IOTA - 82) & 511)]) + fVec4[((IOTA - 83) & 511)]) + fVec4[((IOTA - 86) & 511)]) + fVec4[((IOTA - 87) & 511)]) - fVec4[((IOTA - 207) & 511)]) - fVec4[((IOTA - 280) & 511)]) - fVec4[((IOTA - 344) & 511)]) + fVec4[((IOTA - 346) & 511)]) - fVec4[((IOTA - 353) & 511)]) - fVec4[((IOTA - 361) & 511)]) - fVec4[((IOTA - 363) & 511)]) + fVec4[((IOTA - 365) & 511)]) + fVec4[((IOTA - 429) & 511)]) + fVec4[((IOTA - 495) & 511)])) + ((0.000152592547f * ((((((((((((((((((fVec4[((IOTA - 2) & 511)] + fVec4[((IOTA - 74) & 511)]) - fVec4[((IOTA - 237) & 511)]) + fVec4[((IOTA - 244) & 511)]) - fVec4[((IOTA - 281) & 511)]) - fVec4[((IOTA - 295) & 511)]) + fVec4[((IOTA - 331) & 511)]) + fVec4[((IOTA - 338) & 511)]) - fVec4[((IOTA - 339) & 511)]) + fVec4[((IOTA - 347) & 511)]) - fVec4[((IOTA - 348) & 511)]) - fVec4[((IOTA - 356) & 511)]) + fVec4[((IOTA - 358) & 511)]) + fVec4[((IOTA - 359) & 511)]) - fVec4[((IOTA - 368) & 511)]) - fVec4[((IOTA - 408) & 511)]) + fVec4[((IOTA - 418) & 511)]) + fVec4[((IOTA - 493) & 511)]) + fVec4[((IOTA - 494) & 511)])) + ((0.000274666585f * ((((((((((((((((((fVec4[((IOTA - 75) & 511)] + fVec4[((IOTA - 76) & 511)]) + fVec4[((IOTA - 77) & 511)]) + fVec4[((IOTA - 79) & 511)]) + fVec4[((IOTA - 85) & 511)]) - fVec4[((IOTA - 245) & 511)]) - fVec4[((IOTA - 246) & 511)]) - fVec4[((IOTA - 330) & 511)]) - fVec4[((IOTA - 354) & 511)]) - fVec4[((IOTA - 355) & 511)]) - fVec4[((IOTA - 362) & 511)]) + fVec4[((IOTA - 366) & 511)]) - fVec4[((IOTA - 375) & 511)]) - fVec4[((IOTA - 395) & 511)]) + fVec4[((IOTA - 451) & 511)]) - fVec4[((IOTA - 468) & 511)]) + fVec4[((IOTA - 471) & 511)]) - fVec4[((IOTA - 482) & 511)]) + fVec4[((IOTA - 492) & 511)])) + ((0.00100711081f * ((((((fVec4[((IOTA - 96) & 511)] - fVec4[((IOTA - 319) & 511)]) - fVec4[((IOTA - 386) & 511)]) + fVec4[((IOTA - 442) & 511)]) + fVec4[((IOTA - 448) & 511)]) - fVec4[((IOTA - 479) & 511)]) + fVec4[((IOTA - 489) & 511)])) + ((0.000122074038f * ((((((((((((((((((((fTemp5 + fVec4[((IOTA - 1) & 511)]) + fVec4[((IOTA - 3) & 511)]) + fVec4[((IOTA - 4) & 511)]) + fVec4[((IOTA - 5) & 511)]) + fVec4[((IOTA - 19) & 511)]) + fVec4[((IOTA - 20) & 511)]) + fVec4[((IOTA - 28) & 511)]) + fVec4[((IOTA - 29) & 511)]) + fVec4[((IOTA - 30) & 511)]) + fVec4[((IOTA - 31) & 511)]) + fVec4[((IOTA - 32) & 511)]) - fVec4[((IOTA - 38) & 511)]) + fVec4[((IOTA - 46) & 511)]) - fVec4[((IOTA - 68) & 511)]) + fVec4[((IOTA - 73) & 511)]) - fVec4[((IOTA - 177) & 511)]) + fVec4[((IOTA - 345) & 511)]) + fVec4[((IOTA - 367) & 511)]) + fVec4[((IOTA - 388) & 511)]) + fVec4[((IOTA - 483) & 511)])) + ((0.000671407208f * ((((fVec4[((IOTA - 209) & 511)] - fVec4[((IOTA - 320) & 511)]) - fVec4[((IOTA - 370) & 511)]) - fVec4[((IOTA - 371) & 511)]) - fVec4[((IOTA - 478) & 511)])) + ((0.00277718436f * (fVec4[((IOTA - 195) & 511)] + fVec4[((IOTA - 474) & 511)])) + ((0.00204474013f * ((fVec4[((IOTA - 174) & 511)] - fVec4[((IOTA - 260) & 511)]) + fVec4[((IOTA - 462) & 511)])) + ((0.000335703604f * ((((((((((((fVec4[((IOTA - 78) & 511)] + fVec4[((IOTA - 84) & 511)]) - fVec4[((IOTA - 282) & 511)]) - fVec4[((IOTA - 294) & 511)]) - fVec4[((IOTA - 296) & 511)]) + fVec4[((IOTA - 335) & 511)]) + fVec4[((IOTA - 337) & 511)]) - fVec4[((IOTA - 352) & 511)]) - fVec4[((IOTA - 374) & 511)]) - fVec4[((IOTA - 439) & 511)]) + fVec4[((IOTA - 440) & 511)]) + fVec4[((IOTA - 450) & 511)]) + fVec4[((IOTA - 452) & 511)])) + ((0.00314340647f * (fVec4[((IOTA - 424) & 511)] + fVec4[((IOTA - 425) & 511)])) + ((0.00280770287f * fVec4[((IOTA - 422) & 511)]) + ((0.0022583697f * (((fVec4[((IOTA - 128) & 511)] + fVec4[((IOTA - 189) & 511)]) + fVec4[((IOTA - 242) & 511)]) - fVec4[((IOTA - 413) & 511)])) + ((0.00247199927f * ((fVec4[((IOTA - 152) & 511)] - fVec4[((IOTA - 206) & 511)]) - fVec4[((IOTA - 276) & 511)])) + ((0.00292977691f * ((fVec4[((IOTA - 169) & 511)] + fVec4[((IOTA - 241) & 511)]) - fVec4[((IOTA - 250) & 511)])) + ((0.00271614734f * fVec4[((IOTA - 240) & 511)]) + ((0.00634784997f * (fVec4[((IOTA - 168) & 511)] - fVec4[((IOTA - 213) & 511)])) + ((0.00607318338f * (fVec4[((IOTA - 121) & 511)] - fVec4[((IOTA - 204) & 511)])) + ((0.00689718314f * (fVec4[((IOTA - 166) & 511)] - fVec4[((IOTA - 198) & 511)])) + ((0.00381481368f * fVec4[((IOTA - 194) & 511)]) + ((0.00680562761f * fVec4[((IOTA - 188) & 511)]) + ((0.00885036774f * (fVec4[((IOTA - 137) & 511)] + fVec4[((IOTA - 187) & 511)])) + ((0.00717184972f * fVec4[((IOTA - 186) & 511)]) + ((0.0120853297f * (fVec4[((IOTA - 142) & 511)] - fVec4[((IOTA - 183) & 511)])) + ((0.00695822015f * fVec4[((IOTA - 175) & 511)]) + ((0.00619525742f * fVec4[((IOTA - 167) & 511)]) + ((0.00668355357f * (fVec4[((IOTA - 111) & 511)] + fVec4[((IOTA - 165) & 511)])) + ((0.00762962736f * fVec4[((IOTA - 164) & 511)]) + ((0.00567644276f * fVec4[((IOTA - 163) & 511)]) + ((0.0147404401f * fVec4[((IOTA - 155) & 511)]) + ((0.0248115491f * fVec4[((IOTA - 154) & 511)]) + ((0.0189519953f * fVec4[((IOTA - 153) & 511)]) + ((0.0279549547f * fVec4[((IOTA - 141) & 511)]) + ((0.0280159917f * fVec4[((IOTA - 140) & 511)]) + ((0.0220954008f * fVec4[((IOTA - 139) & 511)]) + ((0.00857570115f * fVec4[((IOTA - 138) & 511)]) + ((0.00927762687f * fVec4[((IOTA - 136) & 511)]) + ((0.0141911069f * fVec4[((IOTA - 135) & 511)]) + ((0.0136417737f * fVec4[((IOTA - 134) & 511)]) + ((0.0318918414f * fVec4[((IOTA - 127) & 511)]) + ((0.0259712525f * fVec4[((IOTA - 126) & 511)]) + ((0.0111087374f * fVec4[((IOTA - 125) & 511)]) + ((0.00625629444f * fVec4[((IOTA - 112) & 511)]) + ((0.0301217698f * fVec4[((IOTA - 110) & 511)]) + ((0.0386059135f * fVec4[((IOTA - 109) & 511)]) + ((0.0203863643f * fVec4[((IOTA - 108) & 511)]) + ((0.0261848811f * fVec4[((IOTA - 103) & 511)]) + ((0.217749566f * fVec4[((IOTA - 102) & 511)]) + ((0.305825979f * fVec4[((IOTA - 101) & 511)]) + ((0.255195767f * fVec4[((IOTA - 100) & 511)]) + ((0.130893886f * fVec4[((IOTA - 99) & 511)]) + ((0.00714133121f * fVec4[((IOTA - 97) & 511)]) + (0.0381176174f * fVec4[((IOTA - 98) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))) - (((0.001617481f * ((((((((fVec4[((IOTA - 288) & 511)] + fVec4[((IOTA - 303) & 511)]) - fVec4[((IOTA - 393) & 511)]) - fVec4[((IOTA - 405) & 511)]) + fVec4[((IOTA - 411) & 511)]) + fVec4[((IOTA - 433) & 511)]) - fVec4[((IOTA - 445) & 511)]) - fVec4[((IOTA - 476) & 511)]) - fVec4[((IOTA - 510) & 511)])) + ((0.00155644398f * ((fVec4[((IOTA - 270) & 511)] + fVec4[((IOTA - 305) & 511)]) - fVec4[((IOTA - 509) & 511)])) + ((0.00149540696f * (((((fVec4[((IOTA - 230) & 511)] + fVec4[((IOTA - 286) & 511)]) + fVec4[((IOTA - 287) & 511)]) + fVec4[((IOTA - 432) & 511)]) - fVec4[((IOTA - 502) & 511)]) - fVec4[((IOTA - 508) & 511)])) + ((0.00131229591f * (((((((fVec4[((IOTA - 278) & 511)] + fVec4[((IOTA - 326) & 511)]) + fVec4[((IOTA - 382) & 511)]) - fVec4[((IOTA - 390) & 511)]) + fVec4[((IOTA - 410) & 511)]) - fVec4[((IOTA - 428) & 511)]) - fVec4[((IOTA - 464) & 511)]) - fVec4[((IOTA - 507) & 511)])) + ((0.00109866634f * (((((((fVec4[((IOTA - 300) & 511)] + fVec4[((IOTA - 325) & 511)]) + fVec4[((IOTA - 380) & 511)]) - fVec4[((IOTA - 419) & 511)]) + fVec4[((IOTA - 438) & 511)]) - fVec4[((IOTA - 486) & 511)]) - fVec4[((IOTA - 504) & 511)]) - fVec4[((IOTA - 505) & 511)])) + ((0.0012817774f * (((((fVec4[((IOTA - 307) & 511)] + fVec4[((IOTA - 381) & 511)]) + fVec4[((IOTA - 385) & 511)]) - fVec4[((IOTA - 404) & 511)]) - fVec4[((IOTA - 487) & 511)]) - fVec4[((IOTA - 503) & 511)])) + ((0.00164799951f * (((((((fVec4[((IOTA - 170) & 511)] - fVec4[((IOTA - 239) & 511)]) + fVec4[((IOTA - 304) & 511)]) + fVec4[((IOTA - 309) & 511)]) - fVec4[((IOTA - 391) & 511)]) + fVec4[((IOTA - 416) & 511)]) + fVec4[((IOTA - 437) & 511)]) - fVec4[((IOTA - 500) & 511)])) + ((0.00137333293f * (((((((((((fVec4[((IOTA - 210) & 511)] - fVec4[((IOTA - 228) & 511)]) + fVec4[((IOTA - 269) & 511)]) + fVec4[((IOTA - 285) & 511)]) + fVec4[((IOTA - 292) & 511)]) + fVec4[((IOTA - 306) & 511)]) + fVec4[((IOTA - 327) & 511)]) + fVec4[((IOTA - 384) & 511)]) - fVec4[((IOTA - 406) & 511)]) - fVec4[((IOTA - 444) & 511)]) - fVec4[((IOTA - 447) & 511)]) - fVec4[((IOTA - 499) & 511)])) + ((0.000732444227f * (((((((fVec4[((IOTA - 283) & 511)] + fVec4[((IOTA - 323) & 511)]) - fVec4[((IOTA - 403) & 511)]) - fVec4[((IOTA - 407) & 511)]) + fVec4[((IOTA - 430) & 511)]) - fVec4[((IOTA - 441) & 511)]) - fVec4[((IOTA - 455) & 511)]) - fVec4[((IOTA - 497) & 511)])) + ((0.000762962736f * ((((((fVec4[((IOTA - 226) & 511)] - fVec4[((IOTA - 227) & 511)]) + fVec4[((IOTA - 293) & 511)]) + fVec4[((IOTA - 378) & 511)]) - fVec4[((IOTA - 389) & 511)]) + fVec4[((IOTA - 417) & 511)]) - fVec4[((IOTA - 490) & 511)])) + ((0.000823999755f * (((((fVec4[((IOTA - 236) & 511)] + fVec4[((IOTA - 329) & 511)]) + fVec4[((IOTA - 341) & 511)]) + fVec4[((IOTA - 342) & 511)]) + fVec4[((IOTA - 409) & 511)]) - fVec4[((IOTA - 485) & 511)])) + ((0.00054933317f * (((((((((fVec4[((IOTA - 133) & 511)] + fVec4[((IOTA - 192) & 511)]) - fVec4[((IOTA - 238) & 511)]) + fVec4[((IOTA - 322) & 511)]) + fVec4[((IOTA - 340) & 511)]) + fVec4[((IOTA - 351) & 511)]) + fVec4[((IOTA - 372) & 511)]) - fVec4[((IOTA - 449) & 511)]) - fVec4[((IOTA - 454) & 511)]) + fVec4[((IOTA - 481) & 511)])) + ((0.000946073793f * ((((fVec4[((IOTA - 196) & 511)] + fVec4[((IOTA - 379) & 511)]) - fVec4[((IOTA - 394) & 511)]) + fVec4[((IOTA - 401) & 511)]) + fVec4[((IOTA - 480) & 511)])) + ((0.000396740623f * ((((((fVec4[((IOTA - 247) & 511)] - fVec4[((IOTA - 334) & 511)]) - fVec4[((IOTA - 336) & 511)]) + fVec4[((IOTA - 373) & 511)]) + fVec4[((IOTA - 376) & 511)]) + fVec4[((IOTA - 470) & 511)]) - fVec4[((IOTA - 477) & 511)])) + ((0.0025940733f * (fVec4[((IOTA - 225) & 511)] - fVec4[((IOTA - 475) & 511)])) + ((0.00216681417f * (fVec4[((IOTA - 272) & 511)] - fVec4[((IOTA - 473) & 511)])) + ((6.10370189e-05f * ((((((((((((((((((((((((((((((((fVec4[((IOTA - 22) & 511)] - ((((((((fVec4[((IOTA - 6) & 511)] + fVec4[((IOTA - 7) & 511)]) - fVec4[((IOTA - 10) & 511)]) - fVec4[((IOTA - 11) & 511)]) - fVec4[((IOTA - 12) & 511)]) - fVec4[((IOTA - 13) & 511)]) - fVec4[((IOTA - 14) & 511)]) + fVec4[((IOTA - 18) & 511)]) + fVec4[((IOTA - 21) & 511)])) + fVec4[((IOTA - 23) & 511)]) + fVec4[((IOTA - 24) & 511)]) + fVec4[((IOTA - 25) & 511)]) - fVec4[((IOTA - 27) & 511)]) - fVec4[((IOTA - 33) & 511)]) + fVec4[((IOTA - 35) & 511)]) + fVec4[((IOTA - 36) & 511)]) + fVec4[((IOTA - 37) & 511)]) + fVec4[((IOTA - 39) & 511)]) + fVec4[((IOTA - 40) & 511)]) - fVec4[((IOTA - 43) & 511)]) - fVec4[((IOTA - 44) & 511)]) - fVec4[((IOTA - 45) & 511)]) + fVec4[((IOTA - 50) & 511)]) - fVec4[((IOTA - 53) & 511)]) + fVec4[((IOTA - 57) & 511)]) + fVec4[((IOTA - 59) & 511)]) + fVec4[((IOTA - 61) & 511)]) + fVec4[((IOTA - 62) & 511)]) + fVec4[((IOTA - 63) & 511)]) + fVec4[((IOTA - 64) & 511)]) + fVec4[((IOTA - 65) & 511)]) + fVec4[((IOTA - 66) & 511)]) + fVec4[((IOTA - 67) & 511)]) + fVec4[((IOTA - 70) & 511)]) + fVec4[((IOTA - 88) & 511)]) - fVec4[((IOTA - 357) & 511)]) + fVec4[((IOTA - 360) & 511)]) + fVec4[((IOTA - 364) & 511)]) + fVec4[((IOTA - 402) & 511)]) - fVec4[((IOTA - 467) & 511)])) + ((0.000427259132f * (((fVec4[((IOTA - 162) & 511)] - fVec4[((IOTA - 333) & 511)]) - fVec4[((IOTA - 453) & 511)]) - fVec4[((IOTA - 466) & 511)])) + ((0.000885036774f * (((fVec4[((IOTA - 190) & 511)] + fVec4[((IOTA - 298) & 511)]) + fVec4[((IOTA - 324) & 511)]) - fVec4[((IOTA - 465) & 511)])) + ((0.00210577715f * ((((fVec4[((IOTA - 263) & 511)] + fVec4[((IOTA - 264) & 511)]) + fVec4[((IOTA - 265) & 511)]) - fVec4[((IOTA - 459) & 511)]) - fVec4[((IOTA - 461) & 511)])) + ((0.00219733268f * (((((fVec4[((IOTA - 249) & 511)] + fVec4[((IOTA - 273) & 511)]) + fVec4[((IOTA - 311) & 511)]) + fVec4[((IOTA - 312) & 511)]) + fVec4[((IOTA - 415) & 511)]) - fVec4[((IOTA - 460) & 511)])) + ((0.00183111057f * (((((fVec4[((IOTA - 271) & 511)] + fVec4[((IOTA - 289) & 511)]) - fVec4[((IOTA - 392) & 511)]) + fVec4[((IOTA - 396) & 511)]) - fVec4[((IOTA - 420) & 511)]) - fVec4[((IOTA - 458) & 511)])) + ((0.00143436994f * (((((fVec4[((IOTA - 268) & 511)] + fVec4[((IOTA - 302) & 511)]) + fVec4[((IOTA - 308) & 511)]) + fVec4[((IOTA - 318) & 511)]) + fVec4[((IOTA - 383) & 511)]) - fVec4[((IOTA - 457) & 511)])) + ((0.00115970336f * ((fVec4[((IOTA - 301) & 511)] + fVec4[((IOTA - 328) & 511)]) - fVec4[((IOTA - 443) & 511)])) + ((0.0019226661f * (((((fVec4[((IOTA - 235) & 511)] + fVec4[((IOTA - 266) & 511)]) + fVec4[((IOTA - 314) & 511)]) + fVec4[((IOTA - 316) & 511)]) + fVec4[((IOTA - 412) & 511)]) + fVec4[((IOTA - 436) & 511)])) + ((0.00189214759f * (((fVec4[((IOTA - 262) & 511)] + fVec4[((IOTA - 290) & 511)]) + fVec4[((IOTA - 315) & 511)]) + fVec4[((IOTA - 435) & 511)])) + ((0.00231940672f * (fVec4[((IOTA - 90) & 511)] - fVec4[((IOTA - 427) & 511)])) + ((0.00299081393f * (fVec4[((IOTA - 399) & 511)] - fVec4[((IOTA - 426) & 511)])) + ((0.00305185094f * (fVec4[((IOTA - 259) & 511)] - fVec4[((IOTA - 423) & 511)])) + ((0.00238044374f * ((fVec4[((IOTA - 274) & 511)] + fVec4[((IOTA - 414) & 511)]) - fVec4[((IOTA - 421) & 511)])) + ((0.00198370311f * ((((fVec4[((IOTA - 191) & 511)] + fVec4[((IOTA - 277) & 511)]) + fVec4[((IOTA - 310) & 511)]) + fVec4[((IOTA - 313) & 511)]) + fVec4[((IOTA - 400) & 511)])) + ((0.00347911008f * (fVec4[((IOTA - 231) & 511)] + fVec4[((IOTA - 398) & 511)])) + ((0.00308236945f * fVec4[((IOTA - 397) & 511)]) + ((0.000610370189f * (((((fVec4[((IOTA - 89) & 511)] + fVec4[((IOTA - 279) & 511)]) + fVec4[((IOTA - 297) & 511)]) + fVec4[((IOTA - 343) & 511)]) + fVec4[((IOTA - 350) & 511)]) + fVec4[((IOTA - 377) & 511)])) + ((0.00253303628f * fVec4[((IOTA - 275) & 511)]) + ((0.00436414685f * fVec4[((IOTA - 258) & 511)]) + ((0.00518814661f * (fVec4[((IOTA - 256) & 511)] + fVec4[((IOTA - 257) & 511)])) + ((0.0045167394f * fVec4[((IOTA - 255) & 511)]) + ((0.00402844325f * fVec4[((IOTA - 254) & 511)]) + ((0.00369273964f * fVec4[((IOTA - 253) & 511)]) + ((0.0035401471f * fVec4[((IOTA - 252) & 511)]) + ((0.00335703604f * fVec4[((IOTA - 251) & 511)]) + ((0.00363170262f * fVec4[((IOTA - 234) & 511)]) + ((0.00476088747f * (fVec4[((IOTA - 221) & 511)] + fVec4[((IOTA - 233) & 511)])) + ((0.00491348002f * (fVec4[((IOTA - 215) & 511)] + fVec4[((IOTA - 232) & 511)])) + ((0.00408948027f * fVec4[((IOTA - 224) & 511)]) + ((0.00497451704f * fVec4[((IOTA - 223) & 511)]) + ((0.004852443f * fVec4[((IOTA - 222) & 511)]) + ((0.00537125766f * fVec4[((IOTA - 220) & 511)]) + ((0.00546281319f * fVec4[((IOTA - 219) & 511)]) + ((0.00524918362f * fVec4[((IOTA - 218) & 511)]) + ((0.00482192449f * (fVec4[((IOTA - 197) & 511)] + fVec4[((IOTA - 217) & 511)])) + ((0.00415051728f * fVec4[((IOTA - 216) & 511)]) + ((0.00585955381f * fVec4[((IOTA - 214) & 511)]) + ((0.00564592425f * fVec4[((IOTA - 212) & 511)]) + ((0.0038758507f * fVec4[((IOTA - 211) & 511)]) + ((0.00463881344f * fVec4[((IOTA - 205) & 511)]) + ((0.00628681295f * fVec4[((IOTA - 203) & 511)]) + ((0.00683614612f * fVec4[((IOTA - 202) & 511)]) + ((0.00674459059f * (fVec4[((IOTA - 184) & 511)] + fVec4[((IOTA - 201) & 511)])) + ((0.00708029419f * fVec4[((IOTA - 199) & 511)]) + ((0.00735496078f * fVec4[((IOTA - 200) & 511)]) + ((0.0122074038f * fVec4[((IOTA - 182) & 511)]) + ((0.0110477004f * fVec4[((IOTA - 181) & 511)]) + ((0.01126133f * fVec4[((IOTA - 180) & 511)]) + ((0.011444441f * fVec4[((IOTA - 179) & 511)]) + ((0.00830103457f * fVec4[((IOTA - 178) & 511)]) + ((0.00601214636f * ((fVec4[((IOTA - 114) & 511)] + fVec4[((IOTA - 171) & 511)]) - fVec4[((IOTA - 176) & 511)])) + ((0.00360118411f * fVec4[((IOTA - 173) & 511)]) + ((0.00701925717f * (fVec4[((IOTA - 156) & 511)] + fVec4[((IOTA - 172) & 511)])) + ((0.0109256264f * fVec4[((IOTA - 161) & 511)]) + ((0.025696585f * fVec4[((IOTA - 160) & 511)]) + ((0.0371410251f * fVec4[((IOTA - 159) & 511)]) + ((0.0392773226f * fVec4[((IOTA - 158) & 511)]) + ((0.027558215f * fVec4[((IOTA - 157) & 511)]) + ((0.0149235511f * fVec4[((IOTA - 151) & 511)]) + ((0.0221564379f * fVec4[((IOTA - 150) & 511)]) + ((0.0231025126f * fVec4[((IOTA - 149) & 511)]) + ((0.0209356975f * fVec4[((IOTA - 148) & 511)]) + ((0.0265816227f * (fVec4[((IOTA - 129) & 511)] + fVec4[((IOTA - 147) & 511)])) + ((0.0343638435f * fVec4[((IOTA - 146) & 511)]) + ((0.0384533219f * fVec4[((IOTA - 145) & 511)]) + ((0.0301522873f * fVec4[((IOTA - 144) & 511)]) + ((0.0104373302f * fVec4[((IOTA - 143) & 511)]) + ((0.0214239936f * fVec4[((IOTA - 132) & 511)]) + ((0.0431531742f * fVec4[((IOTA - 131) & 511)]) + ((0.0454115421f * fVec4[((IOTA - 130) & 511)]) + ((0.016296884f * fVec4[((IOTA - 124) & 511)]) + ((0.0126651814f * fVec4[((IOTA - 123) & 511)]) + ((0.0115359966f * fVec4[((IOTA - 122) & 511)]) + ((0.00442518387f * fVec4[((IOTA - 120) & 511)]) + ((0.0163579211f * fVec4[((IOTA - 119) & 511)]) + ((0.0274666585f * fVec4[((IOTA - 118) & 511)]) + ((0.0397351012f * fVec4[((IOTA - 117) & 511)]) + ((0.0234382153f * fVec4[((IOTA - 116) & 511)]) + ((0.0296639912f * fVec4[((IOTA - 115) & 511)]) + ((0.0160222184f * fVec4[((IOTA - 113) & 511)]) + ((0.0342112482f * fVec4[((IOTA - 107) & 511)]) + ((0.137119666f * fVec4[((IOTA - 106) & 511)]) + ((0.186956391f * fVec4[((IOTA - 105) & 511)]) + ((0.14529863f * fVec4[((IOTA - 104) & 511)]) + ((0.0057985168f * fVec4[((IOTA - 95) & 511)]) + ((0.0102847377f * fVec4[((IOTA - 94) & 511)]) + ((0.011383404f * fVec4[((IOTA - 93) & 511)]) + ((0.00540177617f * fVec4[((IOTA - 91) & 511)]) + (0.00906399731f * fVec4[((IOTA - 92) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00170903653f * ((((fVec4[((IOTA - 267) & 511)] + fVec4[((IOTA - 291) & 511)]) + fVec4[((IOTA - 434) & 511)]) - fVec4[((IOTA - 446) & 511)]) - fVec4[((IOTA - 511) & 511)])))))) : (iSlow5 ? (iSlow13 ? ((((0.00125125889f * (((((((((fVec3[((IOTA - 263) & 511)] + fVec3[((IOTA - 267) & 511)]) + fVec3[((IOTA - 304) & 511)]) + fVec3[((IOTA - 308) & 511)]) + fVec3[((IOTA - 338) & 511)]) + fVec3[((IOTA - 342) & 511)]) + fVec3[((IOTA - 364) & 511)]) - fVec3[((IOTA - 416) & 511)]) - fVec3[((IOTA - 468) & 511)]) - fVec3[((IOTA - 507) & 511)])) + ((0.00131229591f * (((((((((((fVec3[((IOTA - 147) & 511)] + fVec3[((IOTA - 243) & 511)]) + fVec3[((IOTA - 248) & 511)]) + fVec3[((IOTA - 268) & 511)]) + fVec3[((IOTA - 311) & 511)]) + fVec3[((IOTA - 341) & 511)]) + fVec3[((IOTA - 343) & 511)]) + fVec3[((IOTA - 356) & 511)]) + fVec3[((IOTA - 386) & 511)]) - fVec3[((IOTA - 460) & 511)]) - fVec3[((IOTA - 504) & 511)]) - fVec3[((IOTA - 506) & 511)])) + ((0.00146488845f * (((((((((((((((fVec3[((IOTA - 59) & 511)] - fVec3[((IOTA - 196) & 511)]) + fVec3[((IOTA - 233) & 511)]) + fVec3[((IOTA - 236) & 511)]) + fVec3[((IOTA - 269) & 511)]) + fVec3[((IOTA - 272) & 511)]) + fVec3[((IOTA - 294) & 511)]) + fVec3[((IOTA - 299) & 511)]) + fVec3[((IOTA - 305) & 511)]) + fVec3[((IOTA - 306) & 511)]) + fVec3[((IOTA - 318) & 511)]) + fVec3[((IOTA - 331) & 511)]) + fVec3[((IOTA - 344) & 511)]) + fVec3[((IOTA - 405) & 511)]) - fVec3[((IOTA - 422) & 511)]) - fVec3[((IOTA - 505) & 511)])) + ((0.00103762932f * ((((((((((((fVec3[((IOTA - 215) & 511)] + fVec3[((IOTA - 230) & 511)]) + fVec3[((IOTA - 266) & 511)]) + fVec3[((IOTA - 276) & 511)]) + fVec3[((IOTA - 300) & 511)]) + fVec3[((IOTA - 324) & 511)]) + fVec3[((IOTA - 377) & 511)]) - fVec3[((IOTA - 389) & 511)]) + fVec3[((IOTA - 403) & 511)]) + fVec3[((IOTA - 408) & 511)]) - fVec3[((IOTA - 462) & 511)]) - fVec3[((IOTA - 467) & 511)]) - fVec3[((IOTA - 503) & 511)])) + ((0.00054933317f * (((((((((((fVec3[((IOTA - 136) & 511)] + fVec3[((IOTA - 163) & 511)]) + fVec3[((IOTA - 241) & 511)]) + fVec3[((IOTA - 249) & 511)]) + fVec3[((IOTA - 314) & 511)]) + fVec3[((IOTA - 329) & 511)]) + fVec3[((IOTA - 363) & 511)]) + fVec3[((IOTA - 387) & 511)]) - fVec3[((IOTA - 418) & 511)]) - fVec3[((IOTA - 419) & 511)]) + fVec3[((IOTA - 449) & 511)]) - fVec3[((IOTA - 501) & 511)])) + ((0.000610370189f * ((((((((fVec3[((IOTA - 176) & 511)] + fVec3[((IOTA - 242) & 511)]) + fVec3[((IOTA - 256) & 511)]) + fVec3[((IOTA - 302) & 511)]) - fVec3[((IOTA - 447) & 511)]) - fVec3[((IOTA - 452) & 511)]) - fVec3[((IOTA - 490) & 511)]) - fVec3[((IOTA - 491) & 511)]) - fVec3[((IOTA - 500) & 511)])) + ((0.000701925717f * ((((((((fVec3[((IOTA - 232) & 511)] + fVec3[((IOTA - 301) & 511)]) - fVec3[((IOTA - 375) & 511)]) - fVec3[((IOTA - 439) & 511)]) - fVec3[((IOTA - 453) & 511)]) - fVec3[((IOTA - 454) & 511)]) - fVec3[((IOTA - 489) & 511)]) - fVec3[((IOTA - 495) & 511)]) - fVec3[((IOTA - 499) & 511)])) + ((0.000488296151f * ((((((fVec3[((IOTA - 195) & 511)] + fVec3[((IOTA - 257) & 511)]) + fVec3[((IOTA - 316) & 511)]) + fVec3[((IOTA - 327) & 511)]) + fVec3[((IOTA - 358) & 511)]) - fVec3[((IOTA - 373) & 511)]) - fVec3[((IOTA - 494) & 511)])) + ((0.00152592547f * ((((((((((fVec3[((IOTA - 235) & 511)] + fVec3[((IOTA - 270) & 511)]) + fVec3[((IOTA - 292) & 511)]) + fVec3[((IOTA - 293) & 511)]) + fVec3[((IOTA - 295) & 511)]) + fVec3[((IOTA - 334) & 511)]) - fVec3[((IOTA - 390) & 511)]) - fVec3[((IOTA - 411) & 511)]) - fVec3[((IOTA - 415) & 511)]) - fVec3[((IOTA - 469) & 511)]) - fVec3[((IOTA - 486) & 511)])) + ((0.0019531846f * (((((((((fVec3[((IOTA - 206) & 511)] - fVec3[((IOTA - 211) & 511)]) + fVec3[((IOTA - 238) & 511)]) + fVec3[((IOTA - 262) & 511)]) + fVec3[((IOTA - 278) & 511)]) + fVec3[((IOTA - 350) & 511)]) - fVec3[((IOTA - 427) & 511)]) - fVec3[((IOTA - 472) & 511)]) - fVec3[((IOTA - 484) & 511)]) - fVec3[((IOTA - 485) & 511)])) + ((0.00186162908f * ((((((((((((fVec3[((IOTA - 205) & 511)] - fVec3[((IOTA - 212) & 511)]) + fVec3[((IOTA - 254) & 511)]) + fVec3[((IOTA - 284) & 511)]) + fVec3[((IOTA - 355) & 511)]) + fVec3[((IOTA - 369) & 511)]) - fVec3[((IOTA - 391) & 511)]) - fVec3[((IOTA - 412) & 511)]) - fVec3[((IOTA - 413) & 511)]) - fVec3[((IOTA - 426) & 511)]) - fVec3[((IOTA - 433) & 511)]) - fVec3[((IOTA - 476) & 511)]) - fVec3[((IOTA - 483) & 511)])) + ((0.00167851802f * (((((((((((fVec3[((IOTA - 319) & 511)] + fVec3[((IOTA - 345) & 511)]) + fVec3[((IOTA - 347) & 511)]) + fVec3[((IOTA - 407) & 511)]) - fVec3[((IOTA - 423) & 511)]) - fVec3[((IOTA - 424) & 511)]) - fVec3[((IOTA - 434) & 511)]) - fVec3[((IOTA - 442) & 511)]) - fVec3[((IOTA - 474) & 511)]) - fVec3[((IOTA - 475) & 511)]) - fVec3[((IOTA - 481) & 511)]) - fVec3[((IOTA - 482) & 511)])) + ((0.00173955504f * (((((((((((((fVec3[((IOTA - 144) & 511)] + fVec3[((IOTA - 239) & 511)]) + fVec3[((IOTA - 252) & 511)]) + fVec3[((IOTA - 283) & 511)]) + fVec3[((IOTA - 291) & 511)]) + fVec3[((IOTA - 298) & 511)]) + fVec3[((IOTA - 332) & 511)]) + fVec3[((IOTA - 346) & 511)]) + fVec3[((IOTA - 348) & 511)]) - fVec3[((IOTA - 397) & 511)]) + fVec3[((IOTA - 406) & 511)]) - fVec3[((IOTA - 414) & 511)]) - fVec3[((IOTA - 473) & 511)]) - fVec3[((IOTA - 480) & 511)])) + ((0.00207525864f * ((((fVec3[((IOTA - 208) & 511)] + fVec3[((IOTA - 253) & 511)]) - fVec3[((IOTA - 393) & 511)]) - fVec3[((IOTA - 477) & 511)]) - fVec3[((IOTA - 478) & 511)])) + ((0.00180059206f * (((((((((((fVec3[((IOTA - 141) & 511)] - fVec3[((IOTA - 155) & 511)]) + fVec3[((IOTA - 216) & 511)]) + fVec3[((IOTA - 234) & 511)]) + fVec3[((IOTA - 282) & 511)]) + fVec3[((IOTA - 297) & 511)]) + fVec3[((IOTA - 333) & 511)]) + fVec3[((IOTA - 349) & 511)]) + fVec3[((IOTA - 385) & 511)]) - fVec3[((IOTA - 425) & 511)]) - fVec3[((IOTA - 446) & 511)]) - fVec3[((IOTA - 470) & 511)])) + ((0.00158696249f * ((((((fVec3[((IOTA - 237) & 511)] + fVec3[((IOTA - 259) & 511)]) + fVec3[((IOTA - 271) & 511)]) + fVec3[((IOTA - 296) & 511)]) + fVec3[((IOTA - 320) & 511)]) - fVec3[((IOTA - 458) & 511)]) - fVec3[((IOTA - 459) & 511)])) + ((0.00137333293f * (((((((fVec3[((IOTA - 135) & 511)] + fVec3[((IOTA - 273) & 511)]) + fVec3[((IOTA - 277) & 511)]) + fVec3[((IOTA - 307) & 511)]) + fVec3[((IOTA - 339) & 511)]) + fVec3[((IOTA - 340) & 511)]) - fVec3[((IOTA - 435) & 511)]) - fVec3[((IOTA - 457) & 511)])) + ((0.00271614734f * ((((fVec3[((IOTA - 204) & 511)] + fVec3[((IOTA - 245) & 511)]) + fVec3[((IOTA - 286) & 511)]) + fVec3[((IOTA - 288) & 511)]) - fVec3[((IOTA - 444) & 511)])) + ((0.00228888821f * ((((((((((fVec3[((IOTA - 160) & 511)] + fVec3[((IOTA - 162) & 511)]) + fVec3[((IOTA - 247) & 511)]) + fVec3[((IOTA - 279) & 511)]) + fVec3[((IOTA - 353) & 511)]) + fVec3[((IOTA - 365) & 511)]) - fVec3[((IOTA - 394) & 511)]) - fVec3[((IOTA - 396) & 511)]) - fVec3[((IOTA - 429) & 511)]) - fVec3[((IOTA - 430) & 511)]) - fVec3[((IOTA - 443) & 511)])) + ((0.000762962736f * ((((((((fVec3[((IOTA - 209) & 511)] + fVec3[((IOTA - 326) & 511)]) + fVec3[((IOTA - 370) & 511)]) - fVec3[((IOTA - 374) & 511)]) - fVec3[((IOTA - 398) & 511)]) - fVec3[((IOTA - 417) & 511)]) - fVec3[((IOTA - 420) & 511)]) - fVec3[((IOTA - 438) & 511)]) - fVec3[((IOTA - 440) & 511)])) + ((0.00244148076f * (fVec3[((IOTA - 379) & 511)] - fVec3[((IOTA - 395) & 511)])) + ((0.00234992523f * (((fVec3[((IOTA - 280) & 511)] + fVec3[((IOTA - 285) & 511)]) + fVec3[((IOTA - 289) & 511)]) + fVec3[((IOTA - 381) & 511)])) + ((0.00250251777f * (fVec3[((IOTA - 207) & 511)] + fVec3[((IOTA - 380) & 511)])) + ((0.00305185094f * fVec3[((IOTA - 368) & 511)]) + ((0.00332651753f * ((fVec3[((IOTA - 178) & 511)] + fVec3[((IOTA - 228) & 511)]) + fVec3[((IOTA - 366) & 511)])) + ((0.000213629566f * ((fVec3[((IOTA - 58) & 511)] - (fVec3[((IOTA - 54) & 511)] + fVec3[((IOTA - 55) & 511)])) + fVec3[((IOTA - 362) & 511)])) + ((0.00283822138f * (((fVec3[((IOTA - 174) & 511)] + fVec3[((IOTA - 186) & 511)]) + fVec3[((IOTA - 194) & 511)]) + fVec3[((IOTA - 287) & 511)])) + ((0.00277718436f * fVec3[((IOTA - 246) & 511)]) + ((0.00360118411f * ((fVec3[((IOTA - 202) & 511)] + fVec3[((IOTA - 203) & 511)]) + fVec3[((IOTA - 227) & 511)])) + ((0.00408948027f * (fVec3[((IOTA - 218) & 511)] + fVec3[((IOTA - 226) & 511)])) + ((0.00424207281f * fVec3[((IOTA - 225) & 511)]) + ((0.00375377666f * ((fVec3[((IOTA - 185) & 511)] + fVec3[((IOTA - 187) & 511)]) + fVec3[((IOTA - 223) & 511)])) + ((0.00347911008f * fVec3[((IOTA - 222) & 511)]) + ((0.00457777642f * (fVec3[((IOTA - 184) & 511)] + fVec3[((IOTA - 219) & 511)])) + ((0.00299081393f * fVec3[((IOTA - 217) & 511)]) + ((0.00381481368f * (fVec3[((IOTA - 142) & 511)] + fVec3[((IOTA - 193) & 511)])) + ((0.00500503555f * (fVec3[((IOTA - 179) & 511)] + fVec3[((IOTA - 192) & 511)])) + ((0.00512710959f * fVec3[((IOTA - 191) & 511)]) + ((0.00637836847f * (fVec3[((IOTA - 172) & 511)] + fVec3[((IOTA - 190) & 511)])) + ((0.00595110934f * ((fVec3[((IOTA - 130) & 511)] + fVec3[((IOTA - 183) & 511)]) + fVec3[((IOTA - 189) & 511)])) + ((0.00622577593f * (fVec3[((IOTA - 64) & 511)] + fVec3[((IOTA - 181) & 511)])) + ((0.00518814661f * fVec3[((IOTA - 180) & 511)]) + ((0.00463881344f * fVec3[((IOTA - 173) & 511)]) + ((0.00576799829f * fVec3[((IOTA - 171) & 511)]) + ((0.00665303506f * fVec3[((IOTA - 170) & 511)]) + ((0.00708029419f * (fVec3[((IOTA - 108) & 511)] + fVec3[((IOTA - 169) & 511)])) + ((0.00860621966f * fVec3[((IOTA - 168) & 511)]) + ((0.0038758507f * fVec3[((IOTA - 161) & 511)]) + ((0.0111697745f * (fVec3[((IOTA - 151) & 511)] - fVec3[((IOTA - 156) & 511)])) + ((0.00845362712f * fVec3[((IOTA - 154) & 511)]) + ((0.014618366f * fVec3[((IOTA - 153) & 511)]) + ((0.0132450331f * fVec3[((IOTA - 152) & 511)]) + ((0.0118411817f * fVec3[((IOTA - 150) & 511)]) + ((0.0125431074f * fVec3[((IOTA - 149) & 511)]) + ((0.00866725668f * fVec3[((IOTA - 148) & 511)]) + ((0.0195623655f * fVec3[((IOTA - 129) & 511)]) + ((0.0313425101f * fVec3[((IOTA - 128) & 511)]) + ((0.0361949541f * fVec3[((IOTA - 127) & 511)]) + ((0.0257271044f * fVec3[((IOTA - 126) & 511)]) + ((0.00720236823f * fVec3[((IOTA - 125) & 511)]) + ((0.0112918485f * fVec3[((IOTA - 120) & 511)]) + ((0.0231635496f * fVec3[((IOTA - 119) & 511)]) + ((0.0262764376f * fVec3[((IOTA - 118) & 511)]) + ((0.0284127332f * fVec3[((IOTA - 117) & 511)]) + ((0.0339060649f * fVec3[((IOTA - 116) & 511)]) + ((0.035828732f * fVec3[((IOTA - 115) & 511)]) + ((0.0296639912f * fVec3[((IOTA - 114) & 511)]) + ((0.00698873866f * fVec3[((IOTA - 113) & 511)]) + ((0.0119327372f * (fVec3[((IOTA - 107) & 511)] - fVec3[((IOTA - 109) & 511)])) + ((0.0272530299f * fVec3[((IOTA - 101) & 511)]) + ((0.0656453148f * fVec3[((IOTA - 100) & 511)]) + ((0.0571306497f * fVec3[((IOTA - 99) & 511)]) + ((0.0251777712f * fVec3[((IOTA - 98) & 511)]) + ((0.042298656f * fVec3[((IOTA - 93) & 511)]) + ((0.0433362834f * fVec3[((IOTA - 92) & 511)]) + ((0.0438245796f * fVec3[((IOTA - 91) & 511)]) + ((0.00796533097f * fVec3[((IOTA - 89) & 511)]) + ((0.0106814783f * fVec3[((IOTA - 85) & 511)]) + ((0.0221869573f * fVec3[((IOTA - 84) & 511)]) + ((0.027802363f * fVec3[((IOTA - 83) & 511)]) + ((0.0435499139f * fVec3[((IOTA - 82) & 511)]) + ((0.0217596982f * fVec3[((IOTA - 81) & 511)]) + ((0.0221259203f * fVec3[((IOTA - 80) & 511)]) + ((0.0219733268f * fVec3[((IOTA - 76) & 511)]) + ((0.142887667f * fVec3[((IOTA - 75) & 511)]) + ((0.205755785f * fVec3[((IOTA - 74) & 511)]) + ((0.139683217f * fVec3[((IOTA - 73) & 511)]) + ((0.0074159978f * fVec3[((IOTA - 61) & 511)]) + ((0.00985747855f * fVec3[((IOTA - 63) & 511)]) + ((0.00415051728f * fVec3[((IOTA - 60) & 511)]) + (0.0101931822f * fVec3[((IOTA - 62) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00119022187f * ((((((((((((((fVec3[((IOTA - 240) & 511)] + fVec3[((IOTA - 255) & 511)]) + fVec3[((IOTA - 274) & 511)]) + fVec3[((IOTA - 309) & 511)]) + fVec3[((IOTA - 310) & 511)]) + fVec3[((IOTA - 312) & 511)]) + fVec3[((IOTA - 321) & 511)]) + fVec3[((IOTA - 335) & 511)]) + fVec3[((IOTA - 402) & 511)]) + fVec3[((IOTA - 404) & 511)]) - fVec3[((IOTA - 436) & 511)]) - fVec3[((IOTA - 461) & 511)]) - fVec3[((IOTA - 487) & 511)]) - fVec3[((IOTA - 508) & 511)]) - fVec3[((IOTA - 511) & 511)]))) - (((0.000823999755f * ((((((fVec3[((IOTA - 90) & 511)] - fVec3[((IOTA - 251) & 511)]) - fVec3[((IOTA - 265) & 511)]) - fVec3[((IOTA - 357) & 511)]) - fVec3[((IOTA - 400) & 511)]) + fVec3[((IOTA - 455) & 511)]) + fVec3[((IOTA - 502) & 511)])) + ((0.000976592302f * ((((fVec3[((IOTA - 464) & 511)] - ((((((((fVec3[((IOTA - 175) & 511)] + fVec3[((IOTA - 258) & 511)]) + fVec3[((IOTA - 317) & 511)]) + fVec3[((IOTA - 325) & 511)]) + fVec3[((IOTA - 330) & 511)]) + fVec3[((IOTA - 336) & 511)]) - fVec3[((IOTA - 410) & 511)]) - fVec3[((IOTA - 437) & 511)]) - fVec3[((IOTA - 463) & 511)])) + fVec3[((IOTA - 466) & 511)]) + fVec3[((IOTA - 497) & 511)]) + fVec3[((IOTA - 498) & 511)])) + ((0.000915555283f * ((((((((((fVec3[((IOTA - 145) & 511)] + fVec3[((IOTA - 164) & 511)]) + fVec3[((IOTA - 213) & 511)]) - fVec3[((IOTA - 264) & 511)]) - fVec3[((IOTA - 303) & 511)]) - fVec3[((IOTA - 313) & 511)]) - fVec3[((IOTA - 322) & 511)]) - fVec3[((IOTA - 323) & 511)]) + fVec3[((IOTA - 465) & 511)]) + fVec3[((IOTA - 488) & 511)]) + fVec3[((IOTA - 496) & 511)])) + ((0.00201422162f * ((((((((fVec3[((IOTA - 106) & 511)] - fVec3[((IOTA - 177) & 511)]) - fVec3[((IOTA - 290) & 511)]) - fVec3[((IOTA - 378) & 511)]) - fVec3[((IOTA - 384) & 511)]) + fVec3[((IOTA - 392) & 511)]) + fVec3[((IOTA - 432) & 511)]) + fVec3[((IOTA - 471) & 511)]) + fVec3[((IOTA - 479) & 511)])) + (((0.000335703604f * ((fVec3[((IOTA - 65) & 511)] - fVec3[((IOTA - 250) & 511)]) + fVec3[((IOTA - 451) & 511)])) + ((0.000274666585f * ((fVec3[((IOTA - 388) & 511)] - fVec3[((IOTA - 448) & 511)]) - fVec3[((IOTA - 450) & 511)])) + ((0.00256355479f * fVec3[((IOTA - 445) & 511)]) + ((0.00222785119f * ((((((fVec3[((IOTA - 159) & 511)] - fVec3[((IOTA - 201) & 511)]) - fVec3[((IOTA - 229) & 511)]) - fVec3[((IOTA - 261) & 511)]) - fVec3[((IOTA - 352) & 511)]) - fVec3[((IOTA - 382) & 511)]) + fVec3[((IOTA - 431) & 511)])) + ((0.00213629566f * (((((((fVec3[((IOTA - 199) & 511)] - fVec3[((IOTA - 244) & 511)]) - fVec3[((IOTA - 260) & 511)]) - fVec3[((IOTA - 281) & 511)]) - fVec3[((IOTA - 351) & 511)]) - fVec3[((IOTA - 354) & 511)]) - fVec3[((IOTA - 383) & 511)]) + fVec3[((IOTA - 428) & 511)])) + ((0.000152592547f * (((((((fVec3[((IOTA - 53) & 511)] + fVec3[((IOTA - 56) & 511)]) - fVec3[((IOTA - 200) & 511)]) - fVec3[((IOTA - 359) & 511)]) - fVec3[((IOTA - 361) & 511)]) - fVec3[((IOTA - 371) & 511)]) + fVec3[((IOTA - 372) & 511)]) - fVec3[((IOTA - 399) & 511)])) + ((6.10370189e-05f * (((((((((((((((((((((((((((fVec3[((IOTA - 1) & 511)] + fVec3[((IOTA - 7) & 511)]) + fVec3[((IOTA - 12) & 511)]) + fVec3[((IOTA - 15) & 511)]) + fVec3[((IOTA - 16) & 511)]) + fVec3[((IOTA - 19) & 511)]) + fVec3[((IOTA - 20) & 511)]) - fVec3[((IOTA - 22) & 511)]) + fVec3[((IOTA - 23) & 511)]) + fVec3[((IOTA - 24) & 511)]) + fVec3[((IOTA - 26) & 511)]) + fVec3[((IOTA - 28) & 511)]) + fVec3[((IOTA - 31) & 511)]) + fVec3[((IOTA - 32) & 511)]) + fVec3[((IOTA - 33) & 511)]) + fVec3[((IOTA - 36) & 511)]) + fVec3[((IOTA - 37) & 511)]) + fVec3[((IOTA - 39) & 511)]) + fVec3[((IOTA - 40) & 511)]) + fVec3[((IOTA - 42) & 511)]) + fVec3[((IOTA - 45) & 511)]) + fVec3[((IOTA - 46) & 511)]) + fVec3[((IOTA - 47) & 511)]) + fVec3[((IOTA - 49) & 511)]) + fVec3[((IOTA - 52) & 511)]) - fVec3[((IOTA - 134) & 511)]) - fVec3[((IOTA - 360) & 511)]) - fVec3[((IOTA - 376) & 511)])) + (((0.00430310983f * ((fVec3[((IOTA - 133) & 511)] - fVec3[((IOTA - 220) & 511)]) - fVec3[((IOTA - 224) & 511)])) + ((0.00326548051f * (fVec3[((IOTA - 140) & 511)] + fVec3[((IOTA - 197) & 511)])) + ((0.00540177617f * (fVec3[((IOTA - 66) & 511)] - fVec3[((IOTA - 188) & 511)])) + ((0.00589007232f * (fVec3[((IOTA - 139) & 511)] - fVec3[((IOTA - 182) & 511)])) + ((0.00714133121f * (fVec3[((IOTA - 138) & 511)] - fVec3[((IOTA - 167) & 511)])) + ((0.00338755455f * fVec3[((IOTA - 198) & 511)]) + ((0.00927762687f * fVec3[((IOTA - 158) & 511)]) + ((0.0130314035f * fVec3[((IOTA - 157) & 511)]) + ((0.00317392498f * fVec3[((IOTA - 146) & 511)]) + ((0.00491348002f * (fVec3[((IOTA - 94) & 511)] - fVec3[((IOTA - 143) & 511)])) + ((0.00442518387f * fVec3[((IOTA - 132) & 511)]) + ((0.00262459181f * fVec3[((IOTA - 131) & 511)]) + ((0.0165715516f * fVec3[((IOTA - 124) & 511)]) + ((0.0268257707f * fVec3[((IOTA - 123) & 511)]) + ((0.0247505121f * fVec3[((IOTA - 122) & 511)]) + ((0.00631733146f * fVec3[((IOTA - 121) & 511)]) + ((0.016296884f * fVec3[((IOTA - 112) & 511)]) + ((0.0332041383f * fVec3[((IOTA - 111) & 511)]) + ((0.0286263619f * fVec3[((IOTA - 110) & 511)]) + ((0.0201116987f * fVec3[((IOTA - 105) & 511)]) + ((0.0383312479f * fVec3[((IOTA - 104) & 511)]) + ((0.0377208777f * fVec3[((IOTA - 103) & 511)]) + ((0.0102542192f * fVec3[((IOTA - 102) & 511)]) + ((0.0325022116f * fVec3[((IOTA - 97) & 511)]) + ((0.0602435395f * fVec3[((IOTA - 96) & 511)]) + ((0.0449232459f * fVec3[((IOTA - 95) & 511)]) + ((0.0273140669f * fVec3[((IOTA - 88) & 511)]) + ((0.0028992584f * fVec3[((IOTA - 87) & 511)]) + ((0.0137333293f * fVec3[((IOTA - 86) & 511)]) + ((0.0366832502f * fVec3[((IOTA - 79) & 511)]) + ((0.0535905026f * fVec3[((IOTA - 78) & 511)]) + ((0.0651570186f * fVec3[((IOTA - 77) & 511)]) + ((0.0635700524f * fVec3[((IOTA - 72) & 511)]) + ((0.241798148f * fVec3[((IOTA - 71) & 511)]) + ((0.291512817f * fVec3[((IOTA - 70) & 511)]) + ((0.20368053f * fVec3[((IOTA - 69) & 511)]) + ((0.0185857732f * fVec3[((IOTA - 67) & 511)]) + (0.0832544938f * fVec3[((IOTA - 68) & 511)])))))))))))))))))))))))))))))))))))))) + (0.00366222113f * (((fVec3[((IOTA - 137) & 511)] - fVec3[((IOTA - 166) & 511)]) - fVec3[((IOTA - 221) & 511)]) - fVec3[((IOTA - 367) & 511)])))))))))) + (0.000427259132f * (fVec3[((IOTA - 493) & 511)] - (((fVec3[((IOTA - 231) & 511)] + fVec3[((IOTA - 315) & 511)]) + fVec3[((IOTA - 328) & 511)]) - fVec3[((IOTA - 492) & 511)])))))))) + (0.00109866634f * ((((((((fVec3[((IOTA - 210) & 511)] - fVec3[((IOTA - 275) & 511)]) - fVec3[((IOTA - 337) & 511)]) - fVec3[((IOTA - 401) & 511)]) + fVec3[((IOTA - 421) & 511)]) + fVec3[((IOTA - 441) & 511)]) + fVec3[((IOTA - 456) & 511)]) + fVec3[((IOTA - 509) & 511)]) + fVec3[((IOTA - 510) & 511)])))) : ((((0.000274666585f * ((((fVec2[((IOTA - 342) & 511)] - fVec2[((IOTA - 353) & 511)]) - fVec2[((IOTA - 505) & 511)]) - fVec2[((IOTA - 506) & 511)]) - fVec2[((IOTA - 508) & 511)])) + ((0.000122074038f * (((((fVec2[((IOTA - 59) & 511)] - fVec2[((IOTA - 224) & 511)]) + fVec2[((IOTA - 242) & 511)]) - fVec2[((IOTA - 293) & 511)]) - fVec2[((IOTA - 301) & 511)]) - fVec2[((IOTA - 503) & 511)])) + ((3.05185094e-05f * (((((((((((((((((((((((((((((((((fVec2[((IOTA - 4) & 511)] + fVec2[((IOTA - 5) & 511)]) + fVec2[((IOTA - 6) & 511)]) + fVec2[((IOTA - 7) & 511)]) + fVec2[((IOTA - 8) & 511)]) + fVec2[((IOTA - 9) & 511)]) + fVec2[((IOTA - 10) & 511)]) + fVec2[((IOTA - 11) & 511)]) + fVec2[((IOTA - 15) & 511)]) + fVec2[((IOTA - 16) & 511)]) + fVec2[((IOTA - 17) & 511)]) + fVec2[((IOTA - 18) & 511)]) + fVec2[((IOTA - 22) & 511)]) + fVec2[((IOTA - 23) & 511)]) + fVec2[((IOTA - 26) & 511)]) + fVec2[((IOTA - 27) & 511)]) + fVec2[((IOTA - 28) & 511)]) + fVec2[((IOTA - 29) & 511)]) + fVec2[((IOTA - 30) & 511)]) + fVec2[((IOTA - 31) & 511)]) + fVec2[((IOTA - 36) & 511)]) + fVec2[((IOTA - 37) & 511)]) + fVec2[((IOTA - 38) & 511)]) + fVec2[((IOTA - 43) & 511)]) + fVec2[((IOTA - 44) & 511)]) + fVec2[((IOTA - 50) & 511)]) + fVec2[((IOTA - 54) & 511)]) - fVec2[((IOTA - 192) & 511)]) - fVec2[((IOTA - 202) & 511)]) + fVec2[((IOTA - 208) & 511)]) - fVec2[((IOTA - 302) & 511)]) - fVec2[((IOTA - 303) & 511)]) + fVec2[((IOTA - 442) & 511)]) + fVec2[((IOTA - 502) & 511)])) + ((0.000213629566f * (((((((((((((((fVec2[((IOTA - 57) & 511)] + fVec2[((IOTA - 58) & 511)]) + fVec2[((IOTA - 243) & 511)]) - fVec2[((IOTA - 246) & 511)]) - fVec2[((IOTA - 288) & 511)]) + fVec2[((IOTA - 298) & 511)]) + fVec2[((IOTA - 331) & 511)]) - fVec2[((IOTA - 343) & 511)]) - fVec2[((IOTA - 365) & 511)]) + fVec2[((IOTA - 395) & 511)]) + fVec2[((IOTA - 409) & 511)]) - fVec2[((IOTA - 464) & 511)]) - fVec2[((IOTA - 465) & 511)]) + fVec2[((IOTA - 486) & 511)]) - fVec2[((IOTA - 496) & 511)]) + fVec2[((IOTA - 501) & 511)])) + ((0.000335703604f * fVec2[((IOTA - 500) & 511)]) + ((9.15555283e-05f * (((((((((((fVec2[((IOTA - 46) & 511)] + fVec2[((IOTA - 47) & 511)]) + fVec2[((IOTA - 55) & 511)]) + fVec2[((IOTA - 214) & 511)]) + fVec2[((IOTA - 237) & 511)]) - fVec2[((IOTA - 244) & 511)]) - fVec2[((IOTA - 268) & 511)]) - fVec2[((IOTA - 304) & 511)]) + fVec2[((IOTA - 318) & 511)]) - fVec2[((IOTA - 347) & 511)]) + fVec2[((IOTA - 463) & 511)]) + fVec2[((IOTA - 497) & 511)])) + ((0.000610370189f * ((((fVec2[((IOTA - 234) & 511)] + fVec2[((IOTA - 320) & 511)]) - fVec2[((IOTA - 408) & 511)]) + fVec2[((IOTA - 469) & 511)]) - fVec2[((IOTA - 495) & 511)])) + ((0.00134281442f * (fVec2[((IOTA - 272) & 511)] - fVec2[((IOTA - 491) & 511)])) + ((0.000885036774f * (((((((fVec2[((IOTA - 215) & 511)] + fVec2[((IOTA - 223) & 511)]) - fVec2[((IOTA - 241) & 511)]) + fVec2[((IOTA - 316) & 511)]) + fVec2[((IOTA - 337) & 511)]) - fVec2[((IOTA - 440) & 511)]) + fVec2[((IOTA - 477) & 511)]) + fVec2[((IOTA - 479) & 511)])) + ((0.000823999755f * ((((((fVec2[((IOTA - 270) & 511)] - fVec2[((IOTA - 283) & 511)]) + fVec2[((IOTA - 309) & 511)]) - fVec2[((IOTA - 354) & 511)]) + fVec2[((IOTA - 377) & 511)]) - fVec2[((IOTA - 422) & 511)]) + fVec2[((IOTA - 478) & 511)])) + ((0.000427259132f * (((fVec2[((IOTA - 326) & 511)] - fVec2[((IOTA - 330) & 511)]) - fVec2[((IOTA - 344) & 511)]) + fVec2[((IOTA - 468) & 511)])) + ((0.00109866634f * (fVec2[((IOTA - 484) & 511)] - (((((fVec2[((IOTA - 201) & 511)] - fVec2[((IOTA - 273) & 511)]) + fVec2[((IOTA - 281) & 511)]) - fVec2[((IOTA - 410) & 511)]) - fVec2[((IOTA - 472) & 511)]) - fVec2[((IOTA - 480) & 511)]))) + ((0.00112918485f * ((((fVec2[((IOTA - 256) & 511)] + fVec2[((IOTA - 260) & 511)]) + fVec2[((IOTA - 350) & 511)]) - fVec2[((IOTA - 355) & 511)]) + fVec2[((IOTA - 457) & 511)])) + ((0.00280770287f * (((fVec2[((IOTA - 136) & 511)] + fVec2[((IOTA - 176) & 511)]) + fVec2[((IOTA - 413) & 511)]) - fVec2[((IOTA - 452) & 511)])) + ((0.000183111057f * (((((((fVec2[((IOTA - 114) & 511)] - fVec2[((IOTA - 124) & 511)]) - fVec2[((IOTA - 245) & 511)]) - fVec2[((IOTA - 267) & 511)]) - fVec2[((IOTA - 275) & 511)]) - fVec2[((IOTA - 300) & 511)]) + fVec2[((IOTA - 419) & 511)]) - fVec2[((IOTA - 449) & 511)])) + ((0.00253303628f * fVec2[((IOTA - 445) & 511)]) + ((0.00183111057f * ((((fVec2[((IOTA - 207) & 511)] + fVec2[((IOTA - 218) & 511)]) + fVec2[((IOTA - 322) & 511)]) + fVec2[((IOTA - 411) & 511)]) + fVec2[((IOTA - 444) & 511)])) + ((0.000915555283f * ((((((fVec2[((IOTA - 295) & 511)] + fVec2[((IOTA - 334) & 511)]) + fVec2[((IOTA - 335) & 511)]) + fVec2[((IOTA - 336) & 511)]) + fVec2[((IOTA - 349) & 511)]) + fVec2[((IOTA - 351) & 511)]) + fVec2[((IOTA - 443) & 511)])) + ((0.00057985168f * (((((fVec2[((IOTA - 106) & 511)] + fVec2[((IOTA - 193) & 511)]) - fVec2[((IOTA - 195) & 511)]) + fVec2[((IOTA - 274) & 511)]) + fVec2[((IOTA - 308) & 511)]) - fVec2[((IOTA - 441) & 511)])) + ((0.000518814661f * ((fVec2[((IOTA - 258) & 511)] - fVec2[((IOTA - 327) & 511)]) - fVec2[((IOTA - 436) & 511)])) + ((6.10370189e-05f * (((((((((((fVec2[((IOTA - 19) & 511)] + fVec2[((IOTA - 20) & 511)]) + fVec2[((IOTA - 21) & 511)]) + fVec2[((IOTA - 32) & 511)]) + fVec2[((IOTA - 33) & 511)]) + fVec2[((IOTA - 34) & 511)]) + fVec2[((IOTA - 35) & 511)]) + fVec2[((IOTA - 45) & 511)]) + fVec2[((IOTA - 48) & 511)]) + fVec2[((IOTA - 49) & 511)]) - fVec2[((IOTA - 305) & 511)]) - fVec2[((IOTA - 435) & 511)])) + ((0.00186162908f * ((fVec2[((IOTA - 314) & 511)] - fVec2[((IOTA - 406) & 511)]) + fVec2[((IOTA - 433) & 511)])) + ((0.00308236945f * ((fVec2[((IOTA - 141) & 511)] + fVec2[((IOTA - 206) & 511)]) + fVec2[((IOTA - 432) & 511)])) + ((0.0042115543f * fVec2[((IOTA - 431) & 511)]) + ((0.00497451704f * fVec2[((IOTA - 430) & 511)]) + ((0.00521866512f * fVec2[((IOTA - 429) & 511)]) + ((0.00494399853f * fVec2[((IOTA - 428) & 511)]) + ((0.00408948027f * (fVec2[((IOTA - 362) & 511)] + fVec2[((IOTA - 427) & 511)])) + ((0.00189214759f * (fVec2[((IOTA - 217) & 511)] - fVec2[((IOTA - 454) & 511)])) + ((0.0019226661f * fVec2[((IOTA - 417) & 511)]) + ((0.00256355479f * fVec2[((IOTA - 416) & 511)]) + ((0.00292977691f * (fVec2[((IOTA - 152) & 511)] + fVec2[((IOTA - 415) & 511)])) + ((0.00299081393f * fVec2[((IOTA - 414) & 511)]) + ((0.00241096225f * fVec2[((IOTA - 412) & 511)]) + ((0.00415051728f * (fVec2[((IOTA - 361) & 511)] + fVec2[((IOTA - 393) & 511)])) + ((0.0061342204f * fVec2[((IOTA - 392) & 511)]) + ((0.00744651631f * (fVec2[((IOTA - 158) & 511)] + fVec2[((IOTA - 391) & 511)])) + ((0.00750755332f * fVec2[((IOTA - 390) & 511)]) + ((0.00619525742f * fVec2[((IOTA - 389) & 511)]) + ((0.00372325815f * fVec2[((IOTA - 388) & 511)]) + ((0.00366222113f * (fVec2[((IOTA - 68) & 511)] - fVec2[((IOTA - 383) & 511)])) + ((0.00344859157f * ((fVec2[((IOTA - 205) & 511)] + fVec2[((IOTA - 363) & 511)]) - fVec2[((IOTA - 382) & 511)])) + ((0.00234992523f * fVec2[((IOTA - 376) & 511)]) + ((0.00390636921f * (fVec2[((IOTA - 178) & 511)] + fVec2[((IOTA - 375) & 511)])) + ((0.00436414685f * fVec2[((IOTA - 372) & 511)]) + ((0.00201422162f * ((fVec2[((IOTA - 169) & 511)] - fVec2[((IOTA - 210) & 511)]) + fVec2[((IOTA - 364) & 511)])) + ((0.000671407208f * fVec2[((IOTA - 332) & 511)]) + ((0.0019531846f * fVec2[((IOTA - 324) & 511)]) + ((0.000152592547f * ((((((fVec2[((IOTA - 56) & 511)] - fVec2[((IOTA - 60) & 511)]) - fVec2[((IOTA - 263) & 511)]) - fVec2[((IOTA - 266) & 511)]) - fVec2[((IOTA - 299) & 511)]) + fVec2[((IOTA - 306) & 511)]) + fVec2[((IOTA - 319) & 511)])) + ((0.00198370311f * fVec2[((IOTA - 313) & 511)]) + ((0.00177007355f * fVec2[((IOTA - 312) & 511)]) + ((0.00149540696f * ((fVec2[((IOTA - 216) & 511)] + fVec2[((IOTA - 236) & 511)]) + fVec2[((IOTA - 311) & 511)])) + ((0.00238044374f * fVec2[((IOTA - 359) & 511)]) + ((0.00140385143f * fVec2[((IOTA - 220) & 511)]) + ((0.00164799951f * fVec2[((IOTA - 219) & 511)]) + ((0.00265511032f * fVec2[((IOTA - 204) & 511)]) + ((0.001617481f * fVec2[((IOTA - 203) & 511)]) + ((0.00286873989f * fVec2[((IOTA - 182) & 511)]) + ((0.00460829493f * fVec2[((IOTA - 181) & 511)]) + ((0.00445570238f * fVec2[((IOTA - 180) & 511)]) + ((0.0035401471f * fVec2[((IOTA - 179) & 511)]) + ((0.00482192449f * fVec2[((IOTA - 177) & 511)]) + ((0.00610370189f * fVec2[((IOTA - 168) & 511)]) + ((0.00823999755f * fVec2[((IOTA - 167) & 511)]) + ((0.00827051606f * fVec2[((IOTA - 166) & 511)]) + ((0.00683614612f * fVec2[((IOTA - 165) & 511)]) + ((0.00555436872f * fVec2[((IOTA - 164) & 511)]) + ((0.00247199927f * fVec2[((IOTA - 163) & 511)]) + ((0.00671407208f * fVec2[((IOTA - 157) & 511)]) + ((0.00845362712f * fVec2[((IOTA - 151) & 511)]) + ((0.00607318338f * fVec2[((IOTA - 150) & 511)]) + ((0.00994903408f * (fVec2[((IOTA - 91) & 511)] - fVec2[((IOTA - 147) & 511)])) + ((0.0108951079f * fVec2[((IOTA - 140) & 511)]) + ((0.0159611814f * fVec2[((IOTA - 139) & 511)]) + ((0.0177007355f * fVec2[((IOTA - 138) & 511)]) + ((0.013061922f * fVec2[((IOTA - 137) & 511)]) + ((0.0246284381f * fVec2[((IOTA - 127) & 511)]) + ((0.0242927335f * fVec2[((IOTA - 126) & 511)]) + ((0.0116275521f * fVec2[((IOTA - 125) & 511)]) + ((0.0111392559f * fVec2[((IOTA - 113) & 511)]) + ((0.0192571804f * fVec2[((IOTA - 112) & 511)]) + ((0.0251472518f * fVec2[((IOTA - 111) & 511)]) + ((0.0299386587f * fVec2[((IOTA - 110) & 511)]) + ((0.029053621f * fVec2[((IOTA - 109) & 511)]) + ((0.0292672515f * fVec2[((IOTA - 108) & 511)]) + ((0.0141911069f * fVec2[((IOTA - 107) & 511)]) + ((0.00207525864f * fVec2[((IOTA - 100) & 511)]) + ((0.0136417737f * fVec2[((IOTA - 99) & 511)]) + ((0.0105288858f * fVec2[((IOTA - 98) & 511)]) + ((0.00296029542f * fVec2[((IOTA - 97) & 511)]) + ((0.00891140476f * fVec2[((IOTA - 92) & 511)]) + ((0.0184331797f * fVec2[((IOTA - 85) & 511)]) + ((0.0414746553f * fVec2[((IOTA - 84) & 511)]) + ((0.0613727234f * fVec2[((IOTA - 83) & 511)]) + ((0.0459913947f * fVec2[((IOTA - 82) & 511)]) + ((0.0228278451f * fVec2[((IOTA - 81) & 511)]) + ((0.125705734f * fVec2[((IOTA - 74) & 511)]) + ((0.25238806f * fVec2[((IOTA - 73) & 511)]) + ((0.265297413f * fVec2[((IOTA - 72) & 511)]) + ((0.177587211f * fVec2[((IOTA - 71) & 511)]) + ((0.0176396985f * fVec2[((IOTA - 69) & 511)]) + (0.0723593831f * fVec2[((IOTA - 70) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000366222113f * (((((((((((fVec2[((IOTA - 159) & 511)] - fVec2[((IOTA - 183) & 511)]) - fVec2[((IOTA - 264) & 511)]) - fVec2[((IOTA - 286) & 511)]) + fVec2[((IOTA - 307) & 511)]) + fVec2[((IOTA - 317) & 511)]) + fVec2[((IOTA - 352) & 511)]) - fVec2[((IOTA - 378) & 511)]) + fVec2[((IOTA - 424) & 511)]) + fVec2[((IOTA - 499) & 511)]) - fVec2[((IOTA - 510) & 511)]) - fVec2[((IOTA - 511) & 511)]))) - ((((0.000946073793f * ((fVec2[((IOTA - 439) & 511)] - fVec2[((IOTA - 387) & 511)]) + fVec2[((IOTA - 494) & 511)])) + ((0.00119022187f * ((((fVec2[((IOTA - 212) & 511)] - fVec2[((IOTA - 461) & 511)]) - fVec2[((IOTA - 473) & 511)]) - fVec2[((IOTA - 474) & 511)]) + fVec2[((IOTA - 493) & 511)])) + ((0.00131229591f * (((((((fVec2[((IOTA - 162) & 511)] + fVec2[((IOTA - 225) & 511)]) + fVec2[((IOTA - 280) & 511)]) + fVec2[((IOTA - 386) & 511)]) + fVec2[((IOTA - 398) & 511)]) + fVec2[((IOTA - 407) & 511)]) - fVec2[((IOTA - 481) & 511)]) + fVec2[((IOTA - 492) & 511)])) + ((0.0012817774f * ((fVec2[((IOTA - 209) & 511)] - fVec2[((IOTA - 255) & 511)]) + fVec2[((IOTA - 490) & 511)])) + ((0.00106814783f * ((fVec2[((IOTA - 328) & 511)] - fVec2[((IOTA - 418) & 511)]) + fVec2[((IOTA - 489) & 511)])) + ((0.000732444227f * (((fVec2[((IOTA - 233) & 511)] - fVec2[((IOTA - 257) & 511)]) - fVec2[((IOTA - 259) & 511)]) + fVec2[((IOTA - 488) & 511)])) + ((0.00137333293f * (((fVec2[((IOTA - 198) & 511)] - fVec2[((IOTA - 222) & 511)]) - fVec2[((IOTA - 325) & 511)]) - fVec2[((IOTA - 483) & 511)])) + ((0.00143436994f * (((((fVec2[((IOTA - 196) & 511)] - fVec2[((IOTA - 221) & 511)]) + fVec2[((IOTA - 277) & 511)]) + fVec2[((IOTA - 279) & 511)]) + fVec2[((IOTA - 397) & 511)]) - fVec2[((IOTA - 482) & 511)])) + ((0.00103762932f * ((((((fVec2[((IOTA - 229) & 511)] - fVec2[((IOTA - 254) & 511)]) - fVec2[((IOTA - 261) & 511)]) - fVec2[((IOTA - 296) & 511)]) - fVec2[((IOTA - 338) & 511)]) + fVec2[((IOTA - 370) & 511)]) - fVec2[((IOTA - 476) & 511)])) + ((0.00115970336f * (((fVec2[((IOTA - 61) & 511)] + fVec2[((IOTA - 230) & 511)]) - fVec2[((IOTA - 310) & 511)]) - fVec2[((IOTA - 475) & 511)])) + ((0.000976592302f * ((((((fVec2[((IOTA - 276) & 511)] + fVec2[((IOTA - 282) & 511)]) + fVec2[((IOTA - 329) & 511)]) + fVec2[((IOTA - 356) & 511)]) - fVec2[((IOTA - 358) & 511)]) + fVec2[((IOTA - 396) & 511)]) - fVec2[((IOTA - 471) & 511)])) + ((0.000762962736f * (((fVec2[((IOTA - 290) & 511)] - fVec2[((IOTA - 434) & 511)]) + fVec2[((IOTA - 437) & 511)]) - fVec2[((IOTA - 470) & 511)])) + ((0.000640888698f * (fVec2[((IOTA - 292) & 511)] - fVec2[((IOTA - 462) & 511)])) + ((0.00158696249f * (((fVec2[((IOTA - 228) & 511)] + fVec2[((IOTA - 251) & 511)]) - fVec2[((IOTA - 458) & 511)]) - fVec2[((IOTA - 460) & 511)])) + ((0.00170903653f * ((fVec2[((IOTA - 211) & 511)] + fVec2[((IOTA - 238) & 511)]) - fVec2[((IOTA - 459) & 511)])) + ((0.000793481246f * ((fVec2[((IOTA - 400) & 511)] + fVec2[((IOTA - 421) & 511)]) + fVec2[((IOTA - 455) & 511)])) + ((0.0025940733f * fVec2[((IOTA - 453) & 511)]) + ((0.00244148076f * fVec2[((IOTA - 451) & 511)]) + ((0.00152592547f * ((fVec2[((IOTA - 231) & 511)] - fVec2[((IOTA - 425) & 511)]) + fVec2[((IOTA - 450) & 511)])) + ((0.00122074038f * ((fVec2[((IOTA - 402) & 511)] - fVec2[((IOTA - 339) & 511)]) - fVec2[((IOTA - 448) & 511)])) + ((0.00228888821f * (fVec2[((IOTA - 250) & 511)] - fVec2[((IOTA - 447) & 511)])) + ((0.00274666585f * (fVec2[((IOTA - 239) & 511)] - fVec2[((IOTA - 446) & 511)])) + ((0.000854518265f * ((((fVec2[((IOTA - 291) & 511)] - fVec2[((IOTA - 333) & 511)]) - fVec2[((IOTA - 341) & 511)]) + fVec2[((IOTA - 401) & 511)]) + fVec2[((IOTA - 438) & 511)])) + ((0.0028992584f * (fVec2[((IOTA - 366) & 511)] - fVec2[((IOTA - 426) & 511)])) + ((0.000457777642f * (((((fVec2[((IOTA - 247) & 511)] - fVec2[((IOTA - 253) & 511)]) - fVec2[((IOTA - 294) & 511)]) + fVec2[((IOTA - 345) & 511)]) + fVec2[((IOTA - 420) & 511)]) + fVec2[((IOTA - 423) & 511)])) + ((0.00216681417f * fVec2[((IOTA - 405) & 511)]) + ((0.00213629566f * fVec2[((IOTA - 404) & 511)]) + ((0.00173955504f * fVec2[((IOTA - 403) & 511)]) + ((0.00100711081f * fVec2[((IOTA - 399) & 511)]) + ((0.00204474013f * (((fVec2[((IOTA - 226) & 511)] + fVec2[((IOTA - 249) & 511)]) + fVec2[((IOTA - 380) & 511)]) - fVec2[((IOTA - 394) & 511)])) + ((0.00268562883f * fVec2[((IOTA - 385) & 511)]) + ((0.00341807306f * fVec2[((IOTA - 384) & 511)]) + ((0.00283822138f * fVec2[((IOTA - 381) & 511)]) + ((0.000701925717f * ((fVec2[((IOTA - 284) & 511)] - fVec2[((IOTA - 297) & 511)]) - fVec2[((IOTA - 485) & 511)])) + ((0.00506607257f * (fVec2[((IOTA - 367) & 511)] - fVec2[((IOTA - 374) & 511)])) + ((0.00527970213f * (fVec2[((IOTA - 144) & 511)] - fVec2[((IOTA - 373) & 511)])) + ((0.00210577715f * (((fVec2[((IOTA - 142) & 511)] + fVec2[((IOTA - 227) & 511)]) - fVec2[((IOTA - 323) & 511)]) - fVec2[((IOTA - 371) & 511)])) + ((0.00405896176f * fVec2[((IOTA - 369) & 511)]) + ((0.00561540574f * fVec2[((IOTA - 368) & 511)]) + ((0.00125125889f * (((((fVec2[((IOTA - 199) & 511)] + fVec2[((IOTA - 248) & 511)]) - fVec2[((IOTA - 271) & 511)]) - fVec2[((IOTA - 321) & 511)]) - fVec2[((IOTA - 340) & 511)]) + fVec2[((IOTA - 379) & 511)])) + ((0.000396740623f * (((fVec2[((IOTA - 213) & 511)] - fVec2[((IOTA - 262) & 511)]) + fVec2[((IOTA - 346) & 511)]) - fVec2[((IOTA - 348) & 511)])) + ((0.00347911008f * (fVec2[((IOTA - 62) & 511)] - fVec2[((IOTA - 360) & 511)])) + ((0.00146488845f * (((fVec2[((IOTA - 191) & 511)] + fVec2[((IOTA - 197) & 511)]) + fVec2[((IOTA - 200) & 511)]) - fVec2[((IOTA - 315) & 511)])) + ((0.000488296151f * (fVec2[((IOTA - 252) & 511)] + fVec2[((IOTA - 289) & 511)])) + ((0.00054933317f * fVec2[((IOTA - 285) & 511)]) + ((0.00155644398f * ((fVec2[((IOTA - 232) & 511)] - fVec2[((IOTA - 235) & 511)]) + fVec2[((IOTA - 278) & 511)])) + ((0.0022583697f * fVec2[((IOTA - 240) & 511)]) + ((0.00332651753f * fVec2[((IOTA - 190) & 511)]) + ((0.00518814661f * fVec2[((IOTA - 189) & 511)]) + ((0.00640888698f * fVec2[((IOTA - 188) & 511)]) + ((0.00650044251f * fVec2[((IOTA - 187) & 511)]) + ((0.00616473891f * fVec2[((IOTA - 186) & 511)]) + ((0.0051576281f * fVec2[((IOTA - 185) & 511)]) + ((0.00350962859f * fVec2[((IOTA - 184) & 511)]) + ((0.00363170262f * (fVec2[((IOTA - 90) & 511)] + fVec2[((IOTA - 175) & 511)])) + ((0.0113528855f * fVec2[((IOTA - 174) & 511)]) + ((0.0145878475f * fVec2[((IOTA - 173) & 511)]) + ((0.0121768853f * fVec2[((IOTA - 172) & 511)]) + ((0.00732444227f * fVec2[((IOTA - 171) & 511)]) + ((0.00277718436f * fVec2[((IOTA - 170) & 511)]) + ((0.00628681295f * fVec2[((IOTA - 161) & 511)]) + ((0.00546281319f * fVec2[((IOTA - 160) & 511)]) + ((0.0155644398f * fVec2[((IOTA - 154) & 511)]) + ((0.00704977568f * fVec2[((IOTA - 153) & 511)]) + ((0.00686666463f * fVec2[((IOTA - 148) & 511)]) + ((0.00369273964f * fVec2[((IOTA - 156) & 511)]) + ((0.00848414563f * fVec2[((IOTA - 146) & 511)]) + ((0.00668355357f * fVec2[((IOTA - 145) & 511)]) + ((0.00537125766f * fVec2[((IOTA - 143) & 511)]) + ((0.00949125644f * fVec2[((IOTA - 135) & 511)]) + ((0.0211188085f * fVec2[((IOTA - 134) & 511)]) + ((0.0283516962f * fVec2[((IOTA - 133) & 511)]) + ((0.0299081393f * fVec2[((IOTA - 132) & 511)]) + ((0.0251167342f * fVec2[((IOTA - 131) & 511)]) + ((0.0144047365f * fVec2[((IOTA - 130) & 511)]) + ((0.0165105145f * (fVec2[((IOTA - 96) & 511)] - fVec2[((IOTA - 128) & 511)])) + ((0.0138554033f * fVec2[((IOTA - 155) & 511)]) + ((0.0141300699f * fVec2[((IOTA - 123) & 511)]) + ((0.0198675506f * fVec2[((IOTA - 122) & 511)]) + ((0.0257881414f * fVec2[((IOTA - 121) & 511)]) + ((0.0294503625f * fVec2[((IOTA - 120) & 511)]) + ((0.0340891741f * fVec2[((IOTA - 119) & 511)]) + ((0.0347300656f * fVec2[((IOTA - 118) & 511)]) + ((0.0280465111f * fVec2[((IOTA - 117) & 511)]) + ((0.0216681417f * fVec2[((IOTA - 116) & 511)]) + ((0.0106204413f * fVec2[((IOTA - 115) & 511)]) + ((0.0191351064f * fVec2[((IOTA - 105) & 511)]) + ((0.0262764376f * fVec2[((IOTA - 104) & 511)]) + ((0.0188299213f * fVec2[((IOTA - 102) & 511)]) + ((0.00689718314f * fVec2[((IOTA - 101) & 511)]) + ((0.033722952f * fVec2[((IOTA - 95) & 511)]) + ((0.0342417695f * fVec2[((IOTA - 94) & 511)]) + ((0.0164494775f * fVec2[((IOTA - 93) & 511)]) + ((0.0376598425f * fVec2[((IOTA - 89) & 511)]) + ((0.0411084332f * fVec2[((IOTA - 88) & 511)]) + ((0.0354319885f * fVec2[((IOTA - 87) & 511)]) + ((0.0297555476f * fVec2[((IOTA - 103) & 511)]) + ((0.00881984923f * fVec2[((IOTA - 86) & 511)]) + ((0.0459303558f * fVec2[((IOTA - 80) & 511)]) + ((0.105288856f * fVec2[((IOTA - 79) & 511)]) + ((0.16980499f * fVec2[((IOTA - 78) & 511)]) + ((0.197546318f * fVec2[((IOTA - 77) & 511)]) + ((0.161626026f * fVec2[((IOTA - 76) & 511)]) + ((0.0513016135f * fVec2[((IOTA - 75) & 511)]) + ((0.00222785119f * fVec2[((IOTA - 67) & 511)]) + ((0.0077517014f * fVec2[((IOTA - 66) & 511)]) + ((0.0101931822f * fVec2[((IOTA - 65) & 511)]) + ((0.00659199804f * fVec2[((IOTA - 63) & 511)]) + (0.00946073793f * fVec2[((IOTA - 64) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000244148076f * ((fVec2[((IOTA - 504) & 511)] - ((((((fVec2[((IOTA - 129) & 511)] + fVec2[((IOTA - 194) & 511)]) - fVec2[((IOTA - 265) & 511)]) + fVec2[((IOTA - 269) & 511)]) - fVec2[((IOTA - 287) & 511)]) - fVec2[((IOTA - 357) & 511)]) + fVec2[((IOTA - 467) & 511)])) + fVec2[((IOTA - 507) & 511)]))) + (0.000305185094f * ((((fVec2[((IOTA - 149) & 511)] - fVec2[((IOTA - 456) & 511)]) + fVec2[((IOTA - 487) & 511)]) - fVec2[((IOTA - 498) & 511)]) + fVec2[((IOTA - 509) & 511)]))))) : (iSlow6 ? (((0.000244148076f * ((((((((((((((fVec1[((IOTA - 106) & 511)] - fVec1[((IOTA - 217) & 511)]) + fVec1[((IOTA - 226) & 511)]) + fVec1[((IOTA - 253) & 511)]) + fVec1[((IOTA - 270) & 511)]) + fVec1[((IOTA - 272) & 511)]) - fVec1[((IOTA - 299) & 511)]) - fVec1[((IOTA - 415) & 511)]) - fVec1[((IOTA - 428) & 511)]) - fVec1[((IOTA - 443) & 511)]) + fVec1[((IOTA - 469) & 511)]) + fVec1[((IOTA - 473) & 511)]) + fVec1[((IOTA - 483) & 511)]) + fVec1[((IOTA - 486) & 511)]) + fVec1[((IOTA - 511) & 511)])) + ((0.000183111057f * ((((((((fVec1[((IOTA - 283) & 511)] + fVec1[((IOTA - 288) & 511)]) - fVec1[((IOTA - 385) & 511)]) + fVec1[((IOTA - 426) & 511)]) - fVec1[((IOTA - 465) & 511)]) + fVec1[((IOTA - 468) & 511)]) + fVec1[((IOTA - 482) & 511)]) + fVec1[((IOTA - 487) & 511)]) + fVec1[((IOTA - 510) & 511)])) + ((6.10370189e-05f * (((((fVec1[((IOTA - 234) & 511)] - fVec1[((IOTA - 333) & 511)]) - fVec1[((IOTA - 400) & 511)]) - fVec1[((IOTA - 427) & 511)]) - fVec1[((IOTA - 441) & 511)]) - fVec1[((IOTA - 507) & 511)])) + ((0.000213629566f * ((((((fVec1[((IOTA - 174) & 511)] + fVec1[((IOTA - 291) & 511)]) - fVec1[((IOTA - 319) & 511)]) - fVec1[((IOTA - 417) & 511)]) + fVec1[((IOTA - 419) & 511)]) + fVec1[((IOTA - 480) & 511)]) - fVec1[((IOTA - 506) & 511)])) + ((0.000427259132f * ((((((((((((((fVec1[((IOTA - 159) & 511)] - fVec1[((IOTA - 296) & 511)]) + fVec1[((IOTA - 303) & 511)]) + fVec1[((IOTA - 311) & 511)]) + fVec1[((IOTA - 317) & 511)]) - fVec1[((IOTA - 334) & 511)]) - fVec1[((IOTA - 386) & 511)]) + fVec1[((IOTA - 399) & 511)]) - fVec1[((IOTA - 403) & 511)]) - fVec1[((IOTA - 429) & 511)]) - fVec1[((IOTA - 444) & 511)]) - fVec1[((IOTA - 453) & 511)]) - fVec1[((IOTA - 463) & 511)]) - fVec1[((IOTA - 493) & 511)]) - fVec1[((IOTA - 504) & 511)])) + ((0.000518814661f * (((((fVec1[((IOTA - 273) & 511)] - fVec1[((IOTA - 402) & 511)]) + fVec1[((IOTA - 424) & 511)]) - fVec1[((IOTA - 460) & 511)]) - fVec1[((IOTA - 496) & 511)]) - fVec1[((IOTA - 497) & 511)])) + ((0.000152592547f * (((((fVec1[((IOTA - 363) & 511)] - fVec1[((IOTA - 392) & 511)]) - fVec1[((IOTA - 404) & 511)]) + fVec1[((IOTA - 405) & 511)]) - fVec1[((IOTA - 440) & 511)]) + fVec1[((IOTA - 481) & 511)])) + ((9.15555283e-05f * ((((((((fVec1[((IOTA - 169) & 511)] + fVec1[((IOTA - 215) & 511)]) + fVec1[((IOTA - 231) & 511)]) + fVec1[((IOTA - 238) & 511)]) - fVec1[((IOTA - 285) & 511)]) + fVec1[((IOTA - 287) & 511)]) - fVec1[((IOTA - 434) & 511)]) - fVec1[((IOTA - 442) & 511)]) + fVec1[((IOTA - 467) & 511)])) + ((0.000610370189f * (((((((fVec1[((IOTA - 229) & 511)] + fVec1[((IOTA - 300) & 511)]) - fVec1[((IOTA - 349) & 511)]) - fVec1[((IOTA - 387) & 511)]) + fVec1[((IOTA - 423) & 511)]) - fVec1[((IOTA - 445) & 511)]) - fVec1[((IOTA - 454) & 511)]) - fVec1[((IOTA - 459) & 511)])) + ((0.000732444227f * ((fVec1[((IOTA - 422) & 511)] - ((fVec1[((IOTA - 208) & 511)] + fVec1[((IOTA - 338) & 511)]) + fVec1[((IOTA - 388) & 511)])) - fVec1[((IOTA - 458) & 511)])) + ((0.000854518265f * ((fVec1[((IOTA - 313) & 511)] + fVec1[((IOTA - 410) & 511)]) - fVec1[((IOTA - 456) & 511)])) + ((0.000762962736f * ((((((fVec1[((IOTA - 263) & 511)] - fVec1[((IOTA - 336) & 511)]) - fVec1[((IOTA - 343) & 511)]) + fVec1[((IOTA - 365) & 511)]) - fVec1[((IOTA - 390) & 511)]) - fVec1[((IOTA - 446) & 511)]) - fVec1[((IOTA - 455) & 511)])) + ((0.00057985168f * ((((fVec1[((IOTA - 269) & 511)] - fVec1[((IOTA - 346) & 511)]) - fVec1[((IOTA - 348) & 511)]) - fVec1[((IOTA - 431) & 511)]) - fVec1[((IOTA - 449) & 511)])) + ((0.000701925717f * ((((((((fVec1[((IOTA - 134) & 511)] + fVec1[((IOTA - 259) & 511)]) + fVec1[((IOTA - 274) & 511)]) - fVec1[((IOTA - 298) & 511)]) - fVec1[((IOTA - 309) & 511)]) - fVec1[((IOTA - 345) & 511)]) - fVec1[((IOTA - 351) & 511)]) + fVec1[((IOTA - 421) & 511)]) - fVec1[((IOTA - 448) & 511)])) + ((0.000793481246f * (((((fVec1[((IOTA - 239) & 511)] - fVec1[((IOTA - 337) & 511)]) - fVec1[((IOTA - 344) & 511)]) - fVec1[((IOTA - 352) & 511)]) + fVec1[((IOTA - 411) & 511)]) - fVec1[((IOTA - 447) & 511)])) + ((0.00054933317f * ((((fVec1[((IOTA - 327) & 511)] - fVec1[((IOTA - 340) & 511)]) - fVec1[((IOTA - 347) & 511)]) - fVec1[((IOTA - 391) & 511)]) - fVec1[((IOTA - 430) & 511)])) + ((0.000885036774f * ((((fVec1[((IOTA - 249) & 511)] - fVec1[((IOTA - 305) & 511)]) + fVec1[((IOTA - 330) & 511)]) - fVec1[((IOTA - 354) & 511)]) + fVec1[((IOTA - 409) & 511)])) + ((0.00140385143f * (fVec1[((IOTA - 370) & 511)] + fVec1[((IOTA - 397) & 511)])) + ((0.00143436994f * (((((fVec1[((IOTA - 225) & 511)] + fVec1[((IOTA - 240) & 511)]) + fVec1[((IOTA - 267) & 511)]) - fVec1[((IOTA - 323) & 511)]) + fVec1[((IOTA - 383) & 511)]) + fVec1[((IOTA - 395) & 511)])) + (((0.00256355479f * fVec1[((IOTA - 382) & 511)]) + ((0.00296029542f * fVec1[((IOTA - 380) & 511)]) + ((0.00134281442f * fVec1[((IOTA - 369) & 511)]) + ((0.00115970336f * ((fVec1[((IOTA - 250) & 511)] + fVec1[((IOTA - 276) & 511)]) + fVec1[((IOTA - 367) & 511)])) + ((0.00119022187f * fVec1[((IOTA - 315) & 511)]) + ((0.00155644398f * fVec1[((IOTA - 266) & 511)]) + ((0.00109866634f * (fVec1[((IOTA - 138) & 511)] + fVec1[((IOTA - 261) & 511)])) + ((0.00466933195f * ((fVec1[((IOTA - 123) & 511)] - fVec1[((IOTA - 183) & 511)]) - fVec1[((IOTA - 194) & 511)])) + ((0.00146488845f * (fVec1[((IOTA - 172) & 511)] - fVec1[((IOTA - 177) & 511)])) + ((0.000976592302f * fVec1[((IOTA - 173) & 511)]) + ((0.00131229591f * fVec1[((IOTA - 168) & 511)]) + ((0.00381481368f * (fVec1[((IOTA - 95) & 511)] + fVec1[((IOTA - 166) & 511)])) + ((0.00384533219f * fVec1[((IOTA - 164) & 511)]) + ((0.00439466536f * fVec1[((IOTA - 163) & 511)]) + ((0.00488296151f * fVec1[((IOTA - 162) & 511)]) + ((0.00454725791f * fVec1[((IOTA - 161) & 511)]) + ((0.00286873989f * fVec1[((IOTA - 160) & 511)]) + ((0.00329599902f * fVec1[((IOTA - 155) & 511)]) + ((0.00668355357f * fVec1[((IOTA - 154) & 511)]) + ((0.00842310861f * fVec1[((IOTA - 153) & 511)]) + ((0.00845362712f * fVec1[((IOTA - 152) & 511)]) + ((0.00698873866f * fVec1[((IOTA - 151) & 511)]) + ((0.00463881344f * fVec1[((IOTA - 150) & 511)]) + ((0.00167851802f * fVec1[((IOTA - 149) & 511)]) + ((0.00442518387f * fVec1[((IOTA - 137) & 511)]) + ((0.00665303506f * fVec1[((IOTA - 135) & 511)]) + ((0.00253303628f * fVec1[((IOTA - 130) & 511)]) + ((0.00503555406f * fVec1[((IOTA - 129) & 511)]) + ((0.00601214636f * fVec1[((IOTA - 128) & 511)]) + ((0.0132450331f * fVec1[((IOTA - 125) & 511)]) + ((0.00912503432f * fVec1[((IOTA - 124) & 511)]) + ((0.00314340647f * fVec1[((IOTA - 122) & 511)]) + ((0.00546281319f * fVec1[((IOTA - 121) & 511)]) + ((0.00720236823f * fVec1[((IOTA - 119) & 511)]) + ((0.00680562761f * fVec1[((IOTA - 118) & 511)]) + ((0.00729392376f * fVec1[((IOTA - 117) & 511)]) + ((0.011200293f * (fVec1[((IOTA - 96) & 511)] + fVec1[((IOTA - 116) & 511)])) + ((0.0138554033f * fVec1[((IOTA - 115) & 511)]) + ((0.0142521439f * fVec1[((IOTA - 114) & 511)]) + ((0.0120548112f * fVec1[((IOTA - 113) & 511)]) + ((0.00915555283f * fVec1[((IOTA - 112) & 511)]) + ((0.00878933072f * fVec1[((IOTA - 111) & 511)]) + ((0.00772118289f * (fVec1[((IOTA - 109) & 511)] + fVec1[((IOTA - 110) & 511)])) + ((0.0035401471f * (fVec1[((IOTA - 103) & 511)] + fVec1[((IOTA - 108) & 511)])) + ((0.00891140476f * (fVec1[((IOTA - 5) & 511)] + fVec1[((IOTA - 127) & 511)])) + ((0.0125125889f * fVec1[((IOTA - 126) & 511)]) + ((0.00164799951f * fVec1[((IOTA - 107) & 511)]) + ((0.00183111057f * fVec1[((IOTA - 105) & 511)]) + ((0.0025940733f * fVec1[((IOTA - 104) & 511)]) + ((0.00820947904f * fVec1[((IOTA - 102) & 511)]) + ((0.012878811f * fVec1[((IOTA - 101) & 511)]) + ((0.0177312549f * fVec1[((IOTA - 100) & 511)]) + ((0.0161442924f * fVec1[((IOTA - 99) & 511)]) + ((0.0156254768f * fVec1[((IOTA - 98) & 511)]) + ((0.0130314035f * fVec1[((IOTA - 97) & 511)]) + ((0.0134281442f * fVec1[((IOTA - 64) & 511)]) + ((0.0411999896f * fVec1[((IOTA - 62) & 511)]) + ((0.0405285805f * fVec1[((IOTA - 61) & 511)]) + ((0.0294198431f * fVec1[((IOTA - 60) & 511)]) + ((0.0134891812f * fVec1[((IOTA - 59) & 511)]) + ((0.00219733268f * fVec1[((IOTA - 37) & 511)]) + ((0.0144657735f * fVec1[((IOTA - 36) & 511)]) + ((0.032898955f * fVec1[((IOTA - 35) & 511)]) + ((0.04876858f * fVec1[((IOTA - 34) & 511)]) + ((0.05301065f * fVec1[((IOTA - 33) & 511)]) + ((0.0475173183f * fVec1[((IOTA - 32) & 511)]) + ((0.0307626575f * fVec1[((IOTA - 31) & 511)]) + ((0.0164799951f * fVec1[((IOTA - 30) & 511)]) + ((0.00231940672f * fVec1[((IOTA - 29) & 511)]) + ((0.0164494775f * fVec1[((IOTA - 28) & 511)]) + ((0.0307321399f * fVec1[((IOTA - 27) & 511)]) + ((0.0845667869f * fVec1[((IOTA - 26) & 511)]) + ((0.120242931f * fVec1[((IOTA - 25) & 511)]) + ((0.145390183f * fVec1[((IOTA - 24) & 511)]) + ((0.114413895f * fVec1[((IOTA - 23) & 511)]) + ((0.0952482671f * fVec1[((IOTA - 22) & 511)]) + ((0.0770897567f * fVec1[((IOTA - 21) & 511)]) + ((0.0673848689f * fVec1[((IOTA - 20) & 511)]) + ((0.0488296151f * fVec1[((IOTA - 19) & 511)]) + ((0.0199285876f * fVec1[((IOTA - 18) & 511)]) + ((0.0159611814f * fVec1[((IOTA - 17) & 511)]) + ((0.00930814538f * fVec1[((IOTA - 15) & 511)]) + ((0.0791039765f * fVec1[((IOTA - 9) & 511)]) + ((0.164769426f * fVec1[((IOTA - 8) & 511)]) + ((0.201574758f * fVec1[((IOTA - 7) & 511)]) + ((0.170079648f * fVec1[((IOTA - 6) & 511)]) + (0.0297250282f * fVec1[((IOTA - 63) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000396740623f * (fVec1[((IOTA - 477) & 511)] - (((((((fVec1[((IOTA - 232) & 511)] - fVec1[((IOTA - 280) & 511)]) + fVec1[((IOTA - 293) & 511)]) + fVec1[((IOTA - 295) & 511)]) - fVec1[((IOTA - 384) & 511)]) + fVec1[((IOTA - 401) & 511)]) - fVec1[((IOTA - 413) & 511)]) - fVec1[((IOTA - 476) & 511)]))))))))))))))))))))))) - (((3.05185094e-05f * (((((((((((((fVec1[((IOTA - 206) & 511)] + fVec1[((IOTA - 228) & 511)]) - fVec1[((IOTA - 235) & 511)]) + fVec1[((IOTA - 284) & 511)]) + fVec1[((IOTA - 286) & 511)]) + fVec1[((IOTA - 310) & 511)]) - fVec1[((IOTA - 318) & 511)]) + fVec1[((IOTA - 326) & 511)]) - fVec1[((IOTA - 414) & 511)]) + fVec1[((IOTA - 418) & 511)]) - fVec1[((IOTA - 435) & 511)]) - fVec1[((IOTA - 436) & 511)]) + fVec1[((IOTA - 466) & 511)]) - fVec1[((IOTA - 508) & 511)])) + ((0.000335703604f * (((((((fVec1[((IOTA - 237) & 511)] - fVec1[((IOTA - 256) & 511)]) - fVec1[((IOTA - 290) & 511)]) + fVec1[((IOTA - 416) & 511)]) + fVec1[((IOTA - 452) & 511)]) + fVec1[((IOTA - 464) & 511)]) - fVec1[((IOTA - 475) & 511)]) + fVec1[((IOTA - 505) & 511)])) + ((0.000457777642f * ((((((((((fVec1[((IOTA - 294) & 511)] + fVec1[((IOTA - 320) & 511)]) - fVec1[((IOTA - 406) & 511)]) + fVec1[((IOTA - 450) & 511)]) + fVec1[((IOTA - 462) & 511)]) + fVec1[((IOTA - 494) & 511)]) + fVec1[((IOTA - 499) & 511)]) + fVec1[((IOTA - 500) & 511)]) + fVec1[((IOTA - 501) & 511)]) + fVec1[((IOTA - 502) & 511)]) + fVec1[((IOTA - 503) & 511)])) + ((0.000488296151f * ((((((((((fVec1[((IOTA - 175) & 511)] + fVec1[((IOTA - 218) & 511)]) + fVec1[((IOTA - 245) & 511)]) - fVec1[((IOTA - 252) & 511)]) + fVec1[((IOTA - 341) & 511)]) - fVec1[((IOTA - 364) & 511)]) - fVec1[((IOTA - 420) & 511)]) + fVec1[((IOTA - 432) & 511)]) + fVec1[((IOTA - 461) & 511)]) + fVec1[((IOTA - 495) & 511)]) + fVec1[((IOTA - 498) & 511)])) + ((0.000366222113f * (((((((((((((fVec1[((IOTA - 139) & 511)] + fVec1[((IOTA - 227) & 511)]) - fVec1[((IOTA - 255) & 511)]) - fVec1[((IOTA - 258) & 511)]) - fVec1[((IOTA - 281) & 511)]) - fVec1[((IOTA - 282) & 511)]) + fVec1[((IOTA - 304) & 511)]) - fVec1[((IOTA - 332) & 511)]) - fVec1[((IOTA - 378) & 511)]) - fVec1[((IOTA - 393) & 511)]) - fVec1[((IOTA - 425) & 511)]) + fVec1[((IOTA - 451) & 511)]) - fVec1[((IOTA - 478) & 511)]) + fVec1[((IOTA - 492) & 511)])) + ((0.000274666585f * (((((((((((((((fVec1[((IOTA - 156) & 511)] - fVec1[((IOTA - 170) & 511)]) + fVec1[((IOTA - 205) & 511)]) + fVec1[((IOTA - 207) & 511)]) - fVec1[((IOTA - 244) & 511)]) - fVec1[((IOTA - 254) & 511)]) - fVec1[((IOTA - 257) & 511)]) + fVec1[((IOTA - 362) & 511)]) + fVec1[((IOTA - 438) & 511)]) + fVec1[((IOTA - 439) & 511)]) - fVec1[((IOTA - 470) & 511)]) - fVec1[((IOTA - 471) & 511)]) - fVec1[((IOTA - 472) & 511)]) - fVec1[((IOTA - 479) & 511)]) - fVec1[((IOTA - 485) & 511)]) + fVec1[((IOTA - 491) & 511)])) + ((0.000305185094f * (((((((fVec1[((IOTA - 233) & 511)] + fVec1[((IOTA - 236) & 511)]) + fVec1[((IOTA - 247) & 511)]) - fVec1[((IOTA - 248) & 511)]) - fVec1[((IOTA - 289) & 511)]) + fVec1[((IOTA - 433) & 511)]) - fVec1[((IOTA - 474) & 511)]) - fVec1[((IOTA - 484) & 511)])) + (((0.000640888698f * ((((((((fVec1[((IOTA - 213) & 511)] + fVec1[((IOTA - 222) & 511)]) + fVec1[((IOTA - 325) & 511)]) - fVec1[((IOTA - 331) & 511)]) + fVec1[((IOTA - 339) & 511)]) + fVec1[((IOTA - 342) & 511)]) + fVec1[((IOTA - 350) & 511)]) + fVec1[((IOTA - 361) & 511)]) - fVec1[((IOTA - 412) & 511)])) + ((0.000671407208f * (((((((fVec1[((IOTA - 204) & 511)] - fVec1[((IOTA - 230) & 511)]) + fVec1[((IOTA - 246) & 511)]) - fVec1[((IOTA - 279) & 511)]) + fVec1[((IOTA - 297) & 511)]) - fVec1[((IOTA - 312) & 511)]) + fVec1[((IOTA - 335) & 511)]) - fVec1[((IOTA - 407) & 511)])) + ((0.00158696249f * (fVec1[((IOTA - 16) & 511)] - fVec1[((IOTA - 396) & 511)])) + ((0.00317392498f * (fVec1[((IOTA - 197) & 511)] - fVec1[((IOTA - 381) & 511)])) + ((0.00189214759f * ((fVec1[((IOTA - 178) & 511)] - fVec1[((IOTA - 242) & 511)]) - fVec1[((IOTA - 379) & 511)])) + ((0.00103762932f * ((((((fVec1[((IOTA - 140) & 511)] - fVec1[((IOTA - 171) & 511)]) + fVec1[((IOTA - 201) & 511)]) + fVec1[((IOTA - 211) & 511)]) + fVec1[((IOTA - 212) & 511)]) - fVec1[((IOTA - 268) & 511)]) + fVec1[((IOTA - 377) & 511)])) + ((0.00186162908f * fVec1[((IOTA - 376) & 511)]) + ((0.00177007355f * (fVec1[((IOTA - 158) & 511)] + fVec1[((IOTA - 375) & 511)])) + ((0.00137333293f * (fVec1[((IOTA - 307) & 511)] - fVec1[((IOTA - 371) & 511)])) + ((0.0012817774f * ((((fVec1[((IOTA - 200) & 511)] - fVec1[((IOTA - 243) & 511)]) - fVec1[((IOTA - 265) & 511)]) + fVec1[((IOTA - 322) & 511)]) - fVec1[((IOTA - 368) & 511)])) + ((0.00100711081f * ((((fVec1[((IOTA - 148) & 511)] + fVec1[((IOTA - 210) & 511)]) - fVec1[((IOTA - 278) & 511)]) - fVec1[((IOTA - 329) & 511)]) - fVec1[((IOTA - 366) & 511)])) + ((0.000915555283f * ((((((fVec1[((IOTA - 202) & 511)] - fVec1[((IOTA - 251) & 511)]) - fVec1[((IOTA - 316) & 511)]) + fVec1[((IOTA - 321) & 511)]) - fVec1[((IOTA - 328) & 511)]) + fVec1[((IOTA - 358) & 511)]) + fVec1[((IOTA - 360) & 511)])) + ((0.000946073793f * ((((((((((((fVec1[((IOTA - 203) & 511)] + fVec1[((IOTA - 209) & 511)]) - fVec1[((IOTA - 262) & 511)]) - fVec1[((IOTA - 264) & 511)]) - fVec1[((IOTA - 275) & 511)]) + fVec1[((IOTA - 355) & 511)]) + fVec1[((IOTA - 356) & 511)]) + fVec1[((IOTA - 357) & 511)]) + fVec1[((IOTA - 359) & 511)]) - fVec1[((IOTA - 372) & 511)]) + fVec1[((IOTA - 374) & 511)]) - fVec1[((IOTA - 394) & 511)]) - fVec1[((IOTA - 398) & 511)])) + ((0.00112918485f * (fVec1[((IOTA - 324) & 511)] - fVec1[((IOTA - 302) & 511)])) + ((0.00106814783f * (((fVec1[((IOTA - 176) & 511)] - fVec1[((IOTA - 223) & 511)]) - fVec1[((IOTA - 260) & 511)]) - fVec1[((IOTA - 314) & 511)])) + ((0.00122074038f * ((((fVec1[((IOTA - 219) & 511)] - fVec1[((IOTA - 277) & 511)]) - fVec1[((IOTA - 301) & 511)]) + fVec1[((IOTA - 306) & 511)]) + fVec1[((IOTA - 308) & 511)])) + ((0.0019226661f * (fVec1[((IOTA - 220) & 511)] - fVec1[((IOTA - 241) & 511)])) + ((0.0019531846f * (fVec1[((IOTA - 221) & 511)] - fVec1[((IOTA - 224) & 511)])) + ((0.00170903653f * fVec1[((IOTA - 199) & 511)]) + ((0.00228888821f * fVec1[((IOTA - 198) & 511)]) + ((0.00418103579f * fVec1[((IOTA - 196) & 511)]) + ((0.00473036896f * fVec1[((IOTA - 195) & 511)]) + ((0.00415051728f * fVec1[((IOTA - 193) & 511)]) + ((0.00335703604f * (fVec1[((IOTA - 143) & 511)] + fVec1[((IOTA - 192) & 511)])) + ((0.00283822138f * fVec1[((IOTA - 191) & 511)]) + ((0.00274666585f * fVec1[((IOTA - 190) & 511)]) + ((0.00338755455f * fVec1[((IOTA - 189) & 511)]) + ((0.00411999878f * fVec1[((IOTA - 188) & 511)]) + ((0.00460829493f * fVec1[((IOTA - 187) & 511)]) + ((0.00445570238f * fVec1[((IOTA - 186) & 511)]) + ((0.00430310983f * (fVec1[((IOTA - 184) & 511)] + fVec1[((IOTA - 185) & 511)])) + ((0.00479140598f * fVec1[((IOTA - 182) & 511)]) + ((0.00433362834f * fVec1[((IOTA - 181) & 511)]) + ((0.00344859157f * fVec1[((IOTA - 180) & 511)]) + ((0.00244148076f * fVec1[((IOTA - 179) & 511)]) + ((0.00292977691f * (fVec1[((IOTA - 147) & 511)] - fVec1[((IOTA - 167) & 511)])) + ((0.00375377666f * (fVec1[((IOTA - 146) & 511)] - fVec1[((IOTA - 165) & 511)])) + ((0.00222785119f * fVec1[((IOTA - 157) & 511)]) + ((0.00402844325f * fVec1[((IOTA - 145) & 511)]) + ((0.00390636921f * fVec1[((IOTA - 144) & 511)]) + ((0.00262459181f * fVec1[((IOTA - 142) & 511)]) + ((0.00152592547f * fVec1[((IOTA - 141) & 511)]) + ((0.00759910885f * ((fVec1[((IOTA - 88) & 511)] + fVec1[((IOTA - 132) & 511)]) - fVec1[((IOTA - 136) & 511)])) + ((0.00622577593f * fVec1[((IOTA - 133) & 511)]) + ((0.003234962f * fVec1[((IOTA - 131) & 511)]) + ((0.00784325693f * (fVec1[((IOTA - 89) & 511)] - fVec1[((IOTA - 120) & 511)])) + ((0.00793481246f * fVec1[((IOTA - 94) & 511)]) + ((0.0187383648f * fVec1[((IOTA - 93) & 511)]) + ((0.0250556972f * fVec1[((IOTA - 92) & 511)]) + ((0.0209051799f * fVec1[((IOTA - 91) & 511)]) + ((0.014618366f * fVec1[((IOTA - 90) & 511)]) + ((0.0101931822f * fVec1[((IOTA - 87) & 511)]) + ((0.0172124393f * fVec1[((IOTA - 86) & 511)]) + ((0.0257881414f * fVec1[((IOTA - 85) & 511)]) + ((0.030915251f * fVec1[((IOTA - 84) & 511)]) + ((0.030976288f * fVec1[((IOTA - 83) & 511)]) + ((0.0274971779f * fVec1[((IOTA - 82) & 511)]) + ((0.0239265114f * fVec1[((IOTA - 81) & 511)]) + ((0.0196539201f * fVec1[((IOTA - 80) & 511)]) + ((0.0127567369f * fVec1[((IOTA - 79) & 511)]) + ((0.0042115543f * fVec1[((IOTA - 78) & 511)]) + ((0.00347911008f * fVec1[((IOTA - 77) & 511)]) + ((0.012817774f * fVec1[((IOTA - 76) & 511)]) + ((0.0253608823f * fVec1[((IOTA - 75) & 511)]) + ((0.0304574724f * fVec1[((IOTA - 74) & 511)]) + ((0.0270393994f * fVec1[((IOTA - 73) & 511)]) + ((0.0223395489f * fVec1[((IOTA - 72) & 511)]) + ((0.0203863643f * fVec1[((IOTA - 71) & 511)]) + ((0.0214239936f * (fVec1[((IOTA - 69) & 511)] + fVec1[((IOTA - 70) & 511)])) + ((0.0189825129f * (fVec1[((IOTA - 67) & 511)] + fVec1[((IOTA - 68) & 511)])) + ((0.0143131809f * fVec1[((IOTA - 66) & 511)]) + ((0.00543229468f * fVec1[((IOTA - 65) & 511)]) + ((0.00607318338f * fVec1[((IOTA - 58) & 511)]) + ((0.0190130323f * fVec1[((IOTA - 57) & 511)]) + ((0.0255439933f * fVec1[((IOTA - 56) & 511)]) + ((0.0191045869f * fVec1[((IOTA - 55) & 511)]) + ((0.0142826624f * fVec1[((IOTA - 54) & 511)]) + ((0.0101626636f * fVec1[((IOTA - 53) & 511)]) + ((0.0175176244f * fVec1[((IOTA - 52) & 511)]) + ((0.0207220688f * fVec1[((IOTA - 51) & 511)]) + ((0.0251167342f * fVec1[((IOTA - 50) & 511)]) + ((0.0200811792f * fVec1[((IOTA - 49) & 511)]) + ((0.0214850307f * fVec1[((IOTA - 48) & 511)]) + ((0.0221564379f * fVec1[((IOTA - 47) & 511)]) + ((0.0272835474f * fVec1[((IOTA - 46) & 511)]) + ((0.0302438438f * fVec1[((IOTA - 45) & 511)]) + ((0.0345774703f * fVec1[((IOTA - 44) & 511)]) + ((0.0387585089f * fVec1[((IOTA - 43) & 511)]) + ((0.0390026569f * fVec1[((IOTA - 42) & 511)]) + ((0.0346385092f * fVec1[((IOTA - 41) & 511)]) + ((0.022766808f * fVec1[((IOTA - 40) & 511)]) + ((0.0158391073f * fVec1[((IOTA - 39) & 511)]) + (((((((((((fSlow12 * fTemp0) + (0.104556412f * fVec1[((IOTA - 1) & 511)])) + (0.230811492f * fVec1[((IOTA - 2) & 511)])) + (0.288979769f * fVec1[((IOTA - 3) & 511)])) + (0.188024536f * fVec1[((IOTA - 4) & 511)])) + (0.0254219193f * fVec1[((IOTA - 10) & 511)])) + (0.101565599f * fVec1[((IOTA - 11) & 511)])) + (0.117648855f * fVec1[((IOTA - 12) & 511)])) + (0.0620136112f * fVec1[((IOTA - 13) & 511)])) + (0.0247810297f * fVec1[((IOTA - 14) & 511)])) + (0.00531022064f * fVec1[((IOTA - 38) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000823999755f * (((fVec1[((IOTA - 353) & 511)] + fVec1[((IOTA - 389) & 511)]) - fVec1[((IOTA - 408) & 511)]) + fVec1[((IOTA - 457) & 511)])))))))))) + (0.000122074038f * (((((((fVec1[((IOTA - 214) & 511)] - fVec1[((IOTA - 271) & 511)]) + fVec1[((IOTA - 292) & 511)]) - fVec1[((IOTA - 373) & 511)]) + fVec1[((IOTA - 437) & 511)]) - fVec1[((IOTA - 488) & 511)]) + fVec1[((IOTA - 490) & 511)]) - fVec1[((IOTA - 509) & 511)])))) : (iSlow7 ? ((((0.000671407208f * ((((fVec0[((IOTA - 30) & 511)] - fVec0[((IOTA - 243) & 511)]) + fVec0[((IOTA - 321) & 511)]) + fVec0[((IOTA - 468) & 511)]) + fVec0[((IOTA - 475) & 511)])) + ((0.000640888698f * ((((((((fVec0[((IOTA - 19) & 511)] - fVec0[((IOTA - 192) & 511)]) - fVec0[((IOTA - 229) & 511)]) - fVec0[((IOTA - 242) & 511)]) - fVec0[((IOTA - 246) & 511)]) - fVec0[((IOTA - 248) & 511)]) - fVec0[((IOTA - 249) & 511)]) - fVec0[((IOTA - 258) & 511)]) + fVec0[((IOTA - 472) & 511)])) + ((0.000335703604f * (((((((fVec0[((IOTA - 74) & 511)] - fVec0[((IOTA - 198) & 511)]) + fVec0[((IOTA - 215) & 511)]) - fVec0[((IOTA - 275) & 511)]) - fVec0[((IOTA - 290) & 511)]) + fVec0[((IOTA - 332) & 511)]) + fVec0[((IOTA - 412) & 511)]) + fVec0[((IOTA - 459) & 511)])) + ((0.000183111057f * (((((((((fVec0[((IOTA - 58) & 511)] + fVec0[((IOTA - 175) & 511)]) - fVec0[((IOTA - 270) & 511)]) - fVec0[((IOTA - 272) & 511)]) + fVec0[((IOTA - 331) & 511)]) - fVec0[((IOTA - 354) & 511)]) + fVec0[((IOTA - 357) & 511)]) + fVec0[((IOTA - 392) & 511)]) + fVec0[((IOTA - 401) & 511)]) + fVec0[((IOTA - 449) & 511)])) + ((0.000457777642f * (((fVec0[((IOTA - 118) & 511)] - fVec0[((IOTA - 267) & 511)]) + fVec0[((IOTA - 358) & 511)]) + fVec0[((IOTA - 442) & 511)])) + ((0.000366222113f * (((((((((((fVec0[((IOTA - 84) & 511)] + fVec0[((IOTA - 207) & 511)]) - fVec0[((IOTA - 281) & 511)]) - fVec0[((IOTA - 291) & 511)]) + fVec0[((IOTA - 294) & 511)]) - fVec0[((IOTA - 300) & 511)]) + fVec0[((IOTA - 304) & 511)]) - fVec0[((IOTA - 315) & 511)]) + fVec0[((IOTA - 347) & 511)]) + fVec0[((IOTA - 365) & 511)]) + fVec0[((IOTA - 432) & 511)]) + fVec0[((IOTA - 439) & 511)])) + ((0.00115970336f * fVec0[((IOTA - 422) & 511)]) + ((0.00109866634f * (((fVec0[((IOTA - 319) & 511)] + fVec0[((IOTA - 370) & 511)]) - fVec0[((IOTA - 376) & 511)]) + fVec0[((IOTA - 420) & 511)])) + ((0.000946073793f * ((((fVec0[((IOTA - 152) & 511)] - fVec0[((IOTA - 284) & 511)]) + fVec0[((IOTA - 361) & 511)]) + fVec0[((IOTA - 408) & 511)]) + fVec0[((IOTA - 419) & 511)])) + ((0.000396740623f * (((((((fVec0[((IOTA - 199) & 511)] + fVec0[((IOTA - 200) & 511)]) + fVec0[((IOTA - 239) & 511)]) - fVec0[((IOTA - 254) & 511)]) - fVec0[((IOTA - 256) & 511)]) + fVec0[((IOTA - 264) & 511)]) + fVec0[((IOTA - 352) & 511)]) + fVec0[((IOTA - 411) & 511)])) + ((0.000976592302f * fVec0[((IOTA - 407) & 511)]) + ((0.000854518265f * ((((fVec0[((IOTA - 310) & 511)] + fVec0[((IOTA - 350) & 511)]) + fVec0[((IOTA - 362) & 511)]) - fVec0[((IOTA - 390) & 511)]) + fVec0[((IOTA - 398) & 511)])) + ((0.00134281442f * ((fVec0[((IOTA - 114) & 511)] + fVec0[((IOTA - 161) & 511)]) + fVec0[((IOTA - 397) & 511)])) + ((0.00183111057f * fVec0[((IOTA - 396) & 511)]) + ((0.00204474013f * (fVec0[((IOTA - 160) & 511)] + fVec0[((IOTA - 395) & 511)])) + ((0.00173955504f * fVec0[((IOTA - 394) & 511)]) + ((0.00143436994f * fVec0[((IOTA - 381) & 511)]) + ((0.0022583697f * fVec0[((IOTA - 380) & 511)]) + ((0.000793481246f * (fVec0[((IOTA - 372) & 511)] - ((((fVec0[((IOTA - 143) & 511)] - fVec0[((IOTA - 308) & 511)]) - fVec0[((IOTA - 311) & 511)]) - fVec0[((IOTA - 326) & 511)]) - fVec0[((IOTA - 334) & 511)]))) + (((0.00131229591f * (fVec0[((IOTA - 158) & 511)] - fVec0[((IOTA - 223) & 511)])) + ((0.0019531846f * ((fVec0[((IOTA - 167) & 511)] - fVec0[((IOTA - 183) & 511)]) - fVec0[((IOTA - 211) & 511)])) + ((0.00268562883f * (fVec0[((IOTA - 151) & 511)] - fVec0[((IOTA - 194) & 511)])) + ((0.00216681417f * fVec0[((IOTA - 150) & 511)]) + ((0.0045167394f * fVec0[((IOTA - 113) & 511)]) + ((0.00869777519f * fVec0[((IOTA - 112) & 511)]) + ((0.0112918485f * fVec0[((IOTA - 111) & 511)]) + ((0.0118717002f * fVec0[((IOTA - 110) & 511)]) + ((0.00946073793f * fVec0[((IOTA - 109) & 511)]) + ((0.00598162785f * fVec0[((IOTA - 108) & 511)]) + ((0.00265511032f * fVec0[((IOTA - 107) & 511)]) + ((0.00830103457f * fVec0[((IOTA - 104) & 511)]) + ((0.0120548112f * fVec0[((IOTA - 103) & 511)]) + ((0.0145268105f * fVec0[((IOTA - 102) & 511)]) + ((0.0148319956f * fVec0[((IOTA - 101) & 511)]) + ((0.0104678487f * fVec0[((IOTA - 100) & 511)]) + ((0.00338755455f * fVec0[((IOTA - 99) & 511)]) + ((0.0176091809f * fVec0[((IOTA - 87) & 511)]) + ((0.0209356975f * fVec0[((IOTA - 86) & 511)]) + ((0.0140385143f * fVec0[((IOTA - 85) & 511)]) + ((0.00167851802f * fVec0[((IOTA - 78) & 511)]) + ((0.0038758507f * fVec0[((IOTA - 77) & 511)]) + ((0.00604266487f * fVec0[((IOTA - 76) & 511)]) + ((0.00469985045f * fVec0[((IOTA - 75) & 511)]) + ((0.0195013285f * fVec0[((IOTA - 62) & 511)]) + ((0.0296945106f * fVec0[((IOTA - 61) & 511)]) + ((0.0282296222f * fVec0[((IOTA - 60) & 511)]) + ((0.0157475509f * fVec0[((IOTA - 59) & 511)]) + ((0.00640888698f * fVec0[((IOTA - 54) & 511)]) + ((0.0200811792f * fVec0[((IOTA - 53) & 511)]) + ((0.0250251777f * fVec0[((IOTA - 52) & 511)]) + ((0.0215765871f * fVec0[((IOTA - 51) & 511)]) + ((0.0162053294f * fVec0[((IOTA - 50) & 511)]) + ((0.0200506616f * fVec0[((IOTA - 49) & 511)]) + ((0.032654807f * fVec0[((IOTA - 48) & 511)]) + ((0.0458998382f * fVec0[((IOTA - 47) & 511)]) + ((0.0423902087f * fVec0[((IOTA - 46) & 511)]) + ((0.0199896246f * fVec0[((IOTA - 45) & 511)]) + ((0.0208136234f * fVec0[((IOTA - 35) & 511)]) + ((0.025696585f * fVec0[((IOTA - 34) & 511)]) + ((0.0198675506f * fVec0[((IOTA - 33) & 511)]) + ((0.0157170333f * fVec0[((IOTA - 32) & 511)]) + ((0.0121768853f * fVec0[((IOTA - 31) & 511)]) + ((0.0190435499f * fVec0[((IOTA - 24) & 511)]) + ((0.0838343427f * fVec0[((IOTA - 23) & 511)]) + ((0.112643816f * fVec0[((IOTA - 22) & 511)]) + ((0.0903042704f * fVec0[((IOTA - 21) & 511)]) + (((((((((((((0.120090336f * fVec0[((IOTA - 5) & 511)]) + (0.223944828f * fVec0[((IOTA - 6) & 511)])) + (0.151402324f * fVec0[((IOTA - 7) & 511)])) + (0.0442518406f * fVec0[((IOTA - 8) & 511)])) + (0.0111392559f * fVec0[((IOTA - 10) & 511)])) + (0.0402539149f * fVec0[((IOTA - 11) & 511)])) + (0.0483108014f * fVec0[((IOTA - 12) & 511)])) + (0.0375072472f * fVec0[((IOTA - 13) & 511)])) + (0.0345469527f * fVec0[((IOTA - 14) & 511)])) + (0.0576799847f * fVec0[((IOTA - 15) & 511)])) + (0.0552995391f * fVec0[((IOTA - 16) & 511)])) + (0.0322885849f * fVec0[((IOTA - 17) & 511)])) + (0.0408337675f * fVec0[((IOTA - 20) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000762962736f * (fVec0[((IOTA - 418) & 511)] - (((fVec0[((IOTA - 237) & 511)] + fVec0[((IOTA - 285) & 511)]) + fVec0[((IOTA - 340) & 511)]) - fVec0[((IOTA - 349) & 511)]))))))))))))))))))))))) + (0.000122074038f * (((((((fVec0[((IOTA - 346) & 511)] - (((((fVec0[((IOTA - 117) & 511)] + fVec0[((IOTA - 230) & 511)]) + fVec0[((IOTA - 288) & 511)]) - fVec0[((IOTA - 305) & 511)]) + fVec0[((IOTA - 314) & 511)]) - fVec0[((IOTA - 337) & 511)])) + fVec0[((IOTA - 402) & 511)]) + fVec0[((IOTA - 415) & 511)]) + fVec0[((IOTA - 444) & 511)]) + fVec0[((IOTA - 462) & 511)]) - fVec0[((IOTA - 501) & 511)]) - fVec0[((IOTA - 504) & 511)]))) - (((3.05185094e-05f * ((((((((((fVec0[((IOTA - 238) & 511)] - (((fVec0[((IOTA - 157) & 511)] - fVec0[((IOTA - 208) & 511)]) - fVec0[((IOTA - 214) & 511)]) + fVec0[((IOTA - 232) & 511)])) + fVec0[((IOTA - 265) & 511)]) + fVec0[((IOTA - 273) & 511)]) + fVec0[((IOTA - 280) & 511)]) - fVec0[((IOTA - 353) & 511)]) + fVec0[((IOTA - 373) & 511)]) + fVec0[((IOTA - 429) & 511)]) - fVec0[((IOTA - 451) & 511)]) + fVec0[((IOTA - 506) & 511)]) + fVec0[((IOTA - 510) & 511)])) + (((0.000152592547f * (((((((((((((((fVec0[((IOTA - 205) & 511)] + fVec0[((IOTA - 233) & 511)]) + fVec0[((IOTA - 278) & 511)]) - fVec0[((IOTA - 317) & 511)]) - fVec0[((IOTA - 323) & 511)]) - fVec0[((IOTA - 377) & 511)]) + fVec0[((IOTA - 387) & 511)]) - fVec0[((IOTA - 427) & 511)]) - fVec0[((IOTA - 431) & 511)]) - fVec0[((IOTA - 437) & 511)]) - fVec0[((IOTA - 446) & 511)]) + fVec0[((IOTA - 456) & 511)]) - fVec0[((IOTA - 461) & 511)]) + fVec0[((IOTA - 500) & 511)]) + fVec0[((IOTA - 502) & 511)]) + fVec0[((IOTA - 503) & 511)])) + ((0.000213629566f * (((((((((((((((fVec0[((IOTA - 287) & 511)] + fVec0[((IOTA - 289) & 511)]) + fVec0[((IOTA - 292) & 511)]) + fVec0[((IOTA - 298) & 511)]) - fVec0[((IOTA - 301) & 511)]) - fVec0[((IOTA - 306) & 511)]) + fVec0[((IOTA - 345) & 511)]) + fVec0[((IOTA - 355) & 511)]) - fVec0[((IOTA - 386) & 511)]) - fVec0[((IOTA - 413) & 511)]) - fVec0[((IOTA - 438) & 511)]) + fVec0[((IOTA - 453) & 511)]) + fVec0[((IOTA - 479) & 511)]) + fVec0[((IOTA - 489) & 511)]) + fVec0[((IOTA - 490) & 511)]) + fVec0[((IOTA - 499) & 511)])) + ((0.000274666585f * (((((((((((((((fVec0[((IOTA - 162) & 511)] - fVec0[((IOTA - 240) & 511)]) + fVec0[((IOTA - 241) & 511)]) + fVec0[((IOTA - 262) & 511)]) - fVec0[((IOTA - 313) & 511)]) + fVec0[((IOTA - 338) & 511)]) - fVec0[((IOTA - 426) & 511)]) - fVec0[((IOTA - 448) & 511)]) - fVec0[((IOTA - 458) & 511)]) + fVec0[((IOTA - 480) & 511)]) + fVec0[((IOTA - 482) & 511)]) + fVec0[((IOTA - 492) & 511)]) + fVec0[((IOTA - 493) & 511)]) + fVec0[((IOTA - 494) & 511)]) + fVec0[((IOTA - 495) & 511)]) + fVec0[((IOTA - 498) & 511)])) + ((0.000305185094f * ((((((((((((((((((fVec0[((IOTA - 165) & 511)] + fVec0[((IOTA - 174) & 511)]) - fVec0[((IOTA - 206) & 511)]) + fVec0[((IOTA - 255) & 511)]) - fVec0[((IOTA - 263) & 511)]) - fVec0[((IOTA - 297) & 511)]) + fVec0[((IOTA - 316) & 511)]) - fVec0[((IOTA - 322) & 511)]) - fVec0[((IOTA - 324) & 511)]) - fVec0[((IOTA - 400) & 511)]) - fVec0[((IOTA - 416) & 511)]) + fVec0[((IOTA - 454) & 511)]) + fVec0[((IOTA - 455) & 511)]) + fVec0[((IOTA - 481) & 511)]) + fVec0[((IOTA - 485) & 511)]) + fVec0[((IOTA - 486) & 511)]) + fVec0[((IOTA - 487) & 511)]) + fVec0[((IOTA - 496) & 511)]) + fVec0[((IOTA - 497) & 511)])) + ((0.000244148076f * ((((((((((((((fVec0[((IOTA - 268) & 511)] + fVec0[((IOTA - 271) & 511)]) - fVec0[((IOTA - 330) & 511)]) - fVec0[((IOTA - 385) & 511)]) - fVec0[((IOTA - 403) & 511)]) - fVec0[((IOTA - 436) & 511)]) - fVec0[((IOTA - 443) & 511)]) - fVec0[((IOTA - 447) & 511)]) - fVec0[((IOTA - 460) & 511)]) - fVec0[((IOTA - 463) & 511)]) - fVec0[((IOTA - 477) & 511)]) + fVec0[((IOTA - 483) & 511)]) + fVec0[((IOTA - 484) & 511)]) + fVec0[((IOTA - 488) & 511)]) + fVec0[((IOTA - 491) & 511)])) + ((0.000488296151f * ((((((fVec0[((IOTA - 286) & 511)] - fVec0[((IOTA - 329) & 511)]) - fVec0[((IOTA - 336) & 511)]) - fVec0[((IOTA - 382) & 511)]) + fVec0[((IOTA - 391) & 511)]) - fVec0[((IOTA - 404) & 511)]) - fVec0[((IOTA - 476) & 511)])) + ((0.000732444227f * ((((((((fVec0[((IOTA - 253) & 511)] - fVec0[((IOTA - 318) & 511)]) - fVec0[((IOTA - 328) & 511)]) - fVec0[((IOTA - 335) & 511)]) + fVec0[((IOTA - 343) & 511)]) - fVec0[((IOTA - 351) & 511)]) - fVec0[((IOTA - 368) & 511)]) - fVec0[((IOTA - 409) & 511)]) - fVec0[((IOTA - 474) & 511)])) + ((0.000701925717f * (((((((((fVec0[((IOTA - 203) & 511)] + fVec0[((IOTA - 247) & 511)]) + fVec0[((IOTA - 282) & 511)]) - fVec0[((IOTA - 302) & 511)]) - fVec0[((IOTA - 303) & 511)]) - fVec0[((IOTA - 359) & 511)]) - fVec0[((IOTA - 405) & 511)]) - fVec0[((IOTA - 466) & 511)]) - fVec0[((IOTA - 467) & 511)]) - fVec0[((IOTA - 473) & 511)])) + ((0.00057985168f * (((((((((((fVec0[((IOTA - 115) & 511)] + fVec0[((IOTA - 204) & 511)]) - fVec0[((IOTA - 295) & 511)]) - fVec0[((IOTA - 312) & 511)]) - fVec0[((IOTA - 325) & 511)]) + fVec0[((IOTA - 339) & 511)]) - fVec0[((IOTA - 348) & 511)]) - fVec0[((IOTA - 367) & 511)]) + fVec0[((IOTA - 388) & 511)]) - fVec0[((IOTA - 441) & 511)]) - fVec0[((IOTA - 470) & 511)]) - fVec0[((IOTA - 471) & 511)])) + ((0.000610370189f * ((((((fVec0[((IOTA - 134) & 511)] + fVec0[((IOTA - 191) & 511)]) - fVec0[((IOTA - 296) & 511)]) - fVec0[((IOTA - 333) & 511)]) - fVec0[((IOTA - 363) & 511)]) - fVec0[((IOTA - 465) & 511)]) - fVec0[((IOTA - 469) & 511)])) + ((0.000427259132f * (((((((fVec0[((IOTA - 149) & 511)] + fVec0[((IOTA - 202) & 511)]) + fVec0[((IOTA - 266) & 511)]) + fVec0[((IOTA - 277) & 511)]) - fVec0[((IOTA - 364) & 511)]) - fVec0[((IOTA - 366) & 511)]) - fVec0[((IOTA - 435) & 511)]) - fVec0[((IOTA - 464) & 511)])) + ((0.000518814661f * ((((((((((fVec0[((IOTA - 234) & 511)] + fVec0[((IOTA - 244) & 511)]) + fVec0[((IOTA - 245) & 511)]) + fVec0[((IOTA - 257) & 511)]) + fVec0[((IOTA - 276) & 511)]) - fVec0[((IOTA - 307) & 511)]) + fVec0[((IOTA - 344) & 511)]) - fVec0[((IOTA - 399) & 511)]) - fVec0[((IOTA - 410) & 511)]) - fVec0[((IOTA - 433) & 511)]) - fVec0[((IOTA - 440) & 511)])) + ((0.00054933317f * (((fVec0[((IOTA - 299) & 511)] - fVec0[((IOTA - 417) & 511)]) - fVec0[((IOTA - 425) & 511)]) - fVec0[((IOTA - 434) & 511)])) + ((0.000823999755f * (((((fVec0[((IOTA - 116) & 511)] + fVec0[((IOTA - 119) & 511)]) + fVec0[((IOTA - 209) & 511)]) + fVec0[((IOTA - 341) & 511)]) + fVec0[((IOTA - 342) & 511)]) - fVec0[((IOTA - 424) & 511)])) + ((0.00103762932f * ((fVec0[((IOTA - 95) & 511)] - fVec0[((IOTA - 320) & 511)]) - fVec0[((IOTA - 423) & 511)])) + ((0.00119022187f * (fVec0[((IOTA - 236) & 511)] - fVec0[((IOTA - 421) & 511)])) + ((0.000885036774f * (((((((fVec0[((IOTA - 250) & 511)] + fVec0[((IOTA - 259) & 511)]) + fVec0[((IOTA - 261) & 511)]) - fVec0[((IOTA - 309) & 511)]) - fVec0[((IOTA - 327) & 511)]) - fVec0[((IOTA - 360) & 511)]) + fVec0[((IOTA - 389) & 511)]) - fVec0[((IOTA - 406) & 511)])) + ((0.00234992523f * ((fVec0[((IOTA - 137) & 511)] + fVec0[((IOTA - 184) & 511)]) - fVec0[((IOTA - 379) & 511)])) + ((0.00152592547f * (fVec0[((IOTA - 173) & 511)] - fVec0[((IOTA - 378) & 511)])) + ((0.00149540696f * (fVec0[((IOTA - 193) & 511)] + fVec0[((IOTA - 375) & 511)])) + ((0.00100711081f * (fVec0[((IOTA - 235) & 511)] + fVec0[((IOTA - 374) & 511)])) + ((0.00112918485f * (((fVec0[((IOTA - 135) & 511)] + fVec0[((IOTA - 177) & 511)]) + fVec0[((IOTA - 251) & 511)]) - fVec0[((IOTA - 371) & 511)])) + ((0.000915555283f * ((((fVec0[((IOTA - 142) & 511)] + fVec0[((IOTA - 213) & 511)]) + fVec0[((IOTA - 217) & 511)]) + fVec0[((IOTA - 283) & 511)]) - fVec0[((IOTA - 369) & 511)])) + (((0.00146488845f * fVec0[((IOTA - 228) & 511)]) + ((0.00207525864f * ((fVec0[((IOTA - 144) & 511)] + fVec0[((IOTA - 226) & 511)]) + fVec0[((IOTA - 227) & 511)])) + ((0.001617481f * ((fVec0[((IOTA - 156) & 511)] + fVec0[((IOTA - 197) & 511)]) + fVec0[((IOTA - 225) & 511)])) + ((0.00122074038f * fVec0[((IOTA - 224) & 511)]) + ((0.00177007355f * (fVec0[((IOTA - 96) & 511)] + fVec0[((IOTA - 222) & 511)])) + ((0.00228888821f * (fVec0[((IOTA - 126) & 511)] + fVec0[((IOTA - 221) & 511)])) + ((0.00253303628f * (fVec0[((IOTA - 125) & 511)] + fVec0[((IOTA - 220) & 511)])) + ((0.00170903653f * (fVec0[((IOTA - 141) & 511)] + fVec0[((IOTA - 212) & 511)])) + ((0.00158696249f * (fVec0[((IOTA - 153) & 511)] + fVec0[((IOTA - 210) & 511)])) + ((0.00241096225f * fVec0[((IOTA - 219) & 511)]) + ((0.00180059206f * fVec0[((IOTA - 218) & 511)]) + ((0.0028992584f * (fVec0[((IOTA - 128) & 511)] + fVec0[((IOTA - 196) & 511)])) + ((0.00332651753f * fVec0[((IOTA - 195) & 511)]) + ((0.00125125889f * fVec0[((IOTA - 190) & 511)]) + ((0.00231940672f * fVec0[((IOTA - 189) & 511)]) + ((0.00335703604f * fVec0[((IOTA - 188) & 511)]) + ((0.00393688772f * fVec0[((IOTA - 187) & 511)]) + ((0.00378429517f * fVec0[((IOTA - 186) & 511)]) + ((0.00311288796f * fVec0[((IOTA - 185) & 511)]) + ((0.00219733268f * fVec0[((IOTA - 182) & 511)]) + ((0.00308236945f * (fVec0[((IOTA - 154) & 511)] + fVec0[((IOTA - 181) & 511)])) + ((0.00399792474f * (fVec0[((IOTA - 179) & 511)] + fVec0[((IOTA - 180) & 511)])) + ((0.00277718436f * fVec0[((IOTA - 178) & 511)]) + ((0.00329599902f * (((fVec0[((IOTA - 18) & 511)] - fVec0[((IOTA - 63) & 511)]) + fVec0[((IOTA - 97) & 511)]) + fVec0[((IOTA - 172) & 511)])) + ((0.004852443f * fVec0[((IOTA - 171) & 511)]) + ((0.00488296151f * fVec0[((IOTA - 170) & 511)]) + ((0.00296029542f * fVec0[((IOTA - 169) & 511)]) + ((0.00164799951f * (fVec0[((IOTA - 79) & 511)] - fVec0[((IOTA - 166) & 511)])) + ((0.00201422162f * fVec0[((IOTA - 164) & 511)]) + ((0.00186162908f * fVec0[((IOTA - 163) & 511)]) + ((0.00198370311f * (fVec0[((IOTA - 140) & 511)] - fVec0[((IOTA - 159) & 511)])) + ((0.00292977691f * fVec0[((IOTA - 155) & 511)]) + ((0.00341807306f * fVec0[((IOTA - 148) & 511)]) + ((0.00552385021f * fVec0[((IOTA - 147) & 511)]) + ((0.00570696127f * fVec0[((IOTA - 146) & 511)]) + ((0.0042115543f * fVec0[((IOTA - 145) & 511)]) + ((0.00189214759f * fVec0[((IOTA - 139) & 511)]) + ((0.0019226661f * (fVec0[((IOTA - 138) & 511)] - ((fVec0[((IOTA - 36) & 511)] + fVec0[((IOTA - 106) & 511)]) - fVec0[((IOTA - 127) & 511)]))) + ((0.00210577715f * fVec0[((IOTA - 136) & 511)]) + ((0.00250251777f * ((fVec0[((IOTA - 98) & 511)] + fVec0[((IOTA - 124) & 511)]) + fVec0[((IOTA - 133) & 511)])) + ((0.00680562761f * fVec0[((IOTA - 132) & 511)]) + ((0.0100711081f * fVec0[((IOTA - 131) & 511)]) + ((0.00964384899f * fVec0[((IOTA - 130) & 511)]) + ((0.0061342204f * fVec0[((IOTA - 129) & 511)]) + ((0.00326548051f * fVec0[((IOTA - 123) & 511)]) + ((0.00491348002f * fVec0[((IOTA - 122) & 511)]) + ((0.00555436872f * fVec0[((IOTA - 121) & 511)]) + ((0.00402844325f * fVec0[((IOTA - 120) & 511)]) + ((0.00424207281f * (fVec0[((IOTA - 93) & 511)] - fVec0[((IOTA - 105) & 511)])) + ((0.0140079958f * fVec0[((IOTA - 91) & 511)]) + ((0.0125125889f * fVec0[((IOTA - 90) & 511)]) + ((0.00476088747f * fVec0[((IOTA - 89) & 511)]) + ((0.00708029419f * (fVec0[((IOTA - 73) & 511)] - fVec0[((IOTA - 88) & 511)])) + ((0.00939970091f * fVec0[((IOTA - 92) & 511)]) + ((0.0012817774f * fVec0[((IOTA - 94) & 511)]) + ((0.0102847377f * fVec0[((IOTA - 83) & 511)]) + ((0.0129703665f * fVec0[((IOTA - 82) & 511)]) + ((0.00997955259f * fVec0[((IOTA - 81) & 511)]) + ((0.0054933317f * fVec0[((IOTA - 80) & 511)]) + ((0.0124515519f * (fVec0[((IOTA - 69) & 511)] + fVec0[((IOTA - 72) & 511)])) + ((0.0148014771f * fVec0[((IOTA - 71) & 511)]) + ((0.0135807367f * fVec0[((IOTA - 70) & 511)]) + ((0.0138248848f * fVec0[((IOTA - 68) & 511)]) + ((0.0181890316f * fVec0[((IOTA - 67) & 511)]) + ((0.0208746605f * fVec0[((IOTA - 66) & 511)]) + ((0.0186773278f * fVec0[((IOTA - 65) & 511)]) + (((0.0133671071f * fVec0[((IOTA - 57) & 511)]) + ((0.0171819218f * fVec0[((IOTA - 56) & 511)]) + ((0.0093691824f * fVec0[((IOTA - 55) & 511)]) + ((0.0117801446f * fVec0[((IOTA - 44) & 511)]) + ((0.0340891741f * fVec0[((IOTA - 43) & 511)]) + ((0.0320444368f * fVec0[((IOTA - 42) & 511)]) + ((0.0163884405f * fVec0[((IOTA - 41) & 511)]) + ((0.00784325693f * fVec0[((IOTA - 40) & 511)]) + ((0.0170293283f * fVec0[((IOTA - 39) & 511)]) + ((0.0239265114f * fVec0[((IOTA - 38) & 511)]) + ((0.0169682913f * fVec0[((IOTA - 37) & 511)]) + ((0.0150456252f * fVec0[((IOTA - 29) & 511)]) + ((0.0316171758f * fVec0[((IOTA - 28) & 511)]) + ((0.0583819076f * fVec0[((IOTA - 27) & 511)]) + ((0.0728171617f * fVec0[((IOTA - 26) & 511)]) + (((((((fSlow10 * fTemp0) + (0.179143652f * fVec0[((IOTA - 1) & 511)])) + (0.329630435f * fVec0[((IOTA - 2) & 511)])) + (0.332651764f * fVec0[((IOTA - 3) & 511)])) + (0.130802333f * fVec0[((IOTA - 4) & 511)])) + (0.00714133121f * fVec0[((IOTA - 9) & 511)])) + (0.0500503555f * fVec0[((IOTA - 25) & 511)]))))))))))))))))) + (0.0102237007f * fVec0[((IOTA - 64) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00106814783f * ((fVec0[((IOTA - 252) & 511)] + fVec0[((IOTA - 260) & 511)]) - fVec0[((IOTA - 393) & 511)])))))))))))))))))))))))))) + (9.15555283e-05f * ((((((((fVec0[((IOTA - 269) & 511)] + fVec0[((IOTA - 274) & 511)]) - fVec0[((IOTA - 414) & 511)]) - fVec0[((IOTA - 445) & 511)]) - fVec0[((IOTA - 450) & 511)]) - fVec0[((IOTA - 457) & 511)]) + fVec0[((IOTA - 505) & 511)]) + fVec0[((IOTA - 508) & 511)]) + fVec0[((IOTA - 509) & 511)])))) + (6.10370189e-05f * (((((((((fVec0[((IOTA - 216) & 511)] - fVec0[((IOTA - 231) & 511)]) - fVec0[((IOTA - 279) & 511)]) - fVec0[((IOTA - 293) & 511)]) + fVec0[((IOTA - 356) & 511)]) - fVec0[((IOTA - 384) & 511)]) - fVec0[((IOTA - 428) & 511)]) + fVec0[((IOTA - 452) & 511)]) + fVec0[((IOTA - 507) & 511)]) - fVec0[((IOTA - 511) & 511)])))) : (fSlow8 * fTemp0)))))))));
			IOTA = (IOTA + 1);
		}
	}

};

//----------------------------------------------------------------------------
//  LV2 interface
//----------------------------------------------------------------------------

#line 286 "lv2.cpp"

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>

#include <bitset>
#include <boost/circular_buffer.hpp>

#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
#include <lv2/lv2plug.in/ns/ext/atom/util.h>
#include <lv2/lv2plug.in/ns/ext/urid/urid.h>

// Set this to the proper shared library extension for your system
#ifndef DLLEXT
#define DLLEXT ".so"
#endif

#ifndef URI_PREFIX
#define URI_PREFIX "https://faustlv2.bitbucket.io"
#endif

#ifndef PLUGIN_URI
#define PLUGIN_URI URI_PREFIX "/vintage_mics"
#endif

#define MIDI_EVENT_URI "http://lv2plug.in/ns/ext/midi#MidiEvent"

/* Setting NVOICES at compile time overrides meta data in the Faust source. If
   set, this must be an integer value >= 0. A nonzero value indicates an
   instrument (VSTi) plugin with the given maximum number of voices. Use 1 for
   a monophonic synthesizer, and 0 for a simple effect plugin. If NVOICES
   isn't defined at compile time then the number of voices of an instrument
   plugin can also be set with the global "nvoices" meta data key in the Faust
   source. This setting also adds a special "polyphony" control to the plugin
   which can be used to dynamically adjust the actual number of voices in the
   range 1..NVOICES. */
//#define NVOICES 16

/* This enables a special "tuning" control for instruments which lets you
   select the MTS tuning to be used for the synth. In order to use this, you
   just drop some sysex (.syx) files with MTS octave-based tunings in 1- or
   2-byte format into the ~/.fautvst/tuning directory (these can be generated
   with the author's sclsyx program, https://bitbucket.org/agraef/sclsyx).
   The control will only be shown if any .syx files were found at startup. 0
   selects the default tuning (standard 12-tone equal temperament), i>0 the
   tuning in the ith sysex file (in alphabetic order). */
#ifndef FAUST_MTS
#define FAUST_MTS 1
#endif

/* This allows various manifest data to be generated from the corresponding
   metadata (author, name, description, license) in the Faust source. */
#ifndef FAUST_META
#define FAUST_META 1
#endif

/* This enables automatic MIDI controller mapping based on the midi:ctrl
   attributes in the Faust source. We have this enabled by default, but you
   may have to disable it if the custom controller mapping gets in the way of
   the automation facilities that the host provides. (But then again if the
   host wants to do its own controller mapping then it probably won't, or at
   least shouldn't, send us the MIDI controllers in the first place.) */
#ifndef FAUST_MIDICC
#define FAUST_MIDICC 1
#endif

/* This enables or disables the plugin's custom Qt GUI (cf. lv2ui.cpp). Note
   that this only affects the plugin manifest, the GUI code itself is in a
   separate module created with the lv2ui.cpp architecture. Also, you'll have
   to use the alternative lv2ui manifest templates to tell the LV2 host about
   the GUI. */
#ifndef FAUST_UI
#define FAUST_UI 0
#endif

// You can define these for various debugging output items.
//#define DEBUG_META 1 // recognized MIDI controller metadata
//#define DEBUG_VOICES 1 // triggering of synth voices
//#define DEBUG_VOICE_ALLOC 1 // voice allocation
//#define DEBUG_MIDI 1 // incoming MIDI messages
//#define DEBUG_NOTES 1 // note messages
//#define DEBUG_MIDICC 1 // controller messages
//#define DEBUG_RPN 1 // RPN messages (pitch bend range, master tuning)
//#define DEBUG_MTS 1 // MTS messages (octave/scale tuning)

// Note and voice data structures.

struct NoteInfo {
  uint8_t ch;
  int8_t note;
};

struct VoiceData {
  // Octave tunings (offsets in semitones) per MIDI channel.
  float tuning[16][12];
  // Allocated voices per MIDI channel and note.
  int8_t notes[16][128];
  // Free and used voices.
  int n_free, n_used;
  boost::circular_buffer<int> free_voices;
  boost::circular_buffer<int> used_voices;
  NoteInfo *note_info;
  // Voices queued for note-offs (zero-length notes).
  set<int> queued;
  // Last gate value during run() for each voice. We need to keep track of
  // these so that we can force the Faust synth to retrigger a note when
  // needed.
  float *lastgate;
  // Current pitch bend and pitch bend range on each MIDI channel, in semitones.
  float bend[16], range[16];
  // Current coarse, fine and total master tuning on each MIDI channel (tuning
  // offset relative to A4 = 440 Hz, in semitones).
  float coarse[16], fine[16], tune[16];
  VoiceData(int n) : free_voices(n), used_voices(n) { }
};

#if FAUST_MTS

// Helper classes to read and store MTS tunings.

#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>

#include <string>
#include <vector>

struct MTSTuning {
  char *name; // name of the tuning
  int len; // length of sysex data in bytes
  unsigned char *data; // sysex data
  MTSTuning() : name(0), len(0), data(0) {}
  MTSTuning& operator=(const MTSTuning &t)
  {
    if (this == &t) return *this;
    if (name) free(name); if (data) free(data);
    name = 0; data = 0; len = t.len;
    if (t.name) {
      name = strdup(t.name); assert(name);
    }
    if (t.data) {
      data = (unsigned char*)malloc(len); assert(data);
      memcpy(data, t.data, len);
    }
    return *this;
  }
  MTSTuning(const MTSTuning& t) : name(0), len(0), data(0)
  { *this = t; }
  MTSTuning(const char *filename);
  ~MTSTuning()
  { if (name) free(name); if (data) free(data); }
};

MTSTuning::MTSTuning(const char *filename)
{
  FILE *fp = fopen(filename, "rb");
  name = 0; len = 0; data = 0;
  if (!fp) return;
  struct stat st;
  if (fstat(fileno(fp), &st)) return;
  len = st.st_size;
  data = (unsigned char*)calloc(len, 1);
  if (!data) {
    len = 0; fclose(fp);
    return;
  }
  assert(len > 0);
  if (fread(data, 1, len, fp) < len) {
    free(data); len = 0; data = 0; fclose(fp);
    return;
  }
  fclose(fp);
  // Do some basic sanity checks.
  if (data[0] != 0xf0 || data[len-1] != 0xf7 || // not a sysex message
      (data[1] != 0x7e && data[1] != 0x7f) || data[3] != 8 || // not MTS
      !((len == 21 && data[4] == 8) ||
	(len == 33 && data[4] == 9))) { // no 1- or 2-byte tuning
    free(data); len = 0; data = 0;
    return;
  }
  // Name of the tuning is the basename of the file, without the trailing .syx
  // suffix.
  string nm = filename;
  size_t p = nm.rfind(".syx");
  if (p != string::npos) nm.erase(p);
  p = nm.rfind('/');
  if (p != string::npos) nm.erase(0, p+1);
  name = strdup(nm.c_str());
  assert(name);
}

struct MTSTunings {
  vector<MTSTuning> tuning;
  MTSTunings() {}
  MTSTunings(const char *path);
};

static bool compareByName(const MTSTuning &a, const MTSTuning &b)
{
  return strcmp(a.name, b.name) < 0;
}

MTSTunings::MTSTunings(const char *path)
{
  DIR *dp = opendir(path);
  if (!dp) return;
  struct dirent *d;
  while ((d = readdir(dp))) {
    string nm = d->d_name;
    if (nm.length() > 4 && nm.substr(nm.length()-4) == ".syx") {
      string pathname = path;
      pathname += "/";
      pathname += nm;
      MTSTuning t(pathname.c_str());
      if (t.data) tuning.push_back(t);
    }
  }
  closedir(dp);
  // sort found tunings by name
  sort(tuning.begin(), tuning.end(), compareByName);
}

#endif

#if FAUST_MIDICC
static float ctrlval(const ui_elem_t &el, uint8_t v)
{
  // Translate the given MIDI controller value to the range and stepsize
  // indicated by the Faust control.
  switch (el.type) {
  case UI_BUTTON: case UI_CHECK_BUTTON:
    return (float)(v>=64);
  default:
    /* Continuous controllers. The problem here is that the range 0..127 is
       not symmetric. We'd like to map 64 to the center of the range
       (max-min)/2 and at the same time retain the full control range
       min..max. So let's just pretend that there are 128 controller values
       and map value 127 to the max value anyway. */
    if (v==127)
      return el.max;
    else
      // XXXFIXME: We might want to add proper quantization according to
      // el.step here.
      return el.min+(el.max-el.min)*v/128;
  }
}
#endif

/***************************************************************************/

/* Polyphonic Faust plugin data structure. XXXTODO: At present this is just a
   big struct which exposes all requisite data. Some more work is needed to
   make the interface a bit more abstract and properly encapsulate the
   internal data structures, so that implementation details can be changed
   more easily. */

struct LV2Plugin {
  const int maxvoices;	// maximum number of voices (zero if not an instrument)
  const int ndsps;	// number of dsp instances (1 if maxvoices==0)
  bool active;		// activation status
  int rate;		// sampling rate
  int nvoices;		// current number of voices (<= maxvoices)
  int tuning_no;	// current tuning number (<= n_tunings)
  vintage_mics **dsp;		// the dsps
  LV2UI **ui;		// their Faust interface descriptions
  int n_in, n_out;	// number of input and output control ports
  int *ctrls;		// Faust ui elements (indices into ui->elems)
  float **ports;	// corresponding LV2 data
  float *portvals;	// cached port data from the last run
  float *midivals[16];	// per-midi channel data
  int *inctrls, *outctrls;	// indices for active and passive controls
  float **inputs, **outputs;	// audio buffers
  int freq, gain, gate;	// indices of voice controls
  unsigned n_samples;	// current block size
  float **outbuf;	// audio buffers for mixing down the voices
  float **inbuf;	// dummy input buffer
  LV2_Atom_Sequence* event_port; // midi input
  float *poly, *tuning;	// polyphony and tuning ports
  std::map<uint8_t,int> ctrlmap; // MIDI controller map
  // Needed host features.
  LV2_URID_Map* map;	// the urid extension
  LV2_URID midi_event;	// midi event uri
  // Current RPN MSB and LSB numbers, as set with controllers 101 and 100.
  uint8_t rpn_msb[16], rpn_lsb[16];
  // Current data entry MSB and LSB numbers, as set with controllers 6 and 38.
  uint8_t data_msb[16], data_lsb[16];
  // Synth voice data (instruments only).
  VoiceData *vd;

  // Static methods. These all use static data so they can be invoked before
  // instantiating a plugin.

  // Global meta data (dsp name, author, etc.).
  static Meta *meta;
  static void init_meta()
  {
    if (!meta && (meta = new Meta)) {
      // We allocate the temporary dsp object on the heap here, to prevent
      // large dsp objects from running out of stack in environments where
      // stack space is precious (e.g., Reaper). Note that if any of these
      // allocations fail then no meta data will be available, but at least we
      // won't make the host crash and burn.
      vintage_mics* tmp_dsp = new vintage_mics();
      if (tmp_dsp) {
	tmp_dsp->metadata(meta);
	delete tmp_dsp;
      }
    }
  }
  static const char *meta_get(const char *key, const char *deflt)
  {
    init_meta();
    return meta?meta->get(key, deflt):deflt;
  }

  static const char *pluginName()
  {
    return meta_get("name", "vintage_mics");
  }

  static const char *pluginAuthor()
  {
    return meta_get("author", "");
  }

  static const char *pluginDescription()
  {
    return meta_get("description", "");
  }

  static const char *pluginLicense()
  {
    return meta_get("license", "");
  }

  static const char *pluginVersion()
  {
    return meta_get("version", "");
  }

  // Load a collection of sysex files with MTS tunings in ~/.faust/tuning.
  static int n_tunings;
#if FAUST_MTS
  static MTSTunings *mts;

  static MTSTunings *load_sysex_data()
  {
    if (!mts) {
      string mts_path;
      // Look for FAUST_HOME. If that isn't set, try $HOME/.faust. If HOME
      // isn't set either, just assume a .faust subdir of the cwd.
      const char *home = getenv("FAUST_HOME");
      if (home)
	mts_path = home;
      else {
	home = getenv("HOME");
	if (home) {
	  mts_path = home;
	  mts_path += "/.faust";
	} else
	  mts_path = ".faust";
      }
      // MTS tunings are looked for in this subdir.
      mts_path += "/tuning";
      mts = new MTSTunings(mts_path.c_str());
#ifdef __APPLE__
      if (!mts || mts->tuning.size() == 0) {
	// Also check ~/Library/Faust/Tuning on the Mac.
	home = getenv("HOME");
	if (home) {
	  if (mts) delete mts;
	  mts_path = home;
	  mts_path += "/Library/Faust/Tuning";
	  mts = new MTSTunings(mts_path.c_str());
	}
      }
#endif
      n_tunings = mts->tuning.size();
    }
    return mts;
  }
#endif

  // The number of voices of an instrument plugin. We get this information
  // from the global meta data (nvoices key) of the dsp module if present, and
  // you can also override this setting at compile time by defining the
  // NVOICES macro. If neither is defined or the value is zero then the plugin
  // becomes a simple audio effect instead.
  static int numVoices()
  {
#ifdef NVOICES
    return NVOICES;
#else
    const char *numVoices = meta_get("nvoices", "0");
    int nvoices = atoi(numVoices);
    if (nvoices < 0 ) nvoices = 0;
    return nvoices;
#endif
  }

  // Instance methods.

  LV2Plugin(const int num_voices, const int sr)
    : maxvoices(num_voices), ndsps(num_voices<=0?1:num_voices),
      vd(num_voices>0?new VoiceData(num_voices):0)
  {
    // Initialize static data.
    init_meta();
#if FAUST_MTS
    // Synth: load tuning sysex data if present.
    if (num_voices>0) load_sysex_data();
#endif
    // Allocate data structures and set some reasonable defaults.
    dsp = (vintage_mics**)calloc(ndsps, sizeof(vintage_mics*));
    ui = (LV2UI**)calloc(ndsps, sizeof(LV2UI*));
    assert(dsp && ui);
    if (vd) {
      vd->note_info = (NoteInfo*)calloc(ndsps, sizeof(NoteInfo));
      vd->lastgate = (float*)calloc(ndsps, sizeof(float));
      assert(vd->note_info && vd->lastgate);
    }
    active = false;
    rate = sr;
    nvoices = maxvoices;
    tuning_no = 0;
    n_in = n_out = 0;
    map = NULL;
    midi_event = -1;
    event_port = NULL;
    poly = tuning = NULL;
    freq = gain = gate = -1;
    if (vd) {
      vd->n_free = maxvoices;
      for (int i = 0; i < maxvoices; i++) {
	vd->free_voices.push_back(i);
	vd->lastgate[i] = 0.0f;
      }
      for (int i = 0; i < 16; i++) {
	vd->bend[i] = 0.0f;
	vd->range[i] = 2.0f;
	vd->coarse[i] = vd->fine[i] = vd->tune[i] = 0.0f;
	for (int j = 0; j < 12; j++)
	  vd->tuning[i][j] = 0.0f;
      }
      vd->n_used = 0;
      memset(vd->notes, 0xff, sizeof(vd->notes));
    }
    n_samples = 0;
    ctrls = inctrls = outctrls = NULL;
    ports = inputs = outputs = inbuf = outbuf = NULL;
    portvals = NULL;
    memset(midivals, 0, sizeof(midivals));
    // Initialize the Faust DSPs.
    for (int i = 0; i < ndsps; i++) {
      dsp[i] = new vintage_mics();
      ui[i] = new LV2UI(num_voices);
      dsp[i]->init(rate);
      dsp[i]->buildUserInterface(ui[i]);
    }
    // The ports are numbered as follows: 0..k-1 are the control ports, then
    // come the n audio input ports, then the m audio output ports, and
    // finally the midi input port and the polyphony and tuning controls.
    int k = ui[0]->nports, p = 0, q = 0;
    int n = dsp[0]->getNumInputs(), m = dsp[0]->getNumOutputs();
    // Allocate tables for the built-in control elements and their ports.
    ctrls = (int*)calloc(k, sizeof(int));
    inctrls = (int*)calloc(k, sizeof(int));
    outctrls = (int*)calloc(k, sizeof(int));
    ports = (float**)calloc(k, sizeof(float*));
    portvals = (float*)calloc(k, sizeof(float));
    assert(k == 0 || (ctrls && inctrls && outctrls && ports && portvals));
    for (int ch = 0; ch < 16; ch++) {
      midivals[ch] = (float*)calloc(k, sizeof(float));
      assert(k == 0 || midivals[ch]);
    }
    // Scan the Faust UI for active and passive controls which become the
    // input and output control ports of the plugin, respectively.
    for (int i = 0, j = 0; i < ui[0]->nelems; i++) {
      switch (ui[0]->elems[i].type) {
      case UI_T_GROUP: case UI_H_GROUP: case UI_V_GROUP: case UI_END_GROUP:
	// control groups (ignored right now)
	break;
      case UI_H_BARGRAPH: case UI_V_BARGRAPH:
	// passive controls (output ports)
	ctrls[j++] = i;
	outctrls[q++] = i;
	break;
      default:
	// active controls (input ports)
	if (maxvoices == 0)
	  goto noinstr;
	else if (freq == -1 &&
		 !strcmp(ui[0]->elems[i].label, "freq"))
	  freq = i;
	else if (gain == -1 &&
		 !strcmp(ui[0]->elems[i].label, "gain"))
	  gain = i;
	else if (gate == -1 &&
		 !strcmp(ui[0]->elems[i].label, "gate"))
	  gate = i;
	else {
	noinstr:
#if FAUST_MIDICC
	  std::map< int, list<strpair> >::iterator it =
	    ui[0]->metadata.find(i);
	  if (it != ui[0]->metadata.end()) {
	    // Scan for controller mappings.
	    for (std::list<strpair>::iterator jt = it->second.begin();
		 jt != it->second.end(); jt++) {
	      const char *key = jt->first, *val = jt->second;
#if DEBUG_META
	      fprintf(stderr, "ctrl '%s' meta: '%s' -> '%s'\n",
		      ui[0]->elems[i].label, key, val);
#endif
	      if (strcmp(key, "midi") == 0) {
		unsigned num;
		if (sscanf(val, "ctrl %u", &num) < 1) continue;
#if 0 // enable this to get feedback about controller assignments
		fprintf(stderr, "%s: cc %d -> %s\n", PLUGIN_URI, num,
			ui[0]->elems[i].label);
#endif
		ctrlmap.insert(std::pair<uint8_t,int>(num, p));
	      }
	    }
	  }
#endif
	  ctrls[j++] = i;
	  inctrls[p++] = i;
	  int p = ui[0]->elems[i].port;
	  float val = ui[0]->elems[i].init;
	  assert(p>=0);
	  portvals[p] = val;
	  for (int ch = 0; ch < 16; ch++)
	    midivals[ch][p] = val;
	}
	break;
      }
    }
    // Realloc the inctrls and outctrls vectors to their appropriate sizes.
    inctrls = (int*)realloc(inctrls, p*sizeof(int));
    assert(p == 0 || inctrls);
    outctrls = (int*)realloc(outctrls, q*sizeof(int));
    assert(q == 0 || outctrls);
    n_in = p; n_out = q;
    // Allocate vectors for the audio input and output ports. Like
    // ports, these will be initialized in the connect_port callback.
    inputs = (float**)calloc(n, sizeof(float*));
    assert(n == 0 || inputs);
    outputs = (float**)calloc(m, sizeof(float*));
    assert(m == 0 || outputs);
    if (maxvoices > 0) {
      // Initialize the mixdown buffer.
      outbuf = (float**)calloc(m, sizeof(float*));
      assert(m == 0 || outbuf);
      // We start out with a blocksize of 512 samples here. Hopefully this is
      // enough for most realtime hosts so that we can avoid reallocations
      // later when we know what the actual blocksize is.
      n_samples = 512;
      for (int i = 0; i < m; i++) {
	outbuf[i] = (float*)malloc(n_samples*sizeof(float));
	assert(outbuf[i]);
      }
      // Initialize a 1-sample dummy input buffer used for retriggering notes.
      inbuf = (float**)calloc(n, sizeof(float*));
      assert(n == 0 || inbuf);
      for (int i = 0; i < m; i++) {
	inbuf[i] = (float*)malloc(sizeof(float));
	assert(inbuf[i]);
	*inbuf[i] = 0.0f;
      }
    }
  }

  ~LV2Plugin()
  {
    const int n = dsp[0]->getNumInputs();
    const int m = dsp[0]->getNumOutputs();
    for (int i = 0; i < ndsps; i++) {
      delete dsp[i];
      delete ui[i];
    }
    free(ctrls); free(inctrls); free(outctrls);
    free(ports); free(portvals);
    free(inputs); free(outputs);
    for (int ch = 0; ch < 16; ch++)
      free(midivals[ch]);
    if (inbuf) {
      for (int i = 0; i < n; i++)
	free(inbuf[i]);
      free(inbuf);
    }
    if (outbuf) {
      for (int i = 0; i < m; i++)
	free(outbuf[i]);
      free(outbuf);
    }
    free(dsp); free(ui);
    if (vd) {
      free(vd->note_info);
      free(vd->lastgate);
      delete vd;
    }
  }
  // Voice allocation.

#if DEBUG_VOICE_ALLOC
  void print_voices(const char *msg)
  {
    fprintf(stderr, "%s: notes =", msg);
    for (uint8_t ch = 0; ch < 16; ch++)
      for (int note = 0; note < 128; note++)
	if (vd->notes[ch][note] >= 0)
	  fprintf(stderr, " [%d] %d(#%d)", ch, note, vd->notes[ch][note]);
    fprintf(stderr, "\nqueued (%d):", vd->queued.size());
    for (int i = 0; i < nvoices; i++)
      if (vd->queued.find(i) != vd->queued.end()) fprintf(stderr, " #%d", i);
    fprintf(stderr, "\nused (%d):", vd->n_used);
    for (boost::circular_buffer<int>::iterator it = vd->used_voices.begin();
	 it != vd->used_voices.end(); it++)
      fprintf(stderr, " #%d->%d", *it, vd->note_info[*it].note);
    fprintf(stderr, "\nfree (%d):", vd->n_free);
    for (boost::circular_buffer<int>::iterator it = vd->free_voices.begin();
	 it != vd->free_voices.end(); it++)
      fprintf(stderr, " #%d", *it);
    fprintf(stderr, "\n");
  }
#endif

  int alloc_voice(uint8_t ch, int8_t note, int8_t vel)
  {
    int i = vd->notes[ch][note];
    if (i >= 0) {
      // note already playing on same channel, retrigger it
      voice_off(i);
      voice_on(i, note, vel, ch);
      // move this voice to the end of the used list
      for (boost::circular_buffer<int>::iterator it =
	     vd->used_voices.begin();
	   it != vd->used_voices.end(); it++) {
	if (*it == i) {
	  vd->used_voices.erase(it);
	  vd->used_voices.push_back(i);
	  break;
	}
      }
#if DEBUG_VOICE_ALLOC
      print_voices("retrigger");
#endif
      return i;
    } else if (vd->n_free > 0) {
      // take voice from free list
      int i = vd->free_voices.front();
      vd->free_voices.pop_front();
      vd->n_free--;
      vd->used_voices.push_back(i);
      vd->note_info[i].ch = ch;
      vd->note_info[i].note = note;
      vd->n_used++;
      voice_on(i, note, vel, ch);
      vd->notes[ch][note] = i;
#if DEBUG_VOICE_ALLOC
      print_voices("alloc");
#endif
      return i;
    } else {
      // steal a voice
      assert(vd->n_used > 0);
      // FIXME: Maybe we should look for the oldest note on the *current*
      // channel here, but this is faster.
      int i = vd->used_voices.front();
      int oldch = vd->note_info[i].ch;
      int oldnote = vd->note_info[i].note;
      voice_off(i);
      vd->notes[oldch][oldnote] = -1;
      vd->queued.erase(i);
      vd->used_voices.pop_front();
      vd->used_voices.push_back(i);
      vd->note_info[i].ch = ch;
      vd->note_info[i].note = note;
      voice_on(i, note, vel, ch);
      vd->notes[ch][note] = i;
#if DEBUG_VOICE_ALLOC
      print_voices("steal");
#endif
      return i;
    }
  }

  int dealloc_voice(uint8_t ch, int8_t note, int8_t vel)
  {
    int i = vd->notes[ch][note];
    if (i >= 0) {
      if (vd->lastgate[i] == 0.0f && gate >= 0) {
	// zero-length note, queued for later
	vd->queued.insert(i);
	vd->notes[ch][note] = -1;
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (queued)");
#endif
	return i;
      }
      assert(vd->n_free < nvoices);
      vd->free_voices.push_back(i);
      vd->n_free++;
      voice_off(i);
      vd->notes[ch][note] = -1;
      // erase this voice from the used list
      for (boost::circular_buffer<int>::iterator it =
	     vd->used_voices.begin();
	   it != vd->used_voices.end(); it++) {
	if (*it == i) {
	  vd->used_voices.erase(it);
	  vd->n_used--;
	  break;
	}
      }
#if DEBUG_VOICE_ALLOC
      print_voices("dealloc");
#endif
      return i;
    }
    return -1;
  }


  float midicps(int8_t note, uint8_t chan)
  {
    float pitch = note + vd->tune[chan] +
      vd->tuning[chan][note%12] + vd->bend[chan];
    return 440.0*pow(2, (pitch-69.0)/12.0);
  }

  void voice_on(int i, int8_t note, int8_t vel, uint8_t ch)
  {
    if (vd->lastgate[i] == 1.0f && gate >= 0) {
      // Make sure that the synth sees the 0.0f gate so that the voice is
      // properly retriggered.
      *ui[i]->elems[gate].zone = 0.0f;
      dsp[i]->compute(1, inbuf, outbuf);
    }
#if DEBUG_VOICES
    fprintf(stderr, "voice on: %d %d (%g Hz) %d (%g)\n", i,
	    note, midicps(note, ch), vel, vel/127.0);
#endif
    if (freq >= 0)
      *ui[i]->elems[freq].zone = midicps(note, ch);
    if (gate >= 0)
      *ui[i]->elems[gate].zone = 1.0f;
    if (gain >= 0)
      *ui[i]->elems[gain].zone = vel/127.0;
    // reinitialize the per-channel control data for this voice
    for (int idx = 0; idx < n_in; idx++) {
      int j = inctrls[idx], k = ui[0]->elems[j].port;
      *ui[i]->elems[j].zone = midivals[ch][k];
    }
  }

  void voice_off(int i)
  {
#if DEBUG_VOICES
    fprintf(stderr, "voice off: %d\n", i);
#endif
    if (gate >= 0)
      *ui[i]->elems[gate].zone = 0.0f;
  }

  void update_voices(uint8_t chan)
  {
    // update running voices on the given channel after tuning or pitch bend
    // changes
    for (boost::circular_buffer<int>::iterator it =
	   vd->used_voices.begin();
	 it != vd->used_voices.end(); it++) {
      int i = *it;
      if (vd->note_info[i].ch == chan && freq >= 0) {
	int note = vd->note_info[i].note;
	*ui[i]->elems[freq].zone = midicps(note, chan);
      }
    }
  }

  void all_notes_off()
  {
    for (int i = 0; i < nvoices; i++)
      voice_off(i);
    for (int i = 0; i < 16; i++)
      vd->bend[i] = 0.0f;
    memset(vd->notes, 0xff, sizeof(vd->notes));
    vd->free_voices.clear();
    vd->n_free = nvoices;
    for (int i = 0; i < nvoices; i++)
      vd->free_voices.push_back(i);
    vd->queued.clear();
    vd->used_voices.clear();
    vd->n_used = 0;
  }

  void all_notes_off(uint8_t chan)
  {
    for (boost::circular_buffer<int>::iterator it =
	   vd->used_voices.begin();
	 it != vd->used_voices.end(); ) {
      int i = *it;
      if (vd->note_info[i].ch == chan) {
	assert(vd->n_free < nvoices);
	vd->free_voices.push_back(i);
	vd->n_free++;
	voice_off(i);
	vd->notes[vd->note_info[i].ch][vd->note_info[i].note] = -1;
	vd->queued.erase(i);
	// erase this voice from the used list
	it = vd->used_voices.erase(it);
	vd->n_used--;
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (all-notes-off)");
#endif
      } else
	it++;
    }
    vd->bend[chan] = 0.0f;
  }

  void queued_notes_off()
  {
    if (vd->queued.empty()) return;
    for (int i = 0; i < nvoices; i++)
      if (vd->queued.find(i) != vd->queued.end()) {
	assert(vd->n_free < nvoices);
	vd->free_voices.push_back(i);
	vd->n_free++;
	voice_off(i);
	vd->notes[vd->note_info[i].ch][vd->note_info[i].note] = -1;
	vd->queued.erase(i);
	// erase this voice from the used list
	for (boost::circular_buffer<int>::iterator it =
	       vd->used_voices.begin();
	     it != vd->used_voices.end(); it++) {
	  if (*it == i) {
	    vd->used_voices.erase(it);
	    vd->n_used--;
	    break;
	  }
	}
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (unqueued)");
#endif
      }
  }

  // Plugin activation status. suspend() deactivates a plugin (disables audio
  // processing), resume() reactivates it. Also, set_rate() changes the sample
  // rate. Note that the audio and MIDI process functions (see below) can
  // still be called in deactivated state, but this is optional. The plugin
  // tries to do some reasonable processing in either case, no matter whether
  // the host plugin architecture actually executes callbacks in suspended
  // state or not.

  void suspend()
  {
    active = false;
    if (maxvoices > 0) all_notes_off();
  }

  void resume()
  {
    for (int i = 0; i < ndsps; i++)
      dsp[i]->init(rate);
    for (int i = 0, j = 0; i < ui[0]->nelems; i++) {
      int p = ui[0]->elems[i].port;
      if (p >= 0) {
	float val = ui[0]->elems[i].init;
	portvals[p] = val;
      }
    }
    active = true;
  }

  void set_rate(int sr)
  {
    rate = sr;
    for (int i = 0; i < ndsps; i++)
      dsp[i]->init(rate);
  }

  // Audio and MIDI process functions. The plugin should run these in the
  // appropriate real-time callbacks.

  void process_audio(int blocksz, float **inputs, float **outputs)
  {
    int n = dsp[0]->getNumInputs(), m = dsp[0]->getNumOutputs();
    AVOIDDENORMALS;
    if (maxvoices > 0) queued_notes_off();
    if (!active) {
      // Depending on the plugin architecture and host, this code might never
      // be invoked, since the plugin is deactivitated at this point. But
      // let's do something reasonable here anyway.
      if (n == m) {
	// copy inputs to outputs
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] = inputs[i][j];
      } else {
	// silence
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] = 0.0f;
      }
      return;
    }
    // Handle changes in the polyphony and tuning controls.
    bool is_instr = maxvoices > 0;
    if (is_instr) {
      if (!poly)
	; // this shouldn't happen but...
      else if (nvoices != (int)*poly &&
	       (int)*poly > 0 && (int)*poly <= maxvoices) {
	for (int i = 0; i < nvoices; i++)
	  voice_off(i);
        nvoices = (int)*poly;
	// Reset the voice allocation.
	memset(vd->notes, 0xff, sizeof(vd->notes));
	vd->free_voices.clear();
	vd->n_free = nvoices;
	for (int i = 0; i < nvoices; i++)
	  vd->free_voices.push_back(i);
	vd->used_voices.clear();
	vd->n_used = 0;
      } else
	*poly = nvoices;
#if FAUST_MTS
      if (tuning && tuning_no != (int)*tuning) change_tuning((int)*tuning);
#endif
    }
    // Only update the controls (of all voices simultaneously) if a port value
    // actually changed. This is necessary to allow MIDI controllers to modify
    // the values for individual MIDI channels (see processEvents below). Also
    // note that this will be done *after* processing the MIDI controller data
    // for the current audio block, so manual inputs can still override these.
    for (int i = 0; i < n_in; i++) {
      int j = inctrls[i], k = ui[0]->elems[j].port;
      float &oldval = portvals[k], newval = *ports[k];
      if (newval != oldval) {
	if (is_instr) {
	  // instrument: update running voices
	  for (boost::circular_buffer<int>::iterator it =
		 vd->used_voices.begin();
	       it != vd->used_voices.end(); it++) {
	    int i = *it;
	    *ui[i]->elems[j].zone = newval;
	  }
	} else {
	  // simple effect: here we only have a single dsp instance
	  *ui[0]->elems[j].zone = newval;
	}
	// also update the MIDI controller data for all channels (manual
	// control input is always omni)
	for (int ch = 0; ch < 16; ch++)
	  midivals[ch][k] = newval;
	// record the new value
	oldval = newval;
      }
    }
    // Initialize the output buffers.
    if (n_samples < blocksz) {
      // We need to enlarge the buffers. We're not officially allowed to do
      // this here (presumably in the realtime thread), but since we usually
      // don't know the hosts's block size beforehand, there's really nothing
      // else that we can do. Let's just hope that doing this once suffices,
      // then hopefully noone will notice.
      if (outbuf) {
	for (int i = 0; i < m; i++) {
	  outbuf[i] = (float*)realloc(outbuf[i],
				      blocksz*sizeof(float));
	  assert(outbuf[i]);
	}
      }
      n_samples = blocksz;
    }
    if (outbuf) {
      // Polyphonic instrument: Mix the voices down to one signal.
      for (int i = 0; i < m; i++)
	for (unsigned j = 0; j < blocksz; j++)
	  outputs[i][j] = 0.0f;
      for (int l = 0; l < nvoices; l++) {
	// Let Faust do all the hard work.
	dsp[l]->compute(blocksz, inputs, outbuf);
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] += outbuf[i][j];
      }
    } else {
      // Simple effect: We can write directly to the output buffer.
      dsp[0]->compute(blocksz, inputs, outputs);
    }
    // Finally grab the passive controls and write them back to the
    // corresponding control ports. NOTE: Depending on the plugin
    // architecture, this might require a host call to get the control GUI
    // updated in real-time (if the host supports this at all).
    // FIXME: It's not clear how to aggregate the data of the different
    // voices. We compute the maximum of each control for now.
    for (int i = 0; i < n_out; i++) {
      int j = outctrls[i], k = ui[0]->elems[j].port;
      float *z = ui[0]->elems[j].zone;
      *ports[k] = *z;
      for (int l = 1; l < nvoices; l++) {
	float *z = ui[l]->elems[j].zone;
	if (*ports[k] < *z)
	  *ports[k] = *z;
      }
    }
    // Keep track of the last gates set for each voice, so that voices can be
    // forcibly retriggered if needed.
    if (gate >= 0)
      for (int i = 0; i < nvoices; i++)
	vd->lastgate[i] =
	  *ui[i]->elems[gate].zone;
  }

  // This processes just a single MIDI message, so to process an entire series
  // of MIDI events you'll have to loop over the event data in the plugin's
  // MIDI callback. XXXTODO: Sample-accurate processing of MIDI events.
  
  void process_midi(unsigned char *data, int sz)
  {
#if DEBUG_MIDI
    fprintf(stderr, "midi ev (%d bytes):", sz);
    for (int i = 0; i < sz; i++)
      fprintf(stderr, " 0x%0x", data[i]);
    fprintf(stderr, "\n");
#endif
    uint8_t status = data[0] & 0xf0, chan = data[0] & 0x0f;
    bool is_instr = maxvoices > 0;
    switch (status) {
    case 0x90: {
      if (!is_instr) break;
      // note on
#if DEBUG_NOTES
      fprintf(stderr, "note-on  chan %d, note %d, vel %d\n", chan+1,
	      data[1], data[2]);
#endif
      if (data[2] == 0) goto note_off;
      alloc_voice(chan, data[1], data[2]);
      break;
    }
    case 0x80: {
      if (!is_instr) break;
      // note off
#if DEBUG_NOTES
      fprintf(stderr, "note-off chan %d, note %d, vel %d\n", chan+1,
	      data[1], data[2]);
#endif
      note_off:
      dealloc_voice(chan, data[1], data[2]);
      break;
    }
    case 0xe0: {
      if (!is_instr) break;
      // pitch bend
      // data[1] is LSB, data[2] MSB, range is 0..0x3fff (which maps to
      // -2..+2 semitones by default), center point is 0x2000 = 8192
      int val = data[1] | (data[2]<<7);
      vd->bend[chan] =
	(val-0x2000)/8192.0f*vd->range[chan];
#if DEBUG_MIDICC
      fprintf(stderr, "pitch-bend (chan %d): %g cent\n", chan+1,
	      vd->bend[chan]*100.0);
#endif
      update_voices(chan);
      break;
    }
    case 0xb0: {
      // controller change
      switch (data[1]) {
      case 120: case 123:
	if (!is_instr) break;
	// all-sound-off and all-notes-off controllers (these are treated
	// the same in the current implementation)
	all_notes_off(chan);
#if DEBUG_MIDICC
	fprintf(stderr, "all-notes-off (chan %d)\n", chan+1);
#endif
	break;
      case 121:
	// all-controllers-off (in the current implementation, this just
	// resets the RPN-related controllers)
	data_msb[chan] = data_lsb[chan] = 0;
	rpn_msb[chan] = rpn_lsb[chan] = 0x7f;
#if DEBUG_MIDICC
	fprintf(stderr, "all-controllers-off (chan %d)\n", chan+1);
#endif
	break;
      case 101: case 100:
	// RPN MSB/LSB
	if (data[1] == 101)
	  rpn_msb[chan] = data[2];
	else
	  rpn_lsb[chan] = data[2];
	break;
      case 6: case 38:
	// data entry coarse/fine
	if (data[1] == 6)
	  data_msb[chan] = data[2];
	else
	  data_lsb[chan] = data[2];
	goto rpn;
      case 96: case 97:
	// data increment/decrement
	/* NOTE: The specification of these controllers is a complete
	   mess. Originally, the MIDI specification didn't have anything
	   to say about their exact behaviour at all. Nowadays, the
	   behaviour depends on which RPN or NRPN is being modified, which
	   is also rather confusing. Fortunately, as we only handle RPNs
	   0..2 here anyway, it's sufficient to assume the MSB for RPN #2
	   (channel coarse tuning) and the LSB otherwise. */
	if (rpn_msb[chan] == 0 && rpn_lsb[chan] == 2) {
	  // modify the MSB
	  if (data[1] == 96 && data_msb[chan] < 0x7f)
	    data_msb[chan]++;
	  else if (data[1] == 97 && data_msb[chan] > 0)
	    data_msb[chan]--;
	} else {
	  // modify the LSB
	  if (data[1] == 96 && data_lsb[chan] < 0x7f)
	    data_lsb[chan]++;
	  else if (data[1] == 97 && data_lsb[chan] > 0)
	    data_lsb[chan]--;
	}
      rpn:
	if (!is_instr) break;
	if (rpn_msb[chan] == 0) {
	  switch (rpn_lsb[chan]) {
	  case 0:
	    // pitch bend range, coarse value is in semitones, fine value
	    // in cents
	    vd->range[chan] = data_msb[chan]+
	      data_lsb[chan]/100.0;
#if DEBUG_RPN
	    fprintf(stderr, "pitch-bend-range (chan %d): %g cent\n", chan+1,
		    vd->range[chan]*100.0);
#endif
	    break;
	  case 1:
	    {
	      // channel fine tuning (14 bit value, range -100..+100 cents)
	      int value = (data_msb[chan]<<7) |
		data_lsb[chan];
	      vd->fine[chan] = (value-8192)/8192.0f;
	    }
	    goto master_tune;
	  case 2:
	    // channel coarse tuning (only msb is used, range -64..+63
	    // semitones)
	    vd->coarse[chan] = data_msb[chan]-64;
	  master_tune:
	    vd->tune[chan] = vd->coarse[chan]+
	      vd->fine[chan];
#if DEBUG_RPN
	    fprintf(stderr, "master-tuning (chan %d): %g cent\n", chan+1,
		    vd->tune[chan]*100.0);
#endif
	    update_voices(chan);
	    break;
	  default:
	    break;
	  }
	}
	break;
      default: {
#if FAUST_MIDICC
	// interpret all other controller changes according to the MIDI
	// controller map defined in the Faust plugin itself
	std::map<uint8_t,int>::iterator it = ctrlmap.find(data[1]);
	if (it != ctrlmap.end()) {
	  // defined MIDI controller
	  int j = inctrls[it->second],
	    k = ui[0]->elems[j].port;
	  float val = ctrlval(ui[0]->elems[j], data[2]);
	  midivals[chan][k] = val;
	  if (is_instr) {
	    // instrument: update running voices on this channel
	    for (boost::circular_buffer<int>::iterator it =
		   vd->used_voices.begin();
		 it != vd->used_voices.end(); it++) {
	      int i = *it;
	      if (vd->note_info[i].ch == chan)
		*ui[i]->elems[j].zone = val;
	    }
	  } else {
	    // simple effect: here we only have a single dsp instance and
	    // we're operating in omni mode, so we just update the control no
	    // matter what the midi channel is
	    *ui[0]->elems[j].zone = val;
	  }
#if DEBUG_MIDICC
	  fprintf(stderr, "ctrl-change chan %d, ctrl %d, val %d\n", chan+1,
		  data[1], data[2]);
#endif
	}
#endif
	break;
      }
      }
      break;
    }
    default:
      break;
    }
  }

  // Process an MTS sysex message and update the control values accordingly.

  void process_sysex(uint8_t *data, int sz)
  {
    if (!data || sz < 2) return;
#if DEBUG_MIDI
    fprintf(stderr, "midi sysex (%d bytes):", sz);
    for (int i = 0; i < sz; i++)
      fprintf(stderr, " 0x%0x", data[i]);
    fprintf(stderr, "\n");
#endif
    if (data[0] == 0xf0) {
      // Skip over the f0 and f7 status bytes in case they are included in the
      // dump.
      data++; sz--;
      if (data[sz-1] == 0xf7) sz--;
    }
    if ((data[0] == 0x7e || data[0] == 0x7f) && data[2] == 8) {
      // MIDI tuning standard
      bool realtime = data[0] == 0x7f;
      if ((sz == 19 && data[3] == 8) ||
	  (sz == 31 && data[3] == 9)) {
	// MTS scale/octave tuning 1- or 2-byte form
	bool onebyte = data[3] == 8;
	unsigned chanmsk = (data[4]<<14) | (data[5]<<7) | data[6];
	for (int i = 0; i < 12; i++) {
	  float t;
	  if (onebyte)
	    t = (data[i+7]-64)/100.0;
	  else
	    t = (((data[2*i+7]<<7)|data[2*i+8])-8192)/8192.0;
	  for (uint8_t ch = 0; ch < 16; ch++)
	    if (chanmsk & (1<<ch))
	      vd->tuning[ch][i] = t;
	}
	if (realtime) {
	  for (uint8_t ch = 0; ch < 16; ch++)
	    if (chanmsk & (1<<ch)) {
	      // update running voices on this channel
	      update_voices(ch);
	    }
	}
#if DEBUG_MTS
	fprintf(stderr, "octave-tuning-%s (chan ",
		realtime?"realtime":"non-realtime");
	bool first = true;
	for (uint8_t i = 0; i < 16; )
	  if (chanmsk & (1<<i)) {
	    uint8_t j;
	    for (j = i+1; j < 16 && (chanmsk&(1<<j)); )
	      j++;
	    if (first)
	      first = false;
	    else
	      fprintf(stderr, ",");
	    if (j > i+1)
	      fprintf(stderr, "%u-%u", i+1, j);
	    else
	      fprintf(stderr, "%u", i+1);
	    i = j;
	  } else
	    i++;
	fprintf(stderr, "):");
	if (onebyte) {
	  for (int i = 7; i < 19; i++) {
	    int val = data[i];
	    fprintf(stderr, " %d", val-64);
	  }
	} else {
	  for (int i = 7; i < 31; i++) {
	    int val = data[i++] << 7;
	    val |= data[i];
	    fprintf(stderr, " %g", ((double)val-8192.0)/8192.0*100.0);
	  }
	}
	fprintf(stderr, "\n");
#endif
      }
    }
  }

  // Change to a given preloaded tuning. The given tuning number may be in the
  // range 1..PFaustPlugin::n_tunings, zero denotes the default tuning (equal
  // temperament). This is only supported if FAUST_MTS is defined at compile
  // time.

  void change_tuning(int num)
  {
#if FAUST_MTS
    if (!mts || num == tuning_no) return;
    if (num < 0) num = 0;
    if (num > mts->tuning.size())
      num = mts->tuning.size();
    tuning_no = num;
    if (tuning_no > 0) {
      process_sysex(mts->tuning[tuning_no-1].data,
		    mts->tuning[tuning_no-1].len);
    } else {
      memset(vd->tuning, 0, sizeof(vd->tuning));
#if DEBUG_MTS
      fprintf(stderr,
	      "octave-tuning-default (chan 1-16): equal temperament\n");
#endif
    }
#endif
  }

};

Meta *LV2Plugin::meta = 0;
int LV2Plugin::n_tunings = 0;
#if FAUST_MTS
MTSTunings *LV2Plugin::mts = 0;
#endif

/* LV2-specific part starts here. ********************************************/

static LV2_Handle
instantiate(const LV2_Descriptor*     descriptor,
            double                    rate,
            const char*               bundle_path,
            const LV2_Feature* const* features)
{
  LV2Plugin* plugin =
    new LV2Plugin(LV2Plugin::numVoices(), (int)rate);
  // Scan host features for URID map.
  for (int i = 0; features[i]; i++) {
    if (!strcmp(features[i]->URI, LV2_URID_URI "#map")) {
      plugin->map = (LV2_URID_Map*)features[i]->data;
      plugin->midi_event =
	plugin->map->map(plugin->map->handle, MIDI_EVENT_URI);
    }
  }
  if (!plugin->map) {
    fprintf
      (stderr, "%s: host doesn't support urid:map, giving up\n",
       PLUGIN_URI);
    delete plugin;
    return 0;
  }
  return (LV2_Handle)plugin;
}

static void
cleanup(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  delete plugin;
}

static void
connect_port(LV2_Handle instance,
             uint32_t   port,
             void*      data)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  int i = port, k = plugin->ui[0]->nports;
  int n = plugin->dsp[0]->getNumInputs(), m = plugin->dsp[0]->getNumOutputs();
  if (i < k)
    plugin->ports[i] = (float*)data;
  else {
    i -= k;
    if (i < n)
      plugin->inputs[i] = (float*)data;
    else {
      i -= n;
      if (i < m)
	plugin->outputs[i] = (float*)data;
      else if (i == m)
	plugin->event_port = (LV2_Atom_Sequence*)data;
      else if (i == m+1)
	plugin->poly = (float*)data;
      else if (i == m+2)
	plugin->tuning = (float*)data;
      else
	fprintf(stderr, "%s: bad port number %u\n", PLUGIN_URI, port);
    }
  }
}

static void
run(LV2_Handle instance, uint32_t n_samples)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  // Process incoming MIDI events.
  if (plugin->event_port) {
    LV2_ATOM_SEQUENCE_FOREACH(plugin->event_port, ev) {
      if (ev->body.type == plugin->midi_event) {
	uint8_t *data = (uint8_t*)(ev+1);
#if 0
	// FIXME: Consider doing sample-accurate note onsets here. LV2 keeps
	// track of the exact onset in the frames and subframes fields
	// (http://lv2plug.in/ns/doc/html/structLV2__Atom__Event.html), but we
	// can't use that information at present, since our gate parameter is
	// a control variable which can only change at block boundaries. In
	// the future, the gate could be implemented as an audio signal to get
	// sample-accurate note onsets.
	uint32_t frames = ev->body.frames;
#endif
	if (data[0] == 0xf0)
	  plugin->process_sysex(data, ev->body.size);
	else
	  plugin->process_midi(data, ev->body.size);
      }
    }
  }
  // Process audio.
  plugin->process_audio(n_samples, plugin->inputs, plugin->outputs);
}

static void
activate(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  plugin->resume();
}

static void
deactivate(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  plugin->suspend();
}

const void*
extension_data(const char* uri)
{
  return NULL;
}

static const LV2_Descriptor descriptor = {
  PLUGIN_URI,
  instantiate,
  connect_port,
  activate,
  run,
  deactivate,
  cleanup,
  extension_data
};

extern "C"
LV2_SYMBOL_EXPORT
const LV2_Descriptor*
lv2_descriptor(uint32_t index)
{
  switch (index) {
  case 0:
    return &descriptor;
  default:
    return NULL;
  }
}

//----------------------------------------------------------------------------
//  Dynamic manifest
//----------------------------------------------------------------------------

// NOTE: If your LV2 host doesn't offer this extension then you'll have to
// create a static ttl file with the descriptions of the ports. You can do
// this by compiling this code to a standalone executable. Running the
// executable then prints the manifest on stdout.

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_open(LV2_Dyn_Manifest_Handle *handle,
			  const LV2_Feature *const *features)
{
  LV2Plugin* plugin =
    new LV2Plugin(LV2Plugin::numVoices(), 48000);
  *handle = (LV2_Dyn_Manifest_Handle)plugin;
  return 0;
}

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_get_subjects(LV2_Dyn_Manifest_Handle handle,
				  FILE *fp)
{
  fprintf(fp, "@prefix lv2:  <http://lv2plug.in/ns/lv2core#> .\n\
<%s> a lv2:Plugin .\n", PLUGIN_URI);
  return 0;
}

#include <string>
#include <ctype.h>

static string mangle(const string &s)
{
  string t = s;
  size_t n = s.size();
  for (size_t i = 0; i < n; i++)
    if ((i == 0 && !isalpha(t[i]) && t[i] != '_') ||
	(!isalnum(t[i]) && t[i] != '_'))
      t[i] = '_';
  return t;
}

static unsigned steps(float min, float max, float step)
{
  if (step == 0.0) return 1;
  int n = (max-min)/step;
  if (n < 0) n = -n;
  if (n == 0) n = 1;
  return n;
}

#if FAUST_META
static bool is_xmlstring(const char *s)
{
  // This is just a basic sanity check. The string must not contain any
  // (unescaped) newlines, carriage returns or double quotes.
  return !strchr(s, '\n') && !strchr(s, '\r') && !strchr(s, '"');
}
#endif

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_get_data(LV2_Dyn_Manifest_Handle handle,
			      FILE *fp,
			      const char *uri)
{
  LV2Plugin* plugin = (LV2Plugin*)handle;
  int k = plugin->ui[0]->nports;
  int n = plugin->dsp[0]->getNumInputs(), m = plugin->dsp[0]->getNumOutputs();
  bool is_instr = plugin->maxvoices > 0, have_midi = is_instr;
  // Scan the global metadata for plugin name, description, license etc.
  const char *plugin_name = NULL, *plugin_author = NULL, *plugin_descr = NULL,
    *plugin_version = NULL, *plugin_license = NULL;
#if FAUST_META
  plugin_name = plugin->pluginName();
  plugin_descr = plugin->pluginDescription();
  plugin_author = plugin->pluginAuthor();
  plugin_version = plugin->pluginVersion();
  plugin_license = plugin->pluginLicense();
#endif
  if (!plugin_name || !*plugin_name) plugin_name = "vintage_mics";
  fprintf(fp, "@prefix doap:  <http://usefulinc.com/ns/doap#> .\n\
@prefix foaf:  <http://xmlns.com/foaf/0.1/> .\n\
@prefix lv2:   <http://lv2plug.in/ns/lv2core#> .\n\
@prefix ui:    <http://lv2plug.in/ns/extensions/ui#> .\n\
@prefix epp:   <http://lv2plug.in/ns/ext/port-props#> .\n\
@prefix atom:  <http://lv2plug.in/ns/ext/atom#> .\n\
@prefix rdf:   <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .\n\
@prefix rdfs:  <http://www.w3.org/2000/01/rdf-schema#> .\n\
@prefix units: <http://lv2plug.in/ns/extensions/units#> .\n\
<%s>\n\
       a lv2:Plugin%s ;\n\
       doap:name \"%s\" ;\n\
       lv2:binary <vintage_mics%s> ;\n\
       lv2:optionalFeature epp:supportsStrictBounds ;\n\
       lv2:optionalFeature lv2:hardRtCapable ;\n", PLUGIN_URI,
	  is_instr?", lv2:InstrumentPlugin":"",
	  plugin_name, DLLEXT);
  if (plugin_author && *plugin_author)
    fprintf(fp, "\
       doap:maintainer [ foaf:name \"%s\" ] ;\n", plugin_author);
  // doap:description just seems to be ignored by all LV2 hosts anyway, so we
  // rather use rdfs:comment now which works with Ardour at least.
  if (plugin_descr && *plugin_descr)
    fprintf(fp, "\
       rdfs:comment \"%s\" ;\n", plugin_descr);
  if (plugin_version && *plugin_version)
    fprintf(fp, "\
       doap:revision \"%s\" ;\n", plugin_version);
  if (plugin_license && *plugin_license)
    fprintf(fp, "\
       doap:license \"%s\" ;\n", plugin_license);
#if FAUST_UI
    fprintf(fp, "\
       ui:ui <%sui> ;\n", PLUGIN_URI);
#endif
  int idx = 0;
  // control ports
  for (int i = 0; i < k; i++, idx++) {
    int j = plugin->ctrls[i];
    assert(idx == plugin->ui[0]->elems[j].port);
    fprintf(fp, "%s [\n", idx==0?"    lv2:port":" ,");
    const char *label = plugin->ui[0]->elems[j].label;
    assert(label);
    string sym = mangle(plugin->ui[0]->elems[j].label);
    switch (plugin->ui[0]->elems[j].type) {
    // active controls (input ports)
    case UI_BUTTON: case UI_CHECK_BUTTON:
    fprintf(fp, "\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        lv2:portProperty lv2:toggled ;\n\
	lv2:default 0.00000 ;\n\
	lv2:minimum 0.00000 ;\n\
	lv2:maximum 1.00000 ;\n", idx, sym.c_str(), idx, label);
      break;
    case UI_NUM_ENTRY: case UI_H_SLIDER: case UI_V_SLIDER:
    fprintf(fp, "\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        epp:rangeSteps %u ;\n\
	lv2:default %g ;\n\
	lv2:minimum %g ;\n\
	lv2:maximum %g ;\n", idx, sym.c_str(), idx, label,
	    steps(plugin->ui[0]->elems[j].min,
		  plugin->ui[0]->elems[j].max,
		  plugin->ui[0]->elems[j].step),
	    plugin->ui[0]->elems[j].init,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].max);
      break;
    // passive controls (output ports)
    case UI_H_BARGRAPH: case UI_V_BARGRAPH:
    fprintf(fp, "\
	a lv2:OutputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
	lv2:default %g ;\n\
	lv2:minimum %g ;\n\
	lv2:maximum %g ;\n", idx, sym.c_str(), idx, label,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].max);
      break;
    default:
      assert(0 && "this can't happen");
      break;
    }
    // Scan for Faust control metadata we understand and add corresponding
    // hints to the LV2 description of the port.
    std::map< int, list<strpair> >::iterator it =
      plugin->ui[0]->metadata.find(j);
    if (it != plugin->ui[0]->metadata.end()) {
      for (std::list<strpair>::iterator jt = it->second.begin();
	   jt != it->second.end(); jt++) {
	const char *key = jt->first, *val = jt->second;
#if FAUST_MIDICC
	unsigned num;
	if (!strcmp(key, "midi") && sscanf(val, "ctrl %u", &num) == 1)
	  have_midi = true;
#endif
	if (!strcmp(key, "unit"))
	  fprintf(fp, "\
	units:unit [\n\
            a            units:Unit ;\n\
            units:name   \"%s\" ;\n\
            units:symbol \"%s\" ;\n\
            units:render \"%%f %s\"\n\
	] ;\n", val, val, val);
	if (strcmp(key, "lv2")) continue;
	if (!strcmp(val, "integer"))
	  fprintf(fp, "\
	lv2:portProperty lv2:integer ;\n");
	else if (!strcmp(val, "reportsLatency"))
	  fprintf(fp, "\
	lv2:portProperty lv2:reportsLatency ;\n\
	lv2:designation lv2:latency ;\n");
	else if (!strcmp(val, "hidden") || !strcmp(val, "notOnGUI"))
	  fprintf(fp, "\
	lv2:portProperty epp:notOnGUI ;\n");
	else if (!strncmp(val, "scalepoint", 10) ||
		 !strncmp(val, "scalePoint", 10)) {
	  val += 10;
	  if (!isspace(*val)) continue;
	  char *label = (char*)malloc(strlen(val)+1);
	  float point;
	  int pos;
	  while (sscanf(val, "%s %g%n", label, &point, &pos) == 2) {
	    fprintf(fp, "\
	lv2:scalePoint [ rdfs:label \"%s\"; rdf:value %g ] ;\n",
		    label, point);
	    val += pos;
	  }
	  free(label);
	} else
	  fprintf(stderr, "%s: bad port property '%s:%s'\n", PLUGIN_URI,
		  key, val);
      }
    }
    fprintf(fp, "    ]");
  }
  // audio inputs
  for (int i = 0; i < n; i++, idx++)
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:AudioPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"in%d\" ;\n\
	lv2:name \"in%d\" ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, i, i);
  // audio outputs
  for (int i = 0; i < m; i++, idx++)
    fprintf(fp, "%s [\n\
	a lv2:OutputPort ;\n\
	a lv2:AudioPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"out%d\" ;\n\
	lv2:name \"out%d\" ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, i, i);
  if (have_midi) {
    // midi input
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a atom:AtomPort ;\n\
	atom:bufferType atom:Sequence ;\n\
	atom:supports <http://lv2plug.in/ns/ext/midi#MidiEvent> ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"midiin\" ;\n\
	lv2:name \"midiin\"\n\
    ]", idx==0?"    lv2:port":" ,", idx);
    idx++;
  }
  if (is_instr) {
    // polyphony control
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"polyphony\" ;\n\
	lv2:name \"polyphony\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
#       lv2:portProperty epp:expensive ;\n\
        lv2:portProperty lv2:integer ;\n\
        epp:rangeSteps %d ;\n\
	lv2:default %d ;\n\
	lv2:minimum 1 ;\n\
	lv2:maximum %d ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, plugin->maxvoices-1,
      plugin->maxvoices>1?plugin->maxvoices/2:1,
      plugin->maxvoices);
    idx++;
#if FAUST_MTS
    if (plugin->n_tunings > 0) {
      // tuning control
      fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"tuning\" ;\n\
	lv2:name \"tuning\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        lv2:portProperty lv2:integer ;\n\
        epp:rangeSteps %d ;\n\
	lv2:default 0 ;\n\
	lv2:minimum 0 ;\n\
	lv2:maximum %d ;\n",
	idx==0?"    lv2:port":" ,", idx, plugin->n_tunings, plugin->n_tunings);
      for (int i = 0; i <= plugin->n_tunings; i++)
	fprintf(fp, "\
	lv2:scalePoint [ rdfs:label \"%s\"; rdf:value %d ] ;\n",
		(i>0)?plugin->mts->tuning[i-1].name:"default", i);
      fprintf(fp, "    ]");
      idx++;
    }
#endif
  }
  fprintf(fp, "\n.\n");
  return 0;
}

extern "C"
LV2_SYMBOL_EXPORT
void lv2_dyn_manifest_close(LV2_Dyn_Manifest_Handle handle)
{
  LV2Plugin* plugin = (LV2Plugin*)handle;
  delete plugin;
}

int main()
{
  LV2_Dyn_Manifest_Handle handle;
  LV2_Feature **features = { NULL };
  int res = lv2_dyn_manifest_open(&handle, features);
  if (res) return res;
  res = lv2_dyn_manifest_get_data(handle, stdout, PLUGIN_URI);
  return res;
}

#endif
